// Force strict mode and setup for ESM
"use strict";
import {
  Box_default,
  Newline,
  Spacer,
  Static,
  Text,
  Transform,
  getFrameController,
  kittyFlags,
  kittyModifiers,
  measure_element_default,
  render_default,
  render_to_string_default,
  useAnimation,
  use_app_default,
  use_box_metrics_default,
  use_cursor_default,
  use_focus_default,
  use_focus_manager_default,
  use_input_default,
  use_is_screen_reader_enabled_default,
  use_paste_default,
  use_stderr_default,
  use_stdin_default,
  use_stdout_default,
  use_window_size_default
} from "./chunk-2IIJTXYF.js";
import "./chunk-5QWWOFGG.js";
import "./chunk-QHTIBUWB.js";
import "./chunk-TWPJO254.js";
import "./chunk-5O2XNYP6.js";
import "./chunk-J2S4EL5Y.js";
export {
  Box_default as Box,
  Newline,
  Spacer,
  Static,
  Text,
  Transform,
  getFrameController,
  kittyFlags,
  kittyModifiers,
  measure_element_default as measureElement,
  render_default as render,
  render_to_string_default as renderToString,
  useAnimation,
  use_app_default as useApp,
  use_box_metrics_default as useBoxMetrics,
  use_cursor_default as useCursor,
  use_focus_default as useFocus,
  use_focus_manager_default as useFocusManager,
  use_input_default as useInput,
  use_is_screen_reader_enabled_default as useIsScreenReaderEnabled,
  use_paste_default as usePaste,
  use_stderr_default as useStderr,
  use_stdin_default as useStdin,
  use_stdout_default as useStdout,
  use_window_size_default as useWindowSize
};
