export declare const CONFIG_WRITE_FLAGS: Set<string>;
export declare const CONFIG_READ_FLAGS: Set<string>;
export declare const CONFIG_WRITE_VERBS: Set<string>;
export declare const CONFIG_READ_VERBS: Set<string>;
