// Force strict mode and setup for ESM
"use strict";
import {
  init_esbuild_shims
} from "./chunk-5O2XNYP6.js";

// packages/core/src/agents/team/types.ts
init_esbuild_shims();
var MAX_TEAMMATES = 10;
var LEADER_NAME = "leader";
var TEAMS_DIR = "teams";
var TASKS_DIR = "tasks";
var TEAM_CONFIG_FILENAME = "config.json";
var INBOXES_DIR = "inboxes";
var TEAMMATE_COLORS = [
  "#FF6B6B",
  // red
  "#4ECDC4",
  // teal
  "#45B7D1",
  // blue
  "#FFA07A",
  // salmon
  "#98D8C8",
  // mint
  "#DDA0DD",
  // plum
  "#F0E68C",
  // khaki
  "#87CEEB",
  // sky blue
  "#FFB347",
  // orange
  "#B0E0E6"
  // powder blue
];

export {
  MAX_TEAMMATES,
  LEADER_NAME,
  TEAMS_DIR,
  TASKS_DIR,
  TEAM_CONFIG_FILENAME,
  INBOXES_DIR,
  TEAMMATE_COLORS
};
/**
 * @license
 * Copyright 2025 Qwen
 * SPDX-License-Identifier: Apache-2.0
 */
