import{s as a,c as s,a as e,C as t}from"./chunk-727SXJPM-DHSUk1J7.js";import{_ as i}from"./mermaid.core-fLrhp_4-.js";import"./chunk-FMBD7UC4-DXbPTnqF.js";import"./chunk-ND2GUHAM-BleQdi4d.js";import"./chunk-55IACEB6-Co15vq5x.js";import"./chunk-2J33WTMH-Dzz03hk6.js";import"./index-DJ-z1Oba.js";var n={parser:e,get db(){return new t},renderer:s,styles:a,init:i(r=>{r.class||(r.class={}),r.class.arrowMarkerAbsolute=r.arrowMarkerAbsolute},"init")};export{n as diagram};
