// Force strict mode and setup for ESM
"use strict";
import {
  init_esbuild_shims
} from "./chunk-5O2XNYP6.js";

// packages/acp-bridge/src/bridgeTypes.ts
init_esbuild_shims();
var LOAD_REPLAY_MODE_META_KEY = "qwen.session.loadReplayMode";
var LOAD_REPLAY_META_KEY = "qwen.session.loadReplay";
var LOAD_REPLAY_PAGE_SIZE_META_KEY = "qwen.session.loadReplayPageSize";
var LOAD_REPLAY_HIDE_INHERITED_META_KEY = "qwen.session.loadReplayHideInherited";
var LOAD_REPLAY_BULK_MODE = "bulk";
var LOAD_REPLAY_VERSION = 1;
var REQUESTED_SESSION_ID_META_KEY = "qwen-code/sessionId";
var CHANNEL_STARTUP_PROFILE_META_KEY = "qwen.daemon.channelStartupProfile";
var CHANNEL_STARTUP_PROFILE_VERSION = 1;
var WORKTREE_MCP_DEFER_META_KEY = "qwen.session.deferMcpDiscovery";
var DAEMON_CHANNEL_DELIVERY_META_KEY = "qwen.daemon.channelDelivery";
var MID_TURN_QUEUE_DRAIN_METHOD = "craft/drainMidTurnQueue";
var TODO_STOP_GUARD_CONTINUATION_CLAIM_METHOD = "craft/claimTodoStopGuardContinuation";
var TODO_STOP_GUARD_QUEUE_RELEASE_METHOD = "craft/todoStopGuardQueueReleased";
var PROMPT_CANCEL_METHOD = "craft/cancelPendingPrompt";
var CLIENT_MCP_OVER_WS_CONFIG_FLAG = "__clientMcpOverWs";

export {
  LOAD_REPLAY_MODE_META_KEY,
  LOAD_REPLAY_META_KEY,
  LOAD_REPLAY_PAGE_SIZE_META_KEY,
  LOAD_REPLAY_HIDE_INHERITED_META_KEY,
  LOAD_REPLAY_BULK_MODE,
  LOAD_REPLAY_VERSION,
  REQUESTED_SESSION_ID_META_KEY,
  CHANNEL_STARTUP_PROFILE_META_KEY,
  CHANNEL_STARTUP_PROFILE_VERSION,
  WORKTREE_MCP_DEFER_META_KEY,
  DAEMON_CHANNEL_DELIVERY_META_KEY,
  MID_TURN_QUEUE_DRAIN_METHOD,
  TODO_STOP_GUARD_CONTINUATION_CLAIM_METHOD,
  TODO_STOP_GUARD_QUEUE_RELEASE_METHOD,
  PROMPT_CANCEL_METHOD,
  CLIENT_MCP_OVER_WS_CONFIG_FLAG
};
/**
 * @license
 * Copyright 2025 Qwen Team
 * SPDX-License-Identifier: Apache-2.0
 */
