import { InitResult } from '../../../typings';
export declare class InitSummary implements InitResult {
    readonly bare: boolean;
    readonly path: string;
    readonly existing: boolean;
    readonly gitDir: string;
    constructor(bare: boolean, path: string, existing: boolean, gitDir: string);
}
export declare function parseInit(bare: boolean, path: string, text: string): InitSummary;
