// Force strict mode and setup for ESM
"use strict";
import {
  getPackageJson
} from "./chunk-VJNBRRZG.js";
import {
  init_esbuild_shims
} from "./chunk-5O2XNYP6.js";
import {
  __name
} from "./chunk-J2S4EL5Y.js";

// packages/cli/src/utils/version.ts
init_esbuild_shims();
async function getCliVersion() {
  const pkgJson = await getPackageJson();
  return "0.21.3";
}
__name(getCliVersion, "getCliVersion");

export {
  getCliVersion
};
/**
 * @license
 * Copyright 2025 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
