// Force strict mode and setup for ESM
"use strict";
import {
  require_dist
} from "./chunk-75DOP5OR.js";
import "./chunk-DMTGGOSA.js";
import "./chunk-YQ3U5MUC.js";
import "./chunk-5O2XNYP6.js";
import "./chunk-J2S4EL5Y.js";
export default require_dist();
