// Force strict mode and setup for ESM
"use strict";
import {
  MAX_WORKSPACE_DISPLAY_NAME_LENGTH,
  WorkspaceDisplayNameValidationError,
  WorkspaceRegistrationStore,
  WorkspaceRegistrationStoreCommittedError,
  WorkspaceRegistrationStoreError,
  WorkspaceRegistrationStoreLimitError,
  getWorkspaceRegistrationStorePath,
  normalizeWorkspaceDisplayName,
  workspaceRegistrationId,
  workspaceRegistrationScopeHash
} from "./chunk-3AQCTTEO.js";
import "./chunk-6PLDPT2C.js";
import "./chunk-5HBA2Z7V.js";
import "./chunk-IDS7MSUP.js";
import "./chunk-MR3PXB6E.js";
import "./chunk-KRXPRVGL.js";
import "./chunk-5O2XNYP6.js";
import "./chunk-J2S4EL5Y.js";
export {
  MAX_WORKSPACE_DISPLAY_NAME_LENGTH,
  WorkspaceDisplayNameValidationError,
  WorkspaceRegistrationStore,
  WorkspaceRegistrationStoreCommittedError,
  WorkspaceRegistrationStoreError,
  WorkspaceRegistrationStoreLimitError,
  getWorkspaceRegistrationStorePath,
  normalizeWorkspaceDisplayName,
  workspaceRegistrationId,
  workspaceRegistrationScopeHash
};
