// Force strict mode and setup for ESM
"use strict";
import {
  init_esbuild_shims
} from "./chunk-5O2XNYP6.js";

// packages/acp-bridge/src/bridgeOptions.ts
init_esbuild_shims();
var MAX_SUB_SESSION_PROMPT_CHARS = 1e5;
var MAX_SUB_SESSION_NAME_CHARS = 200;
var CHANNEL_DELIVERY_ERROR_CODES = /* @__PURE__ */ new Set([
  "channel_worker_unavailable",
  "channel_delivery_timeout",
  "channel_delivery_invalid",
  "channel_delivery_rejected",
  "channel_delivery_queue_full",
  "channel_delivery_failed"
]);

export {
  MAX_SUB_SESSION_PROMPT_CHARS,
  MAX_SUB_SESSION_NAME_CHARS,
  CHANNEL_DELIVERY_ERROR_CODES
};
/**
 * @license
 * Copyright 2025 Qwen Team
 * SPDX-License-Identifier: Apache-2.0
 */
