import { type DOMElement } from './dom.js';
import type Output from './output.js';
export type OutputTransformer = (s: string, index: number) => string;
export declare const renderNodeToScreenReaderOutput: (node: DOMElement, options?: {
    parentRole?: string;
    skipStaticElements?: boolean;
}) => string;
declare const renderNodeToOutput: (node: DOMElement, output: Output, options: {
    offsetX?: number;
    offsetY?: number;
    transformers?: OutputTransformer[];
    skipStaticElements: boolean;
    flowIds: Map<unknown, number>;
    nextFlowId: {
        value: number;
    };
}) => void;
export default renderNodeToOutput;
