/**
 * Returns true.
 *
 * @returns {boolean} true.
 * @example
 * stubTrue() // Returns true
 */
declare function stubTrue(): true;
/**
 * Returns true.
 *
 * @returns {boolean} true.
 * @example
 * stubTrue() // Returns true
 */
declare function stubTrue(): true;

export { stubTrue };
