/**
 * Returns false.
 *
 * @returns {boolean} false.
 * @example
 * stubFalse() // Returns false
 */
declare function stubFalse(): false;
/**
 * Returns false.
 *
 * @returns {boolean} false.
 * @example
 * stubFalse() // Returns false
 */
declare function stubFalse(): false;

export { stubFalse };
