import { StringTask } from '../types';
export declare function addSubModuleTask(repo: string, path: string): StringTask<string>;
export declare function initSubModuleTask(customArgs: string[]): StringTask<string>;
export declare function subModuleTask(customArgs: string[]): StringTask<string>;
export declare function updateSubModuleTask(customArgs: string[]): StringTask<string>;
