// Force strict mode and setup for ESM
"use strict";
import {
  CUSTOM_SANDBOX_IMAGE_ENV_VAR,
  HOST_UPDATE_RELAUNCH_ENV_VAR,
  RELAUNCH_EXIT_CODE,
  SKIP_UPDATE_CHECK_ENV_VAR,
  UPDATE_COMPLETE_EXIT_CODE,
  UPDATE_ON_EXIT_MESSAGE,
  UPDATE_RELAUNCH_EXIT_CODE,
  relaunchApp,
  relaunchForUpdate,
  requestUpdateOnExit
} from "./chunk-2XXBJXNM.js";
import "./chunk-3D43T7XT.js";
import "./chunk-5O2XNYP6.js";
import "./chunk-J2S4EL5Y.js";
export {
  CUSTOM_SANDBOX_IMAGE_ENV_VAR,
  HOST_UPDATE_RELAUNCH_ENV_VAR,
  RELAUNCH_EXIT_CODE,
  SKIP_UPDATE_CHECK_ENV_VAR,
  UPDATE_COMPLETE_EXIT_CODE,
  UPDATE_ON_EXIT_MESSAGE,
  UPDATE_RELAUNCH_EXIT_CODE,
  relaunchApp,
  relaunchForUpdate,
  requestUpdateOnExit
};
