import { type DOMElement } from './dom.js';
import { type ScreenSelection, type FrameCell, type FrameBoundary } from './frame-controller.js';
type Result = {
    output: string;
    outputHeight: number;
    staticOutput: string;
    cells?: FrameCell[][];
    boundaries?: Array<Array<FrameBoundary | null>>;
};
declare const renderer: (node: DOMElement, isScreenReaderEnabled: boolean, selection?: ScreenSelection | null) => Result;
export default renderer;
