import { SimpleGitFactory } from './simple-git';

export { pathspec } from '@simple-git/args-pathspec';

export * from './simple-git';
export * from './errors';
export * from './response';
export * from './types';

export declare const gitP: SimpleGitFactory;

export declare const simpleGit: SimpleGitFactory;

export default simpleGit;
