// Force strict mode and setup for ESM
"use strict";
import {
  detectAndEnableKittyProtocol,
  disableKittyProtocol,
  isKittyProtocolEnabled,
  isKittyProtocolSupported,
  pushKittyProtocolFlags
} from "./chunk-NYX53SV4.js";
import "./chunk-5O2XNYP6.js";
import "./chunk-J2S4EL5Y.js";
export {
  detectAndEnableKittyProtocol,
  disableKittyProtocol,
  isKittyProtocolEnabled,
  isKittyProtocolSupported,
  pushKittyProtocolFlags
};
