// Force strict mode and setup for ESM
"use strict";
import {
  beginAcpBootstrapConfigProfiling,
  buildAndFreezeAcpStartupProfile,
  endAcpBootstrapConfigProfiling,
  initializeAcpStartupProfiler,
  isAcpStartupProfilerEnabled,
  markAcpStartup,
  recordAcpConfigStartupEvent,
  resetAcpStartupProfilerForTesting
} from "./chunk-M744OFVE.js";
import "./chunk-UKZEXS6K.js";
import "./chunk-5O2XNYP6.js";
import "./chunk-J2S4EL5Y.js";
export {
  beginAcpBootstrapConfigProfiling,
  buildAndFreezeAcpStartupProfile,
  endAcpBootstrapConfigProfiling,
  initializeAcpStartupProfiler,
  isAcpStartupProfilerEnabled,
  markAcpStartup,
  recordAcpConfigStartupEvent,
  resetAcpStartupProfilerForTesting
};
