export declare const CC_BEL: number;
export declare const CC_ESC: number;
export declare const CC_BACKSLASH: number;
export declare const CC_CSI: number;
export declare const CC_OSC: number;
export declare const CC_C1_ST: number;
export declare const CC_0: number;
export declare const CC_9: number;
export declare const CC_SEMI: number;
export declare const CC_M: number;
export declare const ESCAPES: Set<number>;
export declare const linkCodePrefix: string;
export declare const linkCodePrefixCharCodes: number[];
export declare const linkCodeSuffix = "\u0007";
export declare const linkEndCode: string;
export declare const linkEndCodeST: string;
export declare const linkEndCodeC1ST: string;
