import{s as e,b as r,a,S as s}from"./chunk-AQP2D5EJ-Br8u_E2R.js";import{_ as i}from"./mermaid.core-fLrhp_4-.js";import"./chunk-55IACEB6-Co15vq5x.js";import"./chunk-2J33WTMH-Dzz03hk6.js";import"./index-DJ-z1Oba.js";var p={parser:a,get db(){return new s(2)},renderer:r,styles:e,init:i(t=>{t.state||(t.state={}),t.state.arrowMarkerAbsolute=t.arrowMarkerAbsolute},"init")};export{p as diagram};
