// Force strict mode and setup for ESM
"use strict";
import {
  init_esbuild_shims
} from "./chunk-5O2XNYP6.js";

// packages/acp-bridge/dist/channel-control-timeouts.js
init_esbuild_shims();
var MAX_DAEMON_WORKSPACES = 25;
var CHANNEL_WORKER_STARTUP_TIMEOUT_MS = 3e4;
var CHANNEL_WORKER_STOP_GRACE_MS = 1e4;
var CHANNEL_WORKER_KILL_GRACE_MS = 2e3;
var CHANNEL_CONTROL_CLIENT_HEADROOM_MS = 3e4;
var CHANNEL_WORKER_STOP_TIMEOUT_MS = CHANNEL_WORKER_STOP_GRACE_MS + CHANNEL_WORKER_KILL_GRACE_MS;
var CHANNEL_CONTROL_DEFAULT_TIMEOUT_MS = 2 * MAX_DAEMON_WORKSPACES * (CHANNEL_WORKER_STOP_TIMEOUT_MS + CHANNEL_WORKER_STARTUP_TIMEOUT_MS) + CHANNEL_CONTROL_CLIENT_HEADROOM_MS;

export {
  MAX_DAEMON_WORKSPACES,
  CHANNEL_WORKER_STARTUP_TIMEOUT_MS,
  CHANNEL_WORKER_STOP_GRACE_MS,
  CHANNEL_WORKER_KILL_GRACE_MS,
  CHANNEL_CONTROL_DEFAULT_TIMEOUT_MS
};
/**
 * @license
 * Copyright 2026 Qwen Team
 * SPDX-License-Identifier: Apache-2.0
 */
