import { type Styles } from './styles.js';
declare const wrapText: (text: string, maxWidth: number, wrapType: Styles["textWrap"]) => string;
export type TextBoundary = {
    kind: 'soft' | 'hard';
    joiner: string;
};
export declare const wrapTextWithMetadata: (text: string, maxWidth: number, wrapType: Styles["textWrap"], shouldWrap?: boolean) => {
    text: string;
    boundaries: TextBoundary[];
    selectableRows: boolean[];
};
export default wrapText;
