// Force strict mode and setup for ESM
"use strict";
import {
  init_esbuild_shims
} from "./chunk-5O2XNYP6.js";

// packages/cli/src/utils/updateEventEmitter.ts
init_esbuild_shims();
import { EventEmitter } from "node:events";
var updateEventEmitter = new EventEmitter();

export {
  updateEventEmitter
};
/**
 * @license
 * Copyright 2025 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
