export default {
  overview: 'Overview',
  telegram: 'Telegram',
  weixin: 'WeChat',
  dingtalk: 'DingTalk',
  wecom: 'WeCom',
  feishu: 'Feishu',
  qqbot: 'QQ Bot',
  github: 'GitHub',
  gitlab: 'GitLab',
  plugins: 'Plugins',
};
