// Force strict mode and setup for ESM
"use strict";
import {
  init_esbuild_shims
} from "./chunk-5O2XNYP6.js";
import {
  __name
} from "./chunk-J2S4EL5Y.js";

// packages/core/src/telemetry/constants.ts
init_esbuild_shims();
var SERVICE_NAME = "qwen-code";
var EVENT_USER_PROMPT = "qwen-code.user_prompt";
var EVENT_USER_RETRY = "qwen-code.user_retry";
var EVENT_TOOL_CALL = "qwen-code.tool_call";
var EVENT_API_REQUEST = "qwen-code.api_request";
var EVENT_API_ERROR = "qwen-code.api_error";
var EVENT_API_CANCEL = "qwen-code.api_cancel";
var EVENT_API_RESPONSE = "qwen-code.api_response";
var EVENT_CLI_CONFIG = "qwen-code.config";
var EVENT_EXTENSION_DISABLE = "qwen-code.extension_disable";
var EVENT_EXTENSION_ENABLE = "qwen-code.extension_enable";
var EVENT_EXTENSION_INSTALL = "qwen-code.extension_install";
var EVENT_EXTENSION_UNINSTALL = "qwen-code.extension_uninstall";
var EVENT_EXTENSION_UPDATE = "qwen-code.extension_update";
var EVENT_RIPGREP_FALLBACK = "qwen-code.ripgrep_fallback";
var EVENT_RIPGREP_RUNTIME_RECOVERY = "qwen-code.ripgrep_runtime_recovery";
var EVENT_NEXT_SPEAKER_CHECK = "qwen-code.next_speaker_check";
var EVENT_SLASH_COMMAND = "qwen-code.slash_command";
var EVENT_IDE_CONNECTION = "qwen-code.ide_connection";
var EVENT_CHAT_COMPRESSION = "qwen-code.chat_compression";
var EVENT_CONTENT_RETRY = "qwen-code.chat.content_retry";
var EVENT_CONTENT_RETRY_FAILURE = "qwen-code.chat.content_retry_failure";
var EVENT_PROTOCOL_TAG_SANITIZED = "qwen-code.chat.protocol_tag_sanitized";
var EVENT_API_RETRY = "qwen-code.api_retry";
var EVENT_CONVERSATION_FINISHED = "qwen-code.conversation_finished";
var EVENT_FILE_OPERATION = "qwen-code.file_operation";
var EVENT_MODEL_SLASH_COMMAND = "qwen-code.slash_command.model";
var EVENT_SUBAGENT_EXECUTION = "qwen-code.subagent_execution";
var EVENT_SKILL_LAUNCH = "qwen-code.skill_launch";
var EVENT_AUTH = "qwen-code.auth";
var EVENT_USER_FEEDBACK = "qwen-code.user_feedback";
var EVENT_TOOL_OUTPUT_TRUNCATED = "qwen-code.tool_output_truncated";
var DEFAULT_SENSITIVE_SPAN_ATTRIBUTE_MAX_LENGTH = 1024 * 1024;
var SENSITIVE_SPAN_ATTRIBUTE_MAX_LENGTH_LIMIT = 100 * 1024 * 1024;
function isValidSensitiveSpanAttributeMaxLength(value) {
  return Number.isSafeInteger(value) && value >= 1 && value <= SENSITIVE_SPAN_ATTRIBUTE_MAX_LENGTH_LIMIT;
}
__name(isValidSensitiveSpanAttributeMaxLength, "isValidSensitiveSpanAttributeMaxLength");
var EVENT_PROMPT_SUGGESTION = "qwen-code.prompt_suggestion";
var EVENT_SPECULATION = "qwen-code.speculation";
var EVENT_WORKFLOW_KEYWORD = "qwen-code.workflow_keyword";
var EVENT_WORKFLOW_RUN = "qwen-code.workflow_run";
var EVENT_ARENA_SESSION_STARTED = "qwen-code.arena_session_started";
var EVENT_ARENA_AGENT_COMPLETED = "qwen-code.arena_agent_completed";
var EVENT_ARENA_SESSION_ENDED = "qwen-code.arena_session_ended";
var EVENT_MEMORY_EXTRACT = "qwen-code.memory.extract";
var EVENT_MEMORY_DREAM = "qwen-code.memory.dream";
var EVENT_MEMORY_RECALL = "qwen-code.memory.recall";
var EVENT_MEMORY_RECALL_DELIVERY = "qwen-code.memory.recall.delivery";
var SPAN_INTERACTION = "qwen-code.interaction";
var SPAN_LLM_REQUEST = "qwen-code.llm_request";
var SPAN_TOOL = "qwen-code.tool";
var SPAN_TOOL_EXECUTION = "qwen-code.tool.execution";
var SPAN_TOOL_BLOCKED_ON_USER = "qwen-code.tool.blocked_on_user";
var SPAN_HOOK = "qwen-code.hook";
var SPAN_SUBAGENT = "qwen-code.subagent";

export {
  SERVICE_NAME,
  EVENT_USER_PROMPT,
  EVENT_USER_RETRY,
  EVENT_TOOL_CALL,
  EVENT_API_REQUEST,
  EVENT_API_ERROR,
  EVENT_API_CANCEL,
  EVENT_API_RESPONSE,
  EVENT_CLI_CONFIG,
  EVENT_EXTENSION_DISABLE,
  EVENT_EXTENSION_ENABLE,
  EVENT_EXTENSION_INSTALL,
  EVENT_EXTENSION_UNINSTALL,
  EVENT_EXTENSION_UPDATE,
  EVENT_RIPGREP_FALLBACK,
  EVENT_RIPGREP_RUNTIME_RECOVERY,
  EVENT_NEXT_SPEAKER_CHECK,
  EVENT_SLASH_COMMAND,
  EVENT_IDE_CONNECTION,
  EVENT_CHAT_COMPRESSION,
  EVENT_CONTENT_RETRY,
  EVENT_CONTENT_RETRY_FAILURE,
  EVENT_PROTOCOL_TAG_SANITIZED,
  EVENT_API_RETRY,
  EVENT_CONVERSATION_FINISHED,
  EVENT_FILE_OPERATION,
  EVENT_MODEL_SLASH_COMMAND,
  EVENT_SUBAGENT_EXECUTION,
  EVENT_SKILL_LAUNCH,
  EVENT_AUTH,
  EVENT_USER_FEEDBACK,
  EVENT_TOOL_OUTPUT_TRUNCATED,
  DEFAULT_SENSITIVE_SPAN_ATTRIBUTE_MAX_LENGTH,
  SENSITIVE_SPAN_ATTRIBUTE_MAX_LENGTH_LIMIT,
  isValidSensitiveSpanAttributeMaxLength,
  EVENT_PROMPT_SUGGESTION,
  EVENT_SPECULATION,
  EVENT_WORKFLOW_KEYWORD,
  EVENT_WORKFLOW_RUN,
  EVENT_ARENA_SESSION_STARTED,
  EVENT_ARENA_AGENT_COMPLETED,
  EVENT_ARENA_SESSION_ENDED,
  EVENT_MEMORY_EXTRACT,
  EVENT_MEMORY_DREAM,
  EVENT_MEMORY_RECALL,
  EVENT_MEMORY_RECALL_DELIVERY,
  SPAN_INTERACTION,
  SPAN_LLM_REQUEST,
  SPAN_TOOL,
  SPAN_TOOL_EXECUTION,
  SPAN_TOOL_BLOCKED_ON_USER,
  SPAN_HOOK,
  SPAN_SUBAGENT
};
/**
 * @license
 * Copyright 2025 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
