// Force strict mode and setup for ESM
"use strict";
import {
  require_lib
} from "./chunk-5WV5S2GT.js";
import "./chunk-XWRJCPHC.js";
import "./chunk-5O2XNYP6.js";
import "./chunk-J2S4EL5Y.js";
export default require_lib();
