// Force strict mode and setup for ESM
"use strict";
import {
  init_esbuild_shims
} from "./chunk-5O2XNYP6.js";

// packages/cli/src/config/default-theme-names.ts
init_esbuild_shims();
var DEFAULT_LIGHT_THEME_NAME = "Default Light";
var DEFAULT_DARK_THEME_NAME = "Default";

export {
  DEFAULT_LIGHT_THEME_NAME,
  DEFAULT_DARK_THEME_NAME
};
/**
 * @license
 * Copyright 2025 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
