import { type PublicProps, type Props } from '../components/StdinContext.js';
/**
A React hook that returns the stdin stream and stdin-related utilities.
*/
declare const useStdin: () => PublicProps;
export declare const useStdinContext: () => Props;
export default useStdin;
