/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */var Gd=function(r,t){return Gd=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,a){e.__proto__=a}||function(e,a){for(var n in a)Object.prototype.hasOwnProperty.call(a,n)&&(e[n]=a[n])},Gd(r,t)};function z(r,t){if(typeof t!="function"&&t!==null)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");Gd(r,t);function e(){this.constructor=r}r.prototype=t===null?Object.create(t):(e.prototype=t.prototype,new e)}var xR=function(){function r(){this.firefox=!1,this.ie=!1,this.edge=!1,this.newEdge=!1,this.weChat=!1}return r}(),bR=function(){function r(){this.browser=new xR,this.node=!1,this.wxa=!1,this.worker=!1,this.svgSupported=!1,this.touchEventsSupported=!1,this.pointerEventsSupported=!1,this.domSupported=!1,this.transformSupported=!1,this.transform3dSupported=!1,this.hasGlobalWindow=typeof window<"u"}return r}(),Tt=new bR;typeof wx=="object"&&typeof wx.getSystemInfoSync=="function"?(Tt.wxa=!0,Tt.touchEventsSupported=!0):typeof document>"u"&&typeof self<"u"?Tt.worker=!0:!Tt.hasGlobalWindow||"Deno"in window||typeof navigator<"u"&&typeof navigator.userAgent=="string"&&navigator.userAgent.indexOf("Node.js")>-1?(Tt.node=!0,Tt.svgSupported=!0):wR(navigator.userAgent,Tt);function wR(r,t){var e=t.browser,a=r.match(/Firefox\/([\d.]+)/),n=r.match(/MSIE\s([\d.]+)/)||r.match(/Trident\/.+?rv:(([\d.]+))/),i=r.match(/Edge?\/([\d.]+)/),o=/micromessenger/i.test(r);a&&(e.firefox=!0,e.version=a[1]),n&&(e.ie=!0,e.version=n[1]),i&&(e.edge=!0,e.version=i[1],e.newEdge=+i[1].split(".")[0]>18),o&&(e.weChat=!0),t.svgSupported=typeof SVGRect<"u",t.touchEventsSupported="ontouchstart"in window&&!e.ie&&!e.edge,t.pointerEventsSupported="onpointerdown"in window&&(e.edge||e.ie&&+e.version>=11);var s=t.domSupported=typeof document<"u";if(s){var l=document.documentElement.style;t.transform3dSupported=(e.ie&&"transition"in l||e.edge||"WebKitCSSMatrix"in window&&"m11"in new WebKitCSSMatrix||"MozPerspective"in l)&&!("OTransition"in l),t.transformSupported=t.transform3dSupported||e.ie&&+e.version>=9}}var jy=12,nA="sans-serif",Ya=jy+"px "+nA,TR=20,CR=100,AR="007LLmW'55;N0500LLLLLLLLLL00NNNLzWW\\\\WQb\\0FWLg\\bWb\\WQ\\WrWWQ000CL5LLFLL0LL**F*gLLLL5F0LF\\FFF5.5N";function MR(r){var t={};if(typeof JSON>"u")return t;for(var e=0;e<r.length;e++){var a=String.fromCharCode(e+32),n=(r.charCodeAt(e)-TR)/CR;t[a]=n}return t}var DR=MR(AR),tr={createCanvas:function(){return typeof document<"u"&&document.createElement("canvas")},measureText:function(){var r,t;return function(e,a){if(!r){var n=tr.createCanvas();r=n&&n.getContext("2d")}if(r)return t!==a&&(t=r.font=a||Ya),r.measureText(e);e=e||"",a=a||Ya;var i=/((?:\d+)?\.?\d*)px/.exec(a),o=i&&+i[1]||jy,s=0;if(a.indexOf("mono")>=0)s=o*e.length;else for(var l=0;l<e.length;l++){var u=DR[e[l]];s+=u==null?o:u*o}return{width:s}}}(),loadImage:function(r,t,e){var a=new Image;return a.onload=t,a.onerror=e,a.src=r,a}};function LR(r){for(var t in tr)r[t]&&(tr[t]=r[t])}var iA=Mr(["Function","RegExp","Date","Error","CanvasGradient","CanvasPattern","Image","Canvas"],function(r,t){return r["[object "+t+"]"]=!0,r},{}),oA=Mr(["Int8","Uint8","Uint8Clamped","Int16","Uint16","Int32","Uint32","Float32","Float64"],function(r,t){return r["[object "+t+"Array]"]=!0,r},{}),cs=Object.prototype.toString,Ph=Array.prototype,IR=Ph.forEach,PR=Ph.filter,Jy=Ph.slice,RR=Ph.map,D_=(function(){}).constructor,Vu=D_?D_.prototype:null,Qy="__proto__",kR=2311;function tm(){return kR++}function Rh(){for(var r=[],t=0;t<arguments.length;t++)r[t]=arguments[t];typeof console<"u"&&console.error.apply(console,r)}function et(r){if(r==null||typeof r!="object")return r;var t=r,e=cs.call(r);if(e==="[object Array]"){if(!Uo(r)){t=[];for(var a=0,n=r.length;a<n;a++)t[a]=et(r[a])}}else if(oA[e]){if(!Uo(r)){var i=r.constructor;if(i.from)t=i.from(r);else{t=new i(r.length);for(var a=0,n=r.length;a<n;a++)t[a]=r[a]}}}else if(!iA[e]&&!Uo(r)&&!zi(r)){t={};for(var o in r)r.hasOwnProperty(o)&&o!==Qy&&(t[o]=et(r[o]))}return t}function yt(r,t,e){if(!it(t)||!it(r))return e?et(t):r;for(var a in t)if(t.hasOwnProperty(a)&&a!==Qy){var n=r[a],i=t[a];it(i)&&it(n)&&!W(i)&&!W(n)&&!zi(i)&&!zi(n)&&!Fd(i)&&!Fd(n)&&!Uo(i)&&!Uo(n)?yt(n,i,e):(e||!(a in r))&&(r[a]=et(t[a]))}return r}function kh(r,t){for(var e=r[0],a=1,n=r.length;a<n;a++)e=yt(e,r[a],t);return e}function G(r,t){if(Object.assign)Object.assign(r,t);else for(var e in t)t.hasOwnProperty(e)&&e!==Qy&&(r[e]=t[e]);return r}function nt(r,t,e){for(var a=Ct(t),n=0,i=a.length;n<i;n++){var o=a[n];(e?t[o]!=null:r[o]==null)&&(r[o]=t[o])}return r}var ER=tr.createCanvas;function gt(r,t){if(r){if(r.indexOf)return r.indexOf(t);for(var e=0,a=r.length;e<a;e++)if(r[e]===t)return e}return-1}function em(r,t){var e=r.prototype;function a(){}a.prototype=t.prototype,r.prototype=new a;for(var n in e)e.hasOwnProperty(n)&&(r.prototype[n]=e[n]);r.prototype.constructor=r,r.superClass=t}function Qt(r,t,e){if(r="prototype"in r?r.prototype:r,t="prototype"in t?t.prototype:t,Object.getOwnPropertyNames)for(var a=Object.getOwnPropertyNames(t),n=0;n<a.length;n++){var i=a[n];i!=="constructor"&&(e?t[i]!=null:r[i]==null)&&(r[i]=t[i])}else nt(r,t,e)}function Pe(r){return!r||typeof r=="string"?!1:typeof r.length=="number"}function A(r,t,e){if(r&&t)if(r.forEach&&r.forEach===IR)r.forEach(t,e);else if(r.length===+r.length)for(var a=0,n=r.length;a<n;a++)t.call(e,r[a],a,r);else for(var i in r)r.hasOwnProperty(i)&&t.call(e,r[i],i,r)}function U(r,t,e){if(!r)return[];if(!t)return Eh(r);if(r.map&&r.map===RR)return r.map(t,e);for(var a=[],n=0,i=r.length;n<i;n++)a.push(t.call(e,r[n],n,r));return a}function Mr(r,t,e,a){if(r&&t){for(var n=0,i=r.length;n<i;n++)e=t.call(a,e,r[n],n,r);return e}}function Pt(r,t,e){if(!r)return[];if(!t)return Eh(r);if(r.filter&&r.filter===PR)return r.filter(t,e);for(var a=[],n=0,i=r.length;n<i;n++)t.call(e,r[n],n,r)&&a.push(r[n]);return a}function Nn(r,t,e){if(r&&t){for(var a=0,n=r.length;a<n;a++)if(t.call(e,r[a],a,r))return r[a]}}function Ct(r){if(!r)return[];if(Object.keys)return Object.keys(r);var t=[];for(var e in r)r.hasOwnProperty(e)&&t.push(e);return t}function OR(r,t){for(var e=[],a=2;a<arguments.length;a++)e[a-2]=arguments[a];return function(){return r.apply(t,e.concat(Jy.call(arguments)))}}var $=Vu&&tt(Vu.bind)?Vu.call.bind(Vu.bind):OR;function pt(r){for(var t=[],e=1;e<arguments.length;e++)t[e-1]=arguments[e];return function(){return r.apply(this,t.concat(Jy.call(arguments)))}}function W(r){return Array.isArray?Array.isArray(r):cs.call(r)==="[object Array]"}function tt(r){return typeof r=="function"}function X(r){return typeof r=="string"}function xv(r){return cs.call(r)==="[object String]"}function Mt(r){return typeof r=="number"}function it(r){var t=typeof r;return t==="function"||!!r&&t==="object"}function Fd(r){return!!iA[cs.call(r)]}function Ze(r){return!!oA[cs.call(r)]}function zi(r){return typeof r=="object"&&typeof r.nodeType=="number"&&typeof r.ownerDocument=="object"}function mu(r){return r.colorStops!=null}function sA(r){return r.image!=null}function lA(r){return cs.call(r)==="[object RegExp]"}function Ie(r){return r!==r}function Ce(){for(var r=[],t=0;t<arguments.length;t++)r[t]=arguments[t];for(var e=0,a=r.length;e<a;e++)if(r[e]!=null)return r[e]}function Q(r,t){return r??t}function Qe(r,t,e){return r??t??e}function Eh(r){for(var t=[],e=1;e<arguments.length;e++)t[e-1]=arguments[e];return Jy.apply(r,t)}function _u(r){if(typeof r=="number")return[r,r,r,r];var t=r.length;return t===2?[r[0],r[1],r[0],r[1]]:t===3?[r[0],r[1],r[2],r[1]]:r}function Re(r,t){if(!r)throw new Error(t)}function sr(r){return r==null?null:typeof r.trim=="function"?r.trim():r.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,"")}var uA="__ec_primitive__";function Gl(r){r[uA]=!0}function Uo(r){return r[uA]}var NR=function(){function r(){this.data={}}return r.prototype.delete=function(t){var e=this.has(t);return e&&delete this.data[t],e},r.prototype.has=function(t){return this.data.hasOwnProperty(t)},r.prototype.get=function(t){return this.data[t]},r.prototype.set=function(t,e){return this.data[t]=e,this},r.prototype.keys=function(){return Ct(this.data)},r.prototype.forEach=function(t){var e=this.data;for(var a in e)e.hasOwnProperty(a)&&t(e[a],a)},r}(),fA=typeof Map=="function";function BR(){return fA?new Map:new NR}var vA=function(){function r(t){var e=W(t);this.data=BR();var a=this;t instanceof r?t.each(n):t&&A(t,n);function n(i,o){e?a.set(i,o):a.set(o,i)}}return r.prototype.hasKey=function(t){return this.data.has(t)},r.prototype.get=function(t){return this.data.get(t)},r.prototype.set=function(t,e){return this.data.set(t,e),e},r.prototype.each=function(t,e){this.data.forEach(function(a,n){t.call(e,a,n)})},r.prototype.keys=function(){var t=this.data.keys();return fA?Array.from(t):t},r.prototype.removeKey=function(t){this.data.delete(t)},r}();function j(r){return new vA(r)}function Ko(r,t){for(var e=new r.constructor(r.length+t.length),a=0;a<r.length;a++)e[a]=r[a];for(var n=r.length,a=0;a<t.length;a++)e[a+n]=t[a];return e}function Su(r,t){var e;if(Object.create)e=Object.create(r);else{var a=function(){};a.prototype=r,e=new a}return t&&G(e,t),e}function rm(r){var t=r.style;t.webkitUserSelect="none",t.userSelect="none",t.webkitTapHighlightColor="rgba(0,0,0,0)",t["-webkit-touch-callout"]="none"}function q(r,t){return r.hasOwnProperty(t)}function jt(){}var Cl=180/Math.PI,zR=Number.EPSILON||Math.pow(2,-52);const cq=Object.freeze(Object.defineProperty({__proto__:null,EPSILON:zR,HashMap:vA,RADIAN_TO_DEGREE:Cl,assert:Re,bind:$,clone:et,concatArray:Ko,createCanvas:ER,createHashMap:j,createObject:Su,curry:pt,defaults:nt,disableUserSelect:rm,each:A,eqNaN:Ie,extend:G,filter:Pt,find:Nn,guid:tm,hasOwn:q,indexOf:gt,inherits:em,isArray:W,isArrayLike:Pe,isBuiltInObject:Fd,isDom:zi,isFunction:tt,isGradientObject:mu,isImagePatternObject:sA,isNumber:Mt,isObject:it,isPrimitive:Uo,isRegExp:lA,isString:X,isStringSafe:xv,isTypedArray:Ze,keys:Ct,logError:Rh,map:U,merge:yt,mergeAll:kh,mixin:Qt,noop:jt,normalizeCssArray:_u,reduce:Mr,retrieve:Ce,retrieve2:Q,retrieve3:Qe,setAsPrimitive:Gl,slice:Eh,trim:sr},Symbol.toStringTag,{value:"Module"}));/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */var Hd=function(r,t){return Hd=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,a){e.__proto__=a}||function(e,a){for(var n in a)Object.prototype.hasOwnProperty.call(a,n)&&(e[n]=a[n])},Hd(r,t)};function Zt(r,t){if(typeof t!="function"&&t!==null)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");Hd(r,t);function e(){this.constructor=r}r.prototype=t===null?Object.create(t):(e.prototype=t.prototype,new e)}function Bn(r,t){return r==null&&(r=0),t==null&&(t=0),[r,t]}function Ne(r,t){return r[0]=t[0],r[1]=t[1],r}function ca(r){return[r[0],r[1]]}function Oh(r,t,e){return r[0]=t,r[1]=e,r}function Wd(r,t,e){return r[0]=t[0]+e[0],r[1]=t[1]+e[1],r}function bv(r,t,e,a){return r[0]=t[0]+e[0]*a,r[1]=t[1]+e[1]*a,r}function dn(r,t,e){return r[0]=t[0]-e[0],r[1]=t[1]-e[1],r}function Fl(r){return Math.sqrt(am(r))}var VR=Fl;function am(r){return r[0]*r[0]+r[1]*r[1]}var GR=am;function FR(r,t,e){return r[0]=t[0]*e[0],r[1]=t[1]*e[1],r}function HR(r,t,e){return r[0]=t[0]/e[0],r[1]=t[1]/e[1],r}function WR(r,t){return r[0]*t[0]+r[1]*t[1]}function Al(r,t,e){return r[0]=t[0]*e,r[1]=t[1]*e,r}function qi(r,t){var e=Fl(t);return e===0?(r[0]=0,r[1]=0):(r[0]=t[0]/e,r[1]=t[1]/e),r}function wv(r,t){return Math.sqrt((r[0]-t[0])*(r[0]-t[0])+(r[1]-t[1])*(r[1]-t[1]))}var Ea=wv;function hA(r,t){return(r[0]-t[0])*(r[0]-t[0])+(r[1]-t[1])*(r[1]-t[1])}var bn=hA;function UR(r,t){return r[0]=-t[0],r[1]=-t[1],r}function Ml(r,t,e,a){return r[0]=t[0]+a*(e[0]-t[0]),r[1]=t[1]+a*(e[1]-t[1]),r}function Jt(r,t,e){var a=t[0],n=t[1];return r[0]=e[0]*a+e[2]*n+e[4],r[1]=e[1]*a+e[3]*n+e[5],r}function Oa(r,t,e){return r[0]=Math.min(t[0],e[0]),r[1]=Math.min(t[1],e[1]),r}function Na(r,t,e){return r[0]=Math.max(t[0],e[0]),r[1]=Math.max(t[1],e[1]),r}const pq=Object.freeze(Object.defineProperty({__proto__:null,add:Wd,applyTransform:Jt,clone:ca,copy:Ne,create:Bn,dist:Ea,distSquare:bn,distance:wv,distanceSquare:hA,div:HR,dot:WR,len:Fl,lenSquare:am,length:VR,lengthSquare:GR,lerp:Ml,max:Na,min:Oa,mul:FR,negate:UR,normalize:qi,scale:Al,scaleAndAdd:bv,set:Oh,sub:dn},Symbol.toStringTag,{value:"Module"}));var oo=function(){function r(t,e){this.target=t,this.topTarget=e&&e.topTarget}return r}(),YR=function(){function r(t){this.handler=t,t.on("mousedown",this._dragStart,this),t.on("mousemove",this._drag,this),t.on("mouseup",this._dragEnd,this)}return r.prototype._dragStart=function(t){for(var e=t.target;e&&!e.draggable;)e=e.parent||e.__hostTarget;e&&(this._draggingTarget=e,e.dragging=!0,this._x=t.offsetX,this._y=t.offsetY,this.handler.dispatchToElement(new oo(e,t),"dragstart",t.event))},r.prototype._drag=function(t){var e=this._draggingTarget;if(e){var a=t.offsetX,n=t.offsetY,i=a-this._x,o=n-this._y;this._x=a,this._y=n,e.drift(i,o,t),this.handler.dispatchToElement(new oo(e,t),"drag",t.event);var s=this.handler.findHover(a,n,e).target,l=this._dropTarget;this._dropTarget=s,e!==s&&(l&&s!==l&&this.handler.dispatchToElement(new oo(l,t),"dragleave",t.event),s&&s!==l&&this.handler.dispatchToElement(new oo(s,t),"dragenter",t.event))}},r.prototype._dragEnd=function(t){var e=this._draggingTarget;e&&(e.dragging=!1),this.handler.dispatchToElement(new oo(e,t),"dragend",t.event),this._dropTarget&&this.handler.dispatchToElement(new oo(this._dropTarget,t),"drop",t.event),this._draggingTarget=null,this._dropTarget=null},r}(),Pr=function(){function r(t){t&&(this._$eventProcessor=t)}return r.prototype.on=function(t,e,a,n){this._$handlers||(this._$handlers={});var i=this._$handlers;if(typeof e=="function"&&(n=a,a=e,e=null),!a||!t)return this;var o=this._$eventProcessor;e!=null&&o&&o.normalizeQuery&&(e=o.normalizeQuery(e)),i[t]||(i[t]=[]);for(var s=0;s<i[t].length;s++)if(i[t][s].h===a)return this;var l={h:a,query:e,ctx:n||this,callAtLast:a.zrEventfulCallAtLast},u=i[t].length-1,f=i[t][u];return f&&f.callAtLast?i[t].splice(u,0,l):i[t].push(l),this},r.prototype.isSilent=function(t){var e=this._$handlers;return!e||!e[t]||!e[t].length},r.prototype.off=function(t,e){var a=this._$handlers;if(!a)return this;if(!t)return this._$handlers={},this;if(e){if(a[t]){for(var n=[],i=0,o=a[t].length;i<o;i++)a[t][i].h!==e&&n.push(a[t][i]);a[t]=n}a[t]&&a[t].length===0&&delete a[t]}else delete a[t];return this},r.prototype.trigger=function(t){for(var e=[],a=1;a<arguments.length;a++)e[a-1]=arguments[a];if(!this._$handlers)return this;var n=this._$handlers[t],i=this._$eventProcessor;if(n)for(var o=e.length,s=n.length,l=0;l<s;l++){var u=n[l];if(!(i&&i.filter&&u.query!=null&&!i.filter(t,u.query)))switch(o){case 0:u.h.call(u.ctx);break;case 1:u.h.call(u.ctx,e[0]);break;case 2:u.h.call(u.ctx,e[0],e[1]);break;default:u.h.apply(u.ctx,e);break}}return i&&i.afterTrigger&&i.afterTrigger(t),this},r.prototype.triggerWithContext=function(t){for(var e=[],a=1;a<arguments.length;a++)e[a-1]=arguments[a];if(!this._$handlers)return this;var n=this._$handlers[t],i=this._$eventProcessor;if(n)for(var o=e.length,s=e[o-1],l=n.length,u=0;u<l;u++){var f=n[u];if(!(i&&i.filter&&f.query!=null&&!i.filter(t,f.query)))switch(o){case 0:f.h.call(s);break;case 1:f.h.call(s,e[0]);break;case 2:f.h.call(s,e[0],e[1]);break;default:f.h.apply(s,e.slice(1,o-1));break}}return i&&i.afterTrigger&&i.afterTrigger(t),this},r}(),ZR=Math.log(2);function Ud(r,t,e,a,n,i){var o=a+"-"+n,s=r.length;if(i.hasOwnProperty(o))return i[o];if(t===1){var l=Math.round(Math.log((1<<s)-1&~n)/ZR);return r[e][l]}for(var u=a|1<<e,f=e+1;a&1<<f;)f++;for(var v=0,h=0,c=0;h<s;h++){var p=1<<h;p&n||(v+=(c%2?-1:1)*r[e][h]*Ud(r,t-1,f,u,n|p,i),c++)}return i[o]=v,v}function L_(r,t){var e=[[r[0],r[1],1,0,0,0,-t[0]*r[0],-t[0]*r[1]],[0,0,0,r[0],r[1],1,-t[1]*r[0],-t[1]*r[1]],[r[2],r[3],1,0,0,0,-t[2]*r[2],-t[2]*r[3]],[0,0,0,r[2],r[3],1,-t[3]*r[2],-t[3]*r[3]],[r[4],r[5],1,0,0,0,-t[4]*r[4],-t[4]*r[5]],[0,0,0,r[4],r[5],1,-t[5]*r[4],-t[5]*r[5]],[r[6],r[7],1,0,0,0,-t[6]*r[6],-t[6]*r[7]],[0,0,0,r[6],r[7],1,-t[7]*r[6],-t[7]*r[7]]],a={},n=Ud(e,8,0,0,0,a);if(n!==0){for(var i=[],o=0;o<8;o++)for(var s=0;s<8;s++)i[s]==null&&(i[s]=0),i[s]+=((o+s)%2?-1:1)*Ud(e,7,o===0?1:0,1<<o,1<<s,a)/n*t[o];return function(l,u,f){var v=u*i[6]+f*i[7]+1;l[0]=(u*i[0]+f*i[1]+i[2])/v,l[1]=(u*i[3]+f*i[4]+i[5])/v}}}var Tv="___zrEVENTSAVED",dc=[];function XR(r,t,e,a,n){return Yd(dc,t,a,n,!0)&&Yd(r,e,dc[0],dc[1])}function $R(r,t){r&&e(r),t&&e(t);function e(a){var n=a[Tv];n&&(n.clearMarkers&&n.clearMarkers(),delete a[Tv])}}function Yd(r,t,e,a,n){if(t.getBoundingClientRect&&Tt.domSupported&&!cA(t)){var i=t[Tv]||(t[Tv]={}),o=qR(t,i),s=KR(o,i,n);if(s)return s(r,e,a),!0}return!1}function qR(r,t){var e=t.markers;if(e)return e;e=t.markers=[];for(var a=["left","right"],n=["top","bottom"],i=0;i<4;i++){var o=document.createElement("div"),s=o.style,l=i%2,u=(i>>1)%2;s.cssText=["position: absolute","visibility: hidden","padding: 0","margin: 0","border-width: 0","user-select: none","width:0","height:0",a[l]+":0",n[u]+":0",a[1-l]+":auto",n[1-u]+":auto",""].join("!important;"),r.appendChild(o),e.push(o)}return t.clearMarkers=function(){A(e,function(f){f.parentNode&&f.parentNode.removeChild(f)})},e}function KR(r,t,e){for(var a=e?"invTrans":"trans",n=t[a],i=t.srcCoords,o=[],s=[],l=!0,u=0;u<4;u++){var f=r[u].getBoundingClientRect(),v=2*u,h=f.left,c=f.top;o.push(h,c),l=l&&i&&h===i[v]&&c===i[v+1],s.push(r[u].offsetLeft,r[u].offsetTop)}return l&&n?n:(t.srcCoords=o,t[a]=e?L_(s,o):L_(o,s))}function cA(r){return r.nodeName.toUpperCase()==="CANVAS"}var jR=/([&<>"'])/g,JR={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;"};function ze(r){return r==null?"":(r+"").replace(jR,function(t,e){return JR[e]})}var QR=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,gc=[],tk=Tt.browser.firefox&&+Tt.browser.version.split(".")[0]<39;function Zd(r,t,e,a){return e=e||{},a?I_(r,t,e):tk&&t.layerX!=null&&t.layerX!==t.offsetX?(e.zrX=t.layerX,e.zrY=t.layerY):t.offsetX!=null?(e.zrX=t.offsetX,e.zrY=t.offsetY):I_(r,t,e),e}function I_(r,t,e){if(Tt.domSupported&&r.getBoundingClientRect){var a=t.clientX,n=t.clientY;if(cA(r)){var i=r.getBoundingClientRect();e.zrX=a-i.left,e.zrY=n-i.top;return}else if(Yd(gc,r,a,n)){e.zrX=gc[0],e.zrY=gc[1];return}}e.zrX=e.zrY=0}function nm(r){return r||window.event}function mr(r,t,e){if(t=nm(t),t.zrX!=null)return t;var a=t.type,n=a&&a.indexOf("touch")>=0;if(n){var o=a!=="touchend"?t.targetTouches[0]:t.changedTouches[0];o&&Zd(r,o,t,e)}else{Zd(r,t,t,e);var i=ek(t);t.zrDelta=i?i/120:-(t.detail||0)/3}var s=t.button;return t.which==null&&s!==void 0&&QR.test(t.type)&&(t.which=s&1?1:s&2?3:s&4?2:0),t}function ek(r){var t=r.wheelDelta;if(t)return t;var e=r.deltaX,a=r.deltaY;if(e==null||a==null)return t;var n=Math.abs(a!==0?a:e),i=a>0?-1:a<0?1:e>0?-1:1;return 3*n*i}function Xd(r,t,e,a){r.addEventListener(t,e,a)}function rk(r,t,e,a){r.removeEventListener(t,e,a)}var Za=function(r){r.preventDefault(),r.stopPropagation(),r.cancelBubble=!0};function P_(r){return r.which===2||r.which===3}var ak=function(){function r(){this._track=[]}return r.prototype.recognize=function(t,e,a){return this._doTrack(t,e,a),this._recognize(t)},r.prototype.clear=function(){return this._track.length=0,this},r.prototype._doTrack=function(t,e,a){var n=t.touches;if(n){for(var i={points:[],touches:[],target:e,event:t},o=0,s=n.length;o<s;o++){var l=n[o],u=Zd(a,l,{});i.points.push([u.zrX,u.zrY]),i.touches.push(l)}this._track.push(i)}},r.prototype._recognize=function(t){for(var e in yc)if(yc.hasOwnProperty(e)){var a=yc[e](this._track,t);if(a)return a}},r}();function R_(r){var t=r[1][0]-r[0][0],e=r[1][1]-r[0][1];return Math.sqrt(t*t+e*e)}function nk(r){return[(r[0][0]+r[1][0])/2,(r[0][1]+r[1][1])/2]}var yc={pinch:function(r,t){var e=r.length;if(e){var a=(r[e-1]||{}).points,n=(r[e-2]||{}).points||a;if(n&&n.length>1&&a&&a.length>1){var i=R_(a)/R_(n);!isFinite(i)&&(i=1),t.pinchScale=i;var o=nk(a);return t.pinchX=o[0],t.pinchY=o[1],{type:"pinch",target:r[0].target,event:t}}}}};function me(){return[1,0,0,1,0,0]}function xu(r){return r[0]=1,r[1]=0,r[2]=0,r[3]=1,r[4]=0,r[5]=0,r}function bu(r,t){return r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=t[3],r[4]=t[4],r[5]=t[5],r}function Gr(r,t,e){var a=t[0]*e[0]+t[2]*e[1],n=t[1]*e[0]+t[3]*e[1],i=t[0]*e[2]+t[2]*e[3],o=t[1]*e[2]+t[3]*e[3],s=t[0]*e[4]+t[2]*e[5]+t[4],l=t[1]*e[4]+t[3]*e[5]+t[5];return r[0]=a,r[1]=n,r[2]=i,r[3]=o,r[4]=s,r[5]=l,r}function Ur(r,t,e){return r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=t[3],r[4]=t[4]+e[0],r[5]=t[5]+e[1],r}function Qa(r,t,e,a){a===void 0&&(a=[0,0]);var n=t[0],i=t[2],o=t[4],s=t[1],l=t[3],u=t[5],f=Math.sin(e),v=Math.cos(e);return r[0]=n*v+s*f,r[1]=-n*f+s*v,r[2]=i*v+l*f,r[3]=-i*f+v*l,r[4]=v*(o-a[0])+f*(u-a[1])+a[0],r[5]=v*(u-a[1])-f*(o-a[0])+a[1],r}function Nh(r,t,e){var a=e[0],n=e[1];return r[0]=t[0]*a,r[1]=t[1]*n,r[2]=t[2]*a,r[3]=t[3]*n,r[4]=t[4]*a,r[5]=t[5]*n,r}function Dr(r,t){var e=t[0],a=t[2],n=t[4],i=t[1],o=t[3],s=t[5],l=e*o-i*a;return l?(l=1/l,r[0]=o*l,r[1]=-i*l,r[2]=-a*l,r[3]=e*l,r[4]=(a*s-o*n)*l,r[5]=(i*n-e*s)*l,r):null}function pA(r){var t=me();return bu(t,r),t}const dq=Object.freeze(Object.defineProperty({__proto__:null,clone:pA,copy:bu,create:me,identity:xu,invert:Dr,mul:Gr,rotate:Qa,scale:Nh,translate:Ur},Symbol.toStringTag,{value:"Module"}));var st=function(){function r(t,e){this.x=t||0,this.y=e||0}return r.prototype.copy=function(t){return this.x=t.x,this.y=t.y,this},r.prototype.clone=function(){return new r(this.x,this.y)},r.prototype.set=function(t,e){return this.x=t,this.y=e,this},r.prototype.equal=function(t){return t.x===this.x&&t.y===this.y},r.prototype.add=function(t){return this.x+=t.x,this.y+=t.y,this},r.prototype.scale=function(t){this.x*=t,this.y*=t},r.prototype.scaleAndAdd=function(t,e){this.x+=t.x*e,this.y+=t.y*e},r.prototype.sub=function(t){return this.x-=t.x,this.y-=t.y,this},r.prototype.dot=function(t){return this.x*t.x+this.y*t.y},r.prototype.len=function(){return Math.sqrt(this.x*this.x+this.y*this.y)},r.prototype.lenSquare=function(){return this.x*this.x+this.y*this.y},r.prototype.normalize=function(){var t=this.len();return this.x/=t,this.y/=t,this},r.prototype.distance=function(t){var e=this.x-t.x,a=this.y-t.y;return Math.sqrt(e*e+a*a)},r.prototype.distanceSquare=function(t){var e=this.x-t.x,a=this.y-t.y;return e*e+a*a},r.prototype.negate=function(){return this.x=-this.x,this.y=-this.y,this},r.prototype.transform=function(t){if(t){var e=this.x,a=this.y;return this.x=t[0]*e+t[2]*a+t[4],this.y=t[1]*e+t[3]*a+t[5],this}},r.prototype.toArray=function(t){return t[0]=this.x,t[1]=this.y,t},r.prototype.fromArray=function(t){this.x=t[0],this.y=t[1]},r.set=function(t,e,a){t.x=e,t.y=a},r.copy=function(t,e){t.x=e.x,t.y=e.y},r.len=function(t){return Math.sqrt(t.x*t.x+t.y*t.y)},r.lenSquare=function(t){return t.x*t.x+t.y*t.y},r.dot=function(t,e){return t.x*e.x+t.y*e.y},r.add=function(t,e,a){t.x=e.x+a.x,t.y=e.y+a.y},r.sub=function(t,e,a){t.x=e.x-a.x,t.y=e.y-a.y},r.scale=function(t,e,a){t.x=e.x*a,t.y=e.y*a},r.scaleAndAdd=function(t,e,a,n){t.x=e.x+a.x*n,t.y=e.y+a.y*n},r.lerp=function(t,e,a,n){var i=1-n;t.x=i*e.x+n*a.x,t.y=i*e.y+n*a.y},r}(),Ti=Math.min,Bo=Math.max,$d=Math.abs,k_=["x","y"],ik=["width","height"],Hn=new st,Wn=new st,Un=new st,Yn=new st,nr=dA(),hl=nr.minTv,qd=nr.maxTv,Dl=[0,0],lt=function(){function r(t,e,a,n){r.set(this,t,e,a,n)}return r.set=function(t,e,a,n,i){return n<0&&(e=e+n,n=-n),i<0&&(a=a+i,i=-i),t.x=e,t.y=a,t.width=n,t.height=i,t},r.prototype.union=function(t){var e=Ti(t.x,this.x),a=Ti(t.y,this.y);isFinite(this.x)&&isFinite(this.width)?this.width=Bo(t.x+t.width,this.x+this.width)-e:this.width=t.width,isFinite(this.y)&&isFinite(this.height)?this.height=Bo(t.y+t.height,this.y+this.height)-a:this.height=t.height,this.x=e,this.y=a},r.prototype.applyTransform=function(t){r.applyTransform(this,this,t)},r.prototype.calculateTransform=function(t){var e=this,a=t.width/e.width,n=t.height/e.height,i=me();return Ur(i,i,[-e.x,-e.y]),Nh(i,i,[a,n]),Ur(i,i,[t.x,t.y]),i},r.prototype.intersect=function(t,e,a){return r.intersect(this,t,e,a)},r.intersect=function(t,e,a,n){a&&st.set(a,0,0);var i=n&&n.outIntersectRect||null,o=n&&n.clamp;if(i&&(i.x=i.y=i.width=i.height=NaN),!t||!e)return!1;t instanceof r||(t=r.set(ok,t.x,t.y,t.width,t.height)),e instanceof r||(e=r.set(sk,e.x,e.y,e.width,e.height));var s=!!a;nr.reset(n,s);var l=nr.touchThreshold,u=t.x+l,f=t.x+t.width-l,v=t.y+l,h=t.y+t.height-l,c=e.x+l,p=e.x+e.width-l,d=e.y+l,g=e.y+e.height-l;if(u>f||v>h||c>p||d>g)return!1;var y=!(f<c||p<u||h<d||g<v);return(s||i)&&(Dl[0]=1/0,Dl[1]=0,E_(u,f,c,p,0,s,i,o),E_(v,h,d,g,1,s,i,o),s&&st.copy(a,y?nr.useDir?nr.dirMinTv:hl:qd)),y},r.contain=function(t,e,a){return e>=t.x&&e<=t.x+t.width&&a>=t.y&&a<=t.y+t.height},r.prototype.contain=function(t,e){return r.contain(this,t,e)},r.prototype.clone=function(){return new r(this.x,this.y,this.width,this.height)},r.prototype.copy=function(t){r.copy(this,t)},r.prototype.plain=function(){return{x:this.x,y:this.y,width:this.width,height:this.height}},r.prototype.isFinite=function(){return isFinite(this.x)&&isFinite(this.y)&&isFinite(this.width)&&isFinite(this.height)},r.prototype.isZero=function(){return this.width===0||this.height===0},r.create=function(t){return new r(t.x,t.y,t.width,t.height)},r.copy=function(t,e){return t.x=e.x,t.y=e.y,t.width=e.width,t.height=e.height,t},r.applyTransform=function(t,e,a){if(!a){t!==e&&r.copy(t,e);return}if(a[1]<1e-5&&a[1]>-1e-5&&a[2]<1e-5&&a[2]>-1e-5){var n=a[0],i=a[3],o=a[4],s=a[5];t.x=e.x*n+o,t.y=e.y*i+s,t.width=e.width*n,t.height=e.height*i,t.width<0&&(t.x+=t.width,t.width=-t.width),t.height<0&&(t.y+=t.height,t.height=-t.height);return}Hn.x=Un.x=e.x,Hn.y=Yn.y=e.y,Wn.x=Yn.x=e.x+e.width,Wn.y=Un.y=e.y+e.height,Hn.transform(a),Yn.transform(a),Wn.transform(a),Un.transform(a),t.x=Ti(Hn.x,Wn.x,Un.x,Yn.x),t.y=Ti(Hn.y,Wn.y,Un.y,Yn.y);var l=Bo(Hn.x,Wn.x,Un.x,Yn.x),u=Bo(Hn.y,Wn.y,Un.y,Yn.y);t.width=l-t.x,t.height=u-t.y},r}(),ok=new lt(0,0,0,0),sk=new lt(0,0,0,0);function E_(r,t,e,a,n,i,o,s){var l=$d(t-e),u=$d(a-r),f=Ti(l,u),v=k_[n],h=k_[1-n],c=ik[n];t<e||a<r?l<u?(i&&(qd[v]=-l),s&&(o[v]=t,o[c]=0)):(i&&(qd[v]=u),s&&(o[v]=r,o[c]=0)):(o&&(o[v]=Bo(r,e),o[c]=Ti(t,a)-o[v]),i&&(f<Dl[0]||nr.useDir)&&(Dl[0]=Ti(f,Dl[0]),(l<u||!nr.bidirectional)&&(hl[v]=l,hl[h]=0,nr.useDir&&nr.calcDirMTV()),(l>=u||!nr.bidirectional)&&(hl[v]=-u,hl[h]=0,nr.useDir&&nr.calcDirMTV())))}function dA(){var r=0,t=new st,e=new st,a={minTv:new st,maxTv:new st,useDir:!1,dirMinTv:new st,touchThreshold:0,bidirectional:!0,negativeSize:!1,reset:function(i,o){a.touchThreshold=0,i&&i.touchThreshold!=null&&(a.touchThreshold=Bo(0,i.touchThreshold)),a.negativeSize=!1,o&&(a.minTv.set(1/0,1/0),a.maxTv.set(0,0),a.useDir=!1,i&&i.direction!=null&&(a.useDir=!0,a.dirMinTv.copy(a.minTv),e.copy(a.minTv),r=i.direction,a.bidirectional=i.bidirectional==null||!!i.bidirectional,a.bidirectional||t.set(Math.cos(r),Math.sin(r))))},calcDirMTV:function(){var i=a.minTv,o=a.dirMinTv,s=i.y*i.y+i.x*i.x,l=Math.sin(r),u=Math.cos(r),f=l*i.y+u*i.x;if(n(f)){n(i.x)&&n(i.y)&&o.set(0,0);return}if(e.x=s*u/f,e.y=s*l/f,n(e.x)&&n(e.y)){o.set(0,0);return}(a.bidirectional||t.dot(e)>0)&&e.len()<o.len()&&o.copy(e)}};function n(i){return $d(i)<1e-10}return a}var gA="silent";function lk(r,t,e){return{type:r,event:e,target:t.target,topTarget:t.topTarget,cancelBubble:!1,offsetX:e.zrX,offsetY:e.zrY,gestureEvent:e.gestureEvent,pinchX:e.pinchX,pinchY:e.pinchY,pinchScale:e.pinchScale,wheelDelta:e.zrDelta,zrByTouch:e.zrByTouch,which:e.which,stop:uk}}function uk(){Za(this.event)}var fk=function(r){Zt(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.handler=null,e}return t.prototype.dispose=function(){},t.prototype.setCursor=function(){},t}(Pr),Es=function(){function r(t,e){this.x=t,this.y=e}return r}(),vk=["click","dblclick","mousewheel","mouseout","mouseup","mousedown","mousemove","contextmenu"],mc=new lt(0,0,0,0),yA=function(r){Zt(t,r);function t(e,a,n,i,o){var s=r.call(this)||this;return s._hovered=new Es(0,0),s.storage=e,s.painter=a,s.painterRoot=i,s._pointerSize=o,n=n||new fk,s.proxy=null,s.setHandlerProxy(n),s._draggingMgr=new YR(s),s}return t.prototype.setHandlerProxy=function(e){this.proxy&&this.proxy.dispose(),e&&(A(vk,function(a){e.on&&e.on(a,this[a],this)},this),e.handler=this),this.proxy=e},t.prototype.mousemove=function(e){var a=e.zrX,n=e.zrY,i=mA(this,a,n),o=this._hovered,s=o.target;s&&!s.__zr&&(o=this.findHover(o.x,o.y),s=o.target);var l=this._hovered=i?new Es(a,n):this.findHover(a,n),u=l.target,f=this.proxy;f.setCursor&&f.setCursor(u?u.cursor:"default"),s&&u!==s&&this.dispatchToElement(o,"mouseout",e),this.dispatchToElement(l,"mousemove",e),u&&u!==s&&this.dispatchToElement(l,"mouseover",e)},t.prototype.mouseout=function(e){var a=e.zrEventControl;a!=="only_globalout"&&this.dispatchToElement(this._hovered,"mouseout",e),a!=="no_globalout"&&this.trigger("globalout",{type:"globalout",event:e})},t.prototype.resize=function(){this._hovered=new Es(0,0)},t.prototype.dispatch=function(e,a){var n=this[e];n&&n.call(this,a)},t.prototype.dispose=function(){this.proxy.dispose(),this.storage=null,this.proxy=null,this.painter=null},t.prototype.setCursorStyle=function(e){var a=this.proxy;a.setCursor&&a.setCursor(e)},t.prototype.dispatchToElement=function(e,a,n){e=e||{};var i=e.target;if(!(i&&i.silent)){for(var o="on"+a,s=lk(a,e,n);i&&(i[o]&&(s.cancelBubble=!!i[o].call(i,s)),i.trigger(a,s),i=i.__hostTarget?i.__hostTarget:i.parent,!s.cancelBubble););s.cancelBubble||(this.trigger(a,s),this.painter&&this.painter.eachOtherLayer&&this.painter.eachOtherLayer(function(l){typeof l[o]=="function"&&l[o].call(l,s),l.trigger&&l.trigger(a,s)}))}},t.prototype.findHover=function(e,a,n){var i=this.storage.getDisplayList(),o=new Es(e,a);if(O_(i,o,e,a,n),this._pointerSize&&!o.target){for(var s=[],l=this._pointerSize,u=l/2,f=new lt(e-u,a-u,l,l),v=i.length-1;v>=0;v--){var h=i[v];h!==n&&!h.ignore&&!h.ignoreCoarsePointer&&(!h.parent||!h.parent.ignoreCoarsePointer)&&(mc.copy(h.getBoundingRect()),h.transform&&mc.applyTransform(h.transform),mc.intersect(f)&&s.push(h))}if(s.length)for(var c=4,p=Math.PI/12,d=Math.PI*2,g=0;g<u;g+=c)for(var y=0;y<d;y+=p){var m=e+g*Math.cos(y),_=a+g*Math.sin(y);if(O_(s,o,m,_,n),o.target)return o}}return o},t.prototype.processGesture=function(e,a){this._gestureMgr||(this._gestureMgr=new ak);var n=this._gestureMgr;a==="start"&&n.clear();var i=n.recognize(e,this.findHover(e.zrX,e.zrY,null).target,this.proxy.dom);if(a==="end"&&n.clear(),i){var o=i.type;e.gestureEvent=o;var s=new Es;s.target=i.target,this.dispatchToElement(s,o,i.event)}},t}(Pr);A(["click","mousedown","mouseup","mousewheel","dblclick","contextmenu"],function(r){yA.prototype[r]=function(t){var e=t.zrX,a=t.zrY,n=mA(this,e,a),i,o;if((r!=="mouseup"||!n)&&(i=this.findHover(e,a),o=i.target),r==="mousedown")this._downEl=o,this._downPoint=[t.zrX,t.zrY],this._upEl=o;else if(r==="mouseup")this._upEl=o;else if(r==="click"){if(this._downEl!==this._upEl||!this._downPoint||Ea(this._downPoint,[t.zrX,t.zrY])>4)return;this._downPoint=null}this.dispatchToElement(i,r,t)}});function hk(r,t,e){if(r[r.rectHover?"rectContain":"contain"](t,e)){for(var a=r,n=void 0,i=!1;a;){if(a.ignoreClip&&(i=!0),!i){var o=a.getClipPath();if(o&&!o.contain(t,e))return!1}a.silent&&(n=!0);var s=a.__hostTarget;a=s?a.ignoreHostSilent?null:s:a.parent}return n?gA:!0}return!1}function O_(r,t,e,a,n){for(var i=r.length-1;i>=0;i--){var o=r[i],s=void 0;if(o!==n&&!o.ignore&&(s=hk(o,e,a))&&(!t.topTarget&&(t.topTarget=o),s!==gA)){t.target=o;break}}}function mA(r,t,e){var a=r.painter;return t<0||t>a.getWidth()||e<0||e>a.getHeight()}var _A=32,Os=7;function ck(r){for(var t=0;r>=_A;)t|=r&1,r>>=1;return r+t}function N_(r,t,e,a){var n=t+1;if(n===e)return 1;if(a(r[n++],r[t])<0){for(;n<e&&a(r[n],r[n-1])<0;)n++;pk(r,t,n)}else for(;n<e&&a(r[n],r[n-1])>=0;)n++;return n-t}function pk(r,t,e){for(e--;t<e;){var a=r[t];r[t++]=r[e],r[e--]=a}}function B_(r,t,e,a,n){for(a===t&&a++;a<e;a++){for(var i=r[a],o=t,s=a,l;o<s;)l=o+s>>>1,n(i,r[l])<0?s=l:o=l+1;var u=a-o;switch(u){case 3:r[o+3]=r[o+2];case 2:r[o+2]=r[o+1];case 1:r[o+1]=r[o];break;default:for(;u>0;)r[o+u]=r[o+u-1],u--}r[o]=i}}function _c(r,t,e,a,n,i){var o=0,s=0,l=1;if(i(r,t[e+n])>0){for(s=a-n;l<s&&i(r,t[e+n+l])>0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s),o+=n,l+=n}else{for(s=n+1;l<s&&i(r,t[e+n-l])<=0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s);var u=o;o=n-l,l=n-u}for(o++;o<l;){var f=o+(l-o>>>1);i(r,t[e+f])>0?o=f+1:l=f}return l}function Sc(r,t,e,a,n,i){var o=0,s=0,l=1;if(i(r,t[e+n])<0){for(s=n+1;l<s&&i(r,t[e+n-l])<0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s);var u=o;o=n-l,l=n-u}else{for(s=a-n;l<s&&i(r,t[e+n+l])>=0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s),o+=n,l+=n}for(o++;o<l;){var f=o+(l-o>>>1);i(r,t[e+f])<0?l=f:o=f+1}return l}function dk(r,t){var e=Os,a,n,i=0,o=[];a=[],n=[];function s(c,p){a[i]=c,n[i]=p,i+=1}function l(){for(;i>1;){var c=i-2;if(c>=1&&n[c-1]<=n[c]+n[c+1]||c>=2&&n[c-2]<=n[c]+n[c-1])n[c-1]<n[c+1]&&c--;else if(n[c]>n[c+1])break;f(c)}}function u(){for(;i>1;){var c=i-2;c>0&&n[c-1]<n[c+1]&&c--,f(c)}}function f(c){var p=a[c],d=n[c],g=a[c+1],y=n[c+1];n[c]=d+y,c===i-3&&(a[c+1]=a[c+2],n[c+1]=n[c+2]),i--;var m=Sc(r[g],r,p,d,0,t);p+=m,d-=m,d!==0&&(y=_c(r[p+d-1],r,g,y,y-1,t),y!==0&&(d<=y?v(p,d,g,y):h(p,d,g,y)))}function v(c,p,d,g){var y=0;for(y=0;y<p;y++)o[y]=r[c+y];var m=0,_=d,S=c;if(r[S++]=r[_++],--g===0){for(y=0;y<p;y++)r[S+y]=o[m+y];return}if(p===1){for(y=0;y<g;y++)r[S+y]=r[_+y];r[S+g]=o[m];return}for(var x=e,b,w,T;;){b=0,w=0,T=!1;do if(t(r[_],o[m])<0){if(r[S++]=r[_++],w++,b=0,--g===0){T=!0;break}}else if(r[S++]=o[m++],b++,w=0,--p===1){T=!0;break}while((b|w)<x);if(T)break;do{if(b=Sc(r[_],o,m,p,0,t),b!==0){for(y=0;y<b;y++)r[S+y]=o[m+y];if(S+=b,m+=b,p-=b,p<=1){T=!0;break}}if(r[S++]=r[_++],--g===0){T=!0;break}if(w=_c(o[m],r,_,g,0,t),w!==0){for(y=0;y<w;y++)r[S+y]=r[_+y];if(S+=w,_+=w,g-=w,g===0){T=!0;break}}if(r[S++]=o[m++],--p===1){T=!0;break}x--}while(b>=Os||w>=Os);if(T)break;x<0&&(x=0),x+=2}if(e=x,e<1&&(e=1),p===1){for(y=0;y<g;y++)r[S+y]=r[_+y];r[S+g]=o[m]}else{if(p===0)throw new Error;for(y=0;y<p;y++)r[S+y]=o[m+y]}}function h(c,p,d,g){var y=0;for(y=0;y<g;y++)o[y]=r[d+y];var m=c+p-1,_=g-1,S=d+g-1,x=0,b=0;if(r[S--]=r[m--],--p===0){for(x=S-(g-1),y=0;y<g;y++)r[x+y]=o[y];return}if(g===1){for(S-=p,m-=p,b=S+1,x=m+1,y=p-1;y>=0;y--)r[b+y]=r[x+y];r[S]=o[_];return}for(var w=e;;){var T=0,C=0,M=!1;do if(t(o[_],r[m])<0){if(r[S--]=r[m--],T++,C=0,--p===0){M=!0;break}}else if(r[S--]=o[_--],C++,T=0,--g===1){M=!0;break}while((T|C)<w);if(M)break;do{if(T=p-Sc(o[_],r,c,p,p-1,t),T!==0){for(S-=T,m-=T,p-=T,b=S+1,x=m+1,y=T-1;y>=0;y--)r[b+y]=r[x+y];if(p===0){M=!0;break}}if(r[S--]=o[_--],--g===1){M=!0;break}if(C=g-_c(r[m],o,0,g,g-1,t),C!==0){for(S-=C,_-=C,g-=C,b=S+1,x=_+1,y=0;y<C;y++)r[b+y]=o[x+y];if(g<=1){M=!0;break}}if(r[S--]=r[m--],--p===0){M=!0;break}w--}while(T>=Os||C>=Os);if(M)break;w<0&&(w=0),w+=2}if(e=w,e<1&&(e=1),g===1){for(S-=p,m-=p,b=S+1,x=m+1,y=p-1;y>=0;y--)r[b+y]=r[x+y];r[S]=o[_]}else{if(g===0)throw new Error;for(x=S-(g-1),y=0;y<g;y++)r[x+y]=o[y]}}return{mergeRuns:l,forceMergeRuns:u,pushRun:s}}function tv(r,t,e,a){e||(e=0),a||(a=r.length);var n=a-e;if(!(n<2)){var i=0;if(n<_A){i=N_(r,e,a,t),B_(r,e,a,e+i,t);return}var o=dk(r,t),s=ck(n);do{if(i=N_(r,e,a,t),i<s){var l=n;l>s&&(l=s),B_(r,e,e+l,e+i,t),i=l}o.pushRun(e,i),o.mergeRuns(),n-=i,e+=i}while(n!==0);o.forceMergeRuns()}}var ir=1,cl=2,ko=4,z_=!1;function xc(){z_||(z_=!0,console.warn("z / z2 / zlevel of displayable is invalid, which may cause unexpected errors"))}function V_(r,t){return r.zlevel===t.zlevel?r.z===t.z?r.z2-t.z2:r.z-t.z:r.zlevel-t.zlevel}var gk=function(){function r(){this._roots=[],this._displayList=[],this._displayListLen=0,this.displayableSortFunc=V_}return r.prototype.traverse=function(t,e){for(var a=0;a<this._roots.length;a++)this._roots[a].traverse(t,e)},r.prototype.getDisplayList=function(t,e){e=e||!1;var a=this._displayList;return(t||!a.length)&&this.updateDisplayList(e),a},r.prototype.updateDisplayList=function(t){this._displayListLen=0;for(var e=this._roots,a=this._displayList,n=0,i=e.length;n<i;n++)this._updateAndAddDisplayable(e[n],null,t);a.length=this._displayListLen,tv(a,V_)},r.prototype._updateAndAddDisplayable=function(t,e,a){if(!(t.ignore&&!a)){t.beforeUpdate(),t.update(),t.afterUpdate();var n=t.getClipPath(),i=e&&e.length,o=0,s=t.__clipPaths;if(!t.ignoreClip&&(i||n)){if(s||(s=t.__clipPaths=[]),i)for(var l=0;l<e.length;l++)s[o++]=e[l];for(var u=n,f=t;u;)u.parent=f,u.updateTransform(),s[o++]=u,f=u,u=u.getClipPath()}if(s&&(s.length=o),t.childrenRef){for(var v=t.childrenRef(),h=0;h<v.length;h++){var c=v[h];t.__dirty&&(c.__dirty|=ir),this._updateAndAddDisplayable(c,s,a)}t.__dirty=0}else{var p=t;isNaN(p.z)&&(xc(),p.z=0),isNaN(p.z2)&&(xc(),p.z2=0),isNaN(p.zlevel)&&(xc(),p.zlevel=0),this._displayList[this._displayListLen++]=p}var d=t.getDecalElement&&t.getDecalElement();d&&this._updateAndAddDisplayable(d,s,a);var g=t.getTextGuideLine();g&&this._updateAndAddDisplayable(g,s,a);var y=t.getTextContent();y&&this._updateAndAddDisplayable(y,s,a)}},r.prototype.addRoot=function(t){t.__zr&&t.__zr.storage===this||this._roots.push(t)},r.prototype.delRoot=function(t){if(t instanceof Array){for(var e=0,a=t.length;e<a;e++)this.delRoot(t[e]);return}var n=gt(this._roots,t);n>=0&&this._roots.splice(n,1)},r.prototype.delAllRoots=function(){this._roots=[],this._displayList=[],this._displayListLen=0},r.prototype.getRoots=function(){return this._roots},r.prototype.dispose=function(){this._displayList=null,this._roots=null},r}(),Cv;Cv=Tt.hasGlobalWindow&&(window.requestAnimationFrame&&window.requestAnimationFrame.bind(window)||window.msRequestAnimationFrame&&window.msRequestAnimationFrame.bind(window)||window.mozRequestAnimationFrame||window.webkitRequestAnimationFrame)||function(r){return setTimeout(r,16)};var Ll={linear:function(r){return r},quadraticIn:function(r){return r*r},quadraticOut:function(r){return r*(2-r)},quadraticInOut:function(r){return(r*=2)<1?.5*r*r:-.5*(--r*(r-2)-1)},cubicIn:function(r){return r*r*r},cubicOut:function(r){return--r*r*r+1},cubicInOut:function(r){return(r*=2)<1?.5*r*r*r:.5*((r-=2)*r*r+2)},quarticIn:function(r){return r*r*r*r},quarticOut:function(r){return 1- --r*r*r*r},quarticInOut:function(r){return(r*=2)<1?.5*r*r*r*r:-.5*((r-=2)*r*r*r-2)},quinticIn:function(r){return r*r*r*r*r},quinticOut:function(r){return--r*r*r*r*r+1},quinticInOut:function(r){return(r*=2)<1?.5*r*r*r*r*r:.5*((r-=2)*r*r*r*r+2)},sinusoidalIn:function(r){return 1-Math.cos(r*Math.PI/2)},sinusoidalOut:function(r){return Math.sin(r*Math.PI/2)},sinusoidalInOut:function(r){return .5*(1-Math.cos(Math.PI*r))},exponentialIn:function(r){return r===0?0:Math.pow(1024,r-1)},exponentialOut:function(r){return r===1?1:1-Math.pow(2,-10*r)},exponentialInOut:function(r){return r===0?0:r===1?1:(r*=2)<1?.5*Math.pow(1024,r-1):.5*(-Math.pow(2,-10*(r-1))+2)},circularIn:function(r){return 1-Math.sqrt(1-r*r)},circularOut:function(r){return Math.sqrt(1- --r*r)},circularInOut:function(r){return(r*=2)<1?-.5*(Math.sqrt(1-r*r)-1):.5*(Math.sqrt(1-(r-=2)*r)+1)},elasticIn:function(r){var t,e=.1,a=.4;return r===0?0:r===1?1:(!e||e<1?(e=1,t=a/4):t=a*Math.asin(1/e)/(2*Math.PI),-(e*Math.pow(2,10*(r-=1))*Math.sin((r-t)*(2*Math.PI)/a)))},elasticOut:function(r){var t,e=.1,a=.4;return r===0?0:r===1?1:(!e||e<1?(e=1,t=a/4):t=a*Math.asin(1/e)/(2*Math.PI),e*Math.pow(2,-10*r)*Math.sin((r-t)*(2*Math.PI)/a)+1)},elasticInOut:function(r){var t,e=.1,a=.4;return r===0?0:r===1?1:(!e||e<1?(e=1,t=a/4):t=a*Math.asin(1/e)/(2*Math.PI),(r*=2)<1?-.5*(e*Math.pow(2,10*(r-=1))*Math.sin((r-t)*(2*Math.PI)/a)):e*Math.pow(2,-10*(r-=1))*Math.sin((r-t)*(2*Math.PI)/a)*.5+1)},backIn:function(r){var t=1.70158;return r*r*((t+1)*r-t)},backOut:function(r){var t=1.70158;return--r*r*((t+1)*r+t)+1},backInOut:function(r){var t=2.5949095;return(r*=2)<1?.5*(r*r*((t+1)*r-t)):.5*((r-=2)*r*((t+1)*r+t)+2)},bounceIn:function(r){return 1-Ll.bounceOut(1-r)},bounceOut:function(r){return r<1/2.75?7.5625*r*r:r<2/2.75?7.5625*(r-=1.5/2.75)*r+.75:r<2.5/2.75?7.5625*(r-=2.25/2.75)*r+.9375:7.5625*(r-=2.625/2.75)*r+.984375},bounceInOut:function(r){return r<.5?Ll.bounceIn(r*2)*.5:Ll.bounceOut(r*2-1)*.5+.5}},Gu=Math.pow,wn=Math.sqrt,Av=1e-8,SA=1e-4,G_=wn(3),Fu=1/3,ia=Bn(),br=Bn(),Yo=Bn();function gn(r){return r>-Av&&r<Av}function xA(r){return r>Av||r<-Av}function ge(r,t,e,a,n){var i=1-n;return i*i*(i*r+3*n*t)+n*n*(n*a+3*i*e)}function F_(r,t,e,a,n){var i=1-n;return 3*(((t-r)*i+2*(e-t)*n)*i+(a-e)*n*n)}function Mv(r,t,e,a,n,i){var o=a+3*(t-e)-r,s=3*(e-t*2+r),l=3*(t-r),u=r-n,f=s*s-3*o*l,v=s*l-9*o*u,h=l*l-3*s*u,c=0;if(gn(f)&&gn(v))if(gn(s))i[0]=0;else{var p=-l/s;p>=0&&p<=1&&(i[c++]=p)}else{var d=v*v-4*f*h;if(gn(d)){var g=v/f,p=-s/o+g,y=-g/2;p>=0&&p<=1&&(i[c++]=p),y>=0&&y<=1&&(i[c++]=y)}else if(d>0){var m=wn(d),_=f*s+1.5*o*(-v+m),S=f*s+1.5*o*(-v-m);_<0?_=-Gu(-_,Fu):_=Gu(_,Fu),S<0?S=-Gu(-S,Fu):S=Gu(S,Fu);var p=(-s-(_+S))/(3*o);p>=0&&p<=1&&(i[c++]=p)}else{var x=(2*f*s-3*o*v)/(2*wn(f*f*f)),b=Math.acos(x)/3,w=wn(f),T=Math.cos(b),p=(-s-2*w*T)/(3*o),y=(-s+w*(T+G_*Math.sin(b)))/(3*o),C=(-s+w*(T-G_*Math.sin(b)))/(3*o);p>=0&&p<=1&&(i[c++]=p),y>=0&&y<=1&&(i[c++]=y),C>=0&&C<=1&&(i[c++]=C)}}return c}function bA(r,t,e,a,n){var i=6*e-12*t+6*r,o=9*t+3*a-3*r-9*e,s=3*t-3*r,l=0;if(gn(o)){if(xA(i)){var u=-s/i;u>=0&&u<=1&&(n[l++]=u)}}else{var f=i*i-4*o*s;if(gn(f))n[0]=-i/(2*o);else if(f>0){var v=wn(f),u=(-i+v)/(2*o),h=(-i-v)/(2*o);u>=0&&u<=1&&(n[l++]=u),h>=0&&h<=1&&(n[l++]=h)}}return l}function In(r,t,e,a,n,i){var o=(t-r)*n+r,s=(e-t)*n+t,l=(a-e)*n+e,u=(s-o)*n+o,f=(l-s)*n+s,v=(f-u)*n+u;i[0]=r,i[1]=o,i[2]=u,i[3]=v,i[4]=v,i[5]=f,i[6]=l,i[7]=a}function wA(r,t,e,a,n,i,o,s,l,u,f){var v,h=.005,c=1/0,p,d,g,y;ia[0]=l,ia[1]=u;for(var m=0;m<1;m+=.05)br[0]=ge(r,e,n,o,m),br[1]=ge(t,a,i,s,m),g=bn(ia,br),g<c&&(v=m,c=g);c=1/0;for(var _=0;_<32&&!(h<SA);_++)p=v-h,d=v+h,br[0]=ge(r,e,n,o,p),br[1]=ge(t,a,i,s,p),g=bn(br,ia),p>=0&&g<c?(v=p,c=g):(Yo[0]=ge(r,e,n,o,d),Yo[1]=ge(t,a,i,s,d),y=bn(Yo,ia),d<=1&&y<c?(v=d,c=y):h*=.5);return f&&(f[0]=ge(r,e,n,o,v),f[1]=ge(t,a,i,s,v)),wn(c)}function yk(r,t,e,a,n,i,o,s,l){for(var u=r,f=t,v=0,h=1/l,c=1;c<=l;c++){var p=c*h,d=ge(r,e,n,o,p),g=ge(t,a,i,s,p),y=d-u,m=g-f;v+=Math.sqrt(y*y+m*m),u=d,f=g}return v}function Te(r,t,e,a){var n=1-a;return n*(n*r+2*a*t)+a*a*e}function Kd(r,t,e,a){return 2*((1-a)*(t-r)+a*(e-t))}function mk(r,t,e,a,n){var i=r-2*t+e,o=2*(t-r),s=r-a,l=0;if(gn(i)){if(xA(o)){var u=-s/o;u>=0&&u<=1&&(n[l++]=u)}}else{var f=o*o-4*i*s;if(gn(f)){var u=-o/(2*i);u>=0&&u<=1&&(n[l++]=u)}else if(f>0){var v=wn(f),u=(-o+v)/(2*i),h=(-o-v)/(2*i);u>=0&&u<=1&&(n[l++]=u),h>=0&&h<=1&&(n[l++]=h)}}return l}function TA(r,t,e){var a=r+e-2*t;return a===0?.5:(r-t)/a}function Hl(r,t,e,a,n){var i=(t-r)*a+r,o=(e-t)*a+t,s=(o-i)*a+i;n[0]=r,n[1]=i,n[2]=s,n[3]=s,n[4]=o,n[5]=e}function CA(r,t,e,a,n,i,o,s,l){var u,f=.005,v=1/0;ia[0]=o,ia[1]=s;for(var h=0;h<1;h+=.05){br[0]=Te(r,e,n,h),br[1]=Te(t,a,i,h);var c=bn(ia,br);c<v&&(u=h,v=c)}v=1/0;for(var p=0;p<32&&!(f<SA);p++){var d=u-f,g=u+f;br[0]=Te(r,e,n,d),br[1]=Te(t,a,i,d);var c=bn(br,ia);if(d>=0&&c<v)u=d,v=c;else{Yo[0]=Te(r,e,n,g),Yo[1]=Te(t,a,i,g);var y=bn(Yo,ia);g<=1&&y<v?(u=g,v=y):f*=.5}}return l&&(l[0]=Te(r,e,n,u),l[1]=Te(t,a,i,u)),wn(v)}function _k(r,t,e,a,n,i,o){for(var s=r,l=t,u=0,f=1/o,v=1;v<=o;v++){var h=v*f,c=Te(r,e,n,h),p=Te(t,a,i,h),d=c-s,g=p-l;u+=Math.sqrt(d*d+g*g),s=c,l=p}return u}var Sk=/cubic-bezier\(([0-9,\.e ]+)\)/;function im(r){var t=r&&Sk.exec(r);if(t){var e=t[1].split(","),a=+sr(e[0]),n=+sr(e[1]),i=+sr(e[2]),o=+sr(e[3]);if(isNaN(a+n+i+o))return;var s=[];return function(l){return l<=0?0:l>=1?1:Mv(0,a,i,1,l,s)&&ge(0,n,o,1,s[0])}}}var xk=function(){function r(t){this._inited=!1,this._startTime=0,this._pausedTime=0,this._paused=!1,this._life=t.life||1e3,this._delay=t.delay||0,this.loop=t.loop||!1,this.onframe=t.onframe||jt,this.ondestroy=t.ondestroy||jt,this.onrestart=t.onrestart||jt,t.easing&&this.setEasing(t.easing)}return r.prototype.step=function(t,e){if(this._inited||(this._startTime=t+this._delay,this._inited=!0),this._paused){this._pausedTime+=e;return}var a=this._life,n=t-this._startTime-this._pausedTime,i=n/a;i<0&&(i=0),i=Math.min(i,1);var o=this.easingFunc,s=o?o(i):i;if(this.onframe(s),i===1)if(this.loop){var l=n%a;this._startTime=t-l,this._pausedTime=0,this.onrestart()}else return!0;return!1},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){this._paused=!1},r.prototype.setEasing=function(t){this.easing=t,this.easingFunc=tt(t)?t:Ll[t]||im(t)},r}(),AA=function(){function r(t){this.value=t}return r}(),bk=function(){function r(){this._len=0}return r.prototype.insert=function(t){var e=new AA(t);return this.insertEntry(e),e},r.prototype.insertEntry=function(t){this.head?(this.tail.next=t,t.prev=this.tail,t.next=null,this.tail=t):this.head=this.tail=t,this._len++},r.prototype.remove=function(t){var e=t.prev,a=t.next;e?e.next=a:this.head=a,a?a.prev=e:this.tail=e,t.next=t.prev=null,this._len--},r.prototype.len=function(){return this._len},r.prototype.clear=function(){this.head=this.tail=null,this._len=0},r}(),jo=function(){function r(t){this._list=new bk,this._maxSize=10,this._map={},this._maxSize=t}return r.prototype.put=function(t,e){var a=this._list,n=this._map,i=null;if(n[t]==null){var o=a.len(),s=this._lastRemovedEntry;if(o>=this._maxSize&&o>0){var l=a.head;a.remove(l),delete n[l.key],i=l.value,this._lastRemovedEntry=l}s?s.value=e:s=new AA(e),s.key=t,a.insertEntry(s),n[t]=s}return i},r.prototype.get=function(t){var e=this._map[t],a=this._list;if(e!=null)return e!==a.tail&&(a.remove(e),a.insertEntry(e)),e.value},r.prototype.clear=function(){this._list.clear(),this._map={}},r.prototype.len=function(){return this._list.len()},r}(),H_={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function Fr(r){return r=Math.round(r),r<0?0:r>255?255:r}function wk(r){return r=Math.round(r),r<0?0:r>360?360:r}function Wl(r){return r<0?0:r>1?1:r}function ev(r){var t=r;return t.length&&t.charAt(t.length-1)==="%"?Fr(parseFloat(t)/100*255):Fr(parseInt(t,10))}function Va(r){var t=r;return t.length&&t.charAt(t.length-1)==="%"?Wl(parseFloat(t)/100):Wl(parseFloat(t))}function bc(r,t,e){return e<0?e+=1:e>1&&(e-=1),e*6<1?r+(t-r)*e*6:e*2<1?t:e*3<2?r+(t-r)*(2/3-e)*6:r}function yn(r,t,e){return r+(t-r)*e}function yr(r,t,e,a,n){return r[0]=t,r[1]=e,r[2]=a,r[3]=n,r}function jd(r,t){return r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=t[3],r}var MA=new jo(20),Hu=null;function so(r,t){Hu&&jd(Hu,t),Hu=MA.put(r,Hu||t.slice())}function Ve(r,t){if(r){t=t||[];var e=MA.get(r);if(e)return jd(t,e);r=r+"";var a=r.replace(/ /g,"").toLowerCase();if(a in H_)return jd(t,H_[a]),so(r,t),t;var n=a.length;if(a.charAt(0)==="#"){if(n===4||n===5){var i=parseInt(a.slice(1,4),16);if(!(i>=0&&i<=4095)){yr(t,0,0,0,1);return}return yr(t,(i&3840)>>4|(i&3840)>>8,i&240|(i&240)>>4,i&15|(i&15)<<4,n===5?parseInt(a.slice(4),16)/15:1),so(r,t),t}else if(n===7||n===9){var i=parseInt(a.slice(1,7),16);if(!(i>=0&&i<=16777215)){yr(t,0,0,0,1);return}return yr(t,(i&16711680)>>16,(i&65280)>>8,i&255,n===9?parseInt(a.slice(7),16)/255:1),so(r,t),t}return}var o=a.indexOf("("),s=a.indexOf(")");if(o!==-1&&s+1===n){var l=a.substr(0,o),u=a.substr(o+1,s-(o+1)).split(","),f=1;switch(l){case"rgba":if(u.length!==4)return u.length===3?yr(t,+u[0],+u[1],+u[2],1):yr(t,0,0,0,1);f=Va(u.pop());case"rgb":if(u.length>=3)return yr(t,ev(u[0]),ev(u[1]),ev(u[2]),u.length===3?f:Va(u[3])),so(r,t),t;yr(t,0,0,0,1);return;case"hsla":if(u.length!==4){yr(t,0,0,0,1);return}return u[3]=Va(u[3]),Jd(u,t),so(r,t),t;case"hsl":if(u.length!==3){yr(t,0,0,0,1);return}return Jd(u,t),so(r,t),t;default:return}}yr(t,0,0,0,1)}}function Jd(r,t){var e=(parseFloat(r[0])%360+360)%360/360,a=Va(r[1]),n=Va(r[2]),i=n<=.5?n*(a+1):n+a-n*a,o=n*2-i;return t=t||[],yr(t,Fr(bc(o,i,e+1/3)*255),Fr(bc(o,i,e)*255),Fr(bc(o,i,e-1/3)*255),1),r.length===4&&(t[3]=r[3]),t}function Tk(r){if(r){var t=r[0]/255,e=r[1]/255,a=r[2]/255,n=Math.min(t,e,a),i=Math.max(t,e,a),o=i-n,s=(i+n)/2,l,u;if(o===0)l=0,u=0;else{s<.5?u=o/(i+n):u=o/(2-i-n);var f=((i-t)/6+o/2)/o,v=((i-e)/6+o/2)/o,h=((i-a)/6+o/2)/o;t===i?l=h-v:e===i?l=1/3+f-h:a===i&&(l=2/3+v-f),l<0&&(l+=1),l>1&&(l-=1)}var c=[l*360,u,s];return r[3]!=null&&c.push(r[3]),c}}function Dv(r,t){var e=Ve(r);if(e){for(var a=0;a<3;a++)t<0?e[a]=e[a]*(1-t)|0:e[a]=(255-e[a])*t+e[a]|0,e[a]>255?e[a]=255:e[a]<0&&(e[a]=0);return Cr(e,e.length===4?"rgba":"rgb")}}function Ck(r){var t=Ve(r);if(t)return((1<<24)+(t[0]<<16)+(t[1]<<8)+ +t[2]).toString(16).slice(1)}function Il(r,t,e){if(!(!(t&&t.length)||!(r>=0&&r<=1))){e=e||[];var a=r*(t.length-1),n=Math.floor(a),i=Math.ceil(a),o=t[n],s=t[i],l=a-n;return e[0]=Fr(yn(o[0],s[0],l)),e[1]=Fr(yn(o[1],s[1],l)),e[2]=Fr(yn(o[2],s[2],l)),e[3]=Wl(yn(o[3],s[3],l)),e}}var Ak=Il;function om(r,t,e){if(!(!(t&&t.length)||!(r>=0&&r<=1))){var a=r*(t.length-1),n=Math.floor(a),i=Math.ceil(a),o=Ve(t[n]),s=Ve(t[i]),l=a-n,u=Cr([Fr(yn(o[0],s[0],l)),Fr(yn(o[1],s[1],l)),Fr(yn(o[2],s[2],l)),Wl(yn(o[3],s[3],l))],"rgba");return e?{color:u,leftIndex:n,rightIndex:i,value:a}:u}}var Mk=om;function Ga(r,t,e,a){var n=Ve(r);if(r)return n=Tk(n),t!=null&&(n[0]=wk(tt(t)?t(n[0]):t)),e!=null&&(n[1]=Va(tt(e)?e(n[1]):e)),a!=null&&(n[2]=Va(tt(a)?a(n[2]):a)),Cr(Jd(n),"rgba")}function Ul(r,t){var e=Ve(r);if(e&&t!=null)return e[3]=Wl(t),Cr(e,"rgba")}function Cr(r,t){if(!(!r||!r.length)){var e=r[0]+","+r[1]+","+r[2];return(t==="rgba"||t==="hsva"||t==="hsla")&&(e+=","+r[3]),t+"("+e+")"}}function Yl(r,t){var e=Ve(r);return e?(.299*e[0]+.587*e[1]+.114*e[2])*e[3]/255+(1-e[3])*t:0}function Dk(){return Cr([Math.round(Math.random()*255),Math.round(Math.random()*255),Math.round(Math.random()*255)],"rgb")}var W_=new jo(100);function Lv(r){if(X(r)){var t=W_.get(r);return t||(t=Dv(r,-.1),W_.put(r,t)),t}else if(mu(r)){var e=G({},r);return e.colorStops=U(r.colorStops,function(a){return{offset:a.offset,color:Dv(a.color,-.1)}}),e}return r}const gq=Object.freeze(Object.defineProperty({__proto__:null,fastLerp:Il,fastMapToColor:Ak,lerp:om,lift:Dv,liftColor:Lv,lum:Yl,mapToColor:Mk,modifyAlpha:Ul,modifyHSL:Ga,parse:Ve,parseCssFloat:Va,parseCssInt:ev,random:Dk,stringify:Cr,toHex:Ck},Symbol.toStringTag,{value:"Module"}));var Iv=Math.round;function Zl(r){var t;if(!r||r==="transparent")r="none";else if(typeof r=="string"&&r.indexOf("rgba")>-1){var e=Ve(r);e&&(r="rgb("+e[0]+","+e[1]+","+e[2]+")",t=e[3])}return{color:r,opacity:t??1}}var U_=1e-4;function mn(r){return r<U_&&r>-U_}function Wu(r){return Iv(r*1e3)/1e3}function Qd(r){return Iv(r*1e4)/1e4}function Lk(r){return"matrix("+Wu(r[0])+","+Wu(r[1])+","+Wu(r[2])+","+Wu(r[3])+","+Qd(r[4])+","+Qd(r[5])+")"}var Ik={left:"start",right:"end",center:"middle",middle:"middle"};function Pk(r,t,e){return e==="top"?r+=t/2:e==="bottom"&&(r-=t/2),r}function Rk(r){return r&&(r.shadowBlur||r.shadowOffsetX||r.shadowOffsetY)}function kk(r){var t=r.style,e=r.getGlobalScale();return[t.shadowColor,(t.shadowBlur||0).toFixed(2),(t.shadowOffsetX||0).toFixed(2),(t.shadowOffsetY||0).toFixed(2),e[0],e[1]].join(",")}function DA(r){return r&&!!r.image}function Ek(r){return r&&!!r.svgElement}function sm(r){return DA(r)||Ek(r)}function LA(r){return r.type==="linear"}function IA(r){return r.type==="radial"}function PA(r){return r&&(r.type==="linear"||r.type==="radial")}function Bh(r){return"url(#"+r+")"}function RA(r){var t=r.getGlobalScale(),e=Math.max(t[0],t[1]);return Math.max(Math.ceil(Math.log(e)/Math.log(10)),1)}function kA(r){var t=r.x||0,e=r.y||0,a=(r.rotation||0)*Cl,n=Q(r.scaleX,1),i=Q(r.scaleY,1),o=r.skewX||0,s=r.skewY||0,l=[];return(t||e)&&l.push("translate("+t+"px,"+e+"px)"),a&&l.push("rotate("+a+")"),(n!==1||i!==1)&&l.push("scale("+n+","+i+")"),(o||s)&&l.push("skew("+Iv(o*Cl)+"deg, "+Iv(s*Cl)+"deg)"),l.join(" ")}var Ok=function(){return Tt.hasGlobalWindow&&tt(window.btoa)?function(r){return window.btoa(unescape(encodeURIComponent(r)))}:typeof Buffer<"u"?function(r){return Buffer.from(r).toString("base64")}:function(r){return null}}(),tg=Array.prototype.slice;function Pa(r,t,e){return(t-r)*e+r}function wc(r,t,e,a){for(var n=t.length,i=0;i<n;i++)r[i]=Pa(t[i],e[i],a);return r}function Nk(r,t,e,a){for(var n=t.length,i=n&&t[0].length,o=0;o<n;o++){r[o]||(r[o]=[]);for(var s=0;s<i;s++)r[o][s]=Pa(t[o][s],e[o][s],a)}return r}function Uu(r,t,e,a){for(var n=t.length,i=0;i<n;i++)r[i]=t[i]+e[i]*a;return r}function Y_(r,t,e,a){for(var n=t.length,i=n&&t[0].length,o=0;o<n;o++){r[o]||(r[o]=[]);for(var s=0;s<i;s++)r[o][s]=t[o][s]+e[o][s]*a}return r}function Bk(r,t){for(var e=r.length,a=t.length,n=e>a?t:r,i=Math.min(e,a),o=n[i-1]||{color:[0,0,0,0],offset:0},s=i;s<Math.max(e,a);s++)n.push({offset:o.offset,color:o.color.slice()})}function zk(r,t,e){var a=r,n=t;if(!(!a.push||!n.push)){var i=a.length,o=n.length;if(i!==o){var s=i>o;if(s)a.length=o;else for(var l=i;l<o;l++)a.push(e===1?n[l]:tg.call(n[l]))}for(var u=a[0]&&a[0].length,l=0;l<a.length;l++)if(e===1)isNaN(a[l])&&(a[l]=n[l]);else for(var f=0;f<u;f++)isNaN(a[l][f])&&(a[l][f]=n[l][f])}}function Pl(r){if(Pe(r)){var t=r.length;if(Pe(r[0])){for(var e=[],a=0;a<t;a++)e.push(tg.call(r[a]));return e}return tg.call(r)}return r}function rv(r){return r[0]=Math.floor(r[0])||0,r[1]=Math.floor(r[1])||0,r[2]=Math.floor(r[2])||0,r[3]=r[3]==null?1:r[3],"rgba("+r.join(",")+")"}function Vk(r){return Pe(r&&r[0])?2:1}var Yu=0,av=1,EA=2,pl=3,eg=4,rg=5,Z_=6;function X_(r){return r===eg||r===rg}function Zu(r){return r===av||r===EA}var Ns=[0,0,0,0],Gk=function(){function r(t){this.keyframes=[],this.discrete=!1,this._invalid=!1,this._needsSort=!1,this._lastFr=0,this._lastFrP=0,this.propName=t}return r.prototype.isFinished=function(){return this._finished},r.prototype.setFinished=function(){this._finished=!0,this._additiveTrack&&this._additiveTrack.setFinished()},r.prototype.needsAnimate=function(){return this.keyframes.length>=1},r.prototype.getAdditiveTrack=function(){return this._additiveTrack},r.prototype.addKeyframe=function(t,e,a){this._needsSort=!0;var n=this.keyframes,i=n.length,o=!1,s=Z_,l=e;if(Pe(e)){var u=Vk(e);s=u,(u===1&&!Mt(e[0])||u===2&&!Mt(e[0][0]))&&(o=!0)}else if(Mt(e)&&!Ie(e))s=Yu;else if(X(e))if(!isNaN(+e))s=Yu;else{var f=Ve(e);f&&(l=f,s=pl)}else if(mu(e)){var v=G({},l);v.colorStops=U(e.colorStops,function(c){return{offset:c.offset,color:Ve(c.color)}}),LA(e)?s=eg:IA(e)&&(s=rg),l=v}i===0?this.valType=s:(s!==this.valType||s===Z_)&&(o=!0),this.discrete=this.discrete||o;var h={time:t,value:l,rawValue:e,percent:0};return a&&(h.easing=a,h.easingFunc=tt(a)?a:Ll[a]||im(a)),n.push(h),h},r.prototype.prepare=function(t,e){var a=this.keyframes;this._needsSort&&a.sort(function(d,g){return d.time-g.time});for(var n=this.valType,i=a.length,o=a[i-1],s=this.discrete,l=Zu(n),u=X_(n),f=0;f<i;f++){var v=a[f],h=v.value,c=o.value;v.percent=v.time/t,s||(l&&f!==i-1?zk(h,c,n):u&&Bk(h.colorStops,c.colorStops))}if(!s&&n!==rg&&e&&this.needsAnimate()&&e.needsAnimate()&&n===e.valType&&!e._finished){this._additiveTrack=e;for(var p=a[0].value,f=0;f<i;f++)n===Yu?a[f].additiveValue=a[f].value-p:n===pl?a[f].additiveValue=Uu([],a[f].value,p,-1):Zu(n)&&(a[f].additiveValue=n===av?Uu([],a[f].value,p,-1):Y_([],a[f].value,p,-1))}},r.prototype.step=function(t,e){if(!this._finished){this._additiveTrack&&this._additiveTrack._finished&&(this._additiveTrack=null);var a=this._additiveTrack!=null,n=a?"additiveValue":"value",i=this.valType,o=this.keyframes,s=o.length,l=this.propName,u=i===pl,f,v=this._lastFr,h=Math.min,c,p;if(s===1)c=p=o[0];else{if(e<0)f=0;else if(e<this._lastFrP){var d=h(v+1,s-1);for(f=d;f>=0&&!(o[f].percent<=e);f--);f=h(f,s-2)}else{for(f=v;f<s&&!(o[f].percent>e);f++);f=h(f-1,s-2)}p=o[f+1],c=o[f]}if(c&&p){this._lastFr=f,this._lastFrP=e;var g=p.percent-c.percent,y=g===0?1:h((e-c.percent)/g,1);p.easingFunc&&(y=p.easingFunc(y));var m=a?this._additiveValue:u?Ns:t[l];if((Zu(i)||u)&&!m&&(m=this._additiveValue=[]),this.discrete)t[l]=y<1?c.rawValue:p.rawValue;else if(Zu(i))i===av?wc(m,c[n],p[n],y):Nk(m,c[n],p[n],y);else if(X_(i)){var _=c[n],S=p[n],x=i===eg;t[l]={type:x?"linear":"radial",x:Pa(_.x,S.x,y),y:Pa(_.y,S.y,y),colorStops:U(_.colorStops,function(w,T){var C=S.colorStops[T];return{offset:Pa(w.offset,C.offset,y),color:rv(wc([],w.color,C.color,y))}}),global:S.global},x?(t[l].x2=Pa(_.x2,S.x2,y),t[l].y2=Pa(_.y2,S.y2,y)):t[l].r=Pa(_.r,S.r,y)}else if(u)wc(m,c[n],p[n],y),a||(t[l]=rv(m));else{var b=Pa(c[n],p[n],y);a?this._additiveValue=b:t[l]=b}a&&this._addToTarget(t)}}},r.prototype._addToTarget=function(t){var e=this.valType,a=this.propName,n=this._additiveValue;e===Yu?t[a]=t[a]+n:e===pl?(Ve(t[a],Ns),Uu(Ns,Ns,n,1),t[a]=rv(Ns)):e===av?Uu(t[a],t[a],n,1):e===EA&&Y_(t[a],t[a],n,1)},r}(),lm=function(){function r(t,e,a,n){if(this._tracks={},this._trackKeys=[],this._maxTime=0,this._started=0,this._clip=null,this._target=t,this._loop=e,e&&n){Rh("Can' use additive animation on looped animation.");return}this._additiveAnimators=n,this._allowDiscrete=a}return r.prototype.getMaxTime=function(){return this._maxTime},r.prototype.getDelay=function(){return this._delay},r.prototype.getLoop=function(){return this._loop},r.prototype.getTarget=function(){return this._target},r.prototype.changeTarget=function(t){this._target=t},r.prototype.when=function(t,e,a){return this.whenWithKeys(t,e,Ct(e),a)},r.prototype.whenWithKeys=function(t,e,a,n){for(var i=this._tracks,o=0;o<a.length;o++){var s=a[o],l=i[s];if(!l){l=i[s]=new Gk(s);var u=void 0,f=this._getAdditiveTrack(s);if(f){var v=f.keyframes,h=v[v.length-1];u=h&&h.value,f.valType===pl&&u&&(u=rv(u))}else u=this._target[s];if(u==null)continue;t>0&&l.addKeyframe(0,Pl(u),n),this._trackKeys.push(s)}l.addKeyframe(t,Pl(e[s]),n)}return this._maxTime=Math.max(this._maxTime,t),this},r.prototype.pause=function(){this._clip.pause(),this._paused=!0},r.prototype.resume=function(){this._clip.resume(),this._paused=!1},r.prototype.isPaused=function(){return!!this._paused},r.prototype.duration=function(t){return this._maxTime=t,this._force=!0,this},r.prototype._doneCallback=function(){this._setTracksFinished(),this._clip=null;var t=this._doneCbs;if(t)for(var e=t.length,a=0;a<e;a++)t[a].call(this)},r.prototype._abortedCallback=function(){this._setTracksFinished();var t=this.animation,e=this._abortedCbs;if(t&&t.removeClip(this._clip),this._clip=null,e)for(var a=0;a<e.length;a++)e[a].call(this)},r.prototype._setTracksFinished=function(){for(var t=this._tracks,e=this._trackKeys,a=0;a<e.length;a++)t[e[a]].setFinished()},r.prototype._getAdditiveTrack=function(t){var e,a=this._additiveAnimators;if(a)for(var n=0;n<a.length;n++){var i=a[n].getTrack(t);i&&(e=i)}return e},r.prototype.start=function(t){if(!(this._started>0)){this._started=1;for(var e=this,a=[],n=this._maxTime||0,i=0;i<this._trackKeys.length;i++){var o=this._trackKeys[i],s=this._tracks[o],l=this._getAdditiveTrack(o),u=s.keyframes,f=u.length;if(s.prepare(n,l),s.needsAnimate())if(!this._allowDiscrete&&s.discrete){var v=u[f-1];v&&(e._target[s.propName]=v.rawValue),s.setFinished()}else a.push(s)}if(a.length||this._force){var h=new xk({life:n,loop:this._loop,delay:this._delay||0,onframe:function(c){e._started=2;var p=e._additiveAnimators;if(p){for(var d=!1,g=0;g<p.length;g++)if(p[g]._clip){d=!0;break}d||(e._additiveAnimators=null)}for(var g=0;g<a.length;g++)a[g].step(e._target,c);var y=e._onframeCbs;if(y)for(var g=0;g<y.length;g++)y[g](e._target,c)},ondestroy:function(){e._doneCallback()}});this._clip=h,this.animation&&this.animation.addClip(h),t&&h.setEasing(t)}else this._doneCallback();return this}},r.prototype.stop=function(t){if(this._clip){var e=this._clip;t&&e.onframe(1),this._abortedCallback()}},r.prototype.delay=function(t){return this._delay=t,this},r.prototype.during=function(t){return t&&(this._onframeCbs||(this._onframeCbs=[]),this._onframeCbs.push(t)),this},r.prototype.done=function(t){return t&&(this._doneCbs||(this._doneCbs=[]),this._doneCbs.push(t)),this},r.prototype.aborted=function(t){return t&&(this._abortedCbs||(this._abortedCbs=[]),this._abortedCbs.push(t)),this},r.prototype.getClip=function(){return this._clip},r.prototype.getTrack=function(t){return this._tracks[t]},r.prototype.getTracks=function(){var t=this;return U(this._trackKeys,function(e){return t._tracks[e]})},r.prototype.stopTracks=function(t,e){if(!t.length||!this._clip)return!0;for(var a=this._tracks,n=this._trackKeys,i=0;i<t.length;i++){var o=a[t[i]];o&&!o.isFinished()&&(e?o.step(this._target,1):this._started===1&&o.step(this._target,0),o.setFinished())}for(var s=!0,i=0;i<n.length;i++)if(!a[n[i]].isFinished()){s=!1;break}return s&&this._abortedCallback(),s},r.prototype.saveTo=function(t,e,a){if(t){e=e||this._trackKeys;for(var n=0;n<e.length;n++){var i=e[n],o=this._tracks[i];if(!(!o||o.isFinished())){var s=o.keyframes,l=s[a?0:s.length-1];l&&(t[i]=Pl(l.rawValue))}}}},r.prototype.__changeFinalValue=function(t,e){e=e||Ct(t);for(var a=0;a<e.length;a++){var n=e[a],i=this._tracks[n];if(i){var o=i.keyframes;if(o.length>1){var s=o.pop();i.addKeyframe(s.time,t[n]),i.prepare(this._maxTime,i.getAdditiveTrack())}}}},r}();function zo(){return new Date().getTime()}var Fk=function(r){Zt(t,r);function t(e){var a=r.call(this)||this;return a._running=!1,a._time=0,a._pausedTime=0,a._pauseStart=0,a._paused=!1,e=e||{},a.stage=e.stage||{},a}return t.prototype.addClip=function(e){e.animation&&this.removeClip(e),this._head?(this._tail.next=e,e.prev=this._tail,e.next=null,this._tail=e):this._head=this._tail=e,e.animation=this},t.prototype.addAnimator=function(e){e.animation=this;var a=e.getClip();a&&this.addClip(a)},t.prototype.removeClip=function(e){if(e.animation){var a=e.prev,n=e.next;a?a.next=n:this._head=n,n?n.prev=a:this._tail=a,e.next=e.prev=e.animation=null}},t.prototype.removeAnimator=function(e){var a=e.getClip();a&&this.removeClip(a),e.animation=null},t.prototype.update=function(e){for(var a=zo()-this._pausedTime,n=a-this._time,i=this._head;i;){var o=i.next,s=i.step(a,n);s&&(i.ondestroy(),this.removeClip(i)),i=o}this._time=a,e||(this.trigger("frame",n),this.stage.update&&this.stage.update())},t.prototype._startLoop=function(){var e=this;this._running=!0;function a(){e._running&&(Cv(a),!e._paused&&e.update())}Cv(a)},t.prototype.start=function(){this._running||(this._time=zo(),this._pausedTime=0,this._startLoop())},t.prototype.stop=function(){this._running=!1},t.prototype.pause=function(){this._paused||(this._pauseStart=zo(),this._paused=!0)},t.prototype.resume=function(){this._paused&&(this._pausedTime+=zo()-this._pauseStart,this._paused=!1)},t.prototype.clear=function(){for(var e=this._head;e;){var a=e.next;e.prev=e.next=e.animation=null,e=a}this._head=this._tail=null},t.prototype.isFinished=function(){return this._head==null},t.prototype.animate=function(e,a){a=a||{},this.start();var n=new lm(e,a.loop);return this.addAnimator(n),n},t}(Pr),Hk=300,Tc=Tt.domSupported,Cc=function(){var r=["click","dblclick","mousewheel","wheel","mouseout","mouseup","mousedown","mousemove","contextmenu"],t=["touchstart","touchend","touchmove"],e={pointerdown:1,pointerup:1,pointermove:1,pointerout:1},a=U(r,function(n){var i=n.replace("mouse","pointer");return e.hasOwnProperty(i)?i:n});return{mouse:r,touch:t,pointer:a}}(),$_={mouse:["mousemove","mouseup"],pointer:["pointermove","pointerup"]},q_=!1;function ag(r){var t=r.pointerType;return t==="pen"||t==="touch"}function Wk(r){r.touching=!0,r.touchTimer!=null&&(clearTimeout(r.touchTimer),r.touchTimer=null),r.touchTimer=setTimeout(function(){r.touching=!1,r.touchTimer=null},700)}function Ac(r){r&&(r.zrByTouch=!0)}function Uk(r,t){return mr(r.dom,new Yk(r,t),!0)}function OA(r,t){for(var e=t,a=!1;e&&e.nodeType!==9&&!(a=e.domBelongToZr||e!==t&&e===r.painterRoot);)e=e.parentNode;return a}var Yk=function(){function r(t,e){this.stopPropagation=jt,this.stopImmediatePropagation=jt,this.preventDefault=jt,this.type=e.type,this.target=this.currentTarget=t.dom,this.pointerType=e.pointerType,this.clientX=e.clientX,this.clientY=e.clientY}return r}(),Or={mousedown:function(r){r=mr(this.dom,r),this.__mayPointerCapture=[r.zrX,r.zrY],this.trigger("mousedown",r)},mousemove:function(r){r=mr(this.dom,r);var t=this.__mayPointerCapture;t&&(r.zrX!==t[0]||r.zrY!==t[1])&&this.__togglePointerCapture(!0),this.trigger("mousemove",r)},mouseup:function(r){r=mr(this.dom,r),this.__togglePointerCapture(!1),this.trigger("mouseup",r)},mouseout:function(r){r=mr(this.dom,r);var t=r.toElement||r.relatedTarget;OA(this,t)||(this.__pointerCapturing&&(r.zrEventControl="no_globalout"),this.trigger("mouseout",r))},wheel:function(r){q_=!0,r=mr(this.dom,r),this.trigger("mousewheel",r)},mousewheel:function(r){q_||(r=mr(this.dom,r),this.trigger("mousewheel",r))},touchstart:function(r){r=mr(this.dom,r),Ac(r),this.__lastTouchMoment=new Date,this.handler.processGesture(r,"start"),Or.mousemove.call(this,r),Or.mousedown.call(this,r)},touchmove:function(r){r=mr(this.dom,r),Ac(r),this.handler.processGesture(r,"change"),Or.mousemove.call(this,r)},touchend:function(r){r=mr(this.dom,r),Ac(r),this.handler.processGesture(r,"end"),Or.mouseup.call(this,r),+new Date-+this.__lastTouchMoment<Hk&&Or.click.call(this,r)},pointerdown:function(r){Or.mousedown.call(this,r)},pointermove:function(r){ag(r)||Or.mousemove.call(this,r)},pointerup:function(r){Or.mouseup.call(this,r)},pointerout:function(r){ag(r)||Or.mouseout.call(this,r)}};A(["click","dblclick","contextmenu"],function(r){Or[r]=function(t){t=mr(this.dom,t),this.trigger(r,t)}});var ng={pointermove:function(r){ag(r)||ng.mousemove.call(this,r)},pointerup:function(r){ng.mouseup.call(this,r)},mousemove:function(r){this.trigger("mousemove",r)},mouseup:function(r){var t=this.__pointerCapturing;this.__togglePointerCapture(!1),this.trigger("mouseup",r),t&&(r.zrEventControl="only_globalout",this.trigger("mouseout",r))}};function Zk(r,t){var e=t.domHandlers;Tt.pointerEventsSupported?A(Cc.pointer,function(a){nv(t,a,function(n){e[a].call(r,n)})}):(Tt.touchEventsSupported&&A(Cc.touch,function(a){nv(t,a,function(n){e[a].call(r,n),Wk(t)})}),A(Cc.mouse,function(a){nv(t,a,function(n){n=nm(n),t.touching||e[a].call(r,n)})}))}function Xk(r,t){Tt.pointerEventsSupported?A($_.pointer,e):Tt.touchEventsSupported||A($_.mouse,e);function e(a){function n(i){i=nm(i),OA(r,i.target)||(i=Uk(r,i),t.domHandlers[a].call(r,i))}nv(t,a,n,{capture:!0})}}function nv(r,t,e,a){r.mounted[t]=e,r.listenerOpts[t]=a,Xd(r.domTarget,t,e,a)}function Mc(r){var t=r.mounted;for(var e in t)t.hasOwnProperty(e)&&rk(r.domTarget,e,t[e],r.listenerOpts[e]);r.mounted={}}var K_=function(){function r(t,e){this.mounted={},this.listenerOpts={},this.touching=!1,this.domTarget=t,this.domHandlers=e}return r}(),$k=function(r){Zt(t,r);function t(e,a){var n=r.call(this)||this;return n.__pointerCapturing=!1,n.dom=e,n.painterRoot=a,n._localHandlerScope=new K_(e,Or),Tc&&(n._globalHandlerScope=new K_(document,ng)),Zk(n,n._localHandlerScope),n}return t.prototype.dispose=function(){Mc(this._localHandlerScope),Tc&&Mc(this._globalHandlerScope)},t.prototype.setCursor=function(e){this.dom.style&&(this.dom.style.cursor=e||"default")},t.prototype.__togglePointerCapture=function(e){if(this.__mayPointerCapture=null,Tc&&+this.__pointerCapturing^+e){this.__pointerCapturing=e;var a=this._globalHandlerScope;e?Xk(this,a):Mc(a)}},t}(Pr),NA=1;Tt.hasGlobalWindow&&(NA=Math.max(window.devicePixelRatio||window.screen&&window.screen.deviceXDPI/window.screen.logicalXDPI||1,1));var Pv=NA,ig=.4,og="#333",sg="#ccc",qk="#eee",j_=xu,J_=5e-5;function Zn(r){return r>J_||r<-J_}var Xn=[],lo=[],Dc=me(),Lc=Math.abs,Ba=function(){function r(){}return r.prototype.getLocalTransform=function(t){return r.getLocalTransform(this,t)},r.prototype.setPosition=function(t){this.x=t[0],this.y=t[1]},r.prototype.setScale=function(t){this.scaleX=t[0],this.scaleY=t[1]},r.prototype.setSkew=function(t){this.skewX=t[0],this.skewY=t[1]},r.prototype.setOrigin=function(t){this.originX=t[0],this.originY=t[1]},r.prototype.needLocalTransform=function(){return Zn(this.rotation)||Zn(this.x)||Zn(this.y)||Zn(this.scaleX-1)||Zn(this.scaleY-1)||Zn(this.skewX)||Zn(this.skewY)},r.prototype.updateTransform=function(){var t=this.parent&&this.parent.transform,e=this.needLocalTransform(),a=this.transform;if(!(e||t)){a&&(j_(a),this.invTransform=null);return}a=a||me(),e?this.getLocalTransform(a):j_(a),t&&(e?Gr(a,t,a):bu(a,t)),this.transform=a,this._resolveGlobalScaleRatio(a)},r.prototype._resolveGlobalScaleRatio=function(t){var e=this.globalScaleRatio;if(e!=null&&e!==1){this.getGlobalScale(Xn);var a=Xn[0]<0?-1:1,n=Xn[1]<0?-1:1,i=((Xn[0]-a)*e+a)/Xn[0]||0,o=((Xn[1]-n)*e+n)/Xn[1]||0;t[0]*=i,t[1]*=i,t[2]*=o,t[3]*=o}this.invTransform=this.invTransform||me(),Dr(this.invTransform,t)},r.prototype.getComputedTransform=function(){for(var t=this,e=[];t;)e.push(t),t=t.parent;for(;t=e.pop();)t.updateTransform();return this.transform},r.prototype.setLocalTransform=function(t){if(t){var e=t[0]*t[0]+t[1]*t[1],a=t[2]*t[2]+t[3]*t[3],n=Math.atan2(t[1],t[0]),i=Math.PI/2+n-Math.atan2(t[3],t[2]);a=Math.sqrt(a)*Math.cos(i),e=Math.sqrt(e),this.skewX=i,this.skewY=0,this.rotation=-n,this.x=+t[4],this.y=+t[5],this.scaleX=e,this.scaleY=a,this.originX=0,this.originY=0}},r.prototype.decomposeTransform=function(){if(this.transform){var t=this.parent,e=this.transform;t&&t.transform&&(t.invTransform=t.invTransform||me(),Gr(lo,t.invTransform,e),e=lo);var a=this.originX,n=this.originY;(a||n)&&(Dc[4]=a,Dc[5]=n,Gr(lo,e,Dc),lo[4]-=a,lo[5]-=n,e=lo),this.setLocalTransform(e)}},r.prototype.getGlobalScale=function(t){var e=this.transform;return t=t||[],e?(t[0]=Math.sqrt(e[0]*e[0]+e[1]*e[1]),t[1]=Math.sqrt(e[2]*e[2]+e[3]*e[3]),e[0]<0&&(t[0]=-t[0]),e[3]<0&&(t[1]=-t[1]),t):(t[0]=1,t[1]=1,t)},r.prototype.transformCoordToLocal=function(t,e){var a=[t,e],n=this.invTransform;return n&&Jt(a,a,n),a},r.prototype.transformCoordToGlobal=function(t,e){var a=[t,e],n=this.transform;return n&&Jt(a,a,n),a},r.prototype.getLineScale=function(){var t=this.transform;return t&&Lc(t[0]-1)>1e-10&&Lc(t[3]-1)>1e-10?Math.sqrt(Lc(t[0]*t[3]-t[2]*t[1])):1},r.prototype.copyTransform=function(t){Rv(this,t)},r.getLocalTransform=function(t,e){e=e||[];var a=t.originX||0,n=t.originY||0,i=t.scaleX,o=t.scaleY,s=t.anchorX,l=t.anchorY,u=t.rotation||0,f=t.x,v=t.y,h=t.skewX?Math.tan(t.skewX):0,c=t.skewY?Math.tan(-t.skewY):0;if(a||n||s||l){var p=a+s,d=n+l;e[4]=-p*i-h*d*o,e[5]=-d*o-c*p*i}else e[4]=e[5]=0;return e[0]=i,e[3]=o,e[1]=c*i,e[2]=h*o,u&&Qa(e,e,u),e[4]+=a+f,e[5]+=n+v,e},r.initDefaultProps=function(){var t=r.prototype;t.scaleX=t.scaleY=t.globalScaleRatio=1,t.x=t.y=t.originX=t.originY=t.skewX=t.skewY=t.rotation=t.anchorX=t.anchorY=0}(),r}(),ga=["x","y","originX","originY","anchorX","anchorY","rotation","scaleX","scaleY","skewX","skewY"];function Rv(r,t){for(var e=0;e<ga.length;e++){var a=ga[e];r[a]=t[a]}}function pa(r){Xu||(Xu=new jo(100)),r=r||Ya;var t=Xu.get(r);return t||(t={font:r,strWidthCache:new jo(500),asciiWidthMap:null,asciiWidthMapTried:!1,stWideCharWidth:tr.measureText("国",r).width,asciiCharWidth:tr.measureText("a",r).width},Xu.put(r,t)),t}var Xu;function Kk(r){if(!(Ic>=Q_)){r=r||Ya;for(var t=[],e=+new Date,a=0;a<=127;a++)t[a]=tr.measureText(String.fromCharCode(a),r).width;var n=+new Date-e;return n>16?Ic=Q_:n>2&&Ic++,t}}var Ic=0,Q_=5;function BA(r,t){return r.asciiWidthMapTried||(r.asciiWidthMap=Kk(r.font),r.asciiWidthMapTried=!0),0<=t&&t<=127?r.asciiWidthMap!=null?r.asciiWidthMap[t]:r.asciiCharWidth:r.stWideCharWidth}function da(r,t){var e=r.strWidthCache,a=e.get(t);return a==null&&(a=tr.measureText(t,r.font).width,e.put(t,a)),a}function t1(r,t,e,a){var n=da(pa(t),r),i=wu(t),o=Jo(0,n,e),s=Pi(0,i,a),l=new lt(o,s,n,i);return l}function zh(r,t,e,a){var n=((r||"")+"").split(`
`),i=n.length;if(i===1)return t1(n[0],t,e,a);for(var o=new lt(0,0,0,0),s=0;s<n.length;s++){var l=t1(n[s],t,e,a);s===0?o.copy(l):o.union(l)}return o}function Jo(r,t,e,a){return e==="right"?a?r+=t:r-=t:e==="center"&&(a?r+=t/2:r-=t/2),r}function Pi(r,t,e,a){return e==="middle"?a?r+=t/2:r-=t/2:e==="bottom"&&(a?r+=t:r-=t),r}function wu(r){return pa(r).stWideCharWidth}function Yr(r,t){return typeof r=="string"?r.lastIndexOf("%")>=0?parseFloat(r)/100*t:parseFloat(r):r}function kv(r,t,e){var a=t.position||"inside",n=t.distance!=null?t.distance:5,i=e.height,o=e.width,s=i/2,l=e.x,u=e.y,f="left",v="top";if(a instanceof Array)l+=Yr(a[0],e.width),u+=Yr(a[1],e.height),f=null,v=null;else switch(a){case"left":l-=n,u+=s,f="right",v="middle";break;case"right":l+=n+o,u+=s,v="middle";break;case"top":l+=o/2,u-=n,f="center",v="bottom";break;case"bottom":l+=o/2,u+=i+n,f="center";break;case"inside":l+=o/2,u+=s,f="center",v="middle";break;case"insideLeft":l+=n,u+=s,v="middle";break;case"insideRight":l+=o-n,u+=s,f="right",v="middle";break;case"insideTop":l+=o/2,u+=n,f="center";break;case"insideBottom":l+=o/2,u+=i-n,f="center",v="bottom";break;case"insideTopLeft":l+=n,u+=n;break;case"insideTopRight":l+=o-n,u+=n,f="right";break;case"insideBottomLeft":l+=n,u+=i-n,v="bottom";break;case"insideBottomRight":l+=o-n,u+=i-n,f="right",v="bottom";break}return r=r||{},r.x=l,r.y=u,r.align=f,r.verticalAlign=v,r}var Pc="__zr_normal__",Rc=ga.concat(["ignore"]),jk=Mr(ga,function(r,t){return r[t]=!0,r},{ignore:!1}),uo={},Jk=new lt(0,0,0,0),$u=[],Vh=function(){function r(t){this.id=tm(),this.animators=[],this.currentStates=[],this.states={},this._init(t)}return r.prototype._init=function(t){this.attr(t)},r.prototype.drift=function(t,e,a){switch(this.draggable){case"horizontal":e=0;break;case"vertical":t=0;break}var n=this.transform;n||(n=this.transform=[1,0,0,1,0,0]),n[4]+=t,n[5]+=e,this.decomposeTransform(),this.markRedraw()},r.prototype.beforeUpdate=function(){},r.prototype.afterUpdate=function(){},r.prototype.update=function(){this.updateTransform(),this.__dirty&&this.updateInnerText()},r.prototype.updateInnerText=function(t){var e=this._textContent;if(e&&(!e.ignore||t)){this.textConfig||(this.textConfig={});var a=this.textConfig,n=a.local,i=e.innerTransformable,o=void 0,s=void 0,l=!1;i.parent=n?this:null;var u=!1;i.copyTransform(e);var f=a.position!=null,v=a.autoOverflowArea,h=void 0;if((v||f)&&(h=Jk,a.layoutRect?h.copy(a.layoutRect):h.copy(this.getBoundingRect()),n||h.applyTransform(this.transform)),f){this.calculateTextPosition?this.calculateTextPosition(uo,a,h):kv(uo,a,h),i.x=uo.x,i.y=uo.y,o=uo.align,s=uo.verticalAlign;var c=a.origin;if(c&&a.rotation!=null){var p=void 0,d=void 0;c==="center"?(p=h.width*.5,d=h.height*.5):(p=Yr(c[0],h.width),d=Yr(c[1],h.height)),u=!0,i.originX=-i.x+p+(n?0:h.x),i.originY=-i.y+d+(n?0:h.y)}}a.rotation!=null&&(i.rotation=a.rotation);var g=a.offset;g&&(i.x+=g[0],i.y+=g[1],u||(i.originX=-g[0],i.originY=-g[1]));var y=this._innerTextDefaultStyle||(this._innerTextDefaultStyle={});if(v){var m=y.overflowRect=y.overflowRect||new lt(0,0,0,0);i.getLocalTransform($u),Dr($u,$u),lt.copy(m,h),m.applyTransform($u)}else y.overflowRect=null;var _=a.inside==null?typeof a.position=="string"&&a.position.indexOf("inside")>=0:a.inside,S=void 0,x=void 0,b=void 0;_&&this.canBeInsideText()?(S=a.insideFill,x=a.insideStroke,(S==null||S==="auto")&&(S=this.getInsideTextFill()),(x==null||x==="auto")&&(x=this.getInsideTextStroke(S),b=!0)):(S=a.outsideFill,x=a.outsideStroke,(S==null||S==="auto")&&(S=this.getOutsideFill()),(x==null||x==="auto")&&(x=this.getOutsideStroke(S),b=!0)),S=S||"#000",(S!==y.fill||x!==y.stroke||b!==y.autoStroke||o!==y.align||s!==y.verticalAlign)&&(l=!0,y.fill=S,y.stroke=x,y.autoStroke=b,y.align=o,y.verticalAlign=s,e.setDefaultTextStyle(y)),e.__dirty|=ir,l&&e.dirtyStyle(!0)}},r.prototype.canBeInsideText=function(){return!0},r.prototype.getInsideTextFill=function(){return"#fff"},r.prototype.getInsideTextStroke=function(t){return"#000"},r.prototype.getOutsideFill=function(){return this.__zr&&this.__zr.isDarkMode()?sg:og},r.prototype.getOutsideStroke=function(t){var e=this.__zr&&this.__zr.getBackgroundColor(),a=typeof e=="string"&&Ve(e);a||(a=[255,255,255,1]);for(var n=a[3],i=this.__zr.isDarkMode(),o=0;o<3;o++)a[o]=a[o]*n+(i?0:255)*(1-n);return a[3]=1,Cr(a,"rgba")},r.prototype.traverse=function(t,e){},r.prototype.attrKV=function(t,e){t==="textConfig"?this.setTextConfig(e):t==="textContent"?this.setTextContent(e):t==="clipPath"?this.setClipPath(e):t==="extra"?(this.extra=this.extra||{},G(this.extra,e)):this[t]=e},r.prototype.hide=function(){this.ignore=!0,this.markRedraw()},r.prototype.show=function(){this.ignore=!1,this.markRedraw()},r.prototype.attr=function(t,e){if(typeof t=="string")this.attrKV(t,e);else if(it(t))for(var a=t,n=Ct(a),i=0;i<n.length;i++){var o=n[i];this.attrKV(o,t[o])}return this.markRedraw(),this},r.prototype.saveCurrentToNormalState=function(t){this._innerSaveToNormal(t);for(var e=this._normalState,a=0;a<this.animators.length;a++){var n=this.animators[a],i=n.__fromStateTransition;if(!(n.getLoop()||i&&i!==Pc)){var o=n.targetName,s=o?e[o]:e;n.saveTo(s)}}},r.prototype._innerSaveToNormal=function(t){var e=this._normalState;e||(e=this._normalState={}),t.textConfig&&!e.textConfig&&(e.textConfig=this.textConfig),this._savePrimaryToNormal(t,e,Rc)},r.prototype._savePrimaryToNormal=function(t,e,a){for(var n=0;n<a.length;n++){var i=a[n];t[i]!=null&&!(i in e)&&(e[i]=this[i])}},r.prototype.hasState=function(){return this.currentStates.length>0},r.prototype.getState=function(t){return this.states[t]},r.prototype.ensureState=function(t){var e=this.states;return e[t]||(e[t]={}),e[t]},r.prototype.clearStates=function(t){this.useState(Pc,!1,t)},r.prototype.useState=function(t,e,a,n){var i=t===Pc,o=this.hasState();if(!(!o&&i)){var s=this.currentStates,l=this.stateTransition;if(!(gt(s,t)>=0&&(e||s.length===1))){var u;if(this.stateProxy&&!i&&(u=this.stateProxy(t)),u||(u=this.states&&this.states[t]),!u&&!i){Rh("State "+t+" not exists.");return}i||this.saveCurrentToNormalState(u);var f=!!(u&&u.hoverLayer||n);f&&this._toggleHoverLayerFlag(!0),this._applyStateObj(t,u,this._normalState,e,!a&&!this.__inHover&&l&&l.duration>0,l);var v=this._textContent,h=this._textGuide;return v&&v.useState(t,e,a,f),h&&h.useState(t,e,a,f),i?(this.currentStates=[],this._normalState={}):e?this.currentStates.push(t):this.currentStates=[t],this._updateAnimationTargets(),this.markRedraw(),!f&&this.__inHover&&(this._toggleHoverLayerFlag(!1),this.__dirty&=~ir),u}}},r.prototype.useStates=function(t,e,a){if(!t.length)this.clearStates();else{var n=[],i=this.currentStates,o=t.length,s=o===i.length;if(s){for(var l=0;l<o;l++)if(t[l]!==i[l]){s=!1;break}}if(s)return;for(var l=0;l<o;l++){var u=t[l],f=void 0;this.stateProxy&&(f=this.stateProxy(u,t)),f||(f=this.states[u]),f&&n.push(f)}var v=n[o-1],h=!!(v&&v.hoverLayer||a);h&&this._toggleHoverLayerFlag(!0);var c=this._mergeStates(n),p=this.stateTransition;this.saveCurrentToNormalState(c),this._applyStateObj(t.join(","),c,this._normalState,!1,!e&&!this.__inHover&&p&&p.duration>0,p);var d=this._textContent,g=this._textGuide;d&&d.useStates(t,e,h),g&&g.useStates(t,e,h),this._updateAnimationTargets(),this.currentStates=t.slice(),this.markRedraw(),!h&&this.__inHover&&(this._toggleHoverLayerFlag(!1),this.__dirty&=~ir)}},r.prototype.isSilent=function(){for(var t=this;t;){if(t.silent)return!0;var e=t.__hostTarget;t=e?t.ignoreHostSilent?null:e:t.parent}return!1},r.prototype._updateAnimationTargets=function(){for(var t=0;t<this.animators.length;t++){var e=this.animators[t];e.targetName&&e.changeTarget(this[e.targetName])}},r.prototype.removeState=function(t){var e=gt(this.currentStates,t);if(e>=0){var a=this.currentStates.slice();a.splice(e,1),this.useStates(a)}},r.prototype.replaceState=function(t,e,a){var n=this.currentStates.slice(),i=gt(n,t),o=gt(n,e)>=0;i>=0?o?n.splice(i,1):n[i]=e:a&&!o&&n.push(e),this.useStates(n)},r.prototype.toggleState=function(t,e){e?this.useState(t,!0):this.removeState(t)},r.prototype._mergeStates=function(t){for(var e={},a,n=0;n<t.length;n++){var i=t[n];G(e,i),i.textConfig&&(a=a||{},G(a,i.textConfig))}return a&&(e.textConfig=a),e},r.prototype._applyStateObj=function(t,e,a,n,i,o){var s=!(e&&n);e&&e.textConfig?(this.textConfig=G({},n?this.textConfig:a.textConfig),G(this.textConfig,e.textConfig)):s&&a.textConfig&&(this.textConfig=a.textConfig);for(var l={},u=!1,f=0;f<Rc.length;f++){var v=Rc[f],h=i&&jk[v];e&&e[v]!=null?h?(u=!0,l[v]=e[v]):this[v]=e[v]:s&&a[v]!=null&&(h?(u=!0,l[v]=a[v]):this[v]=a[v])}if(!i)for(var f=0;f<this.animators.length;f++){var c=this.animators[f],p=c.targetName;c.getLoop()||c.__changeFinalValue(p?(e||a)[p]:e||a)}u&&this._transitionState(t,l,o)},r.prototype._attachComponent=function(t){if(!(t.__zr&&!t.__hostTarget)&&t!==this){var e=this.__zr;e&&t.addSelfToZr(e),t.__zr=e,t.__hostTarget=this}},r.prototype._detachComponent=function(t){t.__zr&&t.removeSelfFromZr(t.__zr),t.__zr=null,t.__hostTarget=null},r.prototype.getClipPath=function(){return this._clipPath},r.prototype.setClipPath=function(t){this._clipPath&&this._clipPath!==t&&this.removeClipPath(),this._attachComponent(t),this._clipPath=t,this.markRedraw()},r.prototype.removeClipPath=function(){var t=this._clipPath;t&&(this._detachComponent(t),this._clipPath=null,this.markRedraw())},r.prototype.getTextContent=function(){return this._textContent},r.prototype.setTextContent=function(t){var e=this._textContent;e!==t&&(e&&e!==t&&this.removeTextContent(),t.innerTransformable=new Ba,this._attachComponent(t),this._textContent=t,this.markRedraw())},r.prototype.setTextConfig=function(t){this.textConfig||(this.textConfig={}),G(this.textConfig,t),this.markRedraw()},r.prototype.removeTextConfig=function(){this.textConfig=null,this.markRedraw()},r.prototype.removeTextContent=function(){var t=this._textContent;t&&(t.innerTransformable=null,this._detachComponent(t),this._textContent=null,this._innerTextDefaultStyle=null,this.markRedraw())},r.prototype.getTextGuideLine=function(){return this._textGuide},r.prototype.setTextGuideLine=function(t){this._textGuide&&this._textGuide!==t&&this.removeTextGuideLine(),this._attachComponent(t),this._textGuide=t,this.markRedraw()},r.prototype.removeTextGuideLine=function(){var t=this._textGuide;t&&(this._detachComponent(t),this._textGuide=null,this.markRedraw())},r.prototype.markRedraw=function(){this.__dirty|=ir;var t=this.__zr;t&&(this.__inHover?t.refreshHover():t.refresh()),this.__hostTarget&&this.__hostTarget.markRedraw()},r.prototype.dirty=function(){this.markRedraw()},r.prototype._toggleHoverLayerFlag=function(t){this.__inHover=t;var e=this._textContent,a=this._textGuide;e&&(e.__inHover=t),a&&(a.__inHover=t)},r.prototype.addSelfToZr=function(t){if(this.__zr!==t){this.__zr=t;var e=this.animators;if(e)for(var a=0;a<e.length;a++)t.animation.addAnimator(e[a]);this._clipPath&&this._clipPath.addSelfToZr(t),this._textContent&&this._textContent.addSelfToZr(t),this._textGuide&&this._textGuide.addSelfToZr(t)}},r.prototype.removeSelfFromZr=function(t){if(this.__zr){this.__zr=null;var e=this.animators;if(e)for(var a=0;a<e.length;a++)t.animation.removeAnimator(e[a]);this._clipPath&&this._clipPath.removeSelfFromZr(t),this._textContent&&this._textContent.removeSelfFromZr(t),this._textGuide&&this._textGuide.removeSelfFromZr(t)}},r.prototype.animate=function(t,e,a){var n=t?this[t]:this,i=new lm(n,e,a);return t&&(i.targetName=t),this.addAnimator(i,t),i},r.prototype.addAnimator=function(t,e){var a=this.__zr,n=this;t.during(function(){n.updateDuringAnimation(e)}).done(function(){var i=n.animators,o=gt(i,t);o>=0&&i.splice(o,1)}),this.animators.push(t),a&&a.animation.addAnimator(t),a&&a.wakeUp()},r.prototype.updateDuringAnimation=function(t){this.markRedraw()},r.prototype.stopAnimation=function(t,e){for(var a=this.animators,n=a.length,i=[],o=0;o<n;o++){var s=a[o];!t||t===s.scope?s.stop(e):i.push(s)}return this.animators=i,this},r.prototype.animateTo=function(t,e,a){kc(this,t,e,a)},r.prototype.animateFrom=function(t,e,a){kc(this,t,e,a,!0)},r.prototype._transitionState=function(t,e,a,n){for(var i=kc(this,e,a,n),o=0;o<i.length;o++)i[o].__fromStateTransition=t},r.prototype.getBoundingRect=function(){return null},r.prototype.getPaintRect=function(){return null},r.initDefaultProps=function(){var t=r.prototype;t.type="element",t.name="",t.ignore=t.silent=t.ignoreHostSilent=t.isGroup=t.draggable=t.dragging=t.ignoreClip=t.__inHover=!1,t.__dirty=ir;function e(a,n,i,o){Object.defineProperty(t,a,{get:function(){if(!this[n]){var l=this[n]=[];s(this,l)}return this[n]},set:function(l){this[i]=l[0],this[o]=l[1],this[n]=l,s(this,l)}});function s(l,u){Object.defineProperty(u,0,{get:function(){return l[i]},set:function(f){l[i]=f}}),Object.defineProperty(u,1,{get:function(){return l[o]},set:function(f){l[o]=f}})}}Object.defineProperty&&(e("position","_legacyPos","x","y"),e("scale","_legacyScale","scaleX","scaleY"),e("origin","_legacyOrigin","originX","originY"))}(),r}();Qt(Vh,Pr);Qt(Vh,Ba);function kc(r,t,e,a,n){e=e||{};var i=[];zA(r,"",r,t,e,a,i,n);var o=i.length,s=!1,l=e.done,u=e.aborted,f=function(){s=!0,o--,o<=0&&(s?l&&l():u&&u())},v=function(){o--,o<=0&&(s?l&&l():u&&u())};o||l&&l(),i.length>0&&e.during&&i[0].during(function(p,d){e.during(d)});for(var h=0;h<i.length;h++){var c=i[h];f&&c.done(f),v&&c.aborted(v),e.force&&c.duration(e.duration),c.start(e.easing)}return i}function Ec(r,t,e){for(var a=0;a<e;a++)r[a]=t[a]}function Qk(r){return Pe(r[0])}function tE(r,t,e){if(Pe(t[e]))if(Pe(r[e])||(r[e]=[]),Ze(t[e])){var a=t[e].length;r[e].length!==a&&(r[e]=new t[e].constructor(a),Ec(r[e],t[e],a))}else{var n=t[e],i=r[e],o=n.length;if(Qk(n))for(var s=n[0].length,l=0;l<o;l++)i[l]?Ec(i[l],n[l],s):i[l]=Array.prototype.slice.call(n[l]);else Ec(i,n,o);i.length=n.length}else r[e]=t[e]}function eE(r,t){return r===t||Pe(r)&&Pe(t)&&rE(r,t)}function rE(r,t){var e=r.length;if(e!==t.length)return!1;for(var a=0;a<e;a++)if(r[a]!==t[a])return!1;return!0}function zA(r,t,e,a,n,i,o,s){for(var l=Ct(a),u=n.duration,f=n.delay,v=n.additive,h=n.setToFinal,c=!it(i),p=r.animators,d=[],g=0;g<l.length;g++){var y=l[g],m=a[y];if(m!=null&&e[y]!=null&&(c||i[y]))if(it(m)&&!Pe(m)&&!mu(m)){if(t){s||(e[y]=m,r.updateDuringAnimation(t));continue}zA(r,y,e[y],m,n,i&&i[y],o,s)}else d.push(y);else s||(e[y]=m,r.updateDuringAnimation(t),d.push(y))}var _=d.length;if(!v&&_)for(var S=0;S<p.length;S++){var x=p[S];if(x.targetName===t){var b=x.stopTracks(d);if(b){var w=gt(p,x);p.splice(w,1)}}}if(n.force||(d=Pt(d,function(D){return!eE(a[D],e[D])}),_=d.length),_>0||n.force&&!o.length){var T=void 0,C=void 0,M=void 0;if(s){C={},h&&(T={});for(var S=0;S<_;S++){var y=d[S];C[y]=e[y],h?T[y]=a[y]:e[y]=a[y]}}else if(h){M={};for(var S=0;S<_;S++){var y=d[S];M[y]=Pl(e[y]),tE(e,a,y)}}var x=new lm(e,!1,!1,v?Pt(p,function(I){return I.targetName===t}):null);x.targetName=t,n.scope&&(x.scope=n.scope),h&&T&&x.whenWithKeys(0,T,d),M&&x.whenWithKeys(0,M,d),x.whenWithKeys(u??500,s?C:a,d).delay(f||0),r.addAnimator(x,t),o.push(x)}}var rt=function(r){Zt(t,r);function t(e){var a=r.call(this)||this;return a.isGroup=!0,a._children=[],a.attr(e),a}return t.prototype.childrenRef=function(){return this._children},t.prototype.children=function(){return this._children.slice()},t.prototype.childAt=function(e){return this._children[e]},t.prototype.childOfName=function(e){for(var a=this._children,n=0;n<a.length;n++)if(a[n].name===e)return a[n]},t.prototype.childCount=function(){return this._children.length},t.prototype.add=function(e){return e&&e!==this&&e.parent!==this&&(this._children.push(e),this._doAdd(e)),this},t.prototype.addBefore=function(e,a){if(e&&e!==this&&e.parent!==this&&a&&a.parent===this){var n=this._children,i=n.indexOf(a);i>=0&&(n.splice(i,0,e),this._doAdd(e))}return this},t.prototype.replace=function(e,a){var n=gt(this._children,e);return n>=0&&this.replaceAt(a,n),this},t.prototype.replaceAt=function(e,a){var n=this._children,i=n[a];if(e&&e!==this&&e.parent!==this&&e!==i){n[a]=e,i.parent=null;var o=this.__zr;o&&i.removeSelfFromZr(o),this._doAdd(e)}return this},t.prototype._doAdd=function(e){e.parent&&e.parent.remove(e),e.parent=this;var a=this.__zr;a&&a!==e.__zr&&e.addSelfToZr(a),a&&a.refresh()},t.prototype.remove=function(e){var a=this.__zr,n=this._children,i=gt(n,e);return i<0?this:(n.splice(i,1),e.parent=null,a&&e.removeSelfFromZr(a),a&&a.refresh(),this)},t.prototype.removeAll=function(){for(var e=this._children,a=this.__zr,n=0;n<e.length;n++){var i=e[n];a&&i.removeSelfFromZr(a),i.parent=null}return e.length=0,this},t.prototype.eachChild=function(e,a){for(var n=this._children,i=0;i<n.length;i++){var o=n[i];e.call(a,o,i)}return this},t.prototype.traverse=function(e,a){for(var n=0;n<this._children.length;n++){var i=this._children[n],o=e.call(a,i);i.isGroup&&!o&&i.traverse(e,a)}return this},t.prototype.addSelfToZr=function(e){r.prototype.addSelfToZr.call(this,e);for(var a=0;a<this._children.length;a++){var n=this._children[a];n.addSelfToZr(e)}},t.prototype.removeSelfFromZr=function(e){r.prototype.removeSelfFromZr.call(this,e);for(var a=0;a<this._children.length;a++){var n=this._children[a];n.removeSelfFromZr(e)}},t.prototype.getBoundingRect=function(e){for(var a=new lt(0,0,0,0),n=e||this._children,i=[],o=null,s=0;s<n.length;s++){var l=n[s];if(!(l.ignore||l.invisible)){var u=l.getBoundingRect(),f=l.getLocalTransform(i);f?(lt.applyTransform(a,u,f),o=o||a.clone(),o.union(a)):(o=o||u.clone(),o.union(u))}}return o||a},t}(Vh);rt.prototype.type="group";/*!
* ZRender, a high performance 2d drawing library.
*
* Copyright (c) 2013, Baidu Inc.
* All rights reserved.
*
* LICENSE
* https://github.com/ecomfe/zrender/blob/master/LICENSE.txt
*/var iv={},Ci={};function aE(r){delete Ci[r]}function nE(r){if(!r)return!1;if(typeof r=="string")return Yl(r,1)<ig;if(r.colorStops){for(var t=r.colorStops,e=0,a=t.length,n=0;n<a;n++)e+=Yl(t[n].color,1);return e/=a,e<ig}return!1}var iE=function(){function r(t,e,a){var n=this;this._sleepAfterStill=10,this._stillFrameAccum=0,this._needsRefresh=!0,this._needsRefreshHover=!0,this._darkMode=!1,a=a||{},this.dom=e,this.id=t;var i=new gk,o=a.renderer||"canvas";iv[o]||(o=Ct(iv)[0]),a.useDirtyRect=a.useDirtyRect==null?!1:a.useDirtyRect;var s=new iv[o](e,i,a,t),l=a.ssr||s.ssrOnly;this.storage=i,this.painter=s;var u=!Tt.node&&!Tt.worker&&!l?new $k(s.getViewportRoot(),s.root):null,f=a.useCoarsePointer,v=f==null||f==="auto"?Tt.touchEventsSupported:!!f,h=44,c;v&&(c=Q(a.pointerSize,h)),this.handler=new yA(i,s,u,s.root,c),this.animation=new Fk({stage:{update:l?null:function(){return n._flush(!0)}}}),l||this.animation.start()}return r.prototype.add=function(t){this._disposed||!t||(this.storage.addRoot(t),t.addSelfToZr(this),this.refresh())},r.prototype.remove=function(t){this._disposed||!t||(this.storage.delRoot(t),t.removeSelfFromZr(this),this.refresh())},r.prototype.configLayer=function(t,e){this._disposed||(this.painter.configLayer&&this.painter.configLayer(t,e),this.refresh())},r.prototype.setBackgroundColor=function(t){this._disposed||(this.painter.setBackgroundColor&&this.painter.setBackgroundColor(t),this.refresh(),this._backgroundColor=t,this._darkMode=nE(t))},r.prototype.getBackgroundColor=function(){return this._backgroundColor},r.prototype.setDarkMode=function(t){this._darkMode=t},r.prototype.isDarkMode=function(){return this._darkMode},r.prototype.refreshImmediately=function(t){this._disposed||(t||this.animation.update(!0),this._needsRefresh=!1,this.painter.refresh(),this._needsRefresh=!1)},r.prototype.refresh=function(){this._disposed||(this._needsRefresh=!0,this.animation.start())},r.prototype.flush=function(){this._disposed||this._flush(!1)},r.prototype._flush=function(t){var e,a=zo();this._needsRefresh&&(e=!0,this.refreshImmediately(t)),this._needsRefreshHover&&(e=!0,this.refreshHoverImmediately());var n=zo();e?(this._stillFrameAccum=0,this.trigger("rendered",{elapsedTime:n-a})):this._sleepAfterStill>0&&(this._stillFrameAccum++,this._stillFrameAccum>this._sleepAfterStill&&this.animation.stop())},r.prototype.setSleepAfterStill=function(t){this._sleepAfterStill=t},r.prototype.wakeUp=function(){this._disposed||(this.animation.start(),this._stillFrameAccum=0)},r.prototype.refreshHover=function(){this._needsRefreshHover=!0},r.prototype.refreshHoverImmediately=function(){this._disposed||(this._needsRefreshHover=!1,this.painter.refreshHover&&this.painter.getType()==="canvas"&&this.painter.refreshHover())},r.prototype.resize=function(t){this._disposed||(t=t||{},this.painter.resize(t.width,t.height),this.handler.resize())},r.prototype.clearAnimation=function(){this._disposed||this.animation.clear()},r.prototype.getWidth=function(){if(!this._disposed)return this.painter.getWidth()},r.prototype.getHeight=function(){if(!this._disposed)return this.painter.getHeight()},r.prototype.setCursorStyle=function(t){this._disposed||this.handler.setCursorStyle(t)},r.prototype.findHover=function(t,e){if(!this._disposed)return this.handler.findHover(t,e)},r.prototype.on=function(t,e,a){return this._disposed||this.handler.on(t,e,a),this},r.prototype.off=function(t,e){this._disposed||this.handler.off(t,e)},r.prototype.trigger=function(t,e){this._disposed||this.handler.trigger(t,e)},r.prototype.clear=function(){if(!this._disposed){for(var t=this.storage.getRoots(),e=0;e<t.length;e++)t[e]instanceof rt&&t[e].removeSelfFromZr(this);this.storage.delAllRoots(),this.painter.clear()}},r.prototype.dispose=function(){this._disposed||(this.animation.stop(),this.clear(),this.storage.dispose(),this.painter.dispose(),this.handler.dispose(),this.animation=this.storage=this.painter=this.handler=null,this._disposed=!0,aE(this.id))},r}();function lg(r,t){var e=new iE(tm(),r,t);return Ci[e.id]=e,e}function oE(r){r.dispose()}function sE(){for(var r in Ci)Ci.hasOwnProperty(r)&&Ci[r].dispose();Ci={}}function lE(r){return Ci[r]}function VA(r,t){iv[r]=t}var ug;function GA(r){if(typeof ug=="function")return ug(r)}function FA(r){ug=r}var uE="6.0.0";const yq=Object.freeze(Object.defineProperty({__proto__:null,dispose:oE,disposeAll:sE,getElementSSRData:GA,getInstance:lE,init:lg,registerPainter:VA,registerSSRDataGetter:FA,version:uE},Symbol.toStringTag,{value:"Module"}));var e1=1e-4,HA=20;function fE(r){return r.replace(/^\s+|\s+$/g,"")}var vr=Math.min,re=Math.max,la=Math.abs;function Rt(r,t,e,a){var n=t[0],i=t[1],o=e[0],s=e[1],l=i-n,u=s-o;if(l===0)return u===0?o:(o+s)/2;if(a)if(l>0){if(r<=n)return o;if(r>=i)return s}else{if(r>=n)return o;if(r<=i)return s}else{if(r===n)return o;if(r===i)return s}return(r-n)/l*u+o}var Z=vE;function vE(r,t,e){switch(r){case"center":case"middle":r="50%";break;case"left":case"top":r="0%";break;case"right":case"bottom":r="100%";break}return Ev(r,t,e)}function Ev(r,t,e){return X(r)?fE(r).match(/%$/)?parseFloat(r)/100*t+(e||0):parseFloat(r):r==null?NaN:+r}function ae(r,t,e){return t==null&&(t=10),t=Math.min(Math.max(0,t),HA),r=(+r).toFixed(t),e?r:+r}function lr(r){return r.sort(function(t,e){return t-e}),r}function zr(r){if(r=+r,isNaN(r))return 0;if(r>1e-14){for(var t=1,e=0;e<15;e++,t*=10)if(Math.round(r*t)/t===r)return e}return WA(r)}function WA(r){var t=r.toString().toLowerCase(),e=t.indexOf("e"),a=e>0?+t.slice(e+1):0,n=e>0?e:t.length,i=t.indexOf("."),o=i<0?0:n-1-i;return Math.max(0,o-a)}function um(r,t){var e=Math.log,a=Math.LN10,n=Math.floor(e(r[1]-r[0])/a),i=Math.round(e(la(t[1]-t[0]))/a),o=Math.min(Math.max(-n+i,0),20);return isFinite(o)?o:20}function hE(r,t,e){if(!r[t])return 0;var a=UA(r,e);return a[t]||0}function UA(r,t){var e=Mr(r,function(c,p){return c+(isNaN(p)?0:p)},0);if(e===0)return[];for(var a=Math.pow(10,t),n=U(r,function(c){return(isNaN(c)?0:c)/e*a*100}),i=a*100,o=U(n,function(c){return Math.floor(c)}),s=Mr(o,function(c,p){return c+p},0),l=U(n,function(c,p){return c-o[p]});s<i;){for(var u=Number.NEGATIVE_INFINITY,f=null,v=0,h=l.length;v<h;++v)l[v]>u&&(u=l[v],f=v);++o[f],l[f]=0,++s}return U(o,function(c){return c/a})}function cE(r,t){var e=Math.max(zr(r),zr(t)),a=r+t;return e>HA?a:ae(a,e)}var fg=9007199254740991;function fm(r){var t=Math.PI*2;return(r%t+t)%t}function Qo(r){return r>-e1&&r<e1}var pE=/^(?:(\d{4})(?:[-\/](\d{1,2})(?:[-\/](\d{1,2})(?:[T ](\d{1,2})(?::(\d{1,2})(?::(\d{1,2})(?:[.,](\d+))?)?)?(Z|[\+\-]\d\d:?\d\d)?)?)?)?)?$/;function ba(r){if(r instanceof Date)return r;if(X(r)){var t=pE.exec(r);if(!t)return new Date(NaN);if(t[8]){var e=+t[4]||0;return t[8].toUpperCase()!=="Z"&&(e-=+t[8].slice(0,3)),new Date(Date.UTC(+t[1],+(t[2]||1)-1,+t[3]||1,e,+(t[5]||0),+t[6]||0,t[7]?+t[7].substring(0,3):0))}else return new Date(+t[1],+(t[2]||1)-1,+t[3]||1,+t[4]||0,+(t[5]||0),+t[6]||0,t[7]?+t[7].substring(0,3):0)}else if(r==null)return new Date(NaN);return new Date(Math.round(r))}function YA(r){return Math.pow(10,Gh(r))}function Gh(r){if(r===0)return 0;var t=Math.floor(Math.log(r)/Math.LN10);return r/Math.pow(10,t)>=10&&t++,t}function vm(r,t){var e=Gh(r),a=Math.pow(10,e),n=r/a,i;return t?n<1.5?i=1:n<2.5?i=2:n<4?i=3:n<7?i=5:i=10:n<1?i=1:n<2?i=2:n<3?i=3:n<5?i=5:i=10,r=i*a,e>=-20?+r.toFixed(e<0?-e:0):r}function ov(r,t){var e=(r.length-1)*t+1,a=Math.floor(e),n=+r[a-1],i=e-a;return i?n+i*(r[a]-n):n}function vg(r){r.sort(function(l,u){return s(l,u,0)?-1:1});for(var t=-1/0,e=1,a=0;a<r.length;){for(var n=r[a].interval,i=r[a].close,o=0;o<2;o++)n[o]<=t&&(n[o]=t,i[o]=o?1:1-e),t=n[o],e=i[o];n[0]===n[1]&&i[0]*i[1]!==1?r.splice(a,1):a++}return r;function s(l,u,f){return l.interval[f]<u.interval[f]||l.interval[f]===u.interval[f]&&(l.close[f]-u.close[f]===(f?-1:1)||!f&&s(l,u,1))}}function ya(r){var t=parseFloat(r);return t==r&&(t!==0||!X(r)||r.indexOf("x")<=0)?t:NaN}function hm(r){return!isNaN(ya(r))}function ZA(){return Math.round(Math.random()*9)}function XA(r,t){return t===0?r:XA(t,r%t)}function r1(r,t){return r==null?t:t==null?r:r*t/XA(r,t)}var dE="[ECharts] ",gE=typeof console<"u"&&console.warn&&console.log;function yE(r,t,e){gE&&console[r](dE+t)}function $A(r,t){yE("error",r)}function kt(r){throw new Error(r)}function a1(r,t,e){return(t-r)*e+r}var qA="series\0",KA="\0_ec_\0";function Ft(r){return r instanceof Array?r:r==null?[]:[r]}function Vi(r,t,e){if(r){r[t]=r[t]||{},r.emphasis=r.emphasis||{},r.emphasis[t]=r.emphasis[t]||{};for(var a=0,n=e.length;a<n;a++){var i=e[a];!r.emphasis[t].hasOwnProperty(i)&&r[t].hasOwnProperty(i)&&(r.emphasis[t][i]=r[t][i])}}}var n1=["fontStyle","fontWeight","fontSize","fontFamily","rich","tag","color","textBorderColor","textBorderWidth","width","height","lineHeight","align","verticalAlign","baseline","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY","textShadowColor","textShadowBlur","textShadowOffsetX","textShadowOffsetY","backgroundColor","borderColor","borderWidth","borderRadius","padding"];function ps(r){return it(r)&&!W(r)&&!(r instanceof Date)?r.value:r}function mE(r){return it(r)&&!(r instanceof Array)}function jA(r,t,e){var a=e==="normalMerge",n=e==="replaceMerge",i=e==="replaceAll";r=r||[],t=(t||[]).slice();var o=j();A(t,function(l,u){if(!it(l)){t[u]=null;return}});var s=_E(r,o,e);return(a||n)&&SE(s,r,o,t),a&&xE(s,t),a||n?bE(s,t,n):i&&wE(s,t),TE(s),s}function _E(r,t,e){var a=[];if(e==="replaceAll")return a;for(var n=0;n<r.length;n++){var i=r[n];i&&i.id!=null&&t.set(i.id,n),a.push({existing:e==="replaceMerge"||Xl(i)?null:i,newOption:null,keyInfo:null,brandNew:null})}return a}function SE(r,t,e,a){A(a,function(n,i){if(!(!n||n.id==null)){var o=Rl(n.id),s=e.get(o);if(s!=null){var l=r[s];Re(!l.newOption,'Duplicated option on id "'+o+'".'),l.newOption=n,l.existing=t[s],a[i]=null}}})}function xE(r,t){A(t,function(e,a){if(!(!e||e.name==null))for(var n=0;n<r.length;n++){var i=r[n].existing;if(!r[n].newOption&&i&&(i.id==null||e.id==null)&&!Xl(e)&&!Xl(i)&&JA("name",i,e)){r[n].newOption=e,t[a]=null;return}}})}function bE(r,t,e){A(t,function(a){if(a){for(var n,i=0;(n=r[i])&&(n.newOption||Xl(n.existing)||n.existing&&a.id!=null&&!JA("id",a,n.existing));)i++;n?(n.newOption=a,n.brandNew=e):r.push({newOption:a,brandNew:e,existing:null,keyInfo:null}),i++}})}function wE(r,t){A(t,function(e){r.push({newOption:e,brandNew:!0,existing:null,keyInfo:null})})}function TE(r){var t=j();A(r,function(e){var a=e.existing;a&&t.set(a.id,e)}),A(r,function(e){var a=e.newOption;Re(!a||a.id==null||!t.get(a.id)||t.get(a.id)===e,"id duplicates: "+(a&&a.id)),a&&a.id!=null&&t.set(a.id,e),!e.keyInfo&&(e.keyInfo={})}),A(r,function(e,a){var n=e.existing,i=e.newOption,o=e.keyInfo;if(it(i)){if(o.name=i.name!=null?Rl(i.name):n?n.name:qA+a,n)o.id=Rl(n.id);else if(i.id!=null)o.id=Rl(i.id);else{var s=0;do o.id="\0"+o.name+"\0"+s++;while(t.get(o.id))}t.set(o.id,e)}})}function JA(r,t,e){var a=ve(t[r],null),n=ve(e[r],null);return a!=null&&n!=null&&a===n}function Rl(r){return ve(r,"")}function ve(r,t){return r==null?t:X(r)?r:Mt(r)||xv(r)?r+"":t}function cm(r){var t=r.name;return!!(t&&t.indexOf(qA))}function Xl(r){return r&&r.id!=null&&Rl(r.id).indexOf(KA)===0}function CE(r){return KA+r}function AE(r,t,e){A(r,function(a){var n=a.newOption;it(n)&&(a.keyInfo.mainType=t,a.keyInfo.subType=ME(t,n,a.existing,e))})}function ME(r,t,e,a){var n=t.type?t.type:e?e.subType:a.determineSubType(r,t);return n}function DE(r,t){var e={},a={};return n(r||[],e),n(t||[],a,e),[i(e),i(a)];function n(o,s,l){for(var u=0,f=o.length;u<f;u++){var v=ve(o[u].seriesId,null);if(v==null)return;for(var h=Ft(o[u].dataIndex),c=l&&l[v],p=0,d=h.length;p<d;p++){var g=h[p];c&&c[g]?c[g]=null:(s[v]||(s[v]={}))[g]=1}}}function i(o,s){var l=[];for(var u in o)if(o.hasOwnProperty(u)&&o[u]!=null)if(s)l.push(+u);else{var f=i(o[u],!0);f.length&&l.push({seriesId:u,dataIndex:f})}return l}}function Gi(r,t){if(t.dataIndexInside!=null)return t.dataIndexInside;if(t.dataIndex!=null)return W(t.dataIndex)?U(t.dataIndex,function(e){return r.indexOfRawIndex(e)}):r.indexOfRawIndex(t.dataIndex);if(t.name!=null)return W(t.name)?U(t.name,function(e){return r.indexOfName(e)}):r.indexOfName(t.name)}function St(){var r="__ec_inner_"+LE++;return function(t){return t[r]||(t[r]={})}}var LE=ZA();function Zo(r,t,e){var a=pm(t,e),n=a.mainTypeSpecified,i=a.queryOptionMap,o=a.others,s=o,l=e?e.defaultMainType:null;return!n&&l&&i.set(l,{}),i.each(function(u,f){var v=ds(r,f,u,{useDefault:l===f,enableAll:e&&e.enableAll!=null?e.enableAll:!0,enableNone:e&&e.enableNone!=null?e.enableNone:!0});s[f+"Models"]=v.models,s[f+"Model"]=v.models[0]}),s}function pm(r,t){var e;if(X(r)){var a={};a[r+"Index"]=0,e=a}else e=r;var n=j(),i={},o=!1;return A(e,function(s,l){if(l==="dataIndex"||l==="dataIndexInside"){i[l]=s;return}var u=l.match(/^(\w+)(Index|Id|Name)$/)||[],f=u[1],v=(u[2]||"").toLowerCase();if(!(!f||!v||t&&t.includeMainTypes&&gt(t.includeMainTypes,f)<0)){o=o||!!f;var h=n.get(f)||n.set(f,{});h[v]=s}}),{mainTypeSpecified:o,queryOptionMap:n,others:i}}var Kt={useDefault:!0,enableAll:!1,enableNone:!1},IE={useDefault:!1,enableAll:!0,enableNone:!0};function ds(r,t,e,a){a=a||Kt;var n=e.index,i=e.id,o=e.name,s={models:null,specified:n!=null||i!=null||o!=null};if(!s.specified){var l=void 0;return s.models=a.useDefault&&(l=r.getComponent(t))?[l]:[],s}if(n==="none"||n===!1){if(a.enableNone)return s.models=[],s;n=-1}return n==="all"&&(a.enableAll?n=i=o=null:n=-1),s.models=r.queryComponents({mainType:t,index:n,id:i,name:o}),s}function QA(r,t,e){r.setAttribute?r.setAttribute(t,e):r[t]=e}function PE(r,t){return r.getAttribute?r.getAttribute(t):r[t]}function RE(r){return r==="auto"?Tt.domSupported?"html":"richText":r||"html"}function hg(r,t){var e=j(),a=[];return A(r,function(n){var i=t(n);(e.get(i)||(a.push(i),e.set(i,[]))).push(n)}),{keys:a,buckets:e}}function tM(r,t,e,a,n){var i=t==null||t==="auto";if(a==null)return a;if(Mt(a)){var o=a1(e||0,a,n);return ae(o,i?Math.max(zr(e||0),zr(a)):t)}else{if(X(a))return n<1?e:a;for(var s=[],l=e,u=a,f=Math.max(l?l.length:0,u.length),v=0;v<f;++v){var h=r.getDimensionInfo(v);if(h&&h.type==="ordinal")s[v]=(n<1&&l?l:u)[v];else{var c=l&&l[v]?l[v]:0,p=u[v],o=a1(c,p,n);s[v]=ae(o,i?Math.max(zr(c),zr(p)):t)}}return s}}var Tn=function(){function r(){}return r.prototype.reset=function(t,e,a,n){return this._list=t,this._step=n=n||1,this._idx=e,this._end=a??(n>0?t.length:0),this.item=null,this.key=NaN,this},r.prototype.next=function(){return(this._step>0?this._idx<this._end:this._idx>=this._end)?(this.item=this._list[this._idx],this.key=this._idx=this._idx+this._step,!0):!1},r}();function Oc(r){r.option=r.parentModel=r.ecModel=null}var kE=".",$n="___EC__COMPONENT__CONTAINER___",eM="___EC__EXTENDED_CLASS___";function ua(r){var t={main:"",sub:""};if(r){var e=r.split(kE);t.main=e[0]||"",t.sub=e[1]||""}return t}function EE(r){Re(/^[a-zA-Z0-9_]+([.][a-zA-Z0-9_]+)?$/.test(r),'componentType "'+r+'" illegal')}function OE(r){return!!(r&&r[eM])}function dm(r,t){r.$constructor=r,r.extend=function(e){var a=this,n;return NE(a)?n=function(i){z(o,i);function o(){return i.apply(this,arguments)||this}return o}(a):(n=function(){(e.$constructor||a).apply(this,arguments)},em(n,this)),G(n.prototype,e),n[eM]=!0,n.extend=this.extend,n.superCall=VE,n.superApply=GE,n.superClass=a,n}}function NE(r){return tt(r)&&/^class\s/.test(Function.prototype.toString.call(r))}function rM(r,t){r.extend=t.extend}var BE=Math.round(Math.random()*10);function zE(r){var t=["__\0is_clz",BE++].join("_");r.prototype[t]=!0,r.isInstance=function(e){return!!(e&&e[t])}}function VE(r,t){for(var e=[],a=2;a<arguments.length;a++)e[a-2]=arguments[a];return this.superClass.prototype[t].apply(r,e)}function GE(r,t,e){return this.superClass.prototype[t].apply(r,e)}function Fh(r){var t={};r.registerClass=function(a){var n=a.type||a.prototype.type;if(n){EE(n),a.prototype.type=n;var i=ua(n);if(!i.sub)t[i.main]=a;else if(i.sub!==$n){var o=e(i);o[i.sub]=a}}return a},r.getClass=function(a,n,i){var o=t[a];if(o&&o[$n]&&(o=n?o[n]:null),i&&!o)throw new Error(n?"Component "+a+"."+(n||"")+" is used but not imported.":a+".type should be specified.");return o},r.getClassesByMainType=function(a){var n=ua(a),i=[],o=t[n.main];return o&&o[$n]?A(o,function(s,l){l!==$n&&i.push(s)}):i.push(o),i},r.hasClass=function(a){var n=ua(a);return!!t[n.main]},r.getAllClassMainTypes=function(){var a=[];return A(t,function(n,i){a.push(i)}),a},r.hasSubTypes=function(a){var n=ua(a),i=t[n.main];return i&&i[$n]};function e(a){var n=t[a.main];return(!n||!n[$n])&&(n=t[a.main]={},n[$n]=!0),n}}function Fi(r,t){for(var e=0;e<r.length;e++)r[e][1]||(r[e][1]=r[e][0]);return t=t||!1,function(a,n,i){for(var o={},s=0;s<r.length;s++){var l=r[s][1];if(!(n&&gt(n,l)>=0||i&&gt(i,l)<0)){var u=a.getShallow(l,t);u!=null&&(o[r[s][0]]=u)}}return o}}var FE=[["fill","color"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["opacity"],["shadowColor"]],HE=Fi(FE),WE=function(){function r(){}return r.prototype.getAreaStyle=function(t,e){return HE(this,t,e)},r}(),cg=new jo(50);function UE(r){if(typeof r=="string"){var t=cg.get(r);return t&&t.image}else return r}function gm(r,t,e,a,n){if(r)if(typeof r=="string"){if(t&&t.__zrImageSrc===r||!e)return t;var i=cg.get(r),o={hostEl:e,cb:a,cbPayload:n};return i?(t=i.image,!Hh(t)&&i.pending.push(o)):(t=tr.loadImage(r,i1,i1),t.__zrImageSrc=r,cg.put(r,t.__cachedImgObj={image:t,pending:[o]})),t}else return r;else return t}function i1(){var r=this.__cachedImgObj;this.onload=this.onerror=this.__cachedImgObj=null;for(var t=0;t<r.pending.length;t++){var e=r.pending[t],a=e.cb;a&&a(this,e.cbPayload),e.hostEl.dirty()}r.pending.length=0}function Hh(r){return r&&r.width&&r.height}var Nc=/\{([a-zA-Z0-9_]+)\|([^}]*)\}/g;function YE(r,t,e,a,n){var i={};return aM(i,r,t,e,a,n),i.text}function aM(r,t,e,a,n,i){if(!e){r.text="",r.isTruncated=!1;return}var o=(t+"").split(`
`);i=nM(e,a,n,i);for(var s=!1,l={},u=0,f=o.length;u<f;u++)iM(l,o[u],i),o[u]=l.textLine,s=s||l.isTruncated;r.text=o.join(`
`),r.isTruncated=s}function nM(r,t,e,a){a=a||{};var n=G({},a);e=Q(e,"..."),n.maxIterations=Q(a.maxIterations,2);var i=n.minChar=Q(a.minChar,0),o=n.fontMeasureInfo=pa(t),s=o.asciiCharWidth;n.placeholder=Q(a.placeholder,"");for(var l=r=Math.max(0,r-1),u=0;u<i&&l>=s;u++)l-=s;var f=da(o,e);return f>l&&(e="",f=0),l=r-f,n.ellipsis=e,n.ellipsisWidth=f,n.contentWidth=l,n.containerWidth=r,n}function iM(r,t,e){var a=e.containerWidth,n=e.contentWidth,i=e.fontMeasureInfo;if(!a){r.textLine="",r.isTruncated=!1;return}var o=da(i,t);if(o<=a){r.textLine=t,r.isTruncated=!1;return}for(var s=0;;s++){if(o<=n||s>=e.maxIterations){t+=e.ellipsis;break}var l=s===0?ZE(t,n,i):o>0?Math.floor(t.length*n/o):0;t=t.substr(0,l),o=da(i,t)}t===""&&(t=e.placeholder),r.textLine=t,r.isTruncated=!0}function ZE(r,t,e){for(var a=0,n=0,i=r.length;n<i&&a<t;n++)a+=BA(e,r.charCodeAt(n));return n}function XE(r,t,e,a){var n=ym(r),i=t.overflow,o=t.padding,s=o?o[1]+o[3]:0,l=o?o[0]+o[2]:0,u=t.font,f=i==="truncate",v=wu(u),h=Q(t.lineHeight,v),c=t.lineOverflow==="truncate",p=!1,d=t.width;d==null&&e!=null&&(d=e-s);var g=t.height;g==null&&a!=null&&(g=a-l);var y;d!=null&&(i==="break"||i==="breakAll")?y=n?oM(n,t.font,d,i==="breakAll",0).lines:[]:y=n?n.split(`
`):[];var m=y.length*h;if(g==null&&(g=m),m>g&&c){var _=Math.floor(g/h);p=p||y.length>_,y=y.slice(0,_),m=y.length*h}if(n&&f&&d!=null)for(var S=nM(d,u,t.ellipsis,{minChar:t.truncateMinChar,placeholder:t.placeholder}),x={},b=0;b<y.length;b++)iM(x,y[b],S),y[b]=x.textLine,p=p||x.isTruncated;for(var w=g,T=0,C=pa(u),b=0;b<y.length;b++)T=Math.max(da(C,y[b]),T);d==null&&(d=T);var M=d;return w+=l,M+=s,{lines:y,height:g,outerWidth:M,outerHeight:w,lineHeight:h,calculatedLineHeight:v,contentWidth:T,contentHeight:m,width:d,isTruncated:p}}var $E=function(){function r(){}return r}(),o1=function(){function r(t){this.tokens=[],t&&(this.tokens=t)}return r}(),qE=function(){function r(){this.width=0,this.height=0,this.contentWidth=0,this.contentHeight=0,this.outerWidth=0,this.outerHeight=0,this.lines=[],this.isTruncated=!1}return r}();function KE(r,t,e,a,n){var i=new qE,o=ym(r);if(!o)return i;var s=t.padding,l=s?s[1]+s[3]:0,u=s?s[0]+s[2]:0,f=t.width;f==null&&e!=null&&(f=e-l);var v=t.height;v==null&&a!=null&&(v=a-u);for(var h=t.overflow,c=(h==="break"||h==="breakAll")&&f!=null?{width:f,accumWidth:0,breakAll:h==="breakAll"}:null,p=Nc.lastIndex=0,d;(d=Nc.exec(o))!=null;){var g=d.index;g>p&&Bc(i,o.substring(p,g),t,c),Bc(i,d[2],t,c,d[1]),p=Nc.lastIndex}p<o.length&&Bc(i,o.substring(p,o.length),t,c);var y=[],m=0,_=0,S=h==="truncate",x=t.lineOverflow==="truncate",b={};function w(It,Ot,vt){It.width=Ot,It.lineHeight=vt,m+=vt,_=Math.max(_,Ot)}t:for(var T=0;T<i.lines.length;T++){for(var C=i.lines[T],M=0,D=0,I=0;I<C.tokens.length;I++){var L=C.tokens[I],P=L.styleName&&t.rich[L.styleName]||{},k=L.textPadding=P.padding,R=k?k[1]+k[3]:0,O=L.font=P.font||t.font;L.contentHeight=wu(O);var E=Q(P.height,L.contentHeight);if(L.innerHeight=E,k&&(E+=k[0]+k[2]),L.height=E,L.lineHeight=Qe(P.lineHeight,t.lineHeight,E),L.align=P&&P.align||n,L.verticalAlign=P&&P.verticalAlign||"middle",x&&v!=null&&m+L.lineHeight>v){var B=i.lines.length;I>0?(C.tokens=C.tokens.slice(0,I),w(C,D,M),i.lines=i.lines.slice(0,T+1)):i.lines=i.lines.slice(0,T),i.isTruncated=i.isTruncated||i.lines.length<B;break t}var V=P.width,F=V==null||V==="auto";if(typeof V=="string"&&V.charAt(V.length-1)==="%")L.percentWidth=V,y.push(L),L.contentWidth=da(pa(O),L.text);else{if(F){var H=P.backgroundColor,Y=H&&H.image;Y&&(Y=UE(Y),Hh(Y)&&(L.width=Math.max(L.width,Y.width*E/Y.height)))}var K=S&&f!=null?f-D:null;K!=null&&K<L.width?!F||K<R?(L.text="",L.width=L.contentWidth=0):(aM(b,L.text,K-R,O,t.ellipsis,{minChar:t.truncateMinChar}),L.text=b.text,i.isTruncated=i.isTruncated||b.isTruncated,L.width=L.contentWidth=da(pa(O),L.text)):L.contentWidth=da(pa(O),L.text)}L.width+=R,D+=L.width,P&&(M=Math.max(M,L.lineHeight))}w(C,D,M)}i.outerWidth=i.width=Q(f,_),i.outerHeight=i.height=Q(v,m),i.contentHeight=m,i.contentWidth=_,i.outerWidth+=l,i.outerHeight+=u;for(var T=0;T<y.length;T++){var L=y[T],ft=L.percentWidth;L.width=parseInt(ft,10)/100*i.width}return i}function Bc(r,t,e,a,n){var i=t==="",o=n&&e.rich[n]||{},s=r.lines,l=o.font||e.font,u=!1,f,v;if(a){var h=o.padding,c=h?h[1]+h[3]:0;if(o.width!=null&&o.width!=="auto"){var p=Yr(o.width,a.width)+c;s.length>0&&p+a.accumWidth>a.width&&(f=t.split(`
`),u=!0),a.accumWidth=p}else{var d=oM(t,l,a.width,a.breakAll,a.accumWidth);a.accumWidth=d.accumWidth+c,v=d.linesWidths,f=d.lines}}f||(f=t.split(`
`));for(var g=pa(l),y=0;y<f.length;y++){var m=f[y],_=new $E;if(_.styleName=n,_.text=m,_.isLineHolder=!m&&!i,typeof o.width=="number"?_.width=o.width:_.width=v?v[y]:da(g,m),!y&&!u){var S=(s[s.length-1]||(s[0]=new o1)).tokens,x=S.length;x===1&&S[0].isLineHolder?S[0]=_:(m||!x||i)&&S.push(_)}else s.push(new o1([_]))}}function jE(r){var t=r.charCodeAt(0);return t>=32&&t<=591||t>=880&&t<=4351||t>=4608&&t<=5119||t>=7680&&t<=8303}var JE=Mr(",&?/;] ".split(""),function(r,t){return r[t]=!0,r},{});function QE(r){return jE(r)?!!JE[r]:!0}function oM(r,t,e,a,n){for(var i=[],o=[],s="",l="",u=0,f=0,v=pa(t),h=0;h<r.length;h++){var c=r.charAt(h);if(c===`
`){l&&(s+=l,f+=u),i.push(s),o.push(f),s="",l="",u=0,f=0;continue}var p=BA(v,c.charCodeAt(0)),d=a?!1:!QE(c);if(i.length?f+p>e:n+f+p>e){f?(s||l)&&(d?(s||(s=l,l="",u=0,f=u),i.push(s),o.push(f-u),l+=c,u+=p,s="",f=u):(l&&(s+=l,l="",u=0),i.push(s),o.push(f),s=c,f=p)):d?(i.push(l),o.push(u),l=c,u=p):(i.push(c),o.push(p));continue}f+=p,d?(l+=c,u+=p):(l&&(s+=l,l="",u=0),s+=c)}return l&&(s+=l),s&&(i.push(s),o.push(f)),i.length===1&&(f+=n),{accumWidth:f,lines:i,linesWidths:o}}function s1(r,t,e,a,n,i){if(r.baseX=e,r.baseY=a,r.outerWidth=r.outerHeight=null,!!t){var o=t.width*2,s=t.height*2;lt.set(l1,Jo(e,o,n),Pi(a,s,i),o,s),lt.intersect(t,l1,null,u1);var l=u1.outIntersectRect;r.outerWidth=l.width,r.outerHeight=l.height,r.baseX=Jo(l.x,l.width,n,!0),r.baseY=Pi(l.y,l.height,i,!0)}}var l1=new lt(0,0,0,0),u1={outIntersectRect:{},clamp:!0};function ym(r){return r!=null?r+="":r=""}function tO(r){var t=ym(r.text),e=r.font,a=da(pa(e),t),n=wu(e);return pg(r,a,n,null)}function pg(r,t,e,a){var n=new lt(Jo(r.x||0,t,r.textAlign),Pi(r.y||0,e,r.textBaseline),t,e),i=a??(sM(r)?r.lineWidth:0);return i>0&&(n.x-=i/2,n.y-=i/2,n.width+=i,n.height+=i),n}function sM(r){var t=r.stroke;return t!=null&&t!=="none"&&r.lineWidth>0}var dg="__zr_style_"+Math.round(Math.random()*10),Ri={shadowBlur:0,shadowOffsetX:0,shadowOffsetY:0,shadowColor:"#000",opacity:1,blend:"source-over"},Wh={style:{shadowBlur:!0,shadowOffsetX:!0,shadowOffsetY:!0,shadowColor:!0,opacity:!0}};Ri[dg]=!0;var f1=["z","z2","invisible"],eO=["invisible"],Lr=function(r){Zt(t,r);function t(e){return r.call(this,e)||this}return t.prototype._init=function(e){for(var a=Ct(e),n=0;n<a.length;n++){var i=a[n];i==="style"?this.useStyle(e[i]):r.prototype.attrKV.call(this,i,e[i])}this.style||this.useStyle({})},t.prototype.beforeBrush=function(){},t.prototype.afterBrush=function(){},t.prototype.innerBeforeBrush=function(){},t.prototype.innerAfterBrush=function(){},t.prototype.shouldBePainted=function(e,a,n,i){var o=this.transform;if(this.ignore||this.invisible||this.style.opacity===0||this.culling&&rO(this,e,a)||o&&!o[0]&&!o[3])return!1;if(n&&this.__clipPaths&&this.__clipPaths.length){for(var s=0;s<this.__clipPaths.length;++s)if(this.__clipPaths[s].isZeroArea())return!1}if(i&&this.parent)for(var l=this.parent;l;){if(l.ignore)return!1;l=l.parent}return!0},t.prototype.contain=function(e,a){return this.rectContain(e,a)},t.prototype.traverse=function(e,a){e.call(a,this)},t.prototype.rectContain=function(e,a){var n=this.transformCoordToLocal(e,a),i=this.getBoundingRect();return i.contain(n[0],n[1])},t.prototype.getPaintRect=function(){var e=this._paintRect;if(!this._paintRect||this.__dirty){var a=this.transform,n=this.getBoundingRect(),i=this.style,o=i.shadowBlur||0,s=i.shadowOffsetX||0,l=i.shadowOffsetY||0;e=this._paintRect||(this._paintRect=new lt(0,0,0,0)),a?lt.applyTransform(e,n,a):e.copy(n),(o||s||l)&&(e.width+=o*2+Math.abs(s),e.height+=o*2+Math.abs(l),e.x=Math.min(e.x,e.x+s-o),e.y=Math.min(e.y,e.y+l-o));var u=this.dirtyRectTolerance;e.isZero()||(e.x=Math.floor(e.x-u),e.y=Math.floor(e.y-u),e.width=Math.ceil(e.width+1+u*2),e.height=Math.ceil(e.height+1+u*2))}return e},t.prototype.setPrevPaintRect=function(e){e?(this._prevPaintRect=this._prevPaintRect||new lt(0,0,0,0),this._prevPaintRect.copy(e)):this._prevPaintRect=null},t.prototype.getPrevPaintRect=function(){return this._prevPaintRect},t.prototype.animateStyle=function(e){return this.animate("style",e)},t.prototype.updateDuringAnimation=function(e){e==="style"?this.dirtyStyle():this.markRedraw()},t.prototype.attrKV=function(e,a){e!=="style"?r.prototype.attrKV.call(this,e,a):this.style?this.setStyle(a):this.useStyle(a)},t.prototype.setStyle=function(e,a){return typeof e=="string"?this.style[e]=a:G(this.style,e),this.dirtyStyle(),this},t.prototype.dirtyStyle=function(e){e||this.markRedraw(),this.__dirty|=cl,this._rect&&(this._rect=null)},t.prototype.dirty=function(){this.dirtyStyle()},t.prototype.styleChanged=function(){return!!(this.__dirty&cl)},t.prototype.styleUpdated=function(){this.__dirty&=~cl},t.prototype.createStyle=function(e){return Su(Ri,e)},t.prototype.useStyle=function(e){e[dg]||(e=this.createStyle(e)),this.__inHover?this.__hoverStyle=e:this.style=e,this.dirtyStyle()},t.prototype.isStyleObject=function(e){return e[dg]},t.prototype._innerSaveToNormal=function(e){r.prototype._innerSaveToNormal.call(this,e);var a=this._normalState;e.style&&!a.style&&(a.style=this._mergeStyle(this.createStyle(),this.style)),this._savePrimaryToNormal(e,a,f1)},t.prototype._applyStateObj=function(e,a,n,i,o,s){r.prototype._applyStateObj.call(this,e,a,n,i,o,s);var l=!(a&&i),u;if(a&&a.style?o?i?u=a.style:(u=this._mergeStyle(this.createStyle(),n.style),this._mergeStyle(u,a.style)):(u=this._mergeStyle(this.createStyle(),i?this.style:n.style),this._mergeStyle(u,a.style)):l&&(u=n.style),u)if(o){var f=this.style;if(this.style=this.createStyle(l?{}:f),l)for(var v=Ct(f),h=0;h<v.length;h++){var c=v[h];c in u&&(u[c]=u[c],this.style[c]=f[c])}for(var p=Ct(u),h=0;h<p.length;h++){var c=p[h];this.style[c]=this.style[c]}this._transitionState(e,{style:u},s,this.getAnimationStyleProps())}else this.useStyle(u);for(var d=this.__inHover?eO:f1,h=0;h<d.length;h++){var c=d[h];a&&a[c]!=null?this[c]=a[c]:l&&n[c]!=null&&(this[c]=n[c])}},t.prototype._mergeStates=function(e){for(var a=r.prototype._mergeStates.call(this,e),n,i=0;i<e.length;i++){var o=e[i];o.style&&(n=n||{},this._mergeStyle(n,o.style))}return n&&(a.style=n),a},t.prototype._mergeStyle=function(e,a){return G(e,a),e},t.prototype.getAnimationStyleProps=function(){return Wh},t.initDefaultProps=function(){var e=t.prototype;e.type="displayable",e.invisible=!1,e.z=0,e.z2=0,e.zlevel=0,e.culling=!1,e.cursor="pointer",e.rectHover=!1,e.incremental=!1,e._rect=null,e.dirtyRectTolerance=0,e.__dirty=ir|cl}(),t}(Vh),zc=new lt(0,0,0,0),Vc=new lt(0,0,0,0);function rO(r,t,e){return zc.copy(r.getBoundingRect()),r.transform&&zc.applyTransform(r.transform),Vc.width=t,Vc.height=e,!zc.intersect(Vc)}var Ke=Math.min,je=Math.max,Gc=Math.sin,Fc=Math.cos,qn=Math.PI*2,qu=Bn(),Ku=Bn(),ju=Bn();function Uh(r,t,e){if(r.length!==0){for(var a=r[0],n=a[0],i=a[0],o=a[1],s=a[1],l=1;l<r.length;l++)a=r[l],n=Ke(n,a[0]),i=je(i,a[0]),o=Ke(o,a[1]),s=je(s,a[1]);t[0]=n,t[1]=o,e[0]=i,e[1]=s}}function v1(r,t,e,a,n,i){n[0]=Ke(r,e),n[1]=Ke(t,a),i[0]=je(r,e),i[1]=je(t,a)}var h1=[],c1=[];function aO(r,t,e,a,n,i,o,s,l,u){var f=bA,v=ge,h=f(r,e,n,o,h1);l[0]=1/0,l[1]=1/0,u[0]=-1/0,u[1]=-1/0;for(var c=0;c<h;c++){var p=v(r,e,n,o,h1[c]);l[0]=Ke(p,l[0]),u[0]=je(p,u[0])}h=f(t,a,i,s,c1);for(var c=0;c<h;c++){var d=v(t,a,i,s,c1[c]);l[1]=Ke(d,l[1]),u[1]=je(d,u[1])}l[0]=Ke(r,l[0]),u[0]=je(r,u[0]),l[0]=Ke(o,l[0]),u[0]=je(o,u[0]),l[1]=Ke(t,l[1]),u[1]=je(t,u[1]),l[1]=Ke(s,l[1]),u[1]=je(s,u[1])}function nO(r,t,e,a,n,i,o,s){var l=TA,u=Te,f=je(Ke(l(r,e,n),1),0),v=je(Ke(l(t,a,i),1),0),h=u(r,e,n,f),c=u(t,a,i,v);o[0]=Ke(r,n,h),o[1]=Ke(t,i,c),s[0]=je(r,n,h),s[1]=je(t,i,c)}function iO(r,t,e,a,n,i,o,s,l){var u=Oa,f=Na,v=Math.abs(n-i);if(v%qn<1e-4&&v>1e-4){s[0]=r-e,s[1]=t-a,l[0]=r+e,l[1]=t+a;return}if(qu[0]=Fc(n)*e+r,qu[1]=Gc(n)*a+t,Ku[0]=Fc(i)*e+r,Ku[1]=Gc(i)*a+t,u(s,qu,Ku),f(l,qu,Ku),n=n%qn,n<0&&(n=n+qn),i=i%qn,i<0&&(i=i+qn),n>i&&!o?i+=qn:n<i&&o&&(n+=qn),o){var h=i;i=n,n=h}for(var c=0;c<i;c+=Math.PI/2)c>n&&(ju[0]=Fc(c)*e+r,ju[1]=Gc(c)*a+t,u(s,ju,s),f(l,ju,l))}var Ht={M:1,L:2,C:3,Q:4,A:5,Z:6,R:7},Kn=[],jn=[],qr=[],rn=[],Kr=[],jr=[],Hc=Math.min,Wc=Math.max,Jn=Math.cos,Qn=Math.sin,Aa=Math.abs,gg=Math.PI,vn=gg*2,Uc=typeof Float32Array<"u",Bs=[];function Yc(r){var t=Math.round(r/gg*1e8)/1e8;return t%2*gg}function Yh(r,t){var e=Yc(r[0]);e<0&&(e+=vn);var a=e-r[0],n=r[1];n+=a,!t&&n-e>=vn?n=e+vn:t&&e-n>=vn?n=e-vn:!t&&e>n?n=e+(vn-Yc(e-n)):t&&e<n&&(n=e-(vn-Yc(n-e))),r[0]=e,r[1]=n}var ma=function(){function r(t){this.dpr=1,this._xi=0,this._yi=0,this._x0=0,this._y0=0,this._len=0,t&&(this._saveData=!1),this._saveData&&(this.data=[])}return r.prototype.increaseVersion=function(){this._version++},r.prototype.getVersion=function(){return this._version},r.prototype.setScale=function(t,e,a){a=a||0,a>0&&(this._ux=Aa(a/Pv/t)||0,this._uy=Aa(a/Pv/e)||0)},r.prototype.setDPR=function(t){this.dpr=t},r.prototype.setContext=function(t){this._ctx=t},r.prototype.getContext=function(){return this._ctx},r.prototype.beginPath=function(){return this._ctx&&this._ctx.beginPath(),this.reset(),this},r.prototype.reset=function(){this._saveData&&(this._len=0),this._pathSegLen&&(this._pathSegLen=null,this._pathLen=0),this._version++},r.prototype.moveTo=function(t,e){return this._drawPendingPt(),this.addData(Ht.M,t,e),this._ctx&&this._ctx.moveTo(t,e),this._x0=t,this._y0=e,this._xi=t,this._yi=e,this},r.prototype.lineTo=function(t,e){var a=Aa(t-this._xi),n=Aa(e-this._yi),i=a>this._ux||n>this._uy;if(this.addData(Ht.L,t,e),this._ctx&&i&&this._ctx.lineTo(t,e),i)this._xi=t,this._yi=e,this._pendingPtDist=0;else{var o=a*a+n*n;o>this._pendingPtDist&&(this._pendingPtX=t,this._pendingPtY=e,this._pendingPtDist=o)}return this},r.prototype.bezierCurveTo=function(t,e,a,n,i,o){return this._drawPendingPt(),this.addData(Ht.C,t,e,a,n,i,o),this._ctx&&this._ctx.bezierCurveTo(t,e,a,n,i,o),this._xi=i,this._yi=o,this},r.prototype.quadraticCurveTo=function(t,e,a,n){return this._drawPendingPt(),this.addData(Ht.Q,t,e,a,n),this._ctx&&this._ctx.quadraticCurveTo(t,e,a,n),this._xi=a,this._yi=n,this},r.prototype.arc=function(t,e,a,n,i,o){this._drawPendingPt(),Bs[0]=n,Bs[1]=i,Yh(Bs,o),n=Bs[0],i=Bs[1];var s=i-n;return this.addData(Ht.A,t,e,a,a,n,s,0,o?0:1),this._ctx&&this._ctx.arc(t,e,a,n,i,o),this._xi=Jn(i)*a+t,this._yi=Qn(i)*a+e,this},r.prototype.arcTo=function(t,e,a,n,i){return this._drawPendingPt(),this._ctx&&this._ctx.arcTo(t,e,a,n,i),this},r.prototype.rect=function(t,e,a,n){return this._drawPendingPt(),this._ctx&&this._ctx.rect(t,e,a,n),this.addData(Ht.R,t,e,a,n),this},r.prototype.closePath=function(){this._drawPendingPt(),this.addData(Ht.Z);var t=this._ctx,e=this._x0,a=this._y0;return t&&t.closePath(),this._xi=e,this._yi=a,this},r.prototype.fill=function(t){t&&t.fill(),this.toStatic()},r.prototype.stroke=function(t){t&&t.stroke(),this.toStatic()},r.prototype.len=function(){return this._len},r.prototype.setData=function(t){if(this._saveData){var e=t.length;!(this.data&&this.data.length===e)&&Uc&&(this.data=new Float32Array(e));for(var a=0;a<e;a++)this.data[a]=t[a];this._len=e}},r.prototype.appendPath=function(t){if(this._saveData){t instanceof Array||(t=[t]);for(var e=t.length,a=0,n=this._len,i=0;i<e;i++)a+=t[i].len();var o=this.data;if(Uc&&(o instanceof Float32Array||!o)&&(this.data=new Float32Array(n+a),n>0&&o))for(var s=0;s<n;s++)this.data[s]=o[s];for(var i=0;i<e;i++)for(var l=t[i].data,s=0;s<l.length;s++)this.data[n++]=l[s];this._len=n}},r.prototype.addData=function(t,e,a,n,i,o,s,l,u){if(this._saveData){var f=this.data;this._len+arguments.length>f.length&&(this._expandData(),f=this.data);for(var v=0;v<arguments.length;v++)f[this._len++]=arguments[v]}},r.prototype._drawPendingPt=function(){this._pendingPtDist>0&&(this._ctx&&this._ctx.lineTo(this._pendingPtX,this._pendingPtY),this._pendingPtDist=0)},r.prototype._expandData=function(){if(!(this.data instanceof Array)){for(var t=[],e=0;e<this._len;e++)t[e]=this.data[e];this.data=t}},r.prototype.toStatic=function(){if(this._saveData){this._drawPendingPt();var t=this.data;t instanceof Array&&(t.length=this._len,Uc&&this._len>11&&(this.data=new Float32Array(t)))}},r.prototype.getBoundingRect=function(){qr[0]=qr[1]=Kr[0]=Kr[1]=Number.MAX_VALUE,rn[0]=rn[1]=jr[0]=jr[1]=-Number.MAX_VALUE;var t=this.data,e=0,a=0,n=0,i=0,o;for(o=0;o<this._len;){var s=t[o++],l=o===1;switch(l&&(e=t[o],a=t[o+1],n=e,i=a),s){case Ht.M:e=n=t[o++],a=i=t[o++],Kr[0]=n,Kr[1]=i,jr[0]=n,jr[1]=i;break;case Ht.L:v1(e,a,t[o],t[o+1],Kr,jr),e=t[o++],a=t[o++];break;case Ht.C:aO(e,a,t[o++],t[o++],t[o++],t[o++],t[o],t[o+1],Kr,jr),e=t[o++],a=t[o++];break;case Ht.Q:nO(e,a,t[o++],t[o++],t[o],t[o+1],Kr,jr),e=t[o++],a=t[o++];break;case Ht.A:var u=t[o++],f=t[o++],v=t[o++],h=t[o++],c=t[o++],p=t[o++]+c;o+=1;var d=!t[o++];l&&(n=Jn(c)*v+u,i=Qn(c)*h+f),iO(u,f,v,h,c,p,d,Kr,jr),e=Jn(p)*v+u,a=Qn(p)*h+f;break;case Ht.R:n=e=t[o++],i=a=t[o++];var g=t[o++],y=t[o++];v1(n,i,n+g,i+y,Kr,jr);break;case Ht.Z:e=n,a=i;break}Oa(qr,qr,Kr),Na(rn,rn,jr)}return o===0&&(qr[0]=qr[1]=rn[0]=rn[1]=0),new lt(qr[0],qr[1],rn[0]-qr[0],rn[1]-qr[1])},r.prototype._calculateLength=function(){var t=this.data,e=this._len,a=this._ux,n=this._uy,i=0,o=0,s=0,l=0;this._pathSegLen||(this._pathSegLen=[]);for(var u=this._pathSegLen,f=0,v=0,h=0;h<e;){var c=t[h++],p=h===1;p&&(i=t[h],o=t[h+1],s=i,l=o);var d=-1;switch(c){case Ht.M:i=s=t[h++],o=l=t[h++];break;case Ht.L:{var g=t[h++],y=t[h++],m=g-i,_=y-o;(Aa(m)>a||Aa(_)>n||h===e-1)&&(d=Math.sqrt(m*m+_*_),i=g,o=y);break}case Ht.C:{var S=t[h++],x=t[h++],g=t[h++],y=t[h++],b=t[h++],w=t[h++];d=yk(i,o,S,x,g,y,b,w,10),i=b,o=w;break}case Ht.Q:{var S=t[h++],x=t[h++],g=t[h++],y=t[h++];d=_k(i,o,S,x,g,y,10),i=g,o=y;break}case Ht.A:var T=t[h++],C=t[h++],M=t[h++],D=t[h++],I=t[h++],L=t[h++],P=L+I;h+=1,p&&(s=Jn(I)*M+T,l=Qn(I)*D+C),d=Wc(M,D)*Hc(vn,Math.abs(L)),i=Jn(P)*M+T,o=Qn(P)*D+C;break;case Ht.R:{s=i=t[h++],l=o=t[h++];var k=t[h++],R=t[h++];d=k*2+R*2;break}case Ht.Z:{var m=s-i,_=l-o;d=Math.sqrt(m*m+_*_),i=s,o=l;break}}d>=0&&(u[v++]=d,f+=d)}return this._pathLen=f,f},r.prototype.rebuildPath=function(t,e){var a=this.data,n=this._ux,i=this._uy,o=this._len,s,l,u,f,v,h,c=e<1,p,d,g=0,y=0,m,_=0,S,x;if(!(c&&(this._pathSegLen||this._calculateLength(),p=this._pathSegLen,d=this._pathLen,m=e*d,!m)))t:for(var b=0;b<o;){var w=a[b++],T=b===1;switch(T&&(u=a[b],f=a[b+1],s=u,l=f),w!==Ht.L&&_>0&&(t.lineTo(S,x),_=0),w){case Ht.M:s=u=a[b++],l=f=a[b++],t.moveTo(u,f);break;case Ht.L:{v=a[b++],h=a[b++];var C=Aa(v-u),M=Aa(h-f);if(C>n||M>i){if(c){var D=p[y++];if(g+D>m){var I=(m-g)/D;t.lineTo(u*(1-I)+v*I,f*(1-I)+h*I);break t}g+=D}t.lineTo(v,h),u=v,f=h,_=0}else{var L=C*C+M*M;L>_&&(S=v,x=h,_=L)}break}case Ht.C:{var P=a[b++],k=a[b++],R=a[b++],O=a[b++],E=a[b++],B=a[b++];if(c){var D=p[y++];if(g+D>m){var I=(m-g)/D;In(u,P,R,E,I,Kn),In(f,k,O,B,I,jn),t.bezierCurveTo(Kn[1],jn[1],Kn[2],jn[2],Kn[3],jn[3]);break t}g+=D}t.bezierCurveTo(P,k,R,O,E,B),u=E,f=B;break}case Ht.Q:{var P=a[b++],k=a[b++],R=a[b++],O=a[b++];if(c){var D=p[y++];if(g+D>m){var I=(m-g)/D;Hl(u,P,R,I,Kn),Hl(f,k,O,I,jn),t.quadraticCurveTo(Kn[1],jn[1],Kn[2],jn[2]);break t}g+=D}t.quadraticCurveTo(P,k,R,O),u=R,f=O;break}case Ht.A:var V=a[b++],F=a[b++],H=a[b++],Y=a[b++],K=a[b++],ft=a[b++],It=a[b++],Ot=!a[b++],vt=H>Y?H:Y,at=Aa(H-Y)>.001,dt=K+ft,J=!1;if(c){var D=p[y++];g+D>m&&(dt=K+ft*(m-g)/D,J=!0),g+=D}if(at&&t.ellipse?t.ellipse(V,F,H,Y,It,K,dt,Ot):t.arc(V,F,vt,K,dt,Ot),J)break t;T&&(s=Jn(K)*H+V,l=Qn(K)*Y+F),u=Jn(dt)*H+V,f=Qn(dt)*Y+F;break;case Ht.R:s=u=a[b],l=f=a[b+1],v=a[b++],h=a[b++];var ht=a[b++],zt=a[b++];if(c){var D=p[y++];if(g+D>m){var Dt=m-g;t.moveTo(v,h),t.lineTo(v+Hc(Dt,ht),h),Dt-=ht,Dt>0&&t.lineTo(v+ht,h+Hc(Dt,zt)),Dt-=zt,Dt>0&&t.lineTo(v+Wc(ht-Dt,0),h+zt),Dt-=ht,Dt>0&&t.lineTo(v,h+Wc(zt-Dt,0));break t}g+=D}t.rect(v,h,ht,zt);break;case Ht.Z:if(c){var D=p[y++];if(g+D>m){var I=(m-g)/D;t.lineTo(u*(1-I)+s*I,f*(1-I)+l*I);break t}g+=D}t.closePath(),u=s,f=l}}},r.prototype.clone=function(){var t=new r,e=this.data;return t.data=e.slice?e.slice():Array.prototype.slice.call(e),t._len=this._len,t},r.prototype.canSave=function(){return!!this._saveData},r.CMD=Ht,r.initDefaultProps=function(){var t=r.prototype;t._saveData=!0,t._ux=0,t._uy=0,t._pendingPtDist=0,t._version=0}(),r}();function cn(r,t,e,a,n,i,o){if(n===0)return!1;var s=n,l=0,u=r;if(o>t+s&&o>a+s||o<t-s&&o<a-s||i>r+s&&i>e+s||i<r-s&&i<e-s)return!1;if(r!==e)l=(t-a)/(r-e),u=(r*a-e*t)/(r-e);else return Math.abs(i-r)<=s/2;var f=l*i-o+u,v=f*f/(l*l+1);return v<=s/2*s/2}function oO(r,t,e,a,n,i,o,s,l,u,f){if(l===0)return!1;var v=l;if(f>t+v&&f>a+v&&f>i+v&&f>s+v||f<t-v&&f<a-v&&f<i-v&&f<s-v||u>r+v&&u>e+v&&u>n+v&&u>o+v||u<r-v&&u<e-v&&u<n-v&&u<o-v)return!1;var h=wA(r,t,e,a,n,i,o,s,u,f,null);return h<=v/2}function lM(r,t,e,a,n,i,o,s,l){if(o===0)return!1;var u=o;if(l>t+u&&l>a+u&&l>i+u||l<t-u&&l<a-u&&l<i-u||s>r+u&&s>e+u&&s>n+u||s<r-u&&s<e-u&&s<n-u)return!1;var f=CA(r,t,e,a,n,i,s,l,null);return f<=u/2}var p1=Math.PI*2;function ur(r){return r%=p1,r<0&&(r+=p1),r}var zs=Math.PI*2;function sO(r,t,e,a,n,i,o,s,l){if(o===0)return!1;var u=o;s-=r,l-=t;var f=Math.sqrt(s*s+l*l);if(f-u>e||f+u<e)return!1;if(Math.abs(a-n)%zs<1e-4)return!0;if(i){var v=a;a=ur(n),n=ur(v)}else a=ur(a),n=ur(n);a>n&&(n+=zs);var h=Math.atan2(l,s);return h<0&&(h+=zs),h>=a&&h<=n||h+zs>=a&&h+zs<=n}function Ra(r,t,e,a,n,i){if(i>t&&i>a||i<t&&i<a||a===t)return 0;var o=(i-t)/(a-t),s=a<t?1:-1;(o===1||o===0)&&(s=a<t?.5:-.5);var l=o*(e-r)+r;return l===n?1/0:l>n?s:0}var an=ma.CMD,ti=Math.PI*2,lO=1e-4;function uO(r,t){return Math.abs(r-t)<lO}var Fe=[-1,-1,-1],Sr=[-1,-1];function fO(){var r=Sr[0];Sr[0]=Sr[1],Sr[1]=r}function vO(r,t,e,a,n,i,o,s,l,u){if(u>t&&u>a&&u>i&&u>s||u<t&&u<a&&u<i&&u<s)return 0;var f=Mv(t,a,i,s,u,Fe);if(f===0)return 0;for(var v=0,h=-1,c=void 0,p=void 0,d=0;d<f;d++){var g=Fe[d],y=g===0||g===1?.5:1,m=ge(r,e,n,o,g);m<l||(h<0&&(h=bA(t,a,i,s,Sr),Sr[1]<Sr[0]&&h>1&&fO(),c=ge(t,a,i,s,Sr[0]),h>1&&(p=ge(t,a,i,s,Sr[1]))),h===2?g<Sr[0]?v+=c<t?y:-y:g<Sr[1]?v+=p<c?y:-y:v+=s<p?y:-y:g<Sr[0]?v+=c<t?y:-y:v+=s<c?y:-y)}return v}function hO(r,t,e,a,n,i,o,s){if(s>t&&s>a&&s>i||s<t&&s<a&&s<i)return 0;var l=mk(t,a,i,s,Fe);if(l===0)return 0;var u=TA(t,a,i);if(u>=0&&u<=1){for(var f=0,v=Te(t,a,i,u),h=0;h<l;h++){var c=Fe[h]===0||Fe[h]===1?.5:1,p=Te(r,e,n,Fe[h]);p<o||(Fe[h]<u?f+=v<t?c:-c:f+=i<v?c:-c)}return f}else{var c=Fe[0]===0||Fe[0]===1?.5:1,p=Te(r,e,n,Fe[0]);return p<o?0:i<t?c:-c}}function cO(r,t,e,a,n,i,o,s){if(s-=t,s>e||s<-e)return 0;var l=Math.sqrt(e*e-s*s);Fe[0]=-l,Fe[1]=l;var u=Math.abs(a-n);if(u<1e-4)return 0;if(u>=ti-1e-4){a=0,n=ti;var f=i?1:-1;return o>=Fe[0]+r&&o<=Fe[1]+r?f:0}if(a>n){var v=a;a=n,n=v}a<0&&(a+=ti,n+=ti);for(var h=0,c=0;c<2;c++){var p=Fe[c];if(p+r>o){var d=Math.atan2(s,p),f=i?1:-1;d<0&&(d=ti+d),(d>=a&&d<=n||d+ti>=a&&d+ti<=n)&&(d>Math.PI/2&&d<Math.PI*1.5&&(f=-f),h+=f)}}return h}function uM(r,t,e,a,n){for(var i=r.data,o=r.len(),s=0,l=0,u=0,f=0,v=0,h,c,p=0;p<o;){var d=i[p++],g=p===1;switch(d===an.M&&p>1&&(e||(s+=Ra(l,u,f,v,a,n))),g&&(l=i[p],u=i[p+1],f=l,v=u),d){case an.M:f=i[p++],v=i[p++],l=f,u=v;break;case an.L:if(e){if(cn(l,u,i[p],i[p+1],t,a,n))return!0}else s+=Ra(l,u,i[p],i[p+1],a,n)||0;l=i[p++],u=i[p++];break;case an.C:if(e){if(oO(l,u,i[p++],i[p++],i[p++],i[p++],i[p],i[p+1],t,a,n))return!0}else s+=vO(l,u,i[p++],i[p++],i[p++],i[p++],i[p],i[p+1],a,n)||0;l=i[p++],u=i[p++];break;case an.Q:if(e){if(lM(l,u,i[p++],i[p++],i[p],i[p+1],t,a,n))return!0}else s+=hO(l,u,i[p++],i[p++],i[p],i[p+1],a,n)||0;l=i[p++],u=i[p++];break;case an.A:var y=i[p++],m=i[p++],_=i[p++],S=i[p++],x=i[p++],b=i[p++];p+=1;var w=!!(1-i[p++]);h=Math.cos(x)*_+y,c=Math.sin(x)*S+m,g?(f=h,v=c):s+=Ra(l,u,h,c,a,n);var T=(a-y)*S/_+y;if(e){if(sO(y,m,S,x,x+b,w,t,T,n))return!0}else s+=cO(y,m,S,x,x+b,w,T,n);l=Math.cos(x+b)*_+y,u=Math.sin(x+b)*S+m;break;case an.R:f=l=i[p++],v=u=i[p++];var C=i[p++],M=i[p++];if(h=f+C,c=v+M,e){if(cn(f,v,h,v,t,a,n)||cn(h,v,h,c,t,a,n)||cn(h,c,f,c,t,a,n)||cn(f,c,f,v,t,a,n))return!0}else s+=Ra(h,v,h,c,a,n),s+=Ra(f,c,f,v,a,n);break;case an.Z:if(e){if(cn(l,u,f,v,t,a,n))return!0}else s+=Ra(l,u,f,v,a,n);l=f,u=v;break}}return!e&&!uO(u,v)&&(s+=Ra(l,u,f,v,a,n)||0),s!==0}function pO(r,t,e){return uM(r,0,!1,t,e)}function dO(r,t,e,a){return uM(r,t,!0,e,a)}var Ov=nt({fill:"#000",stroke:null,strokePercent:1,fillOpacity:1,strokeOpacity:1,lineDashOffset:0,lineWidth:1,lineCap:"butt",miterLimit:10,strokeNoScale:!1,strokeFirst:!1},Ri),gO={style:nt({fill:!0,stroke:!0,strokePercent:!0,fillOpacity:!0,strokeOpacity:!0,lineDashOffset:!0,lineWidth:!0,miterLimit:!0},Wh.style)},Zc=ga.concat(["invisible","culling","z","z2","zlevel","parent"]),bt=function(r){Zt(t,r);function t(e){return r.call(this,e)||this}return t.prototype.update=function(){var e=this;r.prototype.update.call(this);var a=this.style;if(a.decal){var n=this._decalEl=this._decalEl||new t;n.buildPath===t.prototype.buildPath&&(n.buildPath=function(l){e.buildPath(l,e.shape)}),n.silent=!0;var i=n.style;for(var o in a)i[o]!==a[o]&&(i[o]=a[o]);i.fill=a.fill?a.decal:null,i.decal=null,i.shadowColor=null,a.strokeFirst&&(i.stroke=null);for(var s=0;s<Zc.length;++s)n[Zc[s]]=this[Zc[s]];n.__dirty|=ir}else this._decalEl&&(this._decalEl=null)},t.prototype.getDecalElement=function(){return this._decalEl},t.prototype._init=function(e){var a=Ct(e);this.shape=this.getDefaultShape();var n=this.getDefaultStyle();n&&this.useStyle(n);for(var i=0;i<a.length;i++){var o=a[i],s=e[o];o==="style"?this.style?G(this.style,s):this.useStyle(s):o==="shape"?G(this.shape,s):r.prototype.attrKV.call(this,o,s)}this.style||this.useStyle({})},t.prototype.getDefaultStyle=function(){return null},t.prototype.getDefaultShape=function(){return{}},t.prototype.canBeInsideText=function(){return this.hasFill()},t.prototype.getInsideTextFill=function(){var e=this.style.fill;if(e!=="none"){if(X(e)){var a=Yl(e,0);return a>.5?og:a>.2?qk:sg}else if(e)return sg}return og},t.prototype.getInsideTextStroke=function(e){var a=this.style.fill;if(X(a)){var n=this.__zr,i=!!(n&&n.isDarkMode()),o=Yl(e,0)<ig;if(i===o)return a}},t.prototype.buildPath=function(e,a,n){},t.prototype.pathUpdated=function(){this.__dirty&=~ko},t.prototype.getUpdatedPathProxy=function(e){return!this.path&&this.createPathProxy(),this.path.beginPath(),this.buildPath(this.path,this.shape,e),this.path},t.prototype.createPathProxy=function(){this.path=new ma(!1)},t.prototype.hasStroke=function(){var e=this.style,a=e.stroke;return!(a==null||a==="none"||!(e.lineWidth>0))},t.prototype.hasFill=function(){var e=this.style,a=e.fill;return a!=null&&a!=="none"},t.prototype.getBoundingRect=function(){var e=this._rect,a=this.style,n=!e;if(n){var i=!1;this.path||(i=!0,this.createPathProxy());var o=this.path;(i||this.__dirty&ko)&&(o.beginPath(),this.buildPath(o,this.shape,!1),this.pathUpdated()),e=o.getBoundingRect()}if(this._rect=e,this.hasStroke()&&this.path&&this.path.len()>0){var s=this._rectStroke||(this._rectStroke=e.clone());if(this.__dirty||n){s.copy(e);var l=a.strokeNoScale?this.getLineScale():1,u=a.lineWidth;if(!this.hasFill()){var f=this.strokeContainThreshold;u=Math.max(u,f??4)}l>1e-10&&(s.width+=u/l,s.height+=u/l,s.x-=u/l/2,s.y-=u/l/2)}return s}return e},t.prototype.contain=function(e,a){var n=this.transformCoordToLocal(e,a),i=this.getBoundingRect(),o=this.style;if(e=n[0],a=n[1],i.contain(e,a)){var s=this.path;if(this.hasStroke()){var l=o.lineWidth,u=o.strokeNoScale?this.getLineScale():1;if(u>1e-10&&(this.hasFill()||(l=Math.max(l,this.strokeContainThreshold)),dO(s,l/u,e,a)))return!0}if(this.hasFill())return pO(s,e,a)}return!1},t.prototype.dirtyShape=function(){this.__dirty|=ko,this._rect&&(this._rect=null),this._decalEl&&this._decalEl.dirtyShape(),this.markRedraw()},t.prototype.dirty=function(){this.dirtyStyle(),this.dirtyShape()},t.prototype.animateShape=function(e){return this.animate("shape",e)},t.prototype.updateDuringAnimation=function(e){e==="style"?this.dirtyStyle():e==="shape"?this.dirtyShape():this.markRedraw()},t.prototype.attrKV=function(e,a){e==="shape"?this.setShape(a):r.prototype.attrKV.call(this,e,a)},t.prototype.setShape=function(e,a){var n=this.shape;return n||(n=this.shape={}),typeof e=="string"?n[e]=a:G(n,e),this.dirtyShape(),this},t.prototype.shapeChanged=function(){return!!(this.__dirty&ko)},t.prototype.createStyle=function(e){return Su(Ov,e)},t.prototype._innerSaveToNormal=function(e){r.prototype._innerSaveToNormal.call(this,e);var a=this._normalState;e.shape&&!a.shape&&(a.shape=G({},this.shape))},t.prototype._applyStateObj=function(e,a,n,i,o,s){r.prototype._applyStateObj.call(this,e,a,n,i,o,s);var l=!(a&&i),u;if(a&&a.shape?o?i?u=a.shape:(u=G({},n.shape),G(u,a.shape)):(u=G({},i?this.shape:n.shape),G(u,a.shape)):l&&(u=n.shape),u)if(o){this.shape=G({},this.shape);for(var f={},v=Ct(u),h=0;h<v.length;h++){var c=v[h];typeof u[c]=="object"?this.shape[c]=u[c]:f[c]=u[c]}this._transitionState(e,{shape:f},s)}else this.shape=u,this.dirtyShape()},t.prototype._mergeStates=function(e){for(var a=r.prototype._mergeStates.call(this,e),n,i=0;i<e.length;i++){var o=e[i];o.shape&&(n=n||{},this._mergeStyle(n,o.shape))}return n&&(a.shape=n),a},t.prototype.getAnimationStyleProps=function(){return gO},t.prototype.isZeroArea=function(){return!1},t.extend=function(e){var a=function(i){Zt(o,i);function o(s){var l=i.call(this,s)||this;return e.init&&e.init.call(l,s),l}return o.prototype.getDefaultStyle=function(){return et(e.style)},o.prototype.getDefaultShape=function(){return et(e.shape)},o}(t);for(var n in e)typeof e[n]=="function"&&(a.prototype[n]=e[n]);return a},t.initDefaultProps=function(){var e=t.prototype;e.type="path",e.strokeContainThreshold=5,e.segmentIgnoreThreshold=0,e.subPixelOptimize=!1,e.autoBatch=!1,e.__dirty=ir|cl|ko}(),t}(Lr),yO=nt({strokeFirst:!0,font:Ya,x:0,y:0,textAlign:"left",textBaseline:"top",miterLimit:2},Ov),ts=function(r){Zt(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.hasStroke=function(){return sM(this.style)},t.prototype.hasFill=function(){var e=this.style,a=e.fill;return a!=null&&a!=="none"},t.prototype.createStyle=function(e){return Su(yO,e)},t.prototype.setBoundingRect=function(e){this._rect=e},t.prototype.getBoundingRect=function(){return this._rect||(this._rect=tO(this.style)),this._rect},t.initDefaultProps=function(){var e=t.prototype;e.dirtyRectTolerance=10}(),t}(Lr);ts.prototype.type="tspan";var mO=nt({x:0,y:0},Ri),_O={style:nt({x:!0,y:!0,width:!0,height:!0,sx:!0,sy:!0,sWidth:!0,sHeight:!0},Wh.style)};function SO(r){return!!(r&&typeof r!="string"&&r.width&&r.height)}var xe=function(r){Zt(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.createStyle=function(e){return Su(mO,e)},t.prototype._getSize=function(e){var a=this.style,n=a[e];if(n!=null)return n;var i=SO(a.image)?a.image:this.__image;if(!i)return 0;var o=e==="width"?"height":"width",s=a[o];return s==null?i[e]:i[e]/i[o]*s},t.prototype.getWidth=function(){return this._getSize("width")},t.prototype.getHeight=function(){return this._getSize("height")},t.prototype.getAnimationStyleProps=function(){return _O},t.prototype.getBoundingRect=function(){var e=this.style;return this._rect||(this._rect=new lt(e.x||0,e.y||0,this.getWidth(),this.getHeight())),this._rect},t}(Lr);xe.prototype.type="image";function xO(r,t){var e=t.x,a=t.y,n=t.width,i=t.height,o=t.r,s,l,u,f;n<0&&(e=e+n,n=-n),i<0&&(a=a+i,i=-i),typeof o=="number"?s=l=u=f=o:o instanceof Array?o.length===1?s=l=u=f=o[0]:o.length===2?(s=u=o[0],l=f=o[1]):o.length===3?(s=o[0],l=f=o[1],u=o[2]):(s=o[0],l=o[1],u=o[2],f=o[3]):s=l=u=f=0;var v;s+l>n&&(v=s+l,s*=n/v,l*=n/v),u+f>n&&(v=u+f,u*=n/v,f*=n/v),l+u>i&&(v=l+u,l*=i/v,u*=i/v),s+f>i&&(v=s+f,s*=i/v,f*=i/v),r.moveTo(e+s,a),r.lineTo(e+n-l,a),l!==0&&r.arc(e+n-l,a+l,l,-Math.PI/2,0),r.lineTo(e+n,a+i-u),u!==0&&r.arc(e+n-u,a+i-u,u,0,Math.PI/2),r.lineTo(e+f,a+i),f!==0&&r.arc(e+f,a+i-f,f,Math.PI/2,Math.PI),r.lineTo(e,a+s),s!==0&&r.arc(e+s,a+s,s,Math.PI,Math.PI*1.5)}var Vo=Math.round;function Zh(r,t,e){if(t){var a=t.x1,n=t.x2,i=t.y1,o=t.y2;r.x1=a,r.x2=n,r.y1=i,r.y2=o;var s=e&&e.lineWidth;return s&&(Vo(a*2)===Vo(n*2)&&(r.x1=r.x2=fr(a,s,!0)),Vo(i*2)===Vo(o*2)&&(r.y1=r.y2=fr(i,s,!0))),r}}function fM(r,t,e){if(t){var a=t.x,n=t.y,i=t.width,o=t.height;r.x=a,r.y=n,r.width=i,r.height=o;var s=e&&e.lineWidth;return s&&(r.x=fr(a,s,!0),r.y=fr(n,s,!0),r.width=Math.max(fr(a+i,s,!1)-r.x,i===0?0:1),r.height=Math.max(fr(n+o,s,!1)-r.y,o===0?0:1)),r}}function fr(r,t,e){if(!t)return r;var a=Vo(r*2);return(a+Vo(t))%2===0?a/2:(a+(e?1:-1))/2}var bO=function(){function r(){this.x=0,this.y=0,this.width=0,this.height=0}return r}(),wO={},_t=function(r){Zt(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new bO},t.prototype.buildPath=function(e,a){var n,i,o,s;if(this.subPixelOptimize){var l=fM(wO,a,this.style);n=l.x,i=l.y,o=l.width,s=l.height,l.r=a.r,a=l}else n=a.x,i=a.y,o=a.width,s=a.height;a.r?xO(e,a):e.rect(n,i,o,s)},t.prototype.isZeroArea=function(){return!this.shape.width||!this.shape.height},t}(bt);_t.prototype.type="rect";var d1={fill:"#000"},g1=2,Jr={},TO={style:nt({fill:!0,stroke:!0,fillOpacity:!0,strokeOpacity:!0,lineWidth:!0,fontSize:!0,lineHeight:!0,width:!0,height:!0,textShadowColor:!0,textShadowBlur:!0,textShadowOffsetX:!0,textShadowOffsetY:!0,backgroundColor:!0,padding:!0,borderColor:!0,borderWidth:!0,borderRadius:!0},Wh.style)},At=function(r){Zt(t,r);function t(e){var a=r.call(this)||this;return a.type="text",a._children=[],a._defaultStyle=d1,a.attr(e),a}return t.prototype.childrenRef=function(){return this._children},t.prototype.update=function(){r.prototype.update.call(this),this.styleChanged()&&this._updateSubTexts();for(var e=0;e<this._children.length;e++){var a=this._children[e];a.zlevel=this.zlevel,a.z=this.z,a.z2=this.z2,a.culling=this.culling,a.cursor=this.cursor,a.invisible=this.invisible}},t.prototype.updateTransform=function(){var e=this.innerTransformable;e?(e.updateTransform(),e.transform&&(this.transform=e.transform)):r.prototype.updateTransform.call(this)},t.prototype.getLocalTransform=function(e){var a=this.innerTransformable;return a?a.getLocalTransform(e):r.prototype.getLocalTransform.call(this,e)},t.prototype.getComputedTransform=function(){return this.__hostTarget&&(this.__hostTarget.getComputedTransform(),this.__hostTarget.updateInnerText(!0)),r.prototype.getComputedTransform.call(this)},t.prototype._updateSubTexts=function(){this._childCursor=0,MO(this.style),this.style.rich?this._updateRichTexts():this._updatePlainTexts(),this._children.length=this._childCursor,this.styleUpdated()},t.prototype.addSelfToZr=function(e){r.prototype.addSelfToZr.call(this,e);for(var a=0;a<this._children.length;a++)this._children[a].__zr=e},t.prototype.removeSelfFromZr=function(e){r.prototype.removeSelfFromZr.call(this,e);for(var a=0;a<this._children.length;a++)this._children[a].__zr=null},t.prototype.getBoundingRect=function(){if(this.styleChanged()&&this._updateSubTexts(),!this._rect){for(var e=new lt(0,0,0,0),a=this._children,n=[],i=null,o=0;o<a.length;o++){var s=a[o],l=s.getBoundingRect(),u=s.getLocalTransform(n);u?(e.copy(l),e.applyTransform(u),i=i||e.clone(),i.union(e)):(i=i||l.clone(),i.union(l))}this._rect=i||e}return this._rect},t.prototype.setDefaultTextStyle=function(e){this._defaultStyle=e||d1},t.prototype.setTextContent=function(e){},t.prototype._mergeStyle=function(e,a){if(!a)return e;var n=a.rich,i=e.rich||n&&{};return G(e,a),n&&i?(this._mergeRich(i,n),e.rich=i):i&&(e.rich=i),e},t.prototype._mergeRich=function(e,a){for(var n=Ct(a),i=0;i<n.length;i++){var o=n[i];e[o]=e[o]||{},G(e[o],a[o])}},t.prototype.getAnimationStyleProps=function(){return TO},t.prototype._getOrCreateChild=function(e){var a=this._children[this._childCursor];return(!a||!(a instanceof e))&&(a=new e),this._children[this._childCursor++]=a,a.__zr=this.__zr,a.parent=this,a},t.prototype._updatePlainTexts=function(){var e=this.style,a=e.font||Ya,n=e.padding,i=this._defaultStyle,o=e.x||0,s=e.y||0,l=e.align||i.align||"left",u=e.verticalAlign||i.verticalAlign||"top";s1(Jr,i.overflowRect,o,s,l,u),o=Jr.baseX,s=Jr.baseY;var f=w1(e),v=XE(f,e,Jr.outerWidth,Jr.outerHeight),h=Xc(e),c=!!e.backgroundColor,p=v.outerHeight,d=v.outerWidth,g=v.lines,y=v.lineHeight;this.isTruncated=!!v.isTruncated;var m=o,_=Pi(s,v.contentHeight,u);if(h||n){var S=Jo(o,d,l),x=Pi(s,p,u);h&&this._renderBackground(e,e,S,x,d,p)}_+=y/2,n&&(m=b1(o,l,n),u==="top"?_+=n[0]:u==="bottom"&&(_-=n[2]));for(var b=0,w=!1,T=!1,C=x1("fill"in e?e.fill:(T=!0,i.fill)),M=S1("stroke"in e?e.stroke:!c&&(!i.autoStroke||T)?(b=g1,w=!0,i.stroke):null),D=e.textShadowBlur>0,I=0;I<g.length;I++){var L=this._getOrCreateChild(ts),P=L.createStyle();L.useStyle(P),P.text=g[I],P.x=m,P.y=_,P.textAlign=l,P.textBaseline="middle",P.opacity=e.opacity,P.strokeFirst=!0,D&&(P.shadowBlur=e.textShadowBlur||0,P.shadowColor=e.textShadowColor||"transparent",P.shadowOffsetX=e.textShadowOffsetX||0,P.shadowOffsetY=e.textShadowOffsetY||0),P.stroke=M,P.fill=C,M&&(P.lineWidth=e.lineWidth||b,P.lineDash=e.lineDash,P.lineDashOffset=e.lineDashOffset||0),P.font=a,m1(P,e),_+=y,L.setBoundingRect(pg(P,v.contentWidth,v.calculatedLineHeight,w?0:null))}},t.prototype._updateRichTexts=function(){var e=this.style,a=this._defaultStyle,n=e.align||a.align,i=e.verticalAlign||a.verticalAlign,o=e.x||0,s=e.y||0;s1(Jr,a.overflowRect,o,s,n,i),o=Jr.baseX,s=Jr.baseY;var l=w1(e),u=KE(l,e,Jr.outerWidth,Jr.outerHeight,n),f=u.width,v=u.outerWidth,h=u.outerHeight,c=e.padding;this.isTruncated=!!u.isTruncated;var p=Jo(o,v,n),d=Pi(s,h,i),g=p,y=d;c&&(g+=c[3],y+=c[0]);var m=g+f;Xc(e)&&this._renderBackground(e,e,p,d,v,h);for(var _=!!e.backgroundColor,S=0;S<u.lines.length;S++){for(var x=u.lines[S],b=x.tokens,w=b.length,T=x.lineHeight,C=x.width,M=0,D=g,I=m,L=w-1,P=void 0;M<w&&(P=b[M],!P.align||P.align==="left");)this._placeToken(P,e,T,y,D,"left",_),C-=P.width,D+=P.width,M++;for(;L>=0&&(P=b[L],P.align==="right");)this._placeToken(P,e,T,y,I,"right",_),C-=P.width,I-=P.width,L--;for(D+=(f-(D-g)-(m-I)-C)/2;M<=L;)P=b[M],this._placeToken(P,e,T,y,D+P.width/2,"center",_),D+=P.width,M++;y+=T}},t.prototype._placeToken=function(e,a,n,i,o,s,l){var u=a.rich[e.styleName]||{};u.text=e.text;var f=e.verticalAlign,v=i+n/2;f==="top"?v=i+e.height/2:f==="bottom"&&(v=i+n-e.height/2);var h=!e.isLineHolder&&Xc(u);h&&this._renderBackground(u,a,s==="right"?o-e.width:s==="center"?o-e.width/2:o,v-e.height/2,e.width,e.height);var c=!!u.backgroundColor,p=e.textPadding;p&&(o=b1(o,s,p),v-=e.height/2-p[0]-e.innerHeight/2);var d=this._getOrCreateChild(ts),g=d.createStyle();d.useStyle(g);var y=this._defaultStyle,m=!1,_=0,S=!1,x=x1("fill"in u?u.fill:"fill"in a?a.fill:(m=!0,y.fill)),b=S1("stroke"in u?u.stroke:"stroke"in a?a.stroke:!c&&!l&&(!y.autoStroke||m)?(_=g1,S=!0,y.stroke):null),w=u.textShadowBlur>0||a.textShadowBlur>0;g.text=e.text,g.x=o,g.y=v,w&&(g.shadowBlur=u.textShadowBlur||a.textShadowBlur||0,g.shadowColor=u.textShadowColor||a.textShadowColor||"transparent",g.shadowOffsetX=u.textShadowOffsetX||a.textShadowOffsetX||0,g.shadowOffsetY=u.textShadowOffsetY||a.textShadowOffsetY||0),g.textAlign=s,g.textBaseline="middle",g.font=e.font||Ya,g.opacity=Qe(u.opacity,a.opacity,1),m1(g,u),b&&(g.lineWidth=Qe(u.lineWidth,a.lineWidth,_),g.lineDash=Q(u.lineDash,a.lineDash),g.lineDashOffset=a.lineDashOffset||0,g.stroke=b),x&&(g.fill=x),d.setBoundingRect(pg(g,e.contentWidth,e.contentHeight,S?0:null))},t.prototype._renderBackground=function(e,a,n,i,o,s){var l=e.backgroundColor,u=e.borderWidth,f=e.borderColor,v=l&&l.image,h=l&&!v,c=e.borderRadius,p=this,d,g;if(h||e.lineHeight||u&&f){d=this._getOrCreateChild(_t),d.useStyle(d.createStyle()),d.style.fill=null;var y=d.shape;y.x=n,y.y=i,y.width=o,y.height=s,y.r=c,d.dirtyShape()}if(h){var m=d.style;m.fill=l||null,m.fillOpacity=Q(e.fillOpacity,1)}else if(v){g=this._getOrCreateChild(xe),g.onload=function(){p.dirtyStyle()};var _=g.style;_.image=l.image,_.x=n,_.y=i,_.width=o,_.height=s}if(u&&f){var m=d.style;m.lineWidth=u,m.stroke=f,m.strokeOpacity=Q(e.strokeOpacity,1),m.lineDash=e.borderDash,m.lineDashOffset=e.borderDashOffset||0,d.strokeContainThreshold=0,d.hasFill()&&d.hasStroke()&&(m.strokeFirst=!0,m.lineWidth*=2)}var S=(d||g).style;S.shadowBlur=e.shadowBlur||0,S.shadowColor=e.shadowColor||"transparent",S.shadowOffsetX=e.shadowOffsetX||0,S.shadowOffsetY=e.shadowOffsetY||0,S.opacity=Qe(e.opacity,a.opacity,1)},t.makeFont=function(e){var a="";return hM(e)&&(a=[e.fontStyle,e.fontWeight,vM(e.fontSize),e.fontFamily||"sans-serif"].join(" ")),a&&sr(a)||e.textFont||e.font},t}(Lr),CO={left:!0,right:1,center:1},AO={top:1,bottom:1,middle:1},y1=["fontStyle","fontWeight","fontSize","fontFamily"];function vM(r){return typeof r=="string"&&(r.indexOf("px")!==-1||r.indexOf("rem")!==-1||r.indexOf("em")!==-1)?r:isNaN(+r)?jy+"px":r+"px"}function m1(r,t){for(var e=0;e<y1.length;e++){var a=y1[e],n=t[a];n!=null&&(r[a]=n)}}function hM(r){return r.fontSize!=null||r.fontFamily||r.fontWeight}function MO(r){return _1(r),A(r.rich,_1),r}function _1(r){if(r){r.font=At.makeFont(r);var t=r.align;t==="middle"&&(t="center"),r.align=t==null||CO[t]?t:"left";var e=r.verticalAlign;e==="center"&&(e="middle"),r.verticalAlign=e==null||AO[e]?e:"top";var a=r.padding;a&&(r.padding=_u(r.padding))}}function S1(r,t){return r==null||t<=0||r==="transparent"||r==="none"?null:r.image||r.colorStops?"#000":r}function x1(r){return r==null||r==="none"?null:r.image||r.colorStops?"#000":r}function b1(r,t,e){return t==="right"?r-e[1]:t==="center"?r+e[3]/2-e[1]/2:r+e[3]}function w1(r){var t=r.text;return t!=null&&(t+=""),t}function Xc(r){return!!(r.backgroundColor||r.lineHeight||r.borderWidth&&r.borderColor)}var ut=St(),yg=function(r,t,e,a){if(a){var n=ut(a);n.dataIndex=e,n.dataType=t,n.seriesIndex=r,n.ssrType="chart",a.type==="group"&&a.traverse(function(i){var o=ut(i);o.seriesIndex=r,o.dataIndex=e,o.dataType=t,o.ssrType="chart"})}},T1=1,C1={},cM=St(),mm=St(),_m=0,Tu=1,Xh=2,Xe=["emphasis","blur","select"],$l=["normal","emphasis","blur","select"],gs=10,DO=9,ki="highlight",sv="downplay",Nv="select",mg="unselect",Bv="toggleSelect",Sm="selectchanged";function fo(r){return r!=null&&r!=="none"}function $h(r,t,e){r.onHoverStateChange&&(r.hoverState||0)!==e&&r.onHoverStateChange(t),r.hoverState=e}function pM(r){$h(r,"emphasis",Xh)}function dM(r){r.hoverState===Xh&&$h(r,"normal",_m)}function xm(r){$h(r,"blur",Tu)}function gM(r){r.hoverState===Tu&&$h(r,"normal",_m)}function LO(r){r.selected=!0}function IO(r){r.selected=!1}function A1(r,t,e){t(r,e)}function tn(r,t,e){A1(r,t,e),r.isGroup&&r.traverse(function(a){A1(a,t,e)})}function zv(r,t){switch(t){case"emphasis":r.hoverState=Xh;break;case"normal":r.hoverState=_m;break;case"blur":r.hoverState=Tu;break;case"select":r.selected=!0}}function PO(r,t,e,a){for(var n=r.style,i={},o=0;o<t.length;o++){var s=t[o],l=n[s];i[s]=l??(a&&a[s])}for(var o=0;o<r.animators.length;o++){var u=r.animators[o];u.__fromStateTransition&&u.__fromStateTransition.indexOf(e)<0&&u.targetName==="style"&&u.saveTo(i,t)}return i}function RO(r,t,e,a){var n=e&&gt(e,"select")>=0,i=!1;if(r instanceof bt){var o=cM(r),s=n&&o.selectFill||o.normalFill,l=n&&o.selectStroke||o.normalStroke;if(fo(s)||fo(l)){a=a||{};var u=a.style||{};u.fill==="inherit"?(i=!0,a=G({},a),u=G({},u),u.fill=s):!fo(u.fill)&&fo(s)?(i=!0,a=G({},a),u=G({},u),u.fill=Lv(s)):!fo(u.stroke)&&fo(l)&&(i||(a=G({},a),u=G({},u)),u.stroke=Lv(l)),a.style=u}}if(a&&a.z2==null){i||(a=G({},a));var f=r.z2EmphasisLift;a.z2=r.z2+(f??gs)}return a}function kO(r,t,e){if(e&&e.z2==null){e=G({},e);var a=r.z2SelectLift;e.z2=r.z2+(a??DO)}return e}function EO(r,t,e){var a=gt(r.currentStates,t)>=0,n=r.style.opacity,i=a?null:PO(r,["opacity"],t,{opacity:1});e=e||{};var o=e.style||{};return o.opacity==null&&(e=G({},e),o=G({opacity:a?n:i.opacity*.1},o),e.style=o),e}function $c(r,t){var e=this.states[r];if(this.style){if(r==="emphasis")return RO(this,r,t,e);if(r==="blur")return EO(this,r,e);if(r==="select")return kO(this,r,e)}return e}function Hi(r){r.stateProxy=$c;var t=r.getTextContent(),e=r.getTextGuideLine();t&&(t.stateProxy=$c),e&&(e.stateProxy=$c)}function M1(r,t){!SM(r,t)&&!r.__highByOuter&&tn(r,pM)}function D1(r,t){!SM(r,t)&&!r.__highByOuter&&tn(r,dM)}function Xa(r,t){r.__highByOuter|=1<<(t||0),tn(r,pM)}function $a(r,t){!(r.__highByOuter&=~(1<<(t||0)))&&tn(r,dM)}function yM(r){tn(r,xm)}function bm(r){tn(r,gM)}function mM(r){tn(r,LO)}function _M(r){tn(r,IO)}function SM(r,t){return r.__highDownSilentOnTouch&&t.zrByTouch}function xM(r){var t=r.getModel(),e=[],a=[];t.eachComponent(function(n,i){var o=mm(i),s=n==="series",l=s?r.getViewOfSeriesModel(i):r.getViewOfComponentModel(i);!s&&a.push(l),o.isBlured&&(l.group.traverse(function(u){gM(u)}),s&&e.push(i)),o.isBlured=!1}),A(a,function(n){n&&n.toggleBlurSeries&&n.toggleBlurSeries(e,!1,t)})}function _g(r,t,e,a){var n=a.getModel();e=e||"coordinateSystem";function i(u,f){for(var v=0;v<f.length;v++){var h=u.getItemGraphicEl(f[v]);h&&bm(h)}}if(r!=null&&!(!t||t==="none")){var o=n.getSeriesByIndex(r),s=o.coordinateSystem;s&&s.master&&(s=s.master);var l=[];n.eachSeries(function(u){var f=o===u,v=u.coordinateSystem;v&&v.master&&(v=v.master);var h=v&&s?v===s:f;if(!(e==="series"&&!f||e==="coordinateSystem"&&!h||t==="series"&&f)){var c=a.getViewOfSeriesModel(u);if(c.group.traverse(function(g){g.__highByOuter&&f&&t==="self"||xm(g)}),Pe(t))i(u.getData(),t);else if(it(t))for(var p=Ct(t),d=0;d<p.length;d++)i(u.getData(p[d]),t[p[d]]);l.push(u),mm(u).isBlured=!0}}),n.eachComponent(function(u,f){if(u!=="series"){var v=a.getViewOfComponentModel(f);v&&v.toggleBlurSeries&&v.toggleBlurSeries(l,!0,n)}})}}function Sg(r,t,e){if(!(r==null||t==null)){var a=e.getModel().getComponent(r,t);if(a){mm(a).isBlured=!0;var n=e.getViewOfComponentModel(a);!n||!n.focusBlurEnabled||n.group.traverse(function(i){xm(i)})}}}function OO(r,t,e){var a=r.seriesIndex,n=r.getData(t.dataType);if(n){var i=Gi(n,t);i=(W(i)?i[0]:i)||0;var o=n.getItemGraphicEl(i);if(!o)for(var s=n.count(),l=0;!o&&l<s;)o=n.getItemGraphicEl(l++);if(o){var u=ut(o);_g(a,u.focus,u.blurScope,e)}else{var f=r.get(["emphasis","focus"]),v=r.get(["emphasis","blurScope"]);f!=null&&_g(a,f,v,e)}}}function wm(r,t,e,a){var n={focusSelf:!1,dispatchers:null};if(r==null||r==="series"||t==null||e==null)return n;var i=a.getModel().getComponent(r,t);if(!i)return n;var o=a.getViewOfComponentModel(i);if(!o||!o.findHighDownDispatchers)return n;for(var s=o.findHighDownDispatchers(e),l,u=0;u<s.length;u++)if(ut(s[u]).focus==="self"){l=!0;break}return{focusSelf:l,dispatchers:s}}function NO(r,t,e){var a=ut(r),n=wm(a.componentMainType,a.componentIndex,a.componentHighDownName,e),i=n.dispatchers,o=n.focusSelf;i?(o&&Sg(a.componentMainType,a.componentIndex,e),A(i,function(s){return M1(s,t)})):(_g(a.seriesIndex,a.focus,a.blurScope,e),a.focus==="self"&&Sg(a.componentMainType,a.componentIndex,e),M1(r,t))}function BO(r,t,e){xM(e);var a=ut(r),n=wm(a.componentMainType,a.componentIndex,a.componentHighDownName,e).dispatchers;n?A(n,function(i){return D1(i,t)}):D1(r,t)}function zO(r,t,e){if(bg(t)){var a=t.dataType,n=r.getData(a),i=Gi(n,t);W(i)||(i=[i]),r[t.type===Bv?"toggleSelect":t.type===Nv?"select":"unselect"](i,a)}}function L1(r){var t=r.getAllData();A(t,function(e){var a=e.data,n=e.type;a.eachItemGraphicEl(function(i,o){r.isSelected(o,n)?mM(i):_M(i)})})}function VO(r){var t=[];return r.eachSeries(function(e){var a=e.getAllData();A(a,function(n){n.data;var i=n.type,o=e.getSelectedDataIndices();if(o.length>0){var s={dataIndex:o,seriesIndex:e.seriesIndex};i!=null&&(s.dataType=i),t.push(s)}})}),t}function Cn(r,t,e){Ai(r,!0),tn(r,Hi),xg(r,t,e)}function GO(r){Ai(r,!1)}function $t(r,t,e,a){a?GO(r):Cn(r,t,e)}function xg(r,t,e){var a=ut(r);t!=null?(a.focus=t,a.blurScope=e):a.focus&&(a.focus=null)}var I1=["emphasis","blur","select"],FO={itemStyle:"getItemStyle",lineStyle:"getLineStyle",areaStyle:"getAreaStyle"};function he(r,t,e,a){e=e||"itemStyle";for(var n=0;n<I1.length;n++){var i=I1[n],o=t.getModel([i,e]),s=r.ensureState(i);s.style=a?a(o):o[FO[e]]()}}function Ai(r,t){var e=t===!1,a=r;r.highDownSilentOnTouch&&(a.__highDownSilentOnTouch=r.highDownSilentOnTouch),(!e||a.__highDownDispatcher)&&(a.__highByOuter=a.__highByOuter||0,a.__highDownDispatcher=!e)}function ql(r){return!!(r&&r.__highDownDispatcher)}function HO(r,t,e){var a=ut(r);a.componentMainType=t.mainType,a.componentIndex=t.componentIndex,a.componentHighDownName=e}function WO(r){var t=C1[r];return t==null&&T1<=32&&(t=C1[r]=T1++),t}function bg(r){var t=r.type;return t===Nv||t===mg||t===Bv}function P1(r){var t=r.type;return t===ki||t===sv}function UO(r){var t=cM(r);t.normalFill=r.style.fill,t.normalStroke=r.style.stroke;var e=r.states.select||{};t.selectFill=e.style&&e.style.fill||null,t.selectStroke=e.style&&e.style.stroke||null}var vo=ma.CMD,YO=[[],[],[]],R1=Math.sqrt,ZO=Math.atan2;function bM(r,t){if(t){var e=r.data,a=r.len(),n,i,o,s,l,u,f=vo.M,v=vo.C,h=vo.L,c=vo.R,p=vo.A,d=vo.Q;for(o=0,s=0;o<a;){switch(n=e[o++],s=o,i=0,n){case f:i=1;break;case h:i=1;break;case v:i=3;break;case d:i=2;break;case p:var g=t[4],y=t[5],m=R1(t[0]*t[0]+t[1]*t[1]),_=R1(t[2]*t[2]+t[3]*t[3]),S=ZO(-t[1]/_,t[0]/m);e[o]*=m,e[o++]+=g,e[o]*=_,e[o++]+=y,e[o++]*=m,e[o++]*=_,e[o++]+=S,e[o++]+=S,o+=2,s=o;break;case c:u[0]=e[o++],u[1]=e[o++],Jt(u,u,t),e[s++]=u[0],e[s++]=u[1],u[0]+=e[o++],u[1]+=e[o++],Jt(u,u,t),e[s++]=u[0],e[s++]=u[1]}for(l=0;l<i;l++){var x=YO[l];x[0]=e[o++],x[1]=e[o++],Jt(x,x,t),e[s++]=x[0],e[s++]=x[1]}}r.increaseVersion()}}var qc=Math.sqrt,Ju=Math.sin,Qu=Math.cos,Vs=Math.PI;function k1(r){return Math.sqrt(r[0]*r[0]+r[1]*r[1])}function wg(r,t){return(r[0]*t[0]+r[1]*t[1])/(k1(r)*k1(t))}function E1(r,t){return(r[0]*t[1]<r[1]*t[0]?-1:1)*Math.acos(wg(r,t))}function O1(r,t,e,a,n,i,o,s,l,u,f){var v=l*(Vs/180),h=Qu(v)*(r-e)/2+Ju(v)*(t-a)/2,c=-1*Ju(v)*(r-e)/2+Qu(v)*(t-a)/2,p=h*h/(o*o)+c*c/(s*s);p>1&&(o*=qc(p),s*=qc(p));var d=(n===i?-1:1)*qc((o*o*(s*s)-o*o*(c*c)-s*s*(h*h))/(o*o*(c*c)+s*s*(h*h)))||0,g=d*o*c/s,y=d*-s*h/o,m=(r+e)/2+Qu(v)*g-Ju(v)*y,_=(t+a)/2+Ju(v)*g+Qu(v)*y,S=E1([1,0],[(h-g)/o,(c-y)/s]),x=[(h-g)/o,(c-y)/s],b=[(-1*h-g)/o,(-1*c-y)/s],w=E1(x,b);if(wg(x,b)<=-1&&(w=Vs),wg(x,b)>=1&&(w=0),w<0){var T=Math.round(w/Vs*1e6)/1e6;w=Vs*2+T%2*Vs}f.addData(u,m,_,o,s,S,w,v,i)}var XO=/([mlvhzcqtsa])([^mlvhzcqtsa]*)/ig,$O=/-?([0-9]*\.)?[0-9]+([eE]-?[0-9]+)?/g;function qO(r){var t=new ma;if(!r)return t;var e=0,a=0,n=e,i=a,o,s=ma.CMD,l=r.match(XO);if(!l)return t;for(var u=0;u<l.length;u++){for(var f=l[u],v=f.charAt(0),h=void 0,c=f.match($O)||[],p=c.length,d=0;d<p;d++)c[d]=parseFloat(c[d]);for(var g=0;g<p;){var y=void 0,m=void 0,_=void 0,S=void 0,x=void 0,b=void 0,w=void 0,T=e,C=a,M=void 0,D=void 0;switch(v){case"l":e+=c[g++],a+=c[g++],h=s.L,t.addData(h,e,a);break;case"L":e=c[g++],a=c[g++],h=s.L,t.addData(h,e,a);break;case"m":e+=c[g++],a+=c[g++],h=s.M,t.addData(h,e,a),n=e,i=a,v="l";break;case"M":e=c[g++],a=c[g++],h=s.M,t.addData(h,e,a),n=e,i=a,v="L";break;case"h":e+=c[g++],h=s.L,t.addData(h,e,a);break;case"H":e=c[g++],h=s.L,t.addData(h,e,a);break;case"v":a+=c[g++],h=s.L,t.addData(h,e,a);break;case"V":a=c[g++],h=s.L,t.addData(h,e,a);break;case"C":h=s.C,t.addData(h,c[g++],c[g++],c[g++],c[g++],c[g++],c[g++]),e=c[g-2],a=c[g-1];break;case"c":h=s.C,t.addData(h,c[g++]+e,c[g++]+a,c[g++]+e,c[g++]+a,c[g++]+e,c[g++]+a),e+=c[g-2],a+=c[g-1];break;case"S":y=e,m=a,M=t.len(),D=t.data,o===s.C&&(y+=e-D[M-4],m+=a-D[M-3]),h=s.C,T=c[g++],C=c[g++],e=c[g++],a=c[g++],t.addData(h,y,m,T,C,e,a);break;case"s":y=e,m=a,M=t.len(),D=t.data,o===s.C&&(y+=e-D[M-4],m+=a-D[M-3]),h=s.C,T=e+c[g++],C=a+c[g++],e+=c[g++],a+=c[g++],t.addData(h,y,m,T,C,e,a);break;case"Q":T=c[g++],C=c[g++],e=c[g++],a=c[g++],h=s.Q,t.addData(h,T,C,e,a);break;case"q":T=c[g++]+e,C=c[g++]+a,e+=c[g++],a+=c[g++],h=s.Q,t.addData(h,T,C,e,a);break;case"T":y=e,m=a,M=t.len(),D=t.data,o===s.Q&&(y+=e-D[M-4],m+=a-D[M-3]),e=c[g++],a=c[g++],h=s.Q,t.addData(h,y,m,e,a);break;case"t":y=e,m=a,M=t.len(),D=t.data,o===s.Q&&(y+=e-D[M-4],m+=a-D[M-3]),e+=c[g++],a+=c[g++],h=s.Q,t.addData(h,y,m,e,a);break;case"A":_=c[g++],S=c[g++],x=c[g++],b=c[g++],w=c[g++],T=e,C=a,e=c[g++],a=c[g++],h=s.A,O1(T,C,e,a,b,w,_,S,x,h,t);break;case"a":_=c[g++],S=c[g++],x=c[g++],b=c[g++],w=c[g++],T=e,C=a,e+=c[g++],a+=c[g++],h=s.A,O1(T,C,e,a,b,w,_,S,x,h,t);break}}(v==="z"||v==="Z")&&(h=s.Z,t.addData(h),e=n,a=i),o=h}return t.toStatic(),t}var wM=function(r){Zt(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.applyTransform=function(e){},t}(bt);function TM(r){return r.setData!=null}function CM(r,t){var e=qO(r),a=G({},t);return a.buildPath=function(n){var i=TM(n);if(i&&n.canSave()){n.appendPath(e);var o=n.getContext();o&&n.rebuildPath(o,1)}else{var o=i?n.getContext():n;o&&e.rebuildPath(o,1)}},a.applyTransform=function(n){bM(e,n),this.dirtyShape()},a}function AM(r,t){return new wM(CM(r,t))}function KO(r,t){var e=CM(r,t),a=function(n){Zt(i,n);function i(o){var s=n.call(this,o)||this;return s.applyTransform=e.applyTransform,s.buildPath=e.buildPath,s}return i}(wM);return a}function jO(r,t){for(var e=[],a=r.length,n=0;n<a;n++){var i=r[n];e.push(i.getUpdatedPathProxy(!0))}var o=new bt(t);return o.createPathProxy(),o.buildPath=function(s){if(TM(s)){s.appendPath(e);var l=s.getContext();l&&s.rebuildPath(l,1)}},o}function Tm(r,t){t=t||{};var e=new bt;return r.shape&&e.setShape(r.shape),e.setStyle(r.style),t.bakeTransform?bM(e.path,r.getComputedTransform()):t.toLocal?e.setLocalTransform(r.getComputedTransform()):e.copyTransform(r),e.buildPath=r.buildPath,e.applyTransform=e.applyTransform,e.z=r.z,e.z2=r.z2,e.zlevel=r.zlevel,e}var JO=function(){function r(){this.cx=0,this.cy=0,this.r=0}return r}(),wa=function(r){Zt(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new JO},t.prototype.buildPath=function(e,a){e.moveTo(a.cx+a.r,a.cy),e.arc(a.cx,a.cy,a.r,0,Math.PI*2)},t}(bt);wa.prototype.type="circle";var QO=function(){function r(){this.cx=0,this.cy=0,this.rx=0,this.ry=0}return r}(),Cu=function(r){Zt(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new QO},t.prototype.buildPath=function(e,a){var n=.5522848,i=a.cx,o=a.cy,s=a.rx,l=a.ry,u=s*n,f=l*n;e.moveTo(i-s,o),e.bezierCurveTo(i-s,o-f,i-u,o-l,i,o-l),e.bezierCurveTo(i+u,o-l,i+s,o-f,i+s,o),e.bezierCurveTo(i+s,o+f,i+u,o+l,i,o+l),e.bezierCurveTo(i-u,o+l,i-s,o+f,i-s,o),e.closePath()},t}(bt);Cu.prototype.type="ellipse";var MM=Math.PI,Kc=MM*2,ei=Math.sin,ho=Math.cos,tN=Math.acos,Oe=Math.atan2,N1=Math.abs,kl=Math.sqrt,dl=Math.max,Qr=Math.min,Er=1e-4;function eN(r,t,e,a,n,i,o,s){var l=e-r,u=a-t,f=o-n,v=s-i,h=v*l-f*u;if(!(h*h<Er))return h=(f*(t-i)-v*(r-n))/h,[r+h*l,t+h*u]}function tf(r,t,e,a,n,i,o){var s=r-e,l=t-a,u=(o?i:-i)/kl(s*s+l*l),f=u*l,v=-u*s,h=r+f,c=t+v,p=e+f,d=a+v,g=(h+p)/2,y=(c+d)/2,m=p-h,_=d-c,S=m*m+_*_,x=n-i,b=h*d-p*c,w=(_<0?-1:1)*kl(dl(0,x*x*S-b*b)),T=(b*_-m*w)/S,C=(-b*m-_*w)/S,M=(b*_+m*w)/S,D=(-b*m+_*w)/S,I=T-g,L=C-y,P=M-g,k=D-y;return I*I+L*L>P*P+k*k&&(T=M,C=D),{cx:T,cy:C,x0:-f,y0:-v,x1:T*(n/x-1),y1:C*(n/x-1)}}function rN(r){var t;if(W(r)){var e=r.length;if(!e)return r;e===1?t=[r[0],r[0],0,0]:e===2?t=[r[0],r[0],r[1],r[1]]:e===3?t=r.concat(r[2]):t=r}else t=[r,r,r,r];return t}function aN(r,t){var e,a=dl(t.r,0),n=dl(t.r0||0,0),i=a>0,o=n>0;if(!(!i&&!o)){if(i||(a=n,n=0),n>a){var s=a;a=n,n=s}var l=t.startAngle,u=t.endAngle;if(!(isNaN(l)||isNaN(u))){var f=t.cx,v=t.cy,h=!!t.clockwise,c=N1(u-l),p=c>Kc&&c%Kc;if(p>Er&&(c=p),!(a>Er))r.moveTo(f,v);else if(c>Kc-Er)r.moveTo(f+a*ho(l),v+a*ei(l)),r.arc(f,v,a,l,u,!h),n>Er&&(r.moveTo(f+n*ho(u),v+n*ei(u)),r.arc(f,v,n,u,l,h));else{var d=void 0,g=void 0,y=void 0,m=void 0,_=void 0,S=void 0,x=void 0,b=void 0,w=void 0,T=void 0,C=void 0,M=void 0,D=void 0,I=void 0,L=void 0,P=void 0,k=a*ho(l),R=a*ei(l),O=n*ho(u),E=n*ei(u),B=c>Er;if(B){var V=t.cornerRadius;V&&(e=rN(V),d=e[0],g=e[1],y=e[2],m=e[3]);var F=N1(a-n)/2;if(_=Qr(F,y),S=Qr(F,m),x=Qr(F,d),b=Qr(F,g),C=w=dl(_,S),M=T=dl(x,b),(w>Er||T>Er)&&(D=a*ho(u),I=a*ei(u),L=n*ho(l),P=n*ei(l),c<MM)){var H=eN(k,R,L,P,D,I,O,E);if(H){var Y=k-H[0],K=R-H[1],ft=D-H[0],It=I-H[1],Ot=1/ei(tN((Y*ft+K*It)/(kl(Y*Y+K*K)*kl(ft*ft+It*It)))/2),vt=kl(H[0]*H[0]+H[1]*H[1]);C=Qr(w,(a-vt)/(Ot+1)),M=Qr(T,(n-vt)/(Ot-1))}}}if(!B)r.moveTo(f+k,v+R);else if(C>Er){var at=Qr(y,C),dt=Qr(m,C),J=tf(L,P,k,R,a,at,h),ht=tf(D,I,O,E,a,dt,h);r.moveTo(f+J.cx+J.x0,v+J.cy+J.y0),C<w&&at===dt?r.arc(f+J.cx,v+J.cy,C,Oe(J.y0,J.x0),Oe(ht.y0,ht.x0),!h):(at>0&&r.arc(f+J.cx,v+J.cy,at,Oe(J.y0,J.x0),Oe(J.y1,J.x1),!h),r.arc(f,v,a,Oe(J.cy+J.y1,J.cx+J.x1),Oe(ht.cy+ht.y1,ht.cx+ht.x1),!h),dt>0&&r.arc(f+ht.cx,v+ht.cy,dt,Oe(ht.y1,ht.x1),Oe(ht.y0,ht.x0),!h))}else r.moveTo(f+k,v+R),r.arc(f,v,a,l,u,!h);if(!(n>Er)||!B)r.lineTo(f+O,v+E);else if(M>Er){var at=Qr(d,M),dt=Qr(g,M),J=tf(O,E,D,I,n,-dt,h),ht=tf(k,R,L,P,n,-at,h);r.lineTo(f+J.cx+J.x0,v+J.cy+J.y0),M<T&&at===dt?r.arc(f+J.cx,v+J.cy,M,Oe(J.y0,J.x0),Oe(ht.y0,ht.x0),!h):(dt>0&&r.arc(f+J.cx,v+J.cy,dt,Oe(J.y0,J.x0),Oe(J.y1,J.x1),!h),r.arc(f,v,n,Oe(J.cy+J.y1,J.cx+J.x1),Oe(ht.cy+ht.y1,ht.cx+ht.x1),h),at>0&&r.arc(f+ht.cx,v+ht.cy,at,Oe(ht.y1,ht.x1),Oe(ht.y0,ht.x0),!h))}else r.lineTo(f+O,v+E),r.arc(f,v,n,u,l,h)}r.closePath()}}}var nN=function(){function r(){this.cx=0,this.cy=0,this.r0=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0,this.cornerRadius=0}return r}(),ke=function(r){Zt(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new nN},t.prototype.buildPath=function(e,a){aN(e,a)},t.prototype.isZeroArea=function(){return this.shape.startAngle===this.shape.endAngle||this.shape.r===this.shape.r0},t}(bt);ke.prototype.type="sector";var iN=function(){function r(){this.cx=0,this.cy=0,this.r=0,this.r0=0}return r}(),ys=function(r){Zt(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new iN},t.prototype.buildPath=function(e,a){var n=a.cx,i=a.cy,o=Math.PI*2;e.moveTo(n+a.r,i),e.arc(n,i,a.r,0,o,!1),e.moveTo(n+a.r0,i),e.arc(n,i,a.r0,0,o,!0)},t}(bt);ys.prototype.type="ring";function oN(r,t,e,a){var n=[],i=[],o=[],s=[],l,u,f,v;if(a){f=[1/0,1/0],v=[-1/0,-1/0];for(var h=0,c=r.length;h<c;h++)Oa(f,f,r[h]),Na(v,v,r[h]);Oa(f,f,a[0]),Na(v,v,a[1])}for(var h=0,c=r.length;h<c;h++){var p=r[h];if(e)l=r[h?h-1:c-1],u=r[(h+1)%c];else if(h===0||h===c-1){n.push(ca(r[h]));continue}else l=r[h-1],u=r[h+1];dn(i,u,l),Al(i,i,t);var d=wv(p,l),g=wv(p,u),y=d+g;y!==0&&(d/=y,g/=y),Al(o,i,-d),Al(s,i,g);var m=Wd([],p,o),_=Wd([],p,s);a&&(Na(m,m,f),Oa(m,m,v),Na(_,_,f),Oa(_,_,v)),n.push(m),n.push(_)}return e&&n.push(n.shift()),n}function DM(r,t,e){var a=t.smooth,n=t.points;if(n&&n.length>=2){if(a){var i=oN(n,a,e,t.smoothConstraint);r.moveTo(n[0][0],n[0][1]);for(var o=n.length,s=0;s<(e?o:o-1);s++){var l=i[s*2],u=i[s*2+1],f=n[(s+1)%o];r.bezierCurveTo(l[0],l[1],u[0],u[1],f[0],f[1])}}else{r.moveTo(n[0][0],n[0][1]);for(var s=1,v=n.length;s<v;s++)r.lineTo(n[s][0],n[s][1])}e&&r.closePath()}}var sN=function(){function r(){this.points=null,this.smooth=0,this.smoothConstraint=null}return r}(),Ee=function(r){Zt(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new sN},t.prototype.buildPath=function(e,a){DM(e,a,!0)},t}(bt);Ee.prototype.type="polygon";var lN=function(){function r(){this.points=null,this.percent=1,this.smooth=0,this.smoothConstraint=null}return r}(),Ae=function(r){Zt(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new lN},t.prototype.buildPath=function(e,a){DM(e,a,!1)},t}(bt);Ae.prototype.type="polyline";var uN={},fN=function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.percent=1}return r}(),ne=function(r){Zt(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new fN},t.prototype.buildPath=function(e,a){var n,i,o,s;if(this.subPixelOptimize){var l=Zh(uN,a,this.style);n=l.x1,i=l.y1,o=l.x2,s=l.y2}else n=a.x1,i=a.y1,o=a.x2,s=a.y2;var u=a.percent;u!==0&&(e.moveTo(n,i),u<1&&(o=n*(1-u)+o*u,s=i*(1-u)+s*u),e.lineTo(o,s))},t.prototype.pointAt=function(e){var a=this.shape;return[a.x1*(1-e)+a.x2*e,a.y1*(1-e)+a.y2*e]},t}(bt);ne.prototype.type="line";var qe=[],vN=function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.cpx1=0,this.cpy1=0,this.percent=1}return r}();function B1(r,t,e){var a=r.cpx2,n=r.cpy2;return a!=null||n!=null?[(e?F_:ge)(r.x1,r.cpx1,r.cpx2,r.x2,t),(e?F_:ge)(r.y1,r.cpy1,r.cpy2,r.y2,t)]:[(e?Kd:Te)(r.x1,r.cpx1,r.x2,t),(e?Kd:Te)(r.y1,r.cpy1,r.y2,t)]}var ms=function(r){Zt(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new vN},t.prototype.buildPath=function(e,a){var n=a.x1,i=a.y1,o=a.x2,s=a.y2,l=a.cpx1,u=a.cpy1,f=a.cpx2,v=a.cpy2,h=a.percent;h!==0&&(e.moveTo(n,i),f==null||v==null?(h<1&&(Hl(n,l,o,h,qe),l=qe[1],o=qe[2],Hl(i,u,s,h,qe),u=qe[1],s=qe[2]),e.quadraticCurveTo(l,u,o,s)):(h<1&&(In(n,l,f,o,h,qe),l=qe[1],f=qe[2],o=qe[3],In(i,u,v,s,h,qe),u=qe[1],v=qe[2],s=qe[3]),e.bezierCurveTo(l,u,f,v,o,s)))},t.prototype.pointAt=function(e){return B1(this.shape,e,!1)},t.prototype.tangentAt=function(e){var a=B1(this.shape,e,!0);return qi(a,a)},t}(bt);ms.prototype.type="bezier-curve";var hN=function(){function r(){this.cx=0,this.cy=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0}return r}(),Au=function(r){Zt(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new hN},t.prototype.buildPath=function(e,a){var n=a.cx,i=a.cy,o=Math.max(a.r,0),s=a.startAngle,l=a.endAngle,u=a.clockwise,f=Math.cos(s),v=Math.sin(s);e.moveTo(f*o+n,v*o+i),e.arc(n,i,o,s,l,!u)},t}(bt);Au.prototype.type="arc";var Mu=function(r){Zt(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="compound",e}return t.prototype._updatePathDirty=function(){for(var e=this.shape.paths,a=this.shapeChanged(),n=0;n<e.length;n++)a=a||e[n].shapeChanged();a&&this.dirtyShape()},t.prototype.beforeBrush=function(){this._updatePathDirty();for(var e=this.shape.paths||[],a=this.getGlobalScale(),n=0;n<e.length;n++)e[n].path||e[n].createPathProxy(),e[n].path.setScale(a[0],a[1],e[n].segmentIgnoreThreshold)},t.prototype.buildPath=function(e,a){for(var n=a.paths||[],i=0;i<n.length;i++)n[i].buildPath(e,n[i].shape,!0)},t.prototype.afterBrush=function(){for(var e=this.shape.paths||[],a=0;a<e.length;a++)e[a].pathUpdated()},t.prototype.getBoundingRect=function(){return this._updatePathDirty.call(this),bt.prototype.getBoundingRect.call(this)},t}(bt),LM=function(){function r(t){this.colorStops=t||[]}return r.prototype.addColorStop=function(t,e){this.colorStops.push({offset:t,color:e})},r}(),Ki=function(r){Zt(t,r);function t(e,a,n,i,o,s){var l=r.call(this,o)||this;return l.x=e??0,l.y=a??0,l.x2=n??1,l.y2=i??0,l.type="linear",l.global=s||!1,l}return t}(LM),Cm=function(r){Zt(t,r);function t(e,a,n,i,o){var s=r.call(this,i)||this;return s.x=e??.5,s.y=a??.5,s.r=n??.5,s.type="radial",s.global=o||!1,s}return t}(LM),jc=Math.min,cN=Math.max,ef=Math.abs,ri=[0,0],ai=[0,0],we=dA(),rf=we.minTv,af=we.maxTv,IM=function(){function r(t,e){this._corners=[],this._axes=[],this._origin=[0,0];for(var a=0;a<4;a++)this._corners[a]=new st;for(var a=0;a<2;a++)this._axes[a]=new st;t&&this.fromBoundingRect(t,e)}return r.prototype.fromBoundingRect=function(t,e){var a=this._corners,n=this._axes,i=t.x,o=t.y,s=i+t.width,l=o+t.height;if(a[0].set(i,o),a[1].set(s,o),a[2].set(s,l),a[3].set(i,l),e)for(var u=0;u<4;u++)a[u].transform(e);st.sub(n[0],a[1],a[0]),st.sub(n[1],a[3],a[0]),n[0].normalize(),n[1].normalize();for(var u=0;u<2;u++)this._origin[u]=n[u].dot(a[0])},r.prototype.intersect=function(t,e,a){var n=!0,i=!e;return e&&st.set(e,0,0),we.reset(a,!i),!this._intersectCheckOneSide(this,t,i,1)&&(n=!1,i)||!this._intersectCheckOneSide(t,this,i,-1)&&(n=!1,i)||!i&&!we.negativeSize&&st.copy(e,n?we.useDir?we.dirMinTv:rf:af),n},r.prototype._intersectCheckOneSide=function(t,e,a,n){for(var i=!0,o=0;o<2;o++){var s=t._axes[o];if(t._getProjMinMaxOnAxis(o,t._corners,ri),t._getProjMinMaxOnAxis(o,e._corners,ai),we.negativeSize||ri[1]<ai[0]||ri[0]>ai[1]){if(i=!1,we.negativeSize||a)return i;var l=ef(ai[0]-ri[1]),u=ef(ri[0]-ai[1]);jc(l,u)>af.len()&&(l<u?st.scale(af,s,-l*n):st.scale(af,s,u*n))}else if(!a){var l=ef(ai[0]-ri[1]),u=ef(ri[0]-ai[1]);(we.useDir||jc(l,u)<rf.len())&&((l<u||!we.bidirectional)&&(st.scale(rf,s,l*n),we.useDir&&we.calcDirMTV()),(l>=u||!we.bidirectional)&&(st.scale(rf,s,-u*n),we.useDir&&we.calcDirMTV()))}}return i},r.prototype._getProjMinMaxOnAxis=function(t,e,a){for(var n=this._axes[t],i=this._origin,o=e[0].dot(n)+i[t],s=o,l=o,u=1;u<e.length;u++){var f=e[u].dot(n)+i[t];s=jc(f,s),l=cN(f,l)}a[0]=s+we.touchThreshold,a[1]=l-we.touchThreshold,we.negativeSize=a[1]<a[0]},r}(),pN=[],PM=function(r){Zt(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.notClear=!0,e.incremental=!0,e._displayables=[],e._temporaryDisplayables=[],e._cursor=0,e}return t.prototype.traverse=function(e,a){e.call(a,this)},t.prototype.useStyle=function(){this.style={}},t.prototype.getCursor=function(){return this._cursor},t.prototype.innerAfterBrush=function(){this._cursor=this._displayables.length},t.prototype.clearDisplaybles=function(){this._displayables=[],this._temporaryDisplayables=[],this._cursor=0,this.markRedraw(),this.notClear=!1},t.prototype.clearTemporalDisplayables=function(){this._temporaryDisplayables=[]},t.prototype.addDisplayable=function(e,a){a?this._temporaryDisplayables.push(e):this._displayables.push(e),this.markRedraw()},t.prototype.addDisplayables=function(e,a){a=a||!1;for(var n=0;n<e.length;n++)this.addDisplayable(e[n],a)},t.prototype.getDisplayables=function(){return this._displayables},t.prototype.getTemporalDisplayables=function(){return this._temporaryDisplayables},t.prototype.eachPendingDisplayable=function(e){for(var a=this._cursor;a<this._displayables.length;a++)e&&e(this._displayables[a]);for(var a=0;a<this._temporaryDisplayables.length;a++)e&&e(this._temporaryDisplayables[a])},t.prototype.update=function(){this.updateTransform();for(var e=this._cursor;e<this._displayables.length;e++){var a=this._displayables[e];a.parent=this,a.update(),a.parent=null}for(var e=0;e<this._temporaryDisplayables.length;e++){var a=this._temporaryDisplayables[e];a.parent=this,a.update(),a.parent=null}},t.prototype.getBoundingRect=function(){if(!this._rect){for(var e=new lt(1/0,1/0,-1/0,-1/0),a=0;a<this._displayables.length;a++){var n=this._displayables[a],i=n.getBoundingRect().clone();n.needLocalTransform()&&i.applyTransform(n.getLocalTransform(pN)),e.union(i)}this._rect=e}return this._rect},t.prototype.contain=function(e,a){var n=this.transformCoordToLocal(e,a),i=this.getBoundingRect();if(i.contain(n[0],n[1]))for(var o=0;o<this._displayables.length;o++){var s=this._displayables[o];if(s.contain(e,a))return!0}return!1},t}(Lr),RM=St();function _s(r,t,e,a,n){var i;if(t&&t.ecModel){var o=t.ecModel.getUpdatePayload();i=o&&o.animation}var s=t&&t.isAnimationEnabled(),l=r==="update";if(s){var u=void 0,f=void 0,v=void 0;a?(u=Q(a.duration,200),f=Q(a.easing,"cubicOut"),v=0):(u=t.getShallow(l?"animationDurationUpdate":"animationDuration"),f=t.getShallow(l?"animationEasingUpdate":"animationEasing"),v=t.getShallow(l?"animationDelayUpdate":"animationDelay")),i&&(i.duration!=null&&(u=i.duration),i.easing!=null&&(f=i.easing),i.delay!=null&&(v=i.delay)),tt(v)&&(v=v(e,n)),tt(u)&&(u=u(e));var h={duration:u||0,delay:v,easing:f};return h}else return null}function Am(r,t,e,a,n,i,o){var s=!1,l;tt(n)?(o=i,i=n,n=null):it(n)&&(i=n.cb,o=n.during,s=n.isFrom,l=n.removeOpt,n=n.dataIndex);var u=r==="leave";u||t.stopAnimation("leave");var f=_s(r,a,n,u?l||{}:null,a&&a.getAnimationDelayParams?a.getAnimationDelayParams(t,n):null);if(f&&f.duration>0){var v=f.duration,h=f.delay,c=f.easing,p={duration:v,delay:h||0,easing:c,done:i,force:!!i||!!o,setToFinal:!u,scope:r,during:o};s?t.animateFrom(e,p):t.animateTo(e,p)}else t.stopAnimation(),!s&&t.attr(e),o&&o(1),i&&i()}function Lt(r,t,e,a,n,i){Am("update",r,t,e,a,n,i)}function Yt(r,t,e,a,n,i){Am("enter",r,t,e,a,n,i)}function Xo(r){if(!r.__zr)return!0;for(var t=0;t<r.animators.length;t++){var e=r.animators[t];if(e.scope==="leave")return!0}return!1}function Pn(r,t,e,a,n,i){Xo(r)||Am("leave",r,t,e,a,n,i)}function z1(r,t,e,a){r.removeTextContent(),r.removeTextGuideLine(),Pn(r,{style:{opacity:0}},t,e,a)}function Fa(r,t,e){function a(){r.parent&&r.parent.remove(r)}r.isGroup?r.traverse(function(n){n.isGroup||z1(n,t,e,a)}):z1(r,t,e,a)}function Ir(r){RM(r).oldStyle=r.style}function dN(r){return RM(r).oldStyle}var Tg={},ct=["x","y"],le=["width","height"];function kM(r){return bt.extend(r)}var gN=KO;function EM(r,t){return gN(r,t)}function Rr(r,t){Tg[r]=t}function Kl(r){if(Tg.hasOwnProperty(r))return Tg[r]}function es(r,t,e,a){var n=AM(r,t);return e&&(a==="center"&&(e=OM(e,n.getBoundingRect())),Dm(n,e)),n}function Mm(r,t,e){var a=new xe({style:{image:r,x:t.x,y:t.y,width:t.width,height:t.height},onload:function(n){if(e==="center"){var i={width:n.width,height:n.height};a.setStyle(OM(t,i))}}});return a}function OM(r,t){var e=t.width/t.height,a=r.height*e,n;a<=r.width?n=r.height:(a=r.width,n=a/e);var i=r.x+r.width/2,o=r.y+r.height/2;return{x:i-a/2,y:o-n/2,width:a,height:n}}var or=jO;function Dm(r,t){if(r.applyTransform){var e=r.getBoundingRect(),a=e.calculateTransform(t);r.applyTransform(a)}}function rs(r,t){return Zh(r,r,{lineWidth:t}),r}function yN(r,t){return fM(r,r,t),r}var lv=fr;function An(r,t){for(var e=xu([]);r&&r!==t;)Gr(e,r.getLocalTransform(),e),r=r.parent;return e}function Hr(r,t,e){return t&&!Pe(t)&&(t=Ba.getLocalTransform(t)),e&&(t=Dr([],t)),Jt([],r,t)}function qh(r,t,e){var a=t[4]===0||t[5]===0||t[0]===0?1:la(2*t[4]/t[0]),n=t[4]===0||t[5]===0||t[2]===0?1:la(2*t[4]/t[2]),i=[r==="left"?-a:r==="right"?a:0,r==="top"?-n:r==="bottom"?n:0];return i=Hr(i,t,e),la(i[0])>la(i[1])?i[0]>0?"right":"left":i[1]>0?"bottom":"top"}function V1(r){return!r.isGroup}function mN(r){return r.shape!=null}function Du(r,t,e){if(!r||!t)return;function a(o){var s={};return o.traverse(function(l){V1(l)&&l.anid&&(s[l.anid]=l)}),s}function n(o){var s={x:o.x,y:o.y,rotation:o.rotation};return mN(o)&&(s.shape=et(o.shape)),s}var i=a(r);t.traverse(function(o){if(V1(o)&&o.anid){var s=i[o.anid];if(s){var l=n(o);o.attr(n(s)),Lt(o,l,e,ut(o).dataIndex)}}})}function Lm(r,t){return U(r,function(e){var a=e[0];a=re(a,t.x),a=vr(a,t.x+t.width);var n=e[1];return n=re(n,t.y),n=vr(n,t.y+t.height),[a,n]})}function NM(r,t){var e=re(r.x,t.x),a=vr(r.x+r.width,t.x+t.width),n=re(r.y,t.y),i=vr(r.y+r.height,t.y+t.height);if(a>=e&&i>=n)return{x:e,y:n,width:a-e,height:i-n}}function Ss(r,t,e){var a=G({rectHover:!0},t),n=a.style={strokeNoScale:!0};if(e=e||{x:-1,y:-1,width:2,height:2},r)return r.indexOf("image://")===0?(n.image=r.slice(8),nt(n,e),new xe(a)):es(r.replace("path://",""),a,e,"center")}function gl(r,t,e,a,n){for(var i=0,o=n[n.length-1];i<n.length;i++){var s=n[i];if(BM(r,t,e,a,s[0],s[1],o[0],o[1]))return!0;o=s}}function BM(r,t,e,a,n,i,o,s){var l=e-r,u=a-t,f=o-n,v=s-i,h=Jc(f,v,l,u);if(_N(h))return!1;var c=r-n,p=t-i,d=Jc(c,p,l,u)/h;if(d<0||d>1)return!1;var g=Jc(c,p,f,v)/h;return!(g<0||g>1)}function Jc(r,t,e,a){return r*a-e*t}function _N(r){return r<=1e-6&&r>=-1e-6}function Wi(r,t,e,a,n){return t==null||(Mt(t)?qt[0]=qt[1]=qt[2]=qt[3]=t:(qt[0]=t[0],qt[1]=t[1],qt[2]=t[2],qt[3]=t[3]),a&&(qt[0]=re(0,qt[0]),qt[1]=re(0,qt[1]),qt[2]=re(0,qt[2]),qt[3]=re(0,qt[3])),e&&(qt[0]=-qt[0],qt[1]=-qt[1],qt[2]=-qt[2],qt[3]=-qt[3]),G1(r,qt,"x","width",3,1,n&&n[0]||0),G1(r,qt,"y","height",0,2,n&&n[1]||0)),r}var qt=[0,0,0,0];function G1(r,t,e,a,n,i,o){var s=t[i]+t[n],l=r[a];r[a]+=s,o=re(0,vr(o,l)),r[a]<o?(r[a]=o,r[e]+=t[n]>=0?-t[n]:t[i]>=0?l+t[i]:la(s)>1e-8?(l-o)*t[n]/s:0):r[e]-=t[n]}function en(r){var t=r.itemTooltipOption,e=r.componentModel,a=r.itemName,n=X(t)?{formatter:t}:t,i=e.mainType,o=e.componentIndex,s={componentType:i,name:a,$vars:["name"]};s[i+"Index"]=o;var l=r.formatterParamsExtra;l&&A(Ct(l),function(f){q(s,f)||(s[f]=l[f],s.$vars.push(f))});var u=ut(r.el);u.componentMainType=i,u.componentIndex=o,u.tooltipConfig={name:a,option:nt({content:a,encodeHTMLContent:!0,formatterParams:s},n)}}function Cg(r,t){var e;r.isGroup&&(e=t(r)),e||r.traverse(t)}function zn(r,t){if(r)if(W(r))for(var e=0;e<r.length;e++)Cg(r[e],t);else Cg(r,t)}function Im(r){return!r||la(r[1])<nf&&la(r[2])<nf||la(r[0])<nf&&la(r[3])<nf}var nf=1e-5;function jl(r,t){return r?lt.copy(r,t):t.clone()}function Pm(r,t){return t?bu(r||me(),t):void 0}function Ui(r){return{z:r.get("z")||0,zlevel:r.get("zlevel")||0}}function zM(r){var t=-1/0,e=1/0;Cg(r,function(i){a(i),a(i.getTextContent()),a(i.getTextGuideLine())});function a(i){if(!(!i||i.isGroup)){var o=i.currentStates;if(o.length)for(var s=0;s<o.length;s++)n(i.states[o[s]]);n(i)}}function n(i){if(i){var o=i.z2;o>t&&(t=o),o<e&&(e=o)}}return e>t&&(e=t=0),{min:e,max:t}}function Kh(r,t,e){VM(r,t,e,-1/0)}function VM(r,t,e,a){if(r.ignoreModelZ)return a;var n=r.getTextContent(),i=r.getTextGuideLine(),o=r.isGroup;if(o)for(var s=r.childrenRef(),l=0;l<s.length;l++)a=re(VM(s[l],t,e,a),a);else r.z=t,r.zlevel=e,a=re(r.z2||0,a);if(n&&(n.z=t,n.zlevel=e,isFinite(a)&&(n.z2=a+2)),i){var u=r.textGuideLineConfig;i.z=t,i.zlevel=e,isFinite(a)&&(i.z2=a+(u&&u.showAbove?1:-1))}return a}Rr("circle",wa);Rr("ellipse",Cu);Rr("sector",ke);Rr("ring",ys);Rr("polygon",Ee);Rr("polyline",Ae);Rr("rect",_t);Rr("line",ne);Rr("bezierCurve",ms);Rr("arc",Au);const ji=Object.freeze(Object.defineProperty({__proto__:null,Arc:Au,BezierCurve:ms,BoundingRect:lt,Circle:wa,CompoundPath:Mu,Ellipse:Cu,Group:rt,Image:xe,IncrementalDisplayable:PM,Line:ne,LinearGradient:Ki,OrientedBoundingRect:IM,Path:bt,Point:st,Polygon:Ee,Polyline:Ae,RadialGradient:Cm,Rect:_t,Ring:ys,Sector:ke,Text:At,WH:le,XY:ct,applyTransform:Hr,calcZ2Range:zM,clipPointsByRect:Lm,clipRectByRect:NM,createIcon:Ss,ensureCopyRect:jl,ensureCopyTransform:Pm,expandOrShrinkRect:Wi,extendPath:EM,extendShape:kM,getShapeClass:Kl,getTransform:An,groupTransition:Du,initProps:Yt,isBoundingRectAxisAligned:Im,isElementRemoved:Xo,lineLineIntersect:BM,linePolygonIntersect:gl,makeImage:Mm,makePath:es,mergePath:or,registerShape:Rr,removeElement:Pn,removeElementWithFadeOut:Fa,resizePath:Dm,retrieveZInfo:Ui,setTooltipConfig:en,subPixelOptimize:lv,subPixelOptimizeLine:rs,subPixelOptimizeRect:yN,transformDirection:qh,traverseElements:zn,traverseUpdateZ:Kh,updateProps:Lt},Symbol.toStringTag,{value:"Module"}));var jh={};function GM(r,t){for(var e=0;e<Xe.length;e++){var a=Xe[e],n=t[a],i=r.ensureState(a);i.style=i.style||{},i.style.text=n}var o=r.currentStates.slice();r.clearStates(!0),r.setStyle({text:t.normal}),r.useStates(o,!0)}function Ag(r,t,e){var a=r.labelFetcher,n=r.labelDataIndex,i=r.labelDimIndex,o=t.normal,s;a&&(s=a.getFormattedLabel(n,"normal",null,i,o&&o.get("formatter"),e!=null?{interpolatedValue:e}:null)),s==null&&(s=tt(r.defaultText)?r.defaultText(n,r,e):r.defaultText);for(var l={normal:s},u=0;u<Xe.length;u++){var f=Xe[u],v=t[f];l[f]=Q(a?a.getFormattedLabel(n,f,null,i,v&&v.get("formatter")):null,s)}return l}function Se(r,t,e,a){e=e||jh;for(var n=r instanceof At,i=!1,o=0;o<$l.length;o++){var s=t[$l[o]];if(s&&s.getShallow("show")){i=!0;break}}var l=n?r:r.getTextContent();if(i){n||(l||(l=new At,r.setTextContent(l)),r.stateProxy&&(l.stateProxy=r.stateProxy));var u=Ag(e,t),f=t.normal,v=!!f.getShallow("show"),h=Gt(f,a&&a.normal,e,!1,!n);h.text=u.normal,n||r.setTextConfig(Vv(f,e,!1));for(var o=0;o<Xe.length;o++){var c=Xe[o],s=t[c];if(s){var p=l.ensureState(c),d=!!Q(s.getShallow("show"),v);if(d!==v&&(p.ignore=!d),p.style=Gt(s,a&&a[c],e,!0,!n),p.style.text=u[c],!n){var g=r.ensureState(c);g.textConfig=Vv(s,e,!0)}}}l.silent=!!f.getShallow("silent"),l.style.x!=null&&(h.x=l.style.x),l.style.y!=null&&(h.y=l.style.y),l.ignore=!v,l.useStyle(h),l.dirty(),e.enableTextSetter&&(xs(l).setLabelText=function(y){var m=Ag(e,t,y);GM(l,m)})}else l&&(l.ignore=!0);r.dirty()}function ce(r,t){t=t||"label";for(var e={normal:r.getModel(t)},a=0;a<Xe.length;a++){var n=Xe[a];e[n]=r.getModel([n,t])}return e}function Gt(r,t,e,a,n){var i={};return SN(i,r,e,a,n),t&&G(i,t),i}function Vv(r,t,e){t=t||{};var a={},n,i=r.getShallow("rotate"),o=Q(r.getShallow("distance"),e?null:5),s=r.getShallow("offset");return n=r.getShallow("position")||(e?null:"inside"),n==="outside"&&(n=t.defaultOutsidePosition||"top"),n!=null&&(a.position=n),s!=null&&(a.offset=s),i!=null&&(i*=Math.PI/180,a.rotation=i),o!=null&&(a.distance=o),a.outsideFill=r.get("color")==="inherit"?t.inheritColor||null:"auto",t.autoOverflowArea!=null&&(a.autoOverflowArea=t.autoOverflowArea),t.layoutRect!=null&&(a.layoutRect=t.layoutRect),a}function SN(r,t,e,a,n){e=e||jh;var i=t.ecModel,o=i&&i.option.textStyle,s=xN(t),l;if(s){l={};var u="richInheritPlainLabel",f=Q(t.get(u),i?i.get(u):void 0);for(var v in s)if(s.hasOwnProperty(v)){var h=t.getModel(["rich",v]);U1(l[v]={},h,o,t,f,e,a,n,!1,!0)}}l&&(r.rich=l);var c=t.get("overflow");c&&(r.overflow=c);var p=t.get("lineOverflow");p&&(r.lineOverflow=p);var d=r,g=t.get("minMargin");if(g!=null)g=Mt(g)?g/2:0,d.margin=[g,g,g,g],d.__marginType=Go.minMargin;else{var y=t.get("textMargin");y!=null&&(d.margin=_u(y),d.__marginType=Go.textMargin)}U1(r,t,o,null,null,e,a,n,!0,!1)}function xN(r){for(var t;r&&r!==r.ecModel;){var e=(r.option||jh).rich;if(e){t=t||{};for(var a=Ct(e),n=0;n<a.length;n++){var i=a[n];t[i]=1}}r=r.parentModel}return t}var F1=["fontStyle","fontWeight","fontSize","fontFamily","textShadowColor","textShadowBlur","textShadowOffsetX","textShadowOffsetY"],H1=["align","lineHeight","width","height","tag","verticalAlign","ellipsis"],W1=["padding","borderWidth","borderRadius","borderDashOffset","backgroundColor","borderColor","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"];function U1(r,t,e,a,n,i,o,s,l,u){e=!o&&e||jh;var f=i&&i.inheritColor,v=t.getShallow("color"),h=t.getShallow("textBorderColor"),c=Q(t.getShallow("opacity"),e.opacity);(v==="inherit"||v==="auto")&&(f?v=f:v=null),(h==="inherit"||h==="auto")&&(f?h=f:h=null),s||(v=v||e.color,h=h||e.textBorderColor),v!=null&&(r.fill=v),h!=null&&(r.stroke=h);var p=Q(t.getShallow("textBorderWidth"),e.textBorderWidth);p!=null&&(r.lineWidth=p);var d=Q(t.getShallow("textBorderType"),e.textBorderType);d!=null&&(r.lineDash=d);var g=Q(t.getShallow("textBorderDashOffset"),e.textBorderDashOffset);g!=null&&(r.lineDashOffset=g),!o&&c==null&&!u&&(c=i&&i.defaultOpacity),c!=null&&(r.opacity=c),!o&&!s&&r.fill==null&&i.inheritColor&&(r.fill=i.inheritColor);for(var y=0;y<F1.length;y++){var m=F1[y],_=n!==!1&&a?Qe(t.getShallow(m),a.getShallow(m),e[m]):Q(t.getShallow(m),e[m]);_!=null&&(r[m]=_)}for(var y=0;y<H1.length;y++){var m=H1[y],_=t.getShallow(m);_!=null&&(r[m]=_)}if(r.verticalAlign==null){var S=t.getShallow("baseline");S!=null&&(r.verticalAlign=S)}if(!l||!i.disableBox){for(var y=0;y<W1.length;y++){var m=W1[y],_=t.getShallow(m);_!=null&&(r[m]=_)}var x=t.getShallow("borderType");x!=null&&(r.borderDash=x),(r.backgroundColor==="auto"||r.backgroundColor==="inherit")&&f&&(r.backgroundColor=f),(r.borderColor==="auto"||r.borderColor==="inherit")&&f&&(r.borderColor=f)}}function Rm(r,t){var e=t&&t.getModel("textStyle");return sr([r.fontStyle||e&&e.getShallow("fontStyle")||"",r.fontWeight||e&&e.getShallow("fontWeight")||"",(r.fontSize||e&&e.getShallow("fontSize")||12)+"px",r.fontFamily||e&&e.getShallow("fontFamily")||"sans-serif"].join(" "))}var xs=St();function FM(r,t,e,a){if(r){var n=xs(r);n.prevValue=n.value,n.value=e;var i=t.normal;n.valueAnimation=i.get("valueAnimation"),n.valueAnimation&&(n.precision=i.get("precision"),n.defaultInterpolatedText=a,n.statesModels=t)}}function HM(r,t,e,a,n){var i=xs(r);if(!i.valueAnimation||i.prevValue===i.value)return;var o=i.defaultInterpolatedText,s=Q(i.interpolatedValue,i.prevValue),l=i.value;function u(f){var v=tM(e,i.precision,s,l,f);i.interpolatedValue=f===1?null:v;var h=Ag({labelDataIndex:t,labelFetcher:n,defaultText:o?o(v):v+""},i.statesModels,v);GM(r,h)}r.percent=0,(i.prevValue==null?Yt:Lt)(r,{percent:1},a,t,null,u)}var Go={minMargin:1,textMargin:2},bN=["textStyle","color"],Qc=["fontStyle","fontWeight","fontSize","fontFamily","padding","lineHeight","rich","width","height","overflow"],tp=new At,wN=function(){function r(){}return r.prototype.getTextColor=function(t){var e=this.ecModel;return this.getShallow("color")||(!t&&e?e.get(bN):null)},r.prototype.getFont=function(){return Rm({fontStyle:this.getShallow("fontStyle"),fontWeight:this.getShallow("fontWeight"),fontSize:this.getShallow("fontSize"),fontFamily:this.getShallow("fontFamily")},this.ecModel)},r.prototype.getTextRect=function(t){for(var e={text:t,verticalAlign:this.getShallow("verticalAlign")||this.getShallow("baseline")},a=0;a<Qc.length;a++)e[Qc[a]]=this.getShallow(Qc[a]);return tp.useStyle(e),tp.update(),tp.getBoundingRect()},r}(),WM=[["lineWidth","width"],["stroke","color"],["opacity"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"],["lineDash","type"],["lineDashOffset","dashOffset"],["lineCap","cap"],["lineJoin","join"],["miterLimit"]],TN=Fi(WM),CN=function(){function r(){}return r.prototype.getLineStyle=function(t){return TN(this,t)},r}(),UM=[["fill","color"],["stroke","borderColor"],["lineWidth","borderWidth"],["opacity"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"],["lineDash","borderType"],["lineDashOffset","borderDashOffset"],["lineCap","borderCap"],["lineJoin","borderJoin"],["miterLimit","borderMiterLimit"]],AN=Fi(UM),MN=function(){function r(){}return r.prototype.getItemStyle=function(t,e){return AN(this,t,e)},r}(),wt=function(){function r(t,e,a){this.parentModel=e,this.ecModel=a,this.option=t}return r.prototype.init=function(t,e,a){},r.prototype.mergeOption=function(t,e){yt(this.option,t,!0)},r.prototype.get=function(t,e){return t==null?this.option:this._doGet(this.parsePath(t),!e&&this.parentModel)},r.prototype.getShallow=function(t,e){var a=this.option,n=a==null?a:a[t];if(n==null&&!e){var i=this.parentModel;i&&(n=i.getShallow(t))}return n},r.prototype.getModel=function(t,e){var a=t!=null,n=a?this.parsePath(t):null,i=a?this._doGet(n):this.option;return e=e||this.parentModel&&this.parentModel.getModel(this.resolveParentPath(n)),new r(i,e,this.ecModel)},r.prototype.isEmpty=function(){return this.option==null},r.prototype.restoreData=function(){},r.prototype.clone=function(){var t=this.constructor;return new t(et(this.option))},r.prototype.parsePath=function(t){return typeof t=="string"?t.split("."):t},r.prototype.resolveParentPath=function(t){return t},r.prototype.isAnimationEnabled=function(){if(!Tt.node&&this.option){if(this.option.animation!=null)return!!this.option.animation;if(this.parentModel)return this.parentModel.isAnimationEnabled()}},r.prototype._doGet=function(t,e){var a=this.option;if(!t)return a;for(var n=0;n<t.length&&!(t[n]&&(a=a&&typeof a=="object"?a[t[n]]:null,a==null));n++);return a==null&&e&&(a=e._doGet(this.resolveParentPath(t),e.parentModel)),a},r}();dm(wt);zE(wt);Qt(wt,CN);Qt(wt,MN);Qt(wt,WE);Qt(wt,wN);var DN=Math.round(Math.random()*10);function bs(r){return[r||"",DN++].join("_")}function LN(r){var t={};r.registerSubTypeDefaulter=function(e,a){var n=ua(e);t[n.main]=a},r.determineSubType=function(e,a){var n=a.type;if(!n){var i=ua(e).main;r.hasSubTypes(e)&&t[i]&&(n=t[i](a))}return n}}function IN(r,t){r.topologicalTravel=function(i,o,s,l){if(!i.length)return;var u=e(o),f=u.graph,v=u.noEntryList,h={};for(A(i,function(m){h[m]=!0});v.length;){var c=v.pop(),p=f[c],d=!!h[c];d&&(s.call(l,c,p.originalDeps.slice()),delete h[c]),A(p.successor,d?y:g)}A(h,function(){var m="";throw new Error(m)});function g(m){f[m].entryCount--,f[m].entryCount===0&&v.push(m)}function y(m){h[m]=!0,g(m)}};function e(i){var o={},s=[];return A(i,function(l){var u=a(o,l),f=u.originalDeps=t(l),v=n(f,i);u.entryCount=v.length,u.entryCount===0&&s.push(l),A(v,function(h){gt(u.predecessor,h)<0&&u.predecessor.push(h);var c=a(o,h);gt(c.successor,h)<0&&c.successor.push(l)})}),{graph:o,noEntryList:s}}function a(i,o){return i[o]||(i[o]={predecessor:[],successor:[]}),i[o]}function n(i,o){var s=[];return A(i,function(l){gt(o,l)>=0&&s.push(l)}),s}}function Vn(r,t){return yt(yt({},r,!0),t,!0)}const PN={time:{month:["January","February","March","April","May","June","July","August","September","October","November","December"],monthAbbr:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayOfWeek:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayOfWeekAbbr:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"]},legend:{selector:{all:"All",inverse:"Inv"}},toolbox:{brush:{title:{rect:"Box Select",polygon:"Lasso Select",lineX:"Horizontally Select",lineY:"Vertically Select",keep:"Keep Selections",clear:"Clear Selections"}},dataView:{title:"Data View",lang:["Data View","Close","Refresh"]},dataZoom:{title:{zoom:"Zoom",back:"Zoom Reset"}},magicType:{title:{line:"Switch to Line Chart",bar:"Switch to Bar Chart",stack:"Stack",tiled:"Tile"}},restore:{title:"Restore"},saveAsImage:{title:"Save as Image",lang:["Right Click to Save Image"]}},series:{typeNames:{pie:"Pie chart",bar:"Bar chart",line:"Line chart",scatter:"Scatter plot",effectScatter:"Ripple scatter plot",radar:"Radar chart",tree:"Tree",treemap:"Treemap",boxplot:"Boxplot",candlestick:"Candlestick",k:"K line chart",heatmap:"Heat map",map:"Map",parallel:"Parallel coordinate map",lines:"Line graph",graph:"Relationship graph",sankey:"Sankey diagram",funnel:"Funnel chart",gauge:"Gauge",pictorialBar:"Pictorial bar",themeRiver:"Theme River Map",sunburst:"Sunburst",custom:"Custom chart",chart:"Chart"}},aria:{general:{withTitle:'This is a chart about "{title}"',withoutTitle:"This is a chart"},series:{single:{prefix:"",withName:" with type {seriesType} named {seriesName}.",withoutName:" with type {seriesType}."},multiple:{prefix:". It consists of {seriesCount} series count.",withName:" The {seriesId} series is a {seriesType} representing {seriesName}.",withoutName:" The {seriesId} series is a {seriesType}.",separator:{middle:"",end:""}}},data:{allData:"The data is as follows: ",partialData:"The first {displayCnt} items are: ",withName:"the data for {name} is {value}",withoutName:"{value}",separator:{middle:", ",end:". "}}}},RN={time:{month:["一月","二月","三月","四月","五月","六月","七月","八月","九月","十月","十一月","十二月"],monthAbbr:["1月","2月","3月","4月","5月","6月","7月","8月","9月","10月","11月","12月"],dayOfWeek:["星期日","星期一","星期二","星期三","星期四","星期五","星期六"],dayOfWeekAbbr:["日","一","二","三","四","五","六"]},legend:{selector:{all:"全选",inverse:"反选"}},toolbox:{brush:{title:{rect:"矩形选择",polygon:"圈选",lineX:"横向选择",lineY:"纵向选择",keep:"保持选择",clear:"清除选择"}},dataView:{title:"数据视图",lang:["数据视图","关闭","刷新"]},dataZoom:{title:{zoom:"区域缩放",back:"区域缩放还原"}},magicType:{title:{line:"切换为折线图",bar:"切换为柱状图",stack:"切换为堆叠",tiled:"切换为平铺"}},restore:{title:"还原"},saveAsImage:{title:"保存为图片",lang:["右键另存为图片"]}},series:{typeNames:{pie:"饼图",bar:"柱状图",line:"折线图",scatter:"散点图",effectScatter:"涟漪散点图",radar:"雷达图",tree:"树图",treemap:"矩形树图",boxplot:"箱型图",candlestick:"K线图",k:"K线图",heatmap:"热力图",map:"地图",parallel:"平行坐标图",lines:"线图",graph:"关系图",sankey:"桑基图",funnel:"漏斗图",gauge:"仪表盘图",pictorialBar:"象形柱图",themeRiver:"主题河流图",sunburst:"旭日图",custom:"自定义图表",chart:"图表"}},aria:{general:{withTitle:"这是一个关于“{title}”的图表。",withoutTitle:"这是一个图表，"},series:{single:{prefix:"",withName:"图表类型是{seriesType}，表示{seriesName}。",withoutName:"图表类型是{seriesType}。"},multiple:{prefix:"它由{seriesCount}个图表系列组成。",withName:"第{seriesId}个系列是一个表示{seriesName}的{seriesType}，",withoutName:"第{seriesId}个系列是一个{seriesType}，",separator:{middle:"；",end:"。"}}},data:{allData:"其数据是——",partialData:"其中，前{displayCnt}项是——",withName:"{name}的数据是{value}",withoutName:"{value}",separator:{middle:"，",end:""}}}};var Gv="ZH",km="EN",$o=km,uv={},Em={},YM=Tt.domSupported?function(){var r=(document.documentElement.lang||navigator.language||navigator.browserLanguage||$o).toUpperCase();return r.indexOf(Gv)>-1?Gv:$o}():$o;function ZM(r,t){r=r.toUpperCase(),Em[r]=new wt(t),uv[r]=t}function kN(r){if(X(r)){var t=uv[r.toUpperCase()]||{};return r===Gv||r===km?et(t):yt(et(t),et(uv[$o]),!1)}else return yt(et(r),et(uv[$o]),!1)}function Mg(r){return Em[r]}function EN(){return Em[$o]}ZM(km,PN);ZM(Gv,RN);var Dg=null;function ON(r){Dg||(Dg=r)}function se(){return Dg}var Om=1e3,Nm=Om*60,El=Nm*60,Tr=El*24,Y1=Tr*365,NN={year:/({yyyy}|{yy})/,month:/({MMMM}|{MMM}|{MM}|{M})/,day:/({dd}|{d})/,hour:/({HH}|{H}|{hh}|{h})/,minute:/({mm}|{m})/,second:/({ss}|{s})/,millisecond:/({SSS}|{S})/},fv={year:"{yyyy}",month:"{MMM}",day:"{d}",hour:"{HH}:{mm}",minute:"{HH}:{mm}",second:"{HH}:{mm}:{ss}",millisecond:"{HH}:{mm}:{ss} {SSS}"},BN="{yyyy}-{MM}-{dd} {HH}:{mm}:{ss} {SSS}",of="{yyyy}-{MM}-{dd}",Z1={year:"{yyyy}",month:"{yyyy}-{MM}",day:of,hour:of+" "+fv.hour,minute:of+" "+fv.minute,second:of+" "+fv.second,millisecond:BN},ar=["year","month","day","hour","minute","second","millisecond"],zN=["year","half-year","quarter","month","week","half-week","day","half-day","quarter-day","hour","minute","second","millisecond"];function VN(r){return!X(r)&&!tt(r)?GN(r):r}function GN(r){r=r||{};var t={},e=!0;return A(ar,function(a){e&&(e=r[a]==null)}),A(ar,function(a,n){var i=r[a];t[a]={};for(var o=null,s=n;s>=0;s--){var l=ar[s],u=it(i)&&!W(i)?i[l]:i,f=void 0;W(u)?(f=u.slice(),o=f[0]||""):X(u)?(o=u,f=[o]):(o==null?o=fv[a]:NN[l].test(o)||(o=t[l][l][0]+" "+o),f=[o],e&&(f[1]="{primary|"+o+"}")),t[a][l]=f}}),t}function He(r,t){return r+="","0000".substr(0,t-r.length)+r}function Ol(r){switch(r){case"half-year":case"quarter":return"month";case"week":case"half-week":return"day";case"half-day":case"quarter-day":return"hour";default:return r}}function FN(r){return r===Ol(r)}function HN(r){switch(r){case"year":case"month":return"day";case"millisecond":return"millisecond";default:return"second"}}function Lu(r,t,e,a){var n=ba(r),i=n[XM(e)](),o=n[Bm(e)]()+1,s=Math.floor((o-1)/3)+1,l=n[zm(e)](),u=n["get"+(e?"UTC":"")+"Day"](),f=n[Vm(e)](),v=(f-1)%12+1,h=n[Gm(e)](),c=n[Fm(e)](),p=n[Hm(e)](),d=f>=12?"pm":"am",g=d.toUpperCase(),y=a instanceof wt?a:Mg(a||YM)||EN(),m=y.getModel("time"),_=m.get("month"),S=m.get("monthAbbr"),x=m.get("dayOfWeek"),b=m.get("dayOfWeekAbbr");return(t||"").replace(/{a}/g,d+"").replace(/{A}/g,g+"").replace(/{yyyy}/g,i+"").replace(/{yy}/g,He(i%100+"",2)).replace(/{Q}/g,s+"").replace(/{MMMM}/g,_[o-1]).replace(/{MMM}/g,S[o-1]).replace(/{MM}/g,He(o,2)).replace(/{M}/g,o+"").replace(/{dd}/g,He(l,2)).replace(/{d}/g,l+"").replace(/{eeee}/g,x[u]).replace(/{ee}/g,b[u]).replace(/{e}/g,u+"").replace(/{HH}/g,He(f,2)).replace(/{H}/g,f+"").replace(/{hh}/g,He(v+"",2)).replace(/{h}/g,v+"").replace(/{mm}/g,He(h,2)).replace(/{m}/g,h+"").replace(/{ss}/g,He(c,2)).replace(/{s}/g,c+"").replace(/{SSS}/g,He(p,3)).replace(/{S}/g,p+"")}function WN(r,t,e,a,n){var i=null;if(X(e))i=e;else if(tt(e)){var o={time:r.time,level:r.time.level},s=se();s&&s.makeAxisLabelFormatterParamBreak(o,r.break),i=e(r.value,t,o)}else{var l=r.time;if(l){var u=e[l.lowerTimeUnit][l.upperTimeUnit];i=u[Math.min(l.level,u.length-1)]||""}else{var f=Fo(r.value,n);i=e[f][f][0]}}return Lu(new Date(r.value),i,n,a)}function Fo(r,t){var e=ba(r),a=e[Bm(t)]()+1,n=e[zm(t)](),i=e[Vm(t)](),o=e[Gm(t)](),s=e[Fm(t)](),l=e[Hm(t)](),u=l===0,f=u&&s===0,v=f&&o===0,h=v&&i===0,c=h&&n===1,p=c&&a===1;return p?"year":c?"month":h?"day":v?"hour":f?"minute":u?"second":"millisecond"}function Fv(r,t,e){switch(t){case"year":r[$M(e)](0);case"month":r[qM(e)](1);case"day":r[KM(e)](0);case"hour":r[jM(e)](0);case"minute":r[JM(e)](0);case"second":r[QM(e)](0)}return r}function XM(r){return r?"getUTCFullYear":"getFullYear"}function Bm(r){return r?"getUTCMonth":"getMonth"}function zm(r){return r?"getUTCDate":"getDate"}function Vm(r){return r?"getUTCHours":"getHours"}function Gm(r){return r?"getUTCMinutes":"getMinutes"}function Fm(r){return r?"getUTCSeconds":"getSeconds"}function Hm(r){return r?"getUTCMilliseconds":"getMilliseconds"}function UN(r){return r?"setUTCFullYear":"setFullYear"}function $M(r){return r?"setUTCMonth":"setMonth"}function qM(r){return r?"setUTCDate":"setDate"}function KM(r){return r?"setUTCHours":"setHours"}function jM(r){return r?"setUTCMinutes":"setMinutes"}function JM(r){return r?"setUTCSeconds":"setSeconds"}function QM(r){return r?"setUTCMilliseconds":"setMilliseconds"}function YN(r,t,e,a,n,i,o,s){var l=new At({style:{text:r,font:t,align:e,verticalAlign:a,padding:n,rich:i,overflow:o?"truncate":null,lineHeight:s}});return l.getBoundingRect()}function Wm(r){if(!hm(r))return X(r)?r:"-";var t=(r+"").split(".");return t[0].replace(/(\d{1,3})(?=(?:\d{3})+(?!\d))/g,"$1,")+(t.length>1?"."+t[1]:"")}function Um(r,t){return r=(r||"").toLowerCase().replace(/-(.)/g,function(e,a){return a.toUpperCase()}),t&&r&&(r=r.charAt(0).toUpperCase()+r.slice(1)),r}var ws=_u;function Lg(r,t,e){var a="{yyyy}-{MM}-{dd} {HH}:{mm}:{ss}";function n(f){return f&&sr(f)?f:"-"}function i(f){return!!(f!=null&&!isNaN(f)&&isFinite(f))}var o=t==="time",s=r instanceof Date;if(o||s){var l=o?ba(r):r;if(isNaN(+l)){if(s)return"-"}else return Lu(l,a,e)}if(t==="ordinal")return xv(r)?n(r):Mt(r)&&i(r)?r+"":"-";var u=ya(r);return i(u)?Wm(u):xv(r)?n(r):typeof r=="boolean"?r+"":"-"}var X1=["a","b","c","d","e","f","g"],ep=function(r,t){return"{"+r+(t??"")+"}"};function Ym(r,t,e){W(t)||(t=[t]);var a=t.length;if(!a)return"";for(var n=t[0].$vars||[],i=0;i<n.length;i++){var o=X1[i];r=r.replace(ep(o),ep(o,0))}for(var s=0;s<a;s++)for(var l=0;l<n.length;l++){var u=t[s][n[l]];r=r.replace(ep(X1[l],s),e?ze(u):u)}return r}function ZN(r,t,e){return A(t,function(a,n){r=r.replace("{"+n+"}",a)}),r}function tD(r,t){var e=X(r)?{color:r,extraCssText:t}:r||{},a=e.color,n=e.type;t=e.extraCssText;var i=e.renderMode||"html";if(!a)return"";if(i==="html")return n==="subItem"?'<span style="display:inline-block;vertical-align:middle;margin-right:8px;margin-left:3px;border-radius:4px;width:4px;height:4px;background-color:'+ze(a)+";"+(t||"")+'"></span>':'<span style="display:inline-block;margin-right:4px;border-radius:10px;width:10px;height:10px;background-color:'+ze(a)+";"+(t||"")+'"></span>';var o=e.markerId||"markerX";return{renderMode:i,content:"{"+o+"|}  ",style:n==="subItem"?{width:4,height:4,borderRadius:2,backgroundColor:a}:{width:10,height:10,borderRadius:5,backgroundColor:a}}}function XN(r,t,e){(r==="week"||r==="month"||r==="quarter"||r==="half-year"||r==="year")&&(r=`MM-dd
yyyy`);var a=ba(t),n=e?"getUTC":"get",i=a[n+"FullYear"](),o=a[n+"Month"]()+1,s=a[n+"Date"](),l=a[n+"Hours"](),u=a[n+"Minutes"](),f=a[n+"Seconds"](),v=a[n+"Milliseconds"]();return r=r.replace("MM",He(o,2)).replace("M",o).replace("yyyy",i).replace("yy",He(i%100+"",2)).replace("dd",He(s,2)).replace("d",s).replace("hh",He(l,2)).replace("h",l).replace("mm",He(u,2)).replace("m",u).replace("ss",He(f,2)).replace("s",f).replace("SSS",He(v,3)),r}function $N(r){return r&&r.charAt(0).toUpperCase()+r.substr(1)}function Yi(r,t){return t=t||"transparent",X(r)?r:it(r)&&r.colorStops&&(r.colorStops[0]||{}).color||t}function Hv(r,t){if(t==="_blank"||t==="blank"){var e=window.open();e.opener=null,e.location.href=r}else window.open(r,t)}var vv={},rp={},Ts=function(){function r(){this._normalMasterList=[],this._nonSeriesBoxMasterList=[]}return r.prototype.create=function(t,e){this._nonSeriesBoxMasterList=a(vv),this._normalMasterList=a(rp);function a(n,i){var o=[];return A(n,function(s,l){var u=s.create(t,e);o=o.concat(u||[])}),o}},r.prototype.update=function(t,e){A(this._normalMasterList,function(a){a.update&&a.update(t,e)})},r.prototype.getCoordinateSystems=function(){return this._normalMasterList.concat(this._nonSeriesBoxMasterList)},r.register=function(t,e){if(t==="matrix"||t==="calendar"){vv[t]=e;return}rp[t]=e},r.get=function(t){return rp[t]||vv[t]},r}();function qN(r){return!!vv[r]}var Ig={coord:1,coord2:2};function KN(r){eD.set(r.fullType,{getCoord2:void 0}).getCoord2=r.getCoord2}var eD=j();function jN(r){var t=r.getShallow("coord",!0),e=Ig.coord;if(t==null){var a=eD.get(r.type);a&&a.getCoord2&&(e=Ig.coord2,t=a.getCoord2(r))}return{coord:t,from:e}}var oa={none:0,dataCoordSys:1,boxCoordSys:2};function rD(r,t){var e=r.getShallow("coordinateSystem"),a=r.getShallow("coordinateSystemUsage",!0),n=oa.none;if(e){var i=r.mainType==="series";a==null&&(a=i?"data":"box"),a==="data"?(n=oa.dataCoordSys,i||(n=oa.none)):a==="box"&&(n=oa.boxCoordSys,!i&&!qN(e)&&(n=oa.none))}return{coordSysType:e,kind:n}}function Iu(r){var t=r.targetModel,e=r.coordSysType,a=r.coordSysProvider,n=r.isDefaultDataCoordSys;r.allowNotFound;var i=rD(t),o=i.kind,s=i.coordSysType;if(n&&o!==oa.dataCoordSys&&(o=oa.dataCoordSys,s=e),o===oa.none||s!==e)return!1;var l=a(e,t);return l?(o===oa.dataCoordSys?t.coordinateSystem=l:t.boxCoordinateSystem=l,!0):!1}var aD=function(r,t){var e=t.getReferringComponents(r,Kt).models[0];return e&&e.coordinateSystem},hv=A,nD=["left","right","top","bottom","width","height"],Mi=[["width","left","right"],["height","top","bottom"]];function Zm(r,t,e,a,n){var i=0,o=0;a==null&&(a=1/0),n==null&&(n=1/0);var s=0;t.eachChild(function(l,u){var f=l.getBoundingRect(),v=t.childAt(u+1),h=v&&v.getBoundingRect(),c,p;if(r==="horizontal"){var d=f.width+(h?-h.x+f.x:0);c=i+d,c>a||l.newline?(i=0,c=d,o+=s+e,s=f.height):s=Math.max(s,f.height)}else{var g=f.height+(h?-h.y+f.y:0);p=o+g,p>n||l.newline?(i+=s+e,o=0,p=g,s=f.width):s=Math.max(s,f.width)}l.newline||(l.x=i,l.y=o,l.markRedraw(),r==="horizontal"?i=c+e:o=p+e)})}var Ei=Zm;pt(Zm,"vertical");pt(Zm,"horizontal");function iD(r,t){return{left:r.getShallow("left",t),top:r.getShallow("top",t),right:r.getShallow("right",t),bottom:r.getShallow("bottom",t),width:r.getShallow("width",t),height:r.getShallow("height",t)}}function JN(r,t){var e=pe(r,t,{enableLayoutOnlyByCenter:!0}),a=r.getBoxLayoutParams(),n,i;if(e.type===yl.point)i=e.refPoint,n=Xt(a,{width:t.getWidth(),height:t.getHeight()});else{var o=r.get("center"),s=W(o)?o:[o,o];n=Xt(a,e.refContainer),i=e.boxCoordFrom===Ig.coord2?e.refPoint:[Z(s[0],n.width)+n.x,Z(s[1],n.height)+n.y]}return{viewRect:n,center:i}}function oD(r,t){var e=JN(r,t),a=e.viewRect,n=e.center,i=r.get("radius");W(i)||(i=[0,i]);var o=Z(a.width,t.getWidth()),s=Z(a.height,t.getHeight()),l=Math.min(o,s),u=Z(i[0],l/2),f=Z(i[1],l/2);return{cx:n[0],cy:n[1],r0:u,r:f,viewRect:a}}function Xt(r,t,e){e=ws(e||0);var a=t.width,n=t.height,i=Z(r.left,a),o=Z(r.top,n),s=Z(r.right,a),l=Z(r.bottom,n),u=Z(r.width,a),f=Z(r.height,n),v=e[2]+e[0],h=e[1]+e[3],c=r.aspect;switch(isNaN(u)&&(u=a-s-h-i),isNaN(f)&&(f=n-l-v-o),c!=null&&(isNaN(u)&&isNaN(f)&&(c>a/n?u=a*.8:f=n*.8),isNaN(u)&&(u=c*f),isNaN(f)&&(f=u/c)),isNaN(i)&&(i=a-s-u-h),isNaN(o)&&(o=n-l-f-v),r.left||r.right){case"center":i=a/2-u/2-e[3];break;case"right":i=a-u-h;break}switch(r.top||r.bottom){case"middle":case"center":o=n/2-f/2-e[0];break;case"bottom":o=n-f-v;break}i=i||0,o=o||0,isNaN(u)&&(u=a-h-i-(s||0)),isNaN(f)&&(f=n-v-o-(l||0));var p=new lt((t.x||0)+i+e[3],(t.y||0)+o+e[0],u,f);return p.margin=e,p}function sD(r,t,e){var a=r.getShallow("preserveAspect",!0);if(!a)return t;var n=t.width/t.height;if(Math.abs(Math.atan(e)-Math.atan(n))<1e-9)return t;var i=r.getShallow("preserveAspectAlign",!0),o=r.getShallow("preserveAspectVerticalAlign",!0),s={width:t.width,height:t.height},l=a==="cover";return n>e&&!l||n<e&&l?(s.width=t.height*e,i==="left"?s.left=0:i==="right"?s.right=0:s.left="center"):(s.height=t.width/e,o==="top"?s.top=0:o==="bottom"?s.bottom=0:s.top="middle"),Xt(s,t)}var yl={rect:1,point:2};function pe(r,t,e){var a,n,i,o=r.boxCoordinateSystem,s;if(o){var l=jN(r),u=l.coord,f=l.from;if(o.dataToLayout){i=yl.rect,s=f;var v=o.dataToLayout(u);a=v.contentRect||v.rect}else e&&e.enableLayoutOnlyByCenter&&o.dataToPoint&&(i=yl.point,s=f,n=o.dataToPoint(u))}return i==null&&(i=yl.rect),i===yl.rect&&(a||(a={x:0,y:0,width:t.getWidth(),height:t.getHeight()}),n=[a.x+a.width/2,a.y+a.height/2]),{type:i,refContainer:a,refPoint:n,boxCoordFrom:s}}function Jh(r,t,e,a,n,i){var o=!n||!n.hv||n.hv[0],s=!n||!n.hv||n.hv[1],l=n&&n.boundingMode||"all";if(i=i||r,i.x=r.x,i.y=r.y,!o&&!s)return!1;var u;if(l==="raw")u=r.type==="group"?new lt(0,0,+t.width||0,+t.height||0):r.getBoundingRect();else if(u=r.getBoundingRect(),r.needLocalTransform()){var f=r.getLocalTransform();u=u.clone(),u.applyTransform(f)}var v=Xt(nt({width:u.width,height:u.height},t),e,a),h=o?v.x-u.x:0,c=s?v.y-u.y:0;return l==="raw"?(i.x=h,i.y=c):(i.x+=h,i.y+=c),i===r&&r.markRedraw(),!0}function QN(r,t){return r[Mi[t][0]]!=null||r[Mi[t][1]]!=null&&r[Mi[t][2]]!=null}function Jl(r){var t=r.layoutMode||r.constructor.layoutMode;return it(t)?t:t?{type:t}:null}function _a(r,t,e){var a=e&&e.ignoreSize;!W(a)&&(a=[a,a]);var n=o(Mi[0],0),i=o(Mi[1],1);l(Mi[0],r,n),l(Mi[1],r,i);function o(u,f){var v={},h=0,c={},p=0,d=2;if(hv(u,function(m){c[m]=r[m]}),hv(u,function(m){q(t,m)&&(v[m]=c[m]=t[m]),s(v,m)&&h++,s(c,m)&&p++}),a[f])return s(t,u[1])?c[u[2]]=null:s(t,u[2])&&(c[u[1]]=null),c;if(p===d||!h)return c;if(h>=d)return v;for(var g=0;g<u.length;g++){var y=u[g];if(!q(v,y)&&q(r,y)){v[y]=r[y];break}}return v}function s(u,f){return u[f]!=null&&u[f]!=="auto"}function l(u,f,v){hv(u,function(h){f[h]=v[h]})}}function Ji(r){return lD({},r)}function lD(r,t){return t&&r&&hv(nD,function(e){q(t,e)&&(r[e]=t[e])}),r}var tB=St(),xt=function(r){z(t,r);function t(e,a,n){var i=r.call(this,e,a,n)||this;return i.uid=bs("ec_cpt_model"),i}return t.prototype.init=function(e,a,n){this.mergeDefaultAndTheme(e,n)},t.prototype.mergeDefaultAndTheme=function(e,a){var n=Jl(this),i=n?Ji(e):{},o=a.getTheme();yt(e,o.get(this.mainType)),yt(e,this.getDefaultOption()),n&&_a(e,i,n)},t.prototype.mergeOption=function(e,a){yt(this.option,e,!0);var n=Jl(this);n&&_a(this.option,e,n)},t.prototype.optionUpdated=function(e,a){},t.prototype.getDefaultOption=function(){var e=this.constructor;if(!OE(e))return e.defaultOption;var a=tB(this);if(!a.defaultOption){for(var n=[],i=e;i;){var o=i.prototype.defaultOption;o&&n.push(o),i=i.superClass}for(var s={},l=n.length-1;l>=0;l--)s=yt(s,n[l],!0);a.defaultOption=s}return a.defaultOption},t.prototype.getReferringComponents=function(e,a){var n=e+"Index",i=e+"Id";return ds(this.ecModel,e,{index:this.get(n,!0),id:this.get(i,!0)},a)},t.prototype.getBoxLayoutParams=function(){return iD(this,!1)},t.prototype.getZLevelKey=function(){return""},t.prototype.setZLevel=function(e){this.option.zlevel=e},t.protoInitialize=function(){var e=t.prototype;e.type="component",e.id="",e.name="",e.mainType="",e.subType="",e.componentIndex=0}(),t}(wt);rM(xt,wt);Fh(xt);LN(xt);IN(xt,eB);function eB(r){var t=[];return A(xt.getClassesByMainType(r),function(e){t=t.concat(e.dependencies||e.prototype.dependencies||[])}),t=U(t,function(e){return ua(e).main}),r!=="dataset"&&gt(t,"dataset")<=0&&t.unshift("dataset"),t}var N={color:{},darkColor:{},size:{}},te=N.color={theme:["#5070dd","#b6d634","#505372","#ff994d","#0ca8df","#ffd10a","#fb628b","#785db0","#3fbe95"],neutral00:"#fff",neutral05:"#f4f7fd",neutral10:"#e8ebf0",neutral15:"#dbdee4",neutral20:"#cfd2d7",neutral25:"#c3c5cb",neutral30:"#b7b9be",neutral35:"#aaacb2",neutral40:"#9ea0a5",neutral45:"#929399",neutral50:"#86878c",neutral55:"#797b7f",neutral60:"#6d6e73",neutral65:"#616266",neutral70:"#54555a",neutral75:"#48494d",neutral80:"#3c3c41",neutral85:"#303034",neutral90:"#232328",neutral95:"#17171b",neutral99:"#000",accent05:"#eff1f9",accent10:"#e0e4f2",accent15:"#d0d6ec",accent20:"#c0c9e6",accent25:"#b1bbdf",accent30:"#a1aed9",accent35:"#91a0d3",accent40:"#8292cc",accent45:"#7285c6",accent50:"#6578ba",accent55:"#5c6da9",accent60:"#536298",accent65:"#4a5787",accent70:"#404c76",accent75:"#374165",accent80:"#2e3654",accent85:"#252b43",accent90:"#1b2032",accent95:"#121521",transparent:"rgba(0,0,0,0)",highlight:"rgba(255,231,130,0.8)"};G(te,{primary:te.neutral80,secondary:te.neutral70,tertiary:te.neutral60,quaternary:te.neutral50,disabled:te.neutral20,border:te.neutral30,borderTint:te.neutral20,borderShade:te.neutral40,background:te.neutral05,backgroundTint:"rgba(234,237,245,0.5)",backgroundTransparent:"rgba(255,255,255,0)",backgroundShade:te.neutral10,shadow:"rgba(0,0,0,0.2)",shadowTint:"rgba(129,130,136,0.2)",axisLine:te.neutral70,axisLineTint:te.neutral40,axisTick:te.neutral70,axisTickMinor:te.neutral60,axisLabel:te.neutral70,axisSplitLine:te.neutral15,axisMinorSplitLine:te.neutral05});for(var ni in te)if(te.hasOwnProperty(ni)){var $1=te[ni];ni==="theme"?N.darkColor.theme=te.theme.slice():ni==="highlight"?N.darkColor.highlight="rgba(255,231,130,0.4)":ni.indexOf("accent")===0?N.darkColor[ni]=Ga($1,null,function(r){return r*.5},function(r){return Math.min(1,1.3-r)}):N.darkColor[ni]=Ga($1,null,function(r){return r*.9},function(r){return 1-Math.pow(r,1.5)})}N.size={xxs:2,xs:5,s:10,m:15,l:20,xl:30,xxl:40,xxxl:50};var uD="";typeof navigator<"u"&&(uD=navigator.platform||"");var co="rgba(0, 0, 0, 0.2)",fD=N.color.theme[0],rB=Ga(fD,null,null,.9);const aB={darkMode:"auto",colorBy:"series",color:N.color.theme,gradientColor:[rB,fD],aria:{decal:{decals:[{color:co,dashArrayX:[1,0],dashArrayY:[2,5],symbolSize:1,rotation:Math.PI/6},{color:co,symbol:"circle",dashArrayX:[[8,8],[0,8,8,0]],dashArrayY:[6,0],symbolSize:.8},{color:co,dashArrayX:[1,0],dashArrayY:[4,3],rotation:-Math.PI/4},{color:co,dashArrayX:[[6,6],[0,6,6,0]],dashArrayY:[6,0]},{color:co,dashArrayX:[[1,0],[1,6]],dashArrayY:[1,0,6,0],rotation:Math.PI/4},{color:co,symbol:"triangle",dashArrayX:[[9,9],[0,9,9,0]],dashArrayY:[7,2],symbolSize:.75}]}},textStyle:{fontFamily:uD.match(/^Win/)?"Microsoft YaHei":"sans-serif",fontSize:12,fontStyle:"normal",fontWeight:"normal"},blendMode:null,stateAnimation:{duration:300,easing:"cubicOut"},animation:"auto",animationDuration:1e3,animationDurationUpdate:500,animationEasing:"cubicInOut",animationEasingUpdate:"cubicInOut",animationThreshold:2e3,progressiveThreshold:3e3,progressive:400,hoverLayerThreshold:3e3,useUTC:!1};var vD=j(["tooltip","label","itemName","itemId","itemGroupId","itemChildGroupId","seriesName"]),hr="original",Me="arrayRows",cr="objectRows",Xr="keyedColumns",Mn="typedArray",hD="unknown",Wr="column",Qi="row",De={Must:1,Might:2,Not:3},cD=St();function nB(r){cD(r).datasetMap=j()}function pD(r,t,e){var a={},n=$m(t);if(!n||!r)return a;var i=[],o=[],s=t.ecModel,l=cD(s).datasetMap,u=n.uid+"_"+e.seriesLayoutBy,f,v;r=r.slice(),A(r,function(d,g){var y=it(d)?d:r[g]={name:d};y.type==="ordinal"&&f==null&&(f=g,v=p(y)),a[y.name]=[]});var h=l.get(u)||l.set(u,{categoryWayDim:v,valueWayDim:0});A(r,function(d,g){var y=d.name,m=p(d);if(f==null){var _=h.valueWayDim;c(a[y],_,m),c(o,_,m),h.valueWayDim+=m}else if(f===g)c(a[y],0,m),c(i,0,m);else{var _=h.categoryWayDim;c(a[y],_,m),c(o,_,m),h.categoryWayDim+=m}});function c(d,g,y){for(var m=0;m<y;m++)d.push(g+m)}function p(d){var g=d.dimsDef;return g?g.length:1}return i.length&&(a.itemName=i),o.length&&(a.seriesName=o),a}function Xm(r,t,e){var a={},n=$m(r);if(!n)return a;var i=t.sourceFormat,o=t.dimensionsDefine,s;(i===cr||i===Xr)&&A(o,function(f,v){(it(f)?f.name:f)==="name"&&(s=v)});var l=function(){for(var f={},v={},h=[],c=0,p=Math.min(5,e);c<p;c++){var d=gD(t.data,i,t.seriesLayoutBy,o,t.startIndex,c);h.push(d);var g=d===De.Not;if(g&&f.v==null&&c!==s&&(f.v=c),(f.n==null||f.n===f.v||!g&&h[f.n]===De.Not)&&(f.n=c),y(f)&&h[f.n]!==De.Not)return f;g||(d===De.Might&&v.v==null&&c!==s&&(v.v=c),(v.n==null||v.n===v.v)&&(v.n=c))}function y(m){return m.v!=null&&m.n!=null}return y(f)?f:y(v)?v:null}();if(l){a.value=[l.v];var u=s??l.n;a.itemName=[u],a.seriesName=[u]}return a}function $m(r){var t=r.get("data",!0);if(!t)return ds(r.ecModel,"dataset",{index:r.get("datasetIndex",!0),id:r.get("datasetId",!0)},Kt).models[0]}function iB(r){return!r.get("transform",!0)&&!r.get("fromTransformResult",!0)?[]:ds(r.ecModel,"dataset",{index:r.get("fromDatasetIndex",!0),id:r.get("fromDatasetId",!0)},Kt).models}function dD(r,t){return gD(r.data,r.sourceFormat,r.seriesLayoutBy,r.dimensionsDefine,r.startIndex,t)}function gD(r,t,e,a,n,i){var o,s=5;if(Ze(r))return De.Not;var l,u;if(a){var f=a[i];it(f)?(l=f.name,u=f.type):X(f)&&(l=f)}if(u!=null)return u==="ordinal"?De.Must:De.Not;if(t===Me){var v=r;if(e===Qi){for(var h=v[i],c=0;c<(h||[]).length&&c<s;c++)if((o=S(h[n+c]))!=null)return o}else for(var c=0;c<v.length&&c<s;c++){var p=v[n+c];if(p&&(o=S(p[i]))!=null)return o}}else if(t===cr){var d=r;if(!l)return De.Not;for(var c=0;c<d.length&&c<s;c++){var g=d[c];if(g&&(o=S(g[l]))!=null)return o}}else if(t===Xr){var y=r;if(!l)return De.Not;var h=y[l];if(!h||Ze(h))return De.Not;for(var c=0;c<h.length&&c<s;c++)if((o=S(h[c]))!=null)return o}else if(t===hr)for(var m=r,c=0;c<m.length&&c<s;c++){var g=m[c],_=ps(g);if(!W(_))return De.Not;if((o=S(_[i]))!=null)return o}function S(x){var b=X(x);if(x!=null&&Number.isFinite(Number(x))&&x!=="")return b?De.Might:De.Not;if(b&&x!=="-")return De.Must}return De.Not}var Pg=j();function oB(r,t){Re(Pg.get(r)==null&&t),Pg.set(r,t)}function sB(r,t,e){var a=Pg.get(t);if(!a)return e;var n=a(r);return n?e.concat(n):e}var q1=St(),lB=St(),qm=function(){function r(){}return r.prototype.getColorFromPalette=function(t,e,a){var n=Ft(this.get("color",!0)),i=this.get("colorLayer",!0);return yD(this,q1,n,i,t,e,a)},r.prototype.clearColorPalette=function(){fB(this,q1)},r}();function Rg(r,t,e,a){var n=Ft(r.get(["aria","decal","decals"]));return yD(r,lB,n,null,t,e,a)}function uB(r,t){for(var e=r.length,a=0;a<e;a++)if(r[a].length>t)return r[a];return r[e-1]}function yD(r,t,e,a,n,i,o){i=i||r;var s=t(i),l=s.paletteIdx||0,u=s.paletteNameMap=s.paletteNameMap||{};if(u.hasOwnProperty(n))return u[n];var f=o==null||!a?e:uB(a,o);if(f=f||e,!(!f||!f.length)){var v=f[l];return n&&(u[n]=v),s.paletteIdx=(l+1)%f.length,v}}function fB(r,t){t(r).paletteIdx=0,t(r).paletteNameMap={}}var sf,Gs,K1,j1="\0_ec_inner",vB=1,Km=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.init=function(e,a,n,i,o,s){i=i||{},this.option=null,this._theme=new wt(i),this._locale=new wt(o),this._optionManager=s},t.prototype.setOption=function(e,a,n){var i=tS(a);this._optionManager.setOption(e,n,i),this._resetOption(null,i)},t.prototype.resetOption=function(e,a){return this._resetOption(e,tS(a))},t.prototype._resetOption=function(e,a){var n=!1,i=this._optionManager;if(!e||e==="recreate"){var o=i.mountOption(e==="recreate");!this.option||e==="recreate"?K1(this,o):(this.restoreData(),this._mergeOption(o,a)),n=!0}if((e==="timeline"||e==="media")&&this.restoreData(),!e||e==="recreate"||e==="timeline"){var s=i.getTimelineOption(this);s&&(n=!0,this._mergeOption(s,a))}if(!e||e==="recreate"||e==="media"){var l=i.getMediaOption(this);l.length&&A(l,function(u){n=!0,this._mergeOption(u,a)},this)}return n},t.prototype.mergeOption=function(e){this._mergeOption(e,null)},t.prototype._mergeOption=function(e,a){var n=this.option,i=this._componentsMap,o=this._componentsCount,s=[],l=j(),u=a&&a.replaceMergeMainTypeMap;nB(this),A(e,function(v,h){v!=null&&(xt.hasClass(h)?h&&(s.push(h),l.set(h,!0)):n[h]=n[h]==null?et(v):yt(n[h],v,!0))}),u&&u.each(function(v,h){xt.hasClass(h)&&!l.get(h)&&(s.push(h),l.set(h,!0))}),xt.topologicalTravel(s,xt.getAllClassMainTypes(),f,this);function f(v){var h=sB(this,v,Ft(e[v])),c=i.get(v),p=c?u&&u.get(v)?"replaceMerge":"normalMerge":"replaceAll",d=jA(c,h,p);AE(d,v,xt),n[v]=null,i.set(v,null),o.set(v,0);var g=[],y=[],m=0,_;A(d,function(S,x){var b=S.existing,w=S.newOption;if(!w)b&&(b.mergeOption({},this),b.optionUpdated({},!1));else{var T=v==="series",C=xt.getClass(v,S.keyInfo.subType,!T);if(!C)return;if(v==="tooltip"){if(_)return;_=!0}if(b&&b.constructor===C)b.name=S.keyInfo.name,b.mergeOption(w,this),b.optionUpdated(w,!1);else{var M=G({componentIndex:x},S.keyInfo);b=new C(w,this,this,M),G(b,M),S.brandNew&&(b.__requireNewView=!0),b.init(w,this,this),b.optionUpdated(null,!0)}}b?(g.push(b.option),y.push(b),m++):(g.push(void 0),y.push(void 0))},this),n[v]=g,i.set(v,y),o.set(v,m),v==="series"&&sf(this)}this._seriesIndices||sf(this)},t.prototype.getOption=function(){var e=et(this.option);return A(e,function(a,n){if(xt.hasClass(n)){for(var i=Ft(a),o=i.length,s=!1,l=o-1;l>=0;l--)i[l]&&!Xl(i[l])?s=!0:(i[l]=null,!s&&o--);i.length=o,e[n]=i}}),delete e[j1],e},t.prototype.setTheme=function(e){this._theme=new wt(e),this._resetOption("recreate",null)},t.prototype.getTheme=function(){return this._theme},t.prototype.getLocaleModel=function(){return this._locale},t.prototype.setUpdatePayload=function(e){this._payload=e},t.prototype.getUpdatePayload=function(){return this._payload},t.prototype.getComponent=function(e,a){var n=this._componentsMap.get(e);if(n){var i=n[a||0];if(i)return i;if(a==null){for(var o=0;o<n.length;o++)if(n[o])return n[o]}}},t.prototype.queryComponents=function(e){var a=e.mainType;if(!a)return[];var n=e.index,i=e.id,o=e.name,s=this._componentsMap.get(a);if(!s||!s.length)return[];var l;return n!=null?(l=[],A(Ft(n),function(u){s[u]&&l.push(s[u])})):i!=null?l=J1("id",i,s):o!=null?l=J1("name",o,s):l=Pt(s,function(u){return!!u}),Q1(l,e)},t.prototype.findComponents=function(e){var a=e.query,n=e.mainType,i=s(a),o=i?this.queryComponents(i):Pt(this._componentsMap.get(n),function(u){return!!u});return l(Q1(o,e));function s(u){var f=n+"Index",v=n+"Id",h=n+"Name";return u&&(u[f]!=null||u[v]!=null||u[h]!=null)?{mainType:n,index:u[f],id:u[v],name:u[h]}:null}function l(u){return e.filter?Pt(u,e.filter):u}},t.prototype.eachComponent=function(e,a,n){var i=this._componentsMap;if(tt(e)){var o=a,s=e;i.each(function(v,h){for(var c=0;v&&c<v.length;c++){var p=v[c];p&&s.call(o,h,p,p.componentIndex)}})}else for(var l=X(e)?i.get(e):it(e)?this.findComponents(e):null,u=0;l&&u<l.length;u++){var f=l[u];f&&a.call(n,f,f.componentIndex)}},t.prototype.getSeriesByName=function(e){var a=ve(e,null);return Pt(this._componentsMap.get("series"),function(n){return!!n&&a!=null&&n.name===a})},t.prototype.getSeriesByIndex=function(e){return this._componentsMap.get("series")[e]},t.prototype.getSeriesByType=function(e){return Pt(this._componentsMap.get("series"),function(a){return!!a&&a.subType===e})},t.prototype.getSeries=function(){return Pt(this._componentsMap.get("series"),function(e){return!!e})},t.prototype.getSeriesCount=function(){return this._componentsCount.get("series")},t.prototype.eachSeries=function(e,a){Gs(this),A(this._seriesIndices,function(n){var i=this._componentsMap.get("series")[n];e.call(a,i,n)},this)},t.prototype.eachRawSeries=function(e,a){A(this._componentsMap.get("series"),function(n){n&&e.call(a,n,n.componentIndex)})},t.prototype.eachSeriesByType=function(e,a,n){Gs(this),A(this._seriesIndices,function(i){var o=this._componentsMap.get("series")[i];o.subType===e&&a.call(n,o,i)},this)},t.prototype.eachRawSeriesByType=function(e,a,n){return A(this.getSeriesByType(e),a,n)},t.prototype.isSeriesFiltered=function(e){return Gs(this),this._seriesIndicesMap.get(e.componentIndex)==null},t.prototype.getCurrentSeriesIndices=function(){return(this._seriesIndices||[]).slice()},t.prototype.filterSeries=function(e,a){Gs(this);var n=[];A(this._seriesIndices,function(i){var o=this._componentsMap.get("series")[i];e.call(a,o,i)&&n.push(i)},this),this._seriesIndices=n,this._seriesIndicesMap=j(n)},t.prototype.restoreData=function(e){sf(this);var a=this._componentsMap,n=[];a.each(function(i,o){xt.hasClass(o)&&n.push(o)}),xt.topologicalTravel(n,xt.getAllClassMainTypes(),function(i){A(a.get(i),function(o){o&&(i!=="series"||!hB(o,e))&&o.restoreData()})})},t.internalField=function(){sf=function(e){var a=e._seriesIndices=[];A(e._componentsMap.get("series"),function(n){n&&a.push(n.componentIndex)}),e._seriesIndicesMap=j(a)},Gs=function(e){},K1=function(e,a){e.option={},e.option[j1]=vB,e._componentsMap=j({series:[]}),e._componentsCount=j();var n=a.aria;it(n)&&n.enabled==null&&(n.enabled=!0),cB(a,e._theme.option),yt(a,aB,!1),e._mergeOption(a,null)}}(),t}(wt);function hB(r,t){if(t){var e=t.seriesIndex,a=t.seriesId,n=t.seriesName;return e!=null&&r.componentIndex!==e||a!=null&&r.id!==a||n!=null&&r.name!==n}}function cB(r,t){var e=r.color&&!r.colorLayer;A(t,function(a,n){n==="colorLayer"&&e||n==="color"&&r.color||xt.hasClass(n)||(typeof a=="object"?r[n]=r[n]?yt(r[n],a,!1):et(a):r[n]==null&&(r[n]=a))})}function J1(r,t,e){if(W(t)){var a=j();return A(t,function(i){if(i!=null){var o=ve(i,null);o!=null&&a.set(i,!0)}}),Pt(e,function(i){return i&&a.get(i[r])})}else{var n=ve(t,null);return Pt(e,function(i){return i&&n!=null&&i[r]===n})}}function Q1(r,t){return t.hasOwnProperty("subType")?Pt(r,function(e){return e&&e.subType===t.subType}):r}function tS(r){var t=j();return r&&A(Ft(r.replaceMerge),function(e){t.set(e,!0)}),{replaceMergeMainTypeMap:t}}Qt(Km,qm);var pB=["getDom","getZr","getWidth","getHeight","getDevicePixelRatio","dispatchAction","isSSR","isDisposed","on","off","getDataURL","getConnectedDataURL","getOption","getId","updateLabelLayout"],mD=function(){function r(t){A(pB,function(e){this[e]=$(t[e],t)},this)}return r}(),dB=/^(min|max)?(.+)$/,gB=function(){function r(t){this._timelineOptions=[],this._mediaList=[],this._currentMediaIndices=[],this._api=t}return r.prototype.setOption=function(t,e,a){t&&(A(Ft(t.series),function(o){o&&o.data&&Ze(o.data)&&Gl(o.data)}),A(Ft(t.dataset),function(o){o&&o.source&&Ze(o.source)&&Gl(o.source)})),t=et(t);var n=this._optionBackup,i=yB(t,e,!n);this._newBaseOption=i.baseOption,n?(i.timelineOptions.length&&(n.timelineOptions=i.timelineOptions),i.mediaList.length&&(n.mediaList=i.mediaList),i.mediaDefault&&(n.mediaDefault=i.mediaDefault)):this._optionBackup=i},r.prototype.mountOption=function(t){var e=this._optionBackup;return this._timelineOptions=e.timelineOptions,this._mediaList=e.mediaList,this._mediaDefault=e.mediaDefault,this._currentMediaIndices=[],et(t?e.baseOption:this._newBaseOption)},r.prototype.getTimelineOption=function(t){var e,a=this._timelineOptions;if(a.length){var n=t.getComponent("timeline");n&&(e=et(a[n.getCurrentIndex()]))}return e},r.prototype.getMediaOption=function(t){var e=this._api.getWidth(),a=this._api.getHeight(),n=this._mediaList,i=this._mediaDefault,o=[],s=[];if(!n.length&&!i)return s;for(var l=0,u=n.length;l<u;l++)mB(n[l].query,e,a)&&o.push(l);return!o.length&&i&&(o=[-1]),o.length&&!SB(o,this._currentMediaIndices)&&(s=U(o,function(f){return et(f===-1?i.option:n[f].option)})),this._currentMediaIndices=o,s},r}();function yB(r,t,e){var a=[],n,i,o=r.baseOption,s=r.timeline,l=r.options,u=r.media,f=!!r.media,v=!!(l||s||o&&o.timeline);o?(i=o,i.timeline||(i.timeline=s)):((v||f)&&(r.options=r.media=null),i=r),f&&W(u)&&A(u,function(c){c&&c.option&&(c.query?a.push(c):n||(n=c))}),h(i),A(l,function(c){return h(c)}),A(a,function(c){return h(c.option)});function h(c){A(t,function(p){p(c,e)})}return{baseOption:i,timelineOptions:l||[],mediaDefault:n,mediaList:a}}function mB(r,t,e){var a={width:t,height:e,aspectratio:t/e},n=!0;return A(r,function(i,o){var s=o.match(dB);if(!(!s||!s[1]||!s[2])){var l=s[1],u=s[2].toLowerCase();_B(a[u],i,l)||(n=!1)}}),n}function _B(r,t,e){return e==="min"?r>=t:e==="max"?r<=t:r===t}function SB(r,t){return r.join(",")===t.join(",")}var kr=A,Ql=it,eS=["areaStyle","lineStyle","nodeStyle","linkStyle","chordStyle","label","labelLine"];function ap(r){var t=r&&r.itemStyle;if(t)for(var e=0,a=eS.length;e<a;e++){var n=eS[e],i=t.normal,o=t.emphasis;i&&i[n]&&(r[n]=r[n]||{},r[n].normal?yt(r[n].normal,i[n]):r[n].normal=i[n],i[n]=null),o&&o[n]&&(r[n]=r[n]||{},r[n].emphasis?yt(r[n].emphasis,o[n]):r[n].emphasis=o[n],o[n]=null)}}function Be(r,t,e){if(r&&r[t]&&(r[t].normal||r[t].emphasis)){var a=r[t].normal,n=r[t].emphasis;a&&(e?(r[t].normal=r[t].emphasis=null,nt(r[t],a)):r[t]=a),n&&(r.emphasis=r.emphasis||{},r.emphasis[t]=n,n.focus&&(r.emphasis.focus=n.focus),n.blurScope&&(r.emphasis.blurScope=n.blurScope))}}function ml(r){Be(r,"itemStyle"),Be(r,"lineStyle"),Be(r,"areaStyle"),Be(r,"label"),Be(r,"labelLine"),Be(r,"upperLabel"),Be(r,"edgeLabel")}function oe(r,t){var e=Ql(r)&&r[t],a=Ql(e)&&e.textStyle;if(a)for(var n=0,i=n1.length;n<i;n++){var o=n1[n];a.hasOwnProperty(o)&&(e[o]=a[o])}}function _r(r){r&&(ml(r),oe(r,"label"),r.emphasis&&oe(r.emphasis,"label"))}function xB(r){if(Ql(r)){ap(r),ml(r),oe(r,"label"),oe(r,"upperLabel"),oe(r,"edgeLabel"),r.emphasis&&(oe(r.emphasis,"label"),oe(r.emphasis,"upperLabel"),oe(r.emphasis,"edgeLabel"));var t=r.markPoint;t&&(ap(t),_r(t));var e=r.markLine;e&&(ap(e),_r(e));var a=r.markArea;a&&_r(a);var n=r.data;if(r.type==="graph"){n=n||r.nodes;var i=r.links||r.edges;if(i&&!Ze(i))for(var o=0;o<i.length;o++)_r(i[o]);A(r.categories,function(u){ml(u)})}if(n&&!Ze(n))for(var o=0;o<n.length;o++)_r(n[o]);if(t=r.markPoint,t&&t.data)for(var s=t.data,o=0;o<s.length;o++)_r(s[o]);if(e=r.markLine,e&&e.data)for(var l=e.data,o=0;o<l.length;o++)W(l[o])?(_r(l[o][0]),_r(l[o][1])):_r(l[o]);r.type==="gauge"?(oe(r,"axisLabel"),oe(r,"title"),oe(r,"detail")):r.type==="treemap"?(Be(r.breadcrumb,"itemStyle"),A(r.levels,function(u){ml(u)})):r.type==="tree"&&ml(r.leaves)}}function Ma(r){return W(r)?r:r?[r]:[]}function rS(r){return(W(r)?r[0]:r)||{}}function bB(r,t){kr(Ma(r.series),function(a){Ql(a)&&xB(a)});var e=["xAxis","yAxis","radiusAxis","angleAxis","singleAxis","parallelAxis","radar"];t&&e.push("valueAxis","categoryAxis","logAxis","timeAxis"),kr(e,function(a){kr(Ma(r[a]),function(n){n&&(oe(n,"axisLabel"),oe(n.axisPointer,"label"))})}),kr(Ma(r.parallel),function(a){var n=a&&a.parallelAxisDefault;oe(n,"axisLabel"),oe(n&&n.axisPointer,"label")}),kr(Ma(r.calendar),function(a){Be(a,"itemStyle"),oe(a,"dayLabel"),oe(a,"monthLabel"),oe(a,"yearLabel")}),kr(Ma(r.radar),function(a){oe(a,"name"),a.name&&a.axisName==null&&(a.axisName=a.name,delete a.name),a.nameGap!=null&&a.axisNameGap==null&&(a.axisNameGap=a.nameGap,delete a.nameGap)}),kr(Ma(r.geo),function(a){Ql(a)&&(_r(a),kr(Ma(a.regions),function(n){_r(n)}))}),kr(Ma(r.timeline),function(a){_r(a),Be(a,"label"),Be(a,"itemStyle"),Be(a,"controlStyle",!0);var n=a.data;W(n)&&A(n,function(i){it(i)&&(Be(i,"label"),Be(i,"itemStyle"))})}),kr(Ma(r.toolbox),function(a){Be(a,"iconStyle"),kr(a.feature,function(n){Be(n,"iconStyle")})}),oe(rS(r.axisPointer),"label"),oe(rS(r.tooltip).axisPointer,"label")}function wB(r,t){for(var e=t.split(","),a=r,n=0;n<e.length&&(a=a&&a[e[n]],a!=null);n++);return a}function TB(r,t,e,a){for(var n=t.split(","),i=r,o,s=0;s<n.length-1;s++)o=n[s],i[o]==null&&(i[o]={}),i=i[o];i[n[s]]==null&&(i[n[s]]=e)}function aS(r){r&&A(CB,function(t){t[0]in r&&!(t[1]in r)&&(r[t[1]]=r[t[0]])})}var CB=[["x","left"],["y","top"],["x2","right"],["y2","bottom"]],AB=["grid","geo","parallel","legend","toolbox","title","visualMap","dataZoom","timeline"],np=[["borderRadius","barBorderRadius"],["borderColor","barBorderColor"],["borderWidth","barBorderWidth"]];function Fs(r){var t=r&&r.itemStyle;if(t)for(var e=0;e<np.length;e++){var a=np[e][1],n=np[e][0];t[a]!=null&&(t[n]=t[a])}}function nS(r){r&&r.alignTo==="edge"&&r.margin!=null&&r.edgeDistance==null&&(r.edgeDistance=r.margin)}function iS(r){r&&r.downplay&&!r.blur&&(r.blur=r.downplay)}function MB(r){r&&r.focusNodeAdjacency!=null&&(r.emphasis=r.emphasis||{},r.emphasis.focus==null&&(r.emphasis.focus="adjacency"))}function _D(r,t){if(r)for(var e=0;e<r.length;e++)t(r[e]),r[e]&&_D(r[e].children,t)}function SD(r,t){bB(r,t),r.series=Ft(r.series),A(r.series,function(e){if(it(e)){var a=e.type;if(a==="line")e.clipOverflow!=null&&(e.clip=e.clipOverflow);else if(a==="pie"||a==="gauge"){e.clockWise!=null&&(e.clockwise=e.clockWise),nS(e.label);var n=e.data;if(n&&!Ze(n))for(var i=0;i<n.length;i++)nS(n[i]);e.hoverOffset!=null&&(e.emphasis=e.emphasis||{},(e.emphasis.scaleSize=null)&&(e.emphasis.scaleSize=e.hoverOffset))}else if(a==="gauge"){var o=wB(e,"pointer.color");o!=null&&TB(e,"itemStyle.color",o)}else if(a==="bar"){Fs(e),Fs(e.backgroundStyle),Fs(e.emphasis);var n=e.data;if(n&&!Ze(n))for(var i=0;i<n.length;i++)typeof n[i]=="object"&&(Fs(n[i]),Fs(n[i]&&n[i].emphasis))}else if(a==="sunburst"){var s=e.highlightPolicy;s&&(e.emphasis=e.emphasis||{},e.emphasis.focus||(e.emphasis.focus=s)),iS(e),_D(e.data,iS)}else a==="graph"||a==="sankey"?MB(e):a==="map"&&(e.mapType&&!e.map&&(e.map=e.mapType),e.mapLocation&&nt(e,e.mapLocation));e.hoverAnimation!=null&&(e.emphasis=e.emphasis||{},e.emphasis&&e.emphasis.scale==null&&(e.emphasis.scale=e.hoverAnimation)),aS(e)}}),r.dataRange&&(r.visualMap=r.dataRange),A(AB,function(e){var a=r[e];a&&(W(a)||(a=[a]),A(a,function(n){aS(n)}))})}function DB(r){var t=j();r.eachSeries(function(e){var a=e.get("stack");if(a){var n=t.get(a)||t.set(a,[]),i=e.getData(),o={stackResultDimension:i.getCalculationInfo("stackResultDimension"),stackedOverDimension:i.getCalculationInfo("stackedOverDimension"),stackedDimension:i.getCalculationInfo("stackedDimension"),stackedByDimension:i.getCalculationInfo("stackedByDimension"),isStackedByIndex:i.getCalculationInfo("isStackedByIndex"),data:i,seriesModel:e};if(!o.stackedDimension||!(o.isStackedByIndex||o.stackedByDimension))return;n.push(o)}}),t.each(function(e){if(e.length!==0){var a=e[0].seriesModel,n=a.get("stackOrder")||"seriesAsc";n==="seriesDesc"&&e.reverse(),A(e,function(i,o){i.data.setCalculationInfo("stackedOnSeries",o>0?e[o-1].seriesModel:null)}),LB(e)}})}function LB(r){A(r,function(t,e){var a=[],n=[NaN,NaN],i=[t.stackResultDimension,t.stackedOverDimension],o=t.data,s=t.isStackedByIndex,l=t.seriesModel.get("stackStrategy")||"samesign";o.modify(i,function(u,f,v){var h=o.get(t.stackedDimension,v);if(isNaN(h))return n;var c,p;s?p=o.getRawIndex(v):c=o.get(t.stackedByDimension,v);for(var d=NaN,g=e-1;g>=0;g--){var y=r[g];if(s||(p=y.data.rawIndexOf(y.stackedByDimension,c)),p>=0){var m=y.data.getByRawIndex(y.stackResultDimension,p);if(l==="all"||l==="positive"&&m>0||l==="negative"&&m<0||l==="samesign"&&h>=0&&m>0||l==="samesign"&&h<=0&&m<0){h=cE(h,m),d=m;break}}}return a[0]=h,a[1]=d,a})})}var Qh=function(){function r(t){this.data=t.data||(t.sourceFormat===Xr?{}:[]),this.sourceFormat=t.sourceFormat||hD,this.seriesLayoutBy=t.seriesLayoutBy||Wr,this.startIndex=t.startIndex||0,this.dimensionsDetectedCount=t.dimensionsDetectedCount,this.metaRawOption=t.metaRawOption;var e=this.dimensionsDefine=t.dimensionsDefine;if(e)for(var a=0;a<e.length;a++){var n=e[a];n.type==null&&dD(this,a)===De.Must&&(n.type="ordinal")}}return r}();function jm(r){return r instanceof Qh}function kg(r,t,e){e=e||xD(r);var a=t.seriesLayoutBy,n=PB(r,e,a,t.sourceHeader,t.dimensions),i=new Qh({data:r,sourceFormat:e,seriesLayoutBy:a,dimensionsDefine:n.dimensionsDefine,startIndex:n.startIndex,dimensionsDetectedCount:n.dimensionsDetectedCount,metaRawOption:et(t)});return i}function Jm(r){return new Qh({data:r,sourceFormat:Ze(r)?Mn:hr})}function IB(r){return new Qh({data:r.data,sourceFormat:r.sourceFormat,seriesLayoutBy:r.seriesLayoutBy,dimensionsDefine:et(r.dimensionsDefine),startIndex:r.startIndex,dimensionsDetectedCount:r.dimensionsDetectedCount})}function xD(r){var t=hD;if(Ze(r))t=Mn;else if(W(r)){r.length===0&&(t=Me);for(var e=0,a=r.length;e<a;e++){var n=r[e];if(n!=null){if(W(n)||Ze(n)){t=Me;break}else if(it(n)){t=cr;break}}}}else if(it(r)){for(var i in r)if(q(r,i)&&Pe(r[i])){t=Xr;break}}return t}function PB(r,t,e,a,n){var i,o;if(!r)return{dimensionsDefine:oS(n),startIndex:o,dimensionsDetectedCount:i};if(t===Me){var s=r;a==="auto"||a==null?sS(function(u){u!=null&&u!=="-"&&(X(u)?o==null&&(o=1):o=0)},e,s,10):o=Mt(a)?a:a?1:0,!n&&o===1&&(n=[],sS(function(u,f){n[f]=u!=null?u+"":""},e,s,1/0)),i=n?n.length:e===Qi?s.length:s[0]?s[0].length:null}else if(t===cr)n||(n=RB(r));else if(t===Xr)n||(n=[],A(r,function(u,f){n.push(f)}));else if(t===hr){var l=ps(r[0]);i=W(l)&&l.length||1}return{startIndex:o,dimensionsDefine:oS(n),dimensionsDetectedCount:i}}function RB(r){for(var t=0,e;t<r.length&&!(e=r[t++]););if(e)return Ct(e)}function oS(r){if(r){var t=j();return U(r,function(e,a){e=it(e)?e:{name:e};var n={name:e.name,displayName:e.displayName,type:e.type};if(n.name==null)return n;n.name+="",n.displayName==null&&(n.displayName=n.name);var i=t.get(n.name);return i?n.name+="-"+i.count++:t.set(n.name,{count:1}),n})}}function sS(r,t,e,a){if(t===Qi)for(var n=0;n<e.length&&n<a;n++)r(e[n]?e[n][0]:null,n);else for(var i=e[0]||[],n=0;n<i.length&&n<a;n++)r(i[n],n)}function bD(r){var t=r.sourceFormat;return t===cr||t===Xr}var ii,oi,si,li,lS,uS,wD=function(){function r(t,e){var a=jm(t)?t:Jm(t);this._source=a;var n=this._data=a.data,i=a.sourceFormat;a.seriesLayoutBy,i===Mn&&(this._offset=0,this._dimSize=e,this._data=n),uS(this,n,a)}return r.prototype.getSource=function(){return this._source},r.prototype.count=function(){return 0},r.prototype.getItem=function(t,e){},r.prototype.appendData=function(t){},r.prototype.clean=function(){},r.protoInitialize=function(){var t=r.prototype;t.pure=!1,t.persistent=!0}(),r.internalField=function(){var t;uS=function(o,s,l){var u=l.sourceFormat,f=l.seriesLayoutBy,v=l.startIndex,h=l.dimensionsDefine,c=lS[Qm(u,f)];if(G(o,c),u===Mn)o.getItem=e,o.count=n,o.fillStorage=a;else{var p=TD(u,f);o.getItem=$(p,null,s,v,h);var d=CD(u,f);o.count=$(d,null,s,v,h)}};var e=function(o,s){o=o-this._offset,s=s||[];for(var l=this._data,u=this._dimSize,f=u*o,v=0;v<u;v++)s[v]=l[f+v];return s},a=function(o,s,l,u){for(var f=this._data,v=this._dimSize,h=0;h<v;h++){for(var c=u[h],p=c[0]==null?1/0:c[0],d=c[1]==null?-1/0:c[1],g=s-o,y=l[h],m=0;m<g;m++){var _=f[m*v+h];y[o+m]=_,_<p&&(p=_),_>d&&(d=_)}c[0]=p,c[1]=d}},n=function(){return this._data?this._data.length/this._dimSize:0};lS=(t={},t[Me+"_"+Wr]={pure:!0,appendData:i},t[Me+"_"+Qi]={pure:!0,appendData:function(){throw new Error('Do not support appendData when set seriesLayoutBy: "row".')}},t[cr]={pure:!0,appendData:i},t[Xr]={pure:!0,appendData:function(o){var s=this._data;A(o,function(l,u){for(var f=s[u]||(s[u]=[]),v=0;v<(l||[]).length;v++)f.push(l[v])})}},t[hr]={appendData:i},t[Mn]={persistent:!1,pure:!0,appendData:function(o){this._data=o},clean:function(){this._offset+=this.count(),this._data=null}},t);function i(o){for(var s=0;s<o.length;s++)this._data.push(o[s])}}(),r}(),lf=function(r){W(r)||$A("series.data or dataset.source must be an array.")};ii={},ii[Me+"_"+Wr]=lf,ii[Me+"_"+Qi]=lf,ii[cr]=lf,ii[Xr]=function(r,t){for(var e=0;e<t.length;e++){var a=t[e].name;a==null&&$A("dimension name must not be null/undefined.")}},ii[hr]=lf;var fS=function(r,t,e,a){return r[a]},kB=(oi={},oi[Me+"_"+Wr]=function(r,t,e,a){return r[a+t]},oi[Me+"_"+Qi]=function(r,t,e,a,n){a+=t;for(var i=n||[],o=r,s=0;s<o.length;s++){var l=o[s];i[s]=l?l[a]:null}return i},oi[cr]=fS,oi[Xr]=function(r,t,e,a,n){for(var i=n||[],o=0;o<e.length;o++){var s=e[o].name,l=s!=null?r[s]:null;i[o]=l?l[a]:null}return i},oi[hr]=fS,oi);function TD(r,t){var e=kB[Qm(r,t)];return e}var vS=function(r,t,e){return r.length},EB=(si={},si[Me+"_"+Wr]=function(r,t,e){return Math.max(0,r.length-t)},si[Me+"_"+Qi]=function(r,t,e){var a=r[0];return a?Math.max(0,a.length-t):0},si[cr]=vS,si[Xr]=function(r,t,e){var a=e[0].name,n=a!=null?r[a]:null;return n?n.length:0},si[hr]=vS,si);function CD(r,t){var e=EB[Qm(r,t)];return e}var ip=function(r,t,e){return r[t]},OB=(li={},li[Me]=ip,li[cr]=function(r,t,e){return r[e]},li[Xr]=ip,li[hr]=function(r,t,e){var a=ps(r);return a instanceof Array?a[t]:a},li[Mn]=ip,li);function AD(r){var t=OB[r];return t}function Qm(r,t){return r===Me?r+"_"+t:r}function as(r,t,e){if(r){var a=r.getRawDataItem(t);if(a!=null){var n=r.getStore(),i=n.getSource().sourceFormat;if(e!=null){var o=r.getDimensionIndex(e),s=n.getDimensionProperty(o);return AD(i)(a,o,s)}else{var l=a;return i===hr&&(l=ps(a)),l}}}}var NB=/\{@(.+?)\}/g,tc=function(){function r(){}return r.prototype.getDataParams=function(t,e){var a=this.getData(e),n=this.getRawValue(t,e),i=a.getRawIndex(t),o=a.getName(t),s=a.getRawDataItem(t),l=a.getItemVisual(t,"style"),u=l&&l[a.getItemVisual(t,"drawType")||"fill"],f=l&&l.stroke,v=this.mainType,h=v==="series",c=a.userOutput&&a.userOutput.get();return{componentType:v,componentSubType:this.subType,componentIndex:this.componentIndex,seriesType:h?this.subType:null,seriesIndex:this.seriesIndex,seriesId:h?this.id:null,seriesName:h?this.name:null,name:o,dataIndex:i,data:s,dataType:e,value:n,color:u,borderColor:f,dimensionNames:c?c.fullDimensions:null,encode:c?c.encode:null,$vars:["seriesName","name","value"]}},r.prototype.getFormattedLabel=function(t,e,a,n,i,o){e=e||"normal";var s=this.getData(a),l=this.getDataParams(t,a);if(o&&(l.value=o.interpolatedValue),n!=null&&W(l.value)&&(l.value=l.value[n]),!i){var u=s.getItemModel(t);i=u.get(e==="normal"?["label","formatter"]:[e,"label","formatter"])}if(tt(i))return l.status=e,l.dimensionIndex=n,i(l);if(X(i)){var f=Ym(i,l);return f.replace(NB,function(v,h){var c=h.length,p=h;p.charAt(0)==="["&&p.charAt(c-1)==="]"&&(p=+p.slice(1,c-1));var d=as(s,t,p);if(o&&W(o.interpolatedValue)){var g=s.getDimensionIndex(p);g>=0&&(d=o.interpolatedValue[g])}return d!=null?d+"":""})}},r.prototype.getRawValue=function(t,e){return as(this.getData(e),t)},r.prototype.formatTooltip=function(t,e,a){},r}();function hS(r){var t,e;return it(r)?r.type&&(e=r):t=r,{text:t,frag:e}}function Nl(r){return new BB(r)}var BB=function(){function r(t){t=t||{},this._reset=t.reset,this._plan=t.plan,this._count=t.count,this._onDirty=t.onDirty,this._dirty=!0}return r.prototype.perform=function(t){var e=this._upstream,a=t&&t.skip;if(this._dirty&&e){var n=this.context;n.data=n.outputData=e.context.outputData}this.__pipeline&&(this.__pipeline.currentTask=this);var i;this._plan&&!a&&(i=this._plan(this.context));var o=f(this._modBy),s=this._modDataCount||0,l=f(t&&t.modBy),u=t&&t.modDataCount||0;(o!==l||s!==u)&&(i="reset");function f(m){return!(m>=1)&&(m=1),m}var v;(this._dirty||i==="reset")&&(this._dirty=!1,v=this._doReset(a)),this._modBy=l,this._modDataCount=u;var h=t&&t.step;if(e?this._dueEnd=e._outputDueEnd:this._dueEnd=this._count?this._count(this.context):1/0,this._progress){var c=this._dueIndex,p=Math.min(h!=null?this._dueIndex+h:1/0,this._dueEnd);if(!a&&(v||c<p)){var d=this._progress;if(W(d))for(var g=0;g<d.length;g++)this._doProgress(d[g],c,p,l,u);else this._doProgress(d,c,p,l,u)}this._dueIndex=p;var y=this._settedOutputEnd!=null?this._settedOutputEnd:p;this._outputDueEnd=y}else this._dueIndex=this._outputDueEnd=this._settedOutputEnd!=null?this._settedOutputEnd:this._dueEnd;return this.unfinished()},r.prototype.dirty=function(){this._dirty=!0,this._onDirty&&this._onDirty(this.context)},r.prototype._doProgress=function(t,e,a,n,i){cS.reset(e,a,n,i),this._callingProgress=t,this._callingProgress({start:e,end:a,count:a-e,next:cS.next},this.context)},r.prototype._doReset=function(t){this._dueIndex=this._outputDueEnd=this._dueEnd=0,this._settedOutputEnd=null;var e,a;!t&&this._reset&&(e=this._reset(this.context),e&&e.progress&&(a=e.forceFirstProgress,e=e.progress),W(e)&&!e.length&&(e=null)),this._progress=e,this._modBy=this._modDataCount=null;var n=this._downstream;return n&&n.dirty(),a},r.prototype.unfinished=function(){return this._progress&&this._dueIndex<this._dueEnd},r.prototype.pipe=function(t){(this._downstream!==t||this._dirty)&&(this._downstream=t,t._upstream=this,t.dirty())},r.prototype.dispose=function(){this._disposed||(this._upstream&&(this._upstream._downstream=null),this._downstream&&(this._downstream._upstream=null),this._dirty=!1,this._disposed=!0)},r.prototype.getUpstream=function(){return this._upstream},r.prototype.getDownstream=function(){return this._downstream},r.prototype.setOutputEnd=function(t){this._outputDueEnd=this._settedOutputEnd=t},r}(),cS=function(){var r,t,e,a,n,i={reset:function(l,u,f,v){t=l,r=u,e=f,a=v,n=Math.ceil(a/e),i.next=e>1&&a>0?s:o}};return i;function o(){return t<r?t++:null}function s(){var l=t%n*e+Math.ceil(t/n),u=t>=r?null:l<a?l:t;return t++,u}}();function Dn(r,t){var e=t&&t.type;return e==="ordinal"?r:(e==="time"&&!Mt(r)&&r!=null&&r!=="-"&&(r=+ba(r)),r==null||r===""?NaN:Number(r))}var zB=j({number:function(r){return parseFloat(r)},time:function(r){return+ba(r)},trim:function(r){return X(r)?sr(r):r}});function MD(r){return zB.get(r)}var DD={lt:function(r,t){return r<t},lte:function(r,t){return r<=t},gt:function(r,t){return r>t},gte:function(r,t){return r>=t}},VB=function(){function r(t,e){if(!Mt(e)){var a="";kt(a)}this._opFn=DD[t],this._rvalFloat=ya(e)}return r.prototype.evaluate=function(t){return Mt(t)?this._opFn(t,this._rvalFloat):this._opFn(ya(t),this._rvalFloat)},r}(),LD=function(){function r(t,e){var a=t==="desc";this._resultLT=a?1:-1,e==null&&(e=a?"min":"max"),this._incomparable=e==="min"?-1/0:1/0}return r.prototype.evaluate=function(t,e){var a=Mt(t)?t:ya(t),n=Mt(e)?e:ya(e),i=isNaN(a),o=isNaN(n);if(i&&(a=this._incomparable),o&&(n=this._incomparable),i&&o){var s=X(t),l=X(e);s&&(a=l?t:0),l&&(n=s?e:0)}return a<n?this._resultLT:a>n?-this._resultLT:0},r}(),GB=function(){function r(t,e){this._rval=e,this._isEQ=t,this._rvalTypeof=typeof e,this._rvalFloat=ya(e)}return r.prototype.evaluate=function(t){var e=t===this._rval;if(!e){var a=typeof t;a!==this._rvalTypeof&&(a==="number"||this._rvalTypeof==="number")&&(e=ya(t)===this._rvalFloat)}return this._isEQ?e:!e},r}();function FB(r,t){return r==="eq"||r==="ne"?new GB(r==="eq",t):q(DD,r)?new VB(r,t):null}var HB=function(){function r(){}return r.prototype.getRawData=function(){throw new Error("not supported")},r.prototype.getRawDataItem=function(t){throw new Error("not supported")},r.prototype.cloneRawData=function(){},r.prototype.getDimensionInfo=function(t){},r.prototype.cloneAllDimensionInfo=function(){},r.prototype.count=function(){},r.prototype.retrieveValue=function(t,e){},r.prototype.retrieveValueFromItem=function(t,e){},r.prototype.convertValue=function(t,e){return Dn(t,e)},r}();function WB(r,t){var e=new HB,a=r.data,n=e.sourceFormat=r.sourceFormat,i=r.startIndex,o="";r.seriesLayoutBy!==Wr&&kt(o);var s=[],l={},u=r.dimensionsDefine;if(u)A(u,function(d,g){var y=d.name,m={index:g,name:y,displayName:d.displayName};if(s.push(m),y!=null){var _="";q(l,y)&&kt(_),l[y]=m}});else for(var f=0;f<r.dimensionsDetectedCount;f++)s.push({index:f});var v=TD(n,Wr);t.__isBuiltIn&&(e.getRawDataItem=function(d){return v(a,i,s,d)},e.getRawData=$(UB,null,r)),e.cloneRawData=$(YB,null,r);var h=CD(n,Wr);e.count=$(h,null,a,i,s);var c=AD(n);e.retrieveValue=function(d,g){var y=v(a,i,s,d);return p(y,g)};var p=e.retrieveValueFromItem=function(d,g){if(d!=null){var y=s[g];if(y)return c(d,g,y.name)}};return e.getDimensionInfo=$(ZB,null,s,l),e.cloneAllDimensionInfo=$(XB,null,s),e}function UB(r){var t=r.sourceFormat;if(!t0(t)){var e="";kt(e)}return r.data}function YB(r){var t=r.sourceFormat,e=r.data;if(!t0(t)){var a="";kt(a)}if(t===Me){for(var n=[],i=0,o=e.length;i<o;i++)n.push(e[i].slice());return n}else if(t===cr){for(var n=[],i=0,o=e.length;i<o;i++)n.push(G({},e[i]));return n}}function ZB(r,t,e){if(e!=null){if(Mt(e)||!isNaN(e)&&!q(t,e))return r[e];if(q(t,e))return t[e]}}function XB(r){return et(r)}var ID=j();function $B(r){r=et(r);var t=r.type,e="";t||kt(e);var a=t.split(":");a.length!==2&&kt(e);var n=!1;a[0]==="echarts"&&(t=a[1],n=!0),r.__isBuiltIn=n,ID.set(t,r)}function qB(r,t,e){var a=Ft(r),n=a.length,i="";n||kt(i);for(var o=0,s=n;o<s;o++){var l=a[o];t=KB(l,t),o!==s-1&&(t.length=Math.max(t.length,1))}return t}function KB(r,t,e,a){var n="";t.length||kt(n),it(r)||kt(n);var i=r.type,o=ID.get(i);o||kt(n);var s=U(t,function(u){return WB(u,o)}),l=Ft(o.transform({upstream:s[0],upstreamList:s,config:et(r.config)}));return U(l,function(u,f){var v="";it(u)||kt(v),u.data||kt(v);var h=xD(u.data);t0(h)||kt(v);var c,p=t[0];if(p&&f===0&&!u.dimensions){var d=p.startIndex;d&&(u.data=p.data.slice(0,d).concat(u.data)),c={seriesLayoutBy:Wr,sourceHeader:d,dimensions:p.metaRawOption.dimensions}}else c={seriesLayoutBy:Wr,sourceHeader:0,dimensions:u.dimensions};return kg(u.data,c,null)})}function t0(r){return r===Me||r===cr}var ec="undefined",jB=typeof Uint32Array===ec?Array:Uint32Array,JB=typeof Uint16Array===ec?Array:Uint16Array,PD=typeof Int32Array===ec?Array:Int32Array,pS=typeof Float64Array===ec?Array:Float64Array,RD={float:pS,int:PD,ordinal:Array,number:Array,time:pS},op;function po(r){return r>65535?jB:JB}function go(){return[1/0,-1/0]}function QB(r){var t=r.constructor;return t===Array?r.slice():new t(r)}function dS(r,t,e,a,n){var i=RD[e||"float"];if(n){var o=r[t],s=o&&o.length;if(s!==a){for(var l=new i(a),u=0;u<s;u++)l[u]=o[u];r[t]=l}}else r[t]=new i(a)}var Eg=function(){function r(){this._chunks=[],this._rawExtent=[],this._extent=[],this._count=0,this._rawCount=0,this._calcDimNameToIdx=j()}return r.prototype.initData=function(t,e,a){this._provider=t,this._chunks=[],this._indices=null,this.getRawIndex=this._getRawIdxIdentity;var n=t.getSource(),i=this.defaultDimValueGetter=op[n.sourceFormat];this._dimValueGetter=a||i,this._rawExtent=[],bD(n),this._dimensions=U(e,function(o){return{type:o.type,property:o.property}}),this._initDataFromProvider(0,t.count())},r.prototype.getProvider=function(){return this._provider},r.prototype.getSource=function(){return this._provider.getSource()},r.prototype.ensureCalculationDimension=function(t,e){var a=this._calcDimNameToIdx,n=this._dimensions,i=a.get(t);if(i!=null){if(n[i].type===e)return i}else i=n.length;return n[i]={type:e},a.set(t,i),this._chunks[i]=new RD[e||"float"](this._rawCount),this._rawExtent[i]=go(),i},r.prototype.collectOrdinalMeta=function(t,e){var a=this._chunks[t],n=this._dimensions[t],i=this._rawExtent,o=n.ordinalOffset||0,s=a.length;o===0&&(i[t]=go());for(var l=i[t],u=o;u<s;u++){var f=a[u]=e.parseAndCollect(a[u]);isNaN(f)||(l[0]=Math.min(f,l[0]),l[1]=Math.max(f,l[1]))}n.ordinalMeta=e,n.ordinalOffset=s,n.type="ordinal"},r.prototype.getOrdinalMeta=function(t){var e=this._dimensions[t],a=e.ordinalMeta;return a},r.prototype.getDimensionProperty=function(t){var e=this._dimensions[t];return e&&e.property},r.prototype.appendData=function(t){var e=this._provider,a=this.count();e.appendData(t);var n=e.count();return e.persistent||(n+=a),a<n&&this._initDataFromProvider(a,n,!0),[a,n]},r.prototype.appendValues=function(t,e){for(var a=this._chunks,n=this._dimensions,i=n.length,o=this._rawExtent,s=this.count(),l=s+Math.max(t.length,e||0),u=0;u<i;u++){var f=n[u];dS(a,u,f.type,l,!0)}for(var v=[],h=s;h<l;h++)for(var c=h-s,p=0;p<i;p++){var f=n[p],d=op.arrayRows.call(this,t[c]||v,f.property,c,p);a[p][h]=d;var g=o[p];d<g[0]&&(g[0]=d),d>g[1]&&(g[1]=d)}return this._rawCount=this._count=l,{start:s,end:l}},r.prototype._initDataFromProvider=function(t,e,a){for(var n=this._provider,i=this._chunks,o=this._dimensions,s=o.length,l=this._rawExtent,u=U(o,function(m){return m.property}),f=0;f<s;f++){var v=o[f];l[f]||(l[f]=go()),dS(i,f,v.type,e,a)}if(n.fillStorage)n.fillStorage(t,e,i,l);else for(var h=[],c=t;c<e;c++){h=n.getItem(c,h);for(var p=0;p<s;p++){var d=i[p],g=this._dimValueGetter(h,u[p],c,p);d[c]=g;var y=l[p];g<y[0]&&(y[0]=g),g>y[1]&&(y[1]=g)}}!n.persistent&&n.clean&&n.clean(),this._rawCount=this._count=e,this._extent=[]},r.prototype.count=function(){return this._count},r.prototype.get=function(t,e){if(!(e>=0&&e<this._count))return NaN;var a=this._chunks[t];return a?a[this.getRawIndex(e)]:NaN},r.prototype.getValues=function(t,e){var a=[],n=[];if(e==null){e=t,t=[];for(var i=0;i<this._dimensions.length;i++)n.push(i)}else n=t;for(var i=0,o=n.length;i<o;i++)a.push(this.get(n[i],e));return a},r.prototype.getByRawIndex=function(t,e){if(!(e>=0&&e<this._rawCount))return NaN;var a=this._chunks[t];return a?a[e]:NaN},r.prototype.getSum=function(t){var e=this._chunks[t],a=0;if(e)for(var n=0,i=this.count();n<i;n++){var o=this.get(t,n);isNaN(o)||(a+=o)}return a},r.prototype.getMedian=function(t){var e=[];this.each([t],function(i){isNaN(i)||e.push(i)});var a=e.sort(function(i,o){return i-o}),n=this.count();return n===0?0:n%2===1?a[(n-1)/2]:(a[n/2]+a[n/2-1])/2},r.prototype.indexOfRawIndex=function(t){if(t>=this._rawCount||t<0)return-1;if(!this._indices)return t;var e=this._indices,a=e[t];if(a!=null&&a<this._count&&a===t)return t;for(var n=0,i=this._count-1;n<=i;){var o=(n+i)/2|0;if(e[o]<t)n=o+1;else if(e[o]>t)i=o-1;else return o}return-1},r.prototype.getIndices=function(){var t,e=this._indices;if(e){var a=e.constructor,n=this._count;if(a===Array){t=new a(n);for(var i=0;i<n;i++)t[i]=e[i]}else t=new a(e.buffer,0,n)}else{var a=po(this._rawCount);t=new a(this.count());for(var i=0;i<t.length;i++)t[i]=i}return t},r.prototype.filter=function(t,e){if(!this._count)return this;for(var a=this.clone(),n=a.count(),i=po(a._rawCount),o=new i(n),s=[],l=t.length,u=0,f=t[0],v=a._chunks,h=0;h<n;h++){var c=void 0,p=a.getRawIndex(h);if(l===0)c=e(h);else if(l===1){var d=v[f][p];c=e(d,h)}else{for(var g=0;g<l;g++)s[g]=v[t[g]][p];s[g]=h,c=e.apply(null,s)}c&&(o[u++]=p)}return u<n&&(a._indices=o),a._count=u,a._extent=[],a._updateGetRawIdx(),a},r.prototype.selectRange=function(t){var e=this.clone(),a=e._count;if(!a)return this;var n=Ct(t),i=n.length;if(!i)return this;var o=e.count(),s=po(e._rawCount),l=new s(o),u=0,f=n[0],v=t[f][0],h=t[f][1],c=e._chunks,p=!1;if(!e._indices){var d=0;if(i===1){for(var g=c[n[0]],y=0;y<a;y++){var m=g[y];(m>=v&&m<=h||isNaN(m))&&(l[u++]=d),d++}p=!0}else if(i===2){for(var g=c[n[0]],_=c[n[1]],S=t[n[1]][0],x=t[n[1]][1],y=0;y<a;y++){var m=g[y],b=_[y];(m>=v&&m<=h||isNaN(m))&&(b>=S&&b<=x||isNaN(b))&&(l[u++]=d),d++}p=!0}}if(!p)if(i===1)for(var y=0;y<o;y++){var w=e.getRawIndex(y),m=c[n[0]][w];(m>=v&&m<=h||isNaN(m))&&(l[u++]=w)}else for(var y=0;y<o;y++){for(var T=!0,w=e.getRawIndex(y),C=0;C<i;C++){var M=n[C],m=c[M][w];(m<t[M][0]||m>t[M][1])&&(T=!1)}T&&(l[u++]=e.getRawIndex(y))}return u<o&&(e._indices=l),e._count=u,e._extent=[],e._updateGetRawIdx(),e},r.prototype.map=function(t,e){var a=this.clone(t);return this._updateDims(a,t,e),a},r.prototype.modify=function(t,e){this._updateDims(this,t,e)},r.prototype._updateDims=function(t,e,a){for(var n=t._chunks,i=[],o=e.length,s=t.count(),l=[],u=t._rawExtent,f=0;f<e.length;f++)u[e[f]]=go();for(var v=0;v<s;v++){for(var h=t.getRawIndex(v),c=0;c<o;c++)l[c]=n[e[c]][h];l[o]=v;var p=a&&a.apply(null,l);if(p!=null){typeof p!="object"&&(i[0]=p,p=i);for(var f=0;f<p.length;f++){var d=e[f],g=p[f],y=u[d],m=n[d];m&&(m[h]=g),g<y[0]&&(y[0]=g),g>y[1]&&(y[1]=g)}}}},r.prototype.lttbDownSample=function(t,e){var a=this.clone([t],!0),n=a._chunks,i=n[t],o=this.count(),s=0,l=Math.floor(1/e),u=this.getRawIndex(0),f,v,h,c=new(po(this._rawCount))(Math.min((Math.ceil(o/l)+2)*2,o));c[s++]=u;for(var p=1;p<o-1;p+=l){for(var d=Math.min(p+l,o-1),g=Math.min(p+l*2,o),y=(g+d)/2,m=0,_=d;_<g;_++){var S=this.getRawIndex(_),x=i[S];isNaN(x)||(m+=x)}m/=g-d;var b=p,w=Math.min(p+l,o),T=p-1,C=i[u];f=-1,h=b;for(var M=-1,D=0,_=b;_<w;_++){var S=this.getRawIndex(_),x=i[S];if(isNaN(x)){D++,M<0&&(M=S);continue}v=Math.abs((T-y)*(x-C)-(T-_)*(m-C)),v>f&&(f=v,h=S)}D>0&&D<w-b&&(c[s++]=Math.min(M,h),h=Math.max(M,h)),c[s++]=h,u=h}return c[s++]=this.getRawIndex(o-1),a._count=s,a._indices=c,a.getRawIndex=this._getRawIdx,a},r.prototype.minmaxDownSample=function(t,e){for(var a=this.clone([t],!0),n=a._chunks,i=Math.floor(1/e),o=n[t],s=this.count(),l=new(po(this._rawCount))(Math.ceil(s/i)*2),u=0,f=0;f<s;f+=i){var v=f,h=o[this.getRawIndex(v)],c=f,p=o[this.getRawIndex(c)],d=i;f+i>s&&(d=s-f);for(var g=0;g<d;g++){var y=this.getRawIndex(f+g),m=o[y];m<h&&(h=m,v=f+g),m>p&&(p=m,c=f+g)}var _=this.getRawIndex(v),S=this.getRawIndex(c);v<c?(l[u++]=_,l[u++]=S):(l[u++]=S,l[u++]=_)}return a._count=u,a._indices=l,a._updateGetRawIdx(),a},r.prototype.downSample=function(t,e,a,n){for(var i=this.clone([t],!0),o=i._chunks,s=[],l=Math.floor(1/e),u=o[t],f=this.count(),v=i._rawExtent[t]=go(),h=new(po(this._rawCount))(Math.ceil(f/l)),c=0,p=0;p<f;p+=l){l>f-p&&(l=f-p,s.length=l);for(var d=0;d<l;d++){var g=this.getRawIndex(p+d);s[d]=u[g]}var y=a(s),m=this.getRawIndex(Math.min(p+n(s,y)||0,f-1));u[m]=y,y<v[0]&&(v[0]=y),y>v[1]&&(v[1]=y),h[c++]=m}return i._count=c,i._indices=h,i._updateGetRawIdx(),i},r.prototype.each=function(t,e){if(this._count)for(var a=t.length,n=this._chunks,i=0,o=this.count();i<o;i++){var s=this.getRawIndex(i);switch(a){case 0:e(i);break;case 1:e(n[t[0]][s],i);break;case 2:e(n[t[0]][s],n[t[1]][s],i);break;default:for(var l=0,u=[];l<a;l++)u[l]=n[t[l]][s];u[l]=i,e.apply(null,u)}}},r.prototype.getDataExtent=function(t){var e=this._chunks[t],a=go();if(!e)return a;var n=this.count(),i=!this._indices,o;if(i)return this._rawExtent[t].slice();if(o=this._extent[t],o)return o.slice();o=a;for(var s=o[0],l=o[1],u=0;u<n;u++){var f=this.getRawIndex(u),v=e[f];v<s&&(s=v),v>l&&(l=v)}return o=[s,l],this._extent[t]=o,o},r.prototype.getRawDataItem=function(t){var e=this.getRawIndex(t);if(this._provider.persistent)return this._provider.getItem(e);for(var a=[],n=this._chunks,i=0;i<n.length;i++)a.push(n[i][e]);return a},r.prototype.clone=function(t,e){var a=new r,n=this._chunks,i=t&&Mr(t,function(s,l){return s[l]=!0,s},{});if(i)for(var o=0;o<n.length;o++)a._chunks[o]=i[o]?QB(n[o]):n[o];else a._chunks=n;return this._copyCommonProps(a),e||(a._indices=this._cloneIndices()),a._updateGetRawIdx(),a},r.prototype._copyCommonProps=function(t){t._count=this._count,t._rawCount=this._rawCount,t._provider=this._provider,t._dimensions=this._dimensions,t._extent=et(this._extent),t._rawExtent=et(this._rawExtent)},r.prototype._cloneIndices=function(){if(this._indices){var t=this._indices.constructor,e=void 0;if(t===Array){var a=this._indices.length;e=new t(a);for(var n=0;n<a;n++)e[n]=this._indices[n]}else e=new t(this._indices);return e}return null},r.prototype._getRawIdxIdentity=function(t){return t},r.prototype._getRawIdx=function(t){return t<this._count&&t>=0?this._indices[t]:-1},r.prototype._updateGetRawIdx=function(){this.getRawIndex=this._indices?this._getRawIdx:this._getRawIdxIdentity},r.internalField=function(){function t(e,a,n,i){return Dn(e[i],this._dimensions[i])}op={arrayRows:t,objectRows:function(e,a,n,i){return Dn(e[a],this._dimensions[i])},keyedColumns:t,original:function(e,a,n,i){var o=e&&(e.value==null?e:e.value);return Dn(o instanceof Array?o[i]:o,this._dimensions[i])},typedArray:function(e,a,n,i){return e[i]}}}(),r}(),kD=function(){function r(t){this._sourceList=[],this._storeList=[],this._upstreamSignList=[],this._versionSignBase=0,this._dirty=!0,this._sourceHost=t}return r.prototype.dirty=function(){this._setLocalSource([],[]),this._storeList=[],this._dirty=!0},r.prototype._setLocalSource=function(t,e){this._sourceList=t,this._upstreamSignList=e,this._versionSignBase++,this._versionSignBase>9e10&&(this._versionSignBase=0)},r.prototype._getVersionSign=function(){return this._sourceHost.uid+"_"+this._versionSignBase},r.prototype.prepareSource=function(){this._isDirty()&&(this._createSource(),this._dirty=!1)},r.prototype._createSource=function(){this._setLocalSource([],[]);var t=this._sourceHost,e=this._getUpstreamSourceManagers(),a=!!e.length,n,i;if(uf(t)){var o=t,s=void 0,l=void 0,u=void 0;if(a){var f=e[0];f.prepareSource(),u=f.getSource(),s=u.data,l=u.sourceFormat,i=[f._getVersionSign()]}else s=o.get("data",!0),l=Ze(s)?Mn:hr,i=[];var v=this._getSourceMetaRawOption()||{},h=u&&u.metaRawOption||{},c=Q(v.seriesLayoutBy,h.seriesLayoutBy)||null,p=Q(v.sourceHeader,h.sourceHeader),d=Q(v.dimensions,h.dimensions),g=c!==h.seriesLayoutBy||!!p!=!!h.sourceHeader||d;n=g?[kg(s,{seriesLayoutBy:c,sourceHeader:p,dimensions:d},l)]:[]}else{var y=t;if(a){var m=this._applyTransform(e);n=m.sourceList,i=m.upstreamSignList}else{var _=y.get("source",!0);n=[kg(_,this._getSourceMetaRawOption(),null)],i=[]}}this._setLocalSource(n,i)},r.prototype._applyTransform=function(t){var e=this._sourceHost,a=e.get("transform",!0),n=e.get("fromTransformResult",!0);if(n!=null){var i="";t.length!==1&&yS(i)}var o,s=[],l=[];return A(t,function(u){u.prepareSource();var f=u.getSource(n||0),v="";n!=null&&!f&&yS(v),s.push(f),l.push(u._getVersionSign())}),a?o=qB(a,s,{datasetIndex:e.componentIndex}):n!=null&&(o=[IB(s[0])]),{sourceList:o,upstreamSignList:l}},r.prototype._isDirty=function(){if(this._dirty)return!0;for(var t=this._getUpstreamSourceManagers(),e=0;e<t.length;e++){var a=t[e];if(a._isDirty()||this._upstreamSignList[e]!==a._getVersionSign())return!0}},r.prototype.getSource=function(t){t=t||0;var e=this._sourceList[t];if(!e){var a=this._getUpstreamSourceManagers();return a[0]&&a[0].getSource(t)}return e},r.prototype.getSharedDataStore=function(t){var e=t.makeStoreSchema();return this._innerGetDataStore(e.dimensions,t.source,e.hash)},r.prototype._innerGetDataStore=function(t,e,a){var n=0,i=this._storeList,o=i[n];o||(o=i[n]={});var s=o[a];if(!s){var l=this._getUpstreamSourceManagers()[0];uf(this._sourceHost)&&l?s=l._innerGetDataStore(t,e,a):(s=new Eg,s.initData(new wD(e,t.length),t)),o[a]=s}return s},r.prototype._getUpstreamSourceManagers=function(){var t=this._sourceHost;if(uf(t)){var e=$m(t);return e?[e.getSourceManager()]:[]}else return U(iB(t),function(a){return a.getSourceManager()})},r.prototype._getSourceMetaRawOption=function(){var t=this._sourceHost,e,a,n;if(uf(t))e=t.get("seriesLayoutBy",!0),a=t.get("sourceHeader",!0),n=t.get("dimensions",!0);else if(!this._getUpstreamSourceManagers().length){var i=t;e=i.get("seriesLayoutBy",!0),a=i.get("sourceHeader",!0),n=i.get("dimensions",!0)}return{seriesLayoutBy:e,sourceHeader:a,dimensions:n}},r}();function gS(r){var t=r.option.transform;t&&Gl(r.option.transform)}function uf(r){return r.mainType==="series"}function yS(r){throw new Error(r)}var tz="line-height:1";function ED(r){var t=r.lineHeight;return t==null?tz:"line-height:"+ze(t+"")+"px"}function OD(r,t){var e=r.color||N.color.tertiary,a=r.fontSize||12,n=r.fontWeight||"400",i=r.color||N.color.secondary,o=r.fontSize||14,s=r.fontWeight||"900";return t==="html"?{nameStyle:"font-size:"+ze(a+"")+"px;color:"+ze(e)+";font-weight:"+ze(n+""),valueStyle:"font-size:"+ze(o+"")+"px;color:"+ze(i)+";font-weight:"+ze(s+"")}:{nameStyle:{fontSize:a,fill:e,fontWeight:n},valueStyle:{fontSize:o,fill:i,fontWeight:s}}}var ez=[0,10,20,30],rz=["",`
`,`

`,`


`];function ue(r,t){return t.type=r,t}function Og(r){return r.type==="section"}function ND(r){return Og(r)?az:nz}function BD(r){if(Og(r)){var t=0,e=r.blocks.length,a=e>1||e>0&&!r.noHeader;return A(r.blocks,function(n){var i=BD(n);i>=t&&(t=i+ +(a&&(!i||Og(n)&&!n.noHeader)))}),t}return 0}function az(r,t,e,a){var n=t.noHeader,i=iz(BD(t)),o=[],s=t.blocks||[];Re(!s||W(s)),s=s||[];var l=r.orderMode;if(t.sortBlocks&&l){s=s.slice();var u={valueAsc:"asc",valueDesc:"desc"};if(q(u,l)){var f=new LD(u[l],null);s.sort(function(d,g){return f.evaluate(d.sortParam,g.sortParam)})}else l==="seriesDesc"&&s.reverse()}A(s,function(d,g){var y=t.valueFormatter,m=ND(d)(y?G(G({},r),{valueFormatter:y}):r,d,g>0?i.html:0,a);m!=null&&o.push(m)});var v=r.renderMode==="richText"?o.join(i.richText):Ng(a,o.join(""),n?e:i.html);if(n)return v;var h=Lg(t.header,"ordinal",r.useUTC),c=OD(a,r.renderMode).nameStyle,p=ED(a);return r.renderMode==="richText"?zD(r,h,c)+i.richText+v:Ng(a,'<div style="'+c+";"+p+';">'+ze(h)+"</div>"+v,e)}function nz(r,t,e,a){var n=r.renderMode,i=t.noName,o=t.noValue,s=!t.markerType,l=t.name,u=r.useUTC,f=t.valueFormatter||r.valueFormatter||function(S){return S=W(S)?S:[S],U(S,function(x,b){return Lg(x,W(c)?c[b]:c,u)})};if(!(i&&o)){var v=s?"":r.markupStyleCreator.makeTooltipMarker(t.markerType,t.markerColor||N.color.secondary,n),h=i?"":Lg(l,"ordinal",u),c=t.valueType,p=o?[]:f(t.value,t.dataIndex),d=!s||!i,g=!s&&i,y=OD(a,n),m=y.nameStyle,_=y.valueStyle;return n==="richText"?(s?"":v)+(i?"":zD(r,h,m))+(o?"":lz(r,p,d,g,_)):Ng(a,(s?"":v)+(i?"":oz(h,!s,m))+(o?"":sz(p,d,g,_)),e)}}function mS(r,t,e,a,n,i){if(r){var o=ND(r),s={useUTC:n,renderMode:e,orderMode:a,markupStyleCreator:t,valueFormatter:r.valueFormatter};return o(s,r,0,i)}}function iz(r){return{html:ez[r],richText:rz[r]}}function Ng(r,t,e){var a='<div style="clear:both"></div>',n="margin: "+e+"px 0 0",i=ED(r);return'<div style="'+n+";"+i+';">'+t+a+"</div>"}function oz(r,t,e){var a=t?"margin-left:2px":"";return'<span style="'+e+";"+a+'">'+ze(r)+"</span>"}function sz(r,t,e,a){var n=e?"10px":"20px",i=t?"float:right;margin-left:"+n:"";return r=W(r)?r:[r],'<span style="'+i+";"+a+'">'+U(r,function(o){return ze(o)}).join("&nbsp;&nbsp;")+"</span>"}function zD(r,t,e){return r.markupStyleCreator.wrapRichTextStyle(t,e)}function lz(r,t,e,a,n){var i=[n],o=a?10:20;return e&&i.push({padding:[0,0,0,o],align:"right"}),r.markupStyleCreator.wrapRichTextStyle(W(t)?t.join("  "):t,i)}function VD(r,t){var e=r.getData().getItemVisual(t,"style"),a=e[r.visualDrawType];return Yi(a)}function GD(r,t){var e=r.get("padding");return e??(t==="richText"?[8,10]:10)}var sp=function(){function r(){this.richTextStyles={},this._nextStyleNameId=ZA()}return r.prototype._generateStyleName=function(){return"__EC_aUTo_"+this._nextStyleNameId++},r.prototype.makeTooltipMarker=function(t,e,a){var n=a==="richText"?this._generateStyleName():null,i=tD({color:e,type:t,renderMode:a,markerId:n});return X(i)?i:(this.richTextStyles[n]=i.style,i.content)},r.prototype.wrapRichTextStyle=function(t,e){var a={};W(e)?A(e,function(i){return G(a,i)}):G(a,e);var n=this._generateStyleName();return this.richTextStyles[n]=a,"{"+n+"|"+t+"}"},r}();function FD(r){var t=r.series,e=r.dataIndex,a=r.multipleSeries,n=t.getData(),i=n.mapDimensionsAll("defaultedTooltip"),o=i.length,s=t.getRawValue(e),l=W(s),u=VD(t,e),f,v,h,c;if(o>1||l&&!o){var p=uz(s,t,e,i,u);f=p.inlineValues,v=p.inlineValueTypes,h=p.blocks,c=p.inlineValues[0]}else if(o){var d=n.getDimensionInfo(i[0]);c=f=as(n,e,i[0]),v=d.type}else c=f=l?s[0]:s;var g=cm(t),y=g&&t.name||"",m=n.getName(e),_=a?y:m;return ue("section",{header:y,noHeader:a||!g,sortParam:c,blocks:[ue("nameValue",{markerType:"item",markerColor:u,name:_,noName:!sr(_),value:f,valueType:v,dataIndex:e})].concat(h||[])})}function uz(r,t,e,a,n){var i=t.getData(),o=Mr(r,function(v,h,c){var p=i.getDimensionInfo(c);return v=v||p&&p.tooltip!==!1&&p.displayName!=null},!1),s=[],l=[],u=[];a.length?A(a,function(v){f(as(i,e,v),v)}):A(r,f);function f(v,h){var c=i.getDimensionInfo(h);!c||c.otherDims.tooltip===!1||(o?u.push(ue("nameValue",{markerType:"subItem",markerColor:n,name:c.displayName,value:v,valueType:c.type})):(s.push(v),l.push(c.type)))}return{inlineValues:s,inlineValueTypes:l,blocks:u}}var nn=St();function ff(r,t){return r.getName(t)||r.getId(t)}var cv="__universalTransitionEnabled",Bt=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e._selectedDataIndicesMap={},e}return t.prototype.init=function(e,a,n){this.seriesIndex=this.componentIndex,this.dataTask=Nl({count:vz,reset:hz}),this.dataTask.context={model:this},this.mergeDefaultAndTheme(e,n);var i=nn(this).sourceManager=new kD(this);i.prepareSource();var o=this.getInitialData(e,n);SS(o,this),this.dataTask.context.data=o,nn(this).dataBeforeProcessed=o,_S(this),this._initSelectedMapFromData(o)},t.prototype.mergeDefaultAndTheme=function(e,a){var n=Jl(this),i=n?Ji(e):{},o=this.subType;xt.hasClass(o)&&(o+="Series"),yt(e,a.getTheme().get(this.subType)),yt(e,this.getDefaultOption()),Vi(e,"label",["show"]),this.fillDataTextStyle(e.data),n&&_a(e,i,n)},t.prototype.mergeOption=function(e,a){e=yt(this.option,e,!0),this.fillDataTextStyle(e.data);var n=Jl(this);n&&_a(this.option,e,n);var i=nn(this).sourceManager;i.dirty(),i.prepareSource();var o=this.getInitialData(e,a);SS(o,this),this.dataTask.dirty(),this.dataTask.context.data=o,nn(this).dataBeforeProcessed=o,_S(this),this._initSelectedMapFromData(o)},t.prototype.fillDataTextStyle=function(e){if(e&&!Ze(e))for(var a=["show"],n=0;n<e.length;n++)e[n]&&e[n].label&&Vi(e[n],"label",a)},t.prototype.getInitialData=function(e,a){},t.prototype.appendData=function(e){var a=this.getRawData();a.appendData(e.data)},t.prototype.getData=function(e){var a=Bg(this);if(a){var n=a.context.data;return e==null||!n.getLinkedData?n:n.getLinkedData(e)}else return nn(this).data},t.prototype.getAllData=function(){var e=this.getData();return e&&e.getLinkedDataAll?e.getLinkedDataAll():[{data:e}]},t.prototype.setData=function(e){var a=Bg(this);if(a){var n=a.context;n.outputData=e,a!==this.dataTask&&(n.data=e)}nn(this).data=e},t.prototype.getEncode=function(){var e=this.get("encode",!0);if(e)return j(e)},t.prototype.getSourceManager=function(){return nn(this).sourceManager},t.prototype.getSource=function(){return this.getSourceManager().getSource()},t.prototype.getRawData=function(){return nn(this).dataBeforeProcessed},t.prototype.getColorBy=function(){var e=this.get("colorBy");return e||"series"},t.prototype.isColorBySeries=function(){return this.getColorBy()==="series"},t.prototype.getBaseAxis=function(){var e=this.coordinateSystem;return e&&e.getBaseAxis&&e.getBaseAxis()},t.prototype.indicesOfNearest=function(e,a,n,i){var o=this.getData(),s=this.coordinateSystem,l=s&&s.getAxis(e);if(!s||!l)return[];var u=l.dataToCoord(n);i==null&&(i=1/0);var f=[],v=1/0,h=-1,c=0;return o.each(a,function(p,d){var g=l.dataToCoord(p),y=u-g,m=Math.abs(y);m<=i&&((m<v||m===v&&y>=0&&h<0)&&(v=m,h=y,c=0),y===h&&(f[c++]=d))}),f.length=c,f},t.prototype.formatTooltip=function(e,a,n){return FD({series:this,dataIndex:e,multipleSeries:a})},t.prototype.isAnimationEnabled=function(){var e=this.ecModel;if(Tt.node&&!(e&&e.ssr))return!1;var a=this.getShallow("animation");return a&&this.getData().count()>this.getShallow("animationThreshold")&&(a=!1),!!a},t.prototype.restoreData=function(){this.dataTask.dirty()},t.prototype.getColorFromPalette=function(e,a,n){var i=this.ecModel,o=qm.prototype.getColorFromPalette.call(this,e,a,n);return o||(o=i.getColorFromPalette(e,a,n)),o},t.prototype.coordDimToDataDim=function(e){return this.getRawData().mapDimensionsAll(e)},t.prototype.getProgressive=function(){return this.get("progressive")},t.prototype.getProgressiveThreshold=function(){return this.get("progressiveThreshold")},t.prototype.select=function(e,a){this._innerSelect(this.getData(a),e)},t.prototype.unselect=function(e,a){var n=this.option.selectedMap;if(n){var i=this.option.selectedMode,o=this.getData(a);if(i==="series"||n==="all"){this.option.selectedMap={},this._selectedDataIndicesMap={};return}for(var s=0;s<e.length;s++){var l=e[s],u=ff(o,l);n[u]=!1,this._selectedDataIndicesMap[u]=-1}}},t.prototype.toggleSelect=function(e,a){for(var n=[],i=0;i<e.length;i++)n[0]=e[i],this.isSelected(e[i],a)?this.unselect(n,a):this.select(n,a)},t.prototype.getSelectedDataIndices=function(){if(this.option.selectedMap==="all")return[].slice.call(this.getData().getIndices());for(var e=this._selectedDataIndicesMap,a=Ct(e),n=[],i=0;i<a.length;i++){var o=e[a[i]];o>=0&&n.push(o)}return n},t.prototype.isSelected=function(e,a){var n=this.option.selectedMap;if(!n)return!1;var i=this.getData(a);return(n==="all"||n[ff(i,e)])&&!i.getItemModel(e).get(["select","disabled"])},t.prototype.isUniversalTransitionEnabled=function(){if(this[cv])return!0;var e=this.option.universalTransition;return e?e===!0?!0:e&&e.enabled:!1},t.prototype._innerSelect=function(e,a){var n,i,o=this.option,s=o.selectedMode,l=a.length;if(!(!s||!l)){if(s==="series")o.selectedMap="all";else if(s==="multiple"){it(o.selectedMap)||(o.selectedMap={});for(var u=o.selectedMap,f=0;f<l;f++){var v=a[f],h=ff(e,v);u[h]=!0,this._selectedDataIndicesMap[h]=e.getRawIndex(v)}}else if(s==="single"||s===!0){var c=a[l-1],h=ff(e,c);o.selectedMap=(n={},n[h]=!0,n),this._selectedDataIndicesMap=(i={},i[h]=e.getRawIndex(c),i)}}},t.prototype._initSelectedMapFromData=function(e){if(!this.option.selectedMap){var a=[];e.hasItemOption&&e.each(function(n){var i=e.getRawDataItem(n);i&&i.selected&&a.push(n)}),a.length>0&&this._innerSelect(e,a)}},t.registerClass=function(e){return xt.registerClass(e)},t.protoInitialize=function(){var e=t.prototype;e.type="series.__base__",e.seriesIndex=0,e.ignoreStyleOnData=!1,e.hasSymbolVisual=!1,e.defaultSymbol="circle",e.visualStyleAccessPath="itemStyle",e.visualDrawType="fill"}(),t}(xt);Qt(Bt,tc);Qt(Bt,qm);rM(Bt,xt);function _S(r){var t=r.name;cm(r)||(r.name=fz(r)||t)}function fz(r){var t=r.getRawData(),e=t.mapDimensionsAll("seriesName"),a=[];return A(e,function(n){var i=t.getDimensionInfo(n);i.displayName&&a.push(i.displayName)}),a.join(" ")}function vz(r){return r.model.getRawData().count()}function hz(r){var t=r.model;return t.setData(t.getRawData().cloneShallow()),cz}function cz(r,t){t.outputData&&r.end>t.outputData.count()&&t.model.getRawData().cloneShallow(t.outputData)}function SS(r,t){A(Ko(r.CHANGABLE_METHODS,r.DOWNSAMPLE_METHODS),function(e){r.wrapMethod(e,pt(pz,t))})}function pz(r,t){var e=Bg(r);return e&&e.setOutputEnd((t||this).count()),t}function Bg(r){var t=(r.ecModel||{}).scheduler,e=t&&t.getPipeline(r.uid);if(e){var a=e.currentTask;if(a){var n=a.agentStubMap;n&&(a=n.get(r.uid))}return a}}var Wt=function(){function r(){this.group=new rt,this.uid=bs("viewComponent")}return r.prototype.init=function(t,e){},r.prototype.render=function(t,e,a,n){},r.prototype.dispose=function(t,e){},r.prototype.updateView=function(t,e,a,n){},r.prototype.updateLayout=function(t,e,a,n){},r.prototype.updateVisual=function(t,e,a,n){},r.prototype.toggleBlurSeries=function(t,e,a){},r.prototype.eachRendered=function(t){var e=this.group;e&&e.traverse(t)},r}();dm(Wt);Fh(Wt);function Cs(){var r=St();return function(t){var e=r(t),a=t.pipelineContext,n=!!e.large,i=!!e.progressiveRender,o=e.large=!!(a&&a.large),s=e.progressiveRender=!!(a&&a.progressiveRender);return(n!==o||i!==s)&&"reset"}}var HD=St(),dz=Cs(),Nt=function(){function r(){this.group=new rt,this.uid=bs("viewChart"),this.renderTask=Nl({plan:gz,reset:yz}),this.renderTask.context={view:this}}return r.prototype.init=function(t,e){},r.prototype.render=function(t,e,a,n){},r.prototype.highlight=function(t,e,a,n){var i=t.getData(n&&n.dataType);i&&bS(i,n,"emphasis")},r.prototype.downplay=function(t,e,a,n){var i=t.getData(n&&n.dataType);i&&bS(i,n,"normal")},r.prototype.remove=function(t,e){this.group.removeAll()},r.prototype.dispose=function(t,e){},r.prototype.updateView=function(t,e,a,n){this.render(t,e,a,n)},r.prototype.updateLayout=function(t,e,a,n){this.render(t,e,a,n)},r.prototype.updateVisual=function(t,e,a,n){this.render(t,e,a,n)},r.prototype.eachRendered=function(t){zn(this.group,t)},r.markUpdateMethod=function(t,e){HD(t).updateMethod=e},r.protoInitialize=function(){var t=r.prototype;t.type="chart"}(),r}();function xS(r,t,e){r&&ql(r)&&(t==="emphasis"?Xa:$a)(r,e)}function bS(r,t,e){var a=Gi(r,t),n=t&&t.highlightKey!=null?WO(t.highlightKey):null;a!=null?A(Ft(a),function(i){xS(r.getItemGraphicEl(i),e,n)}):r.eachItemGraphicEl(function(i){xS(i,e,n)})}dm(Nt);Fh(Nt);function gz(r){return dz(r.model)}function yz(r){var t=r.model,e=r.ecModel,a=r.api,n=r.payload,i=t.pipelineContext.progressiveRender,o=r.view,s=n&&HD(n).updateMethod,l=i?"incrementalPrepareRender":s&&o[s]?s:"render";return l!=="render"&&o[l](t,e,a,n),mz[l]}var mz={incrementalPrepareRender:{progress:function(r,t){t.view.incrementalRender(r,t.model,t.ecModel,t.api,t.payload)}},render:{forceFirstProgress:!0,progress:function(r,t){t.view.render(t.model,t.ecModel,t.api,t.payload)}}},Wv="\0__throttleOriginMethod",wS="\0__throttleRate",TS="\0__throttleType";function e0(r,t,e){var a,n=0,i=0,o=null,s,l,u,f;t=t||0;function v(){i=new Date().getTime(),o=null,r.apply(l,u||[])}var h=function(){for(var c=[],p=0;p<arguments.length;p++)c[p]=arguments[p];a=new Date().getTime(),l=this,u=c;var d=f||t,g=f||e;f=null,s=a-(g?n:i)-d,clearTimeout(o),g?o=setTimeout(v,d):s>=0?v():o=setTimeout(v,-s),n=a};return h.clear=function(){o&&(clearTimeout(o),o=null)},h.debounceNextCall=function(c){f=c},h}function As(r,t,e,a){var n=r[t];if(n){var i=n[Wv]||n,o=n[TS],s=n[wS];if(s!==e||o!==a){if(e==null||!a)return r[t]=i;n=r[t]=e0(i,e,a==="debounce"),n[Wv]=i,n[TS]=a,n[wS]=e}return n}}function tu(r,t){var e=r[t];e&&e[Wv]&&(e.clear&&e.clear(),r[t]=e[Wv])}var CS=St(),AS={itemStyle:Fi(UM,!0),lineStyle:Fi(WM,!0)},_z={lineStyle:"stroke",itemStyle:"fill"};function WD(r,t){var e=r.visualStyleMapper||AS[t];return e||(console.warn("Unknown style type '"+t+"'."),AS.itemStyle)}function UD(r,t){var e=r.visualDrawType||_z[t];return e||(console.warn("Unknown style type '"+t+"'."),"fill")}var Sz={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,t){var e=r.getData(),a=r.visualStyleAccessPath||"itemStyle",n=r.getModel(a),i=WD(r,a),o=i(n),s=n.getShallow("decal");s&&(e.setVisual("decal",s),s.dirty=!0);var l=UD(r,a),u=o[l],f=tt(u)?u:null,v=o.fill==="auto"||o.stroke==="auto";if(!o[l]||f||v){var h=r.getColorFromPalette(r.name,null,t.getSeriesCount());o[l]||(o[l]=h,e.setVisual("colorFromPalette",!0)),o.fill=o.fill==="auto"||tt(o.fill)?h:o.fill,o.stroke=o.stroke==="auto"||tt(o.stroke)?h:o.stroke}if(e.setVisual("style",o),e.setVisual("drawType",l),!t.isSeriesFiltered(r)&&f)return e.setVisual("colorFromPalette",!1),{dataEach:function(c,p){var d=r.getDataParams(p),g=G({},o);g[l]=f(d),c.setItemVisual(p,"style",g)}}}},Hs=new wt,xz={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,t){if(!(r.ignoreStyleOnData||t.isSeriesFiltered(r))){var e=r.getData(),a=r.visualStyleAccessPath||"itemStyle",n=WD(r,a),i=e.getVisual("drawType");return{dataEach:e.hasItemOption?function(o,s){var l=o.getRawDataItem(s);if(l&&l[a]){Hs.option=l[a];var u=n(Hs),f=o.ensureUniqueItemVisual(s,"style");G(f,u),Hs.option.decal&&(o.setItemVisual(s,"decal",Hs.option.decal),Hs.option.decal.dirty=!0),i in u&&o.setItemVisual(s,"colorFromPalette",!1)}}:null}}}},bz={performRawSeries:!0,overallReset:function(r){var t=j();r.eachSeries(function(e){var a=e.getColorBy();if(!e.isColorBySeries()){var n=e.type+"-"+a,i=t.get(n);i||(i={},t.set(n,i)),CS(e).scope=i}}),r.eachSeries(function(e){if(!(e.isColorBySeries()||r.isSeriesFiltered(e))){var a=e.getRawData(),n={},i=e.getData(),o=CS(e).scope,s=e.visualStyleAccessPath||"itemStyle",l=UD(e,s);i.each(function(u){var f=i.getRawIndex(u);n[f]=u}),a.each(function(u){var f=n[u],v=i.getItemVisual(f,"colorFromPalette");if(v){var h=i.ensureUniqueItemVisual(f,"style"),c=a.getName(u)||u+"",p=a.count();h[l]=e.getColorFromPalette(c,o,p)}})}})}},vf=Math.PI;function wz(r,t){t=t||{},nt(t,{text:"loading",textColor:N.color.primary,fontSize:12,fontWeight:"normal",fontStyle:"normal",fontFamily:"sans-serif",maskColor:"rgba(255,255,255,0.8)",showSpinner:!0,color:N.color.theme[0],spinnerRadius:10,lineWidth:5,zlevel:0});var e=new rt,a=new _t({style:{fill:t.maskColor},zlevel:t.zlevel,z:1e4});e.add(a);var n=new At({style:{text:t.text,fill:t.textColor,fontSize:t.fontSize,fontWeight:t.fontWeight,fontStyle:t.fontStyle,fontFamily:t.fontFamily},zlevel:t.zlevel,z:10001}),i=new _t({style:{fill:"none"},textContent:n,textConfig:{position:"right",distance:10},zlevel:t.zlevel,z:10001});e.add(i);var o;return t.showSpinner&&(o=new Au({shape:{startAngle:-vf/2,endAngle:-vf/2+.1,r:t.spinnerRadius},style:{stroke:t.color,lineCap:"round",lineWidth:t.lineWidth},zlevel:t.zlevel,z:10001}),o.animateShape(!0).when(1e3,{endAngle:vf*3/2}).start("circularInOut"),o.animateShape(!0).when(1e3,{startAngle:vf*3/2}).delay(300).start("circularInOut"),e.add(o)),e.resize=function(){var s=n.getBoundingRect().width,l=t.showSpinner?t.spinnerRadius:0,u=(r.getWidth()-l*2-(t.showSpinner&&s?10:0)-s)/2-(t.showSpinner&&s?0:5+s/2)+(t.showSpinner?0:s/2)+(s?0:l),f=r.getHeight()/2;t.showSpinner&&o.setShape({cx:u,cy:f}),i.setShape({x:u-l,y:f-l,width:l*2,height:l*2}),a.setShape({x:0,y:0,width:r.getWidth(),height:r.getHeight()})},e.resize(),e}var YD=function(){function r(t,e,a,n){this._stageTaskMap=j(),this.ecInstance=t,this.api=e,a=this._dataProcessorHandlers=a.slice(),n=this._visualHandlers=n.slice(),this._allHandlers=a.concat(n)}return r.prototype.restoreData=function(t,e){t.restoreData(e),this._stageTaskMap.each(function(a){var n=a.overallTask;n&&n.dirty()})},r.prototype.getPerformArgs=function(t,e){if(t.__pipeline){var a=this._pipelineMap.get(t.__pipeline.id),n=a.context,i=!e&&a.progressiveEnabled&&(!n||n.progressiveRender)&&t.__idxInPipeline>a.blockIndex,o=i?a.step:null,s=n&&n.modDataCount,l=s!=null?Math.ceil(s/o):null;return{step:o,modBy:l,modDataCount:s}}},r.prototype.getPipeline=function(t){return this._pipelineMap.get(t)},r.prototype.updateStreamModes=function(t,e){var a=this._pipelineMap.get(t.uid),n=t.getData(),i=n.count(),o=a.progressiveEnabled&&e.incrementalPrepareRender&&i>=a.threshold,s=t.get("large")&&i>=t.get("largeThreshold"),l=t.get("progressiveChunkMode")==="mod"?i:null;t.pipelineContext=a.context={progressiveRender:o,modDataCount:l,large:s}},r.prototype.restorePipelines=function(t){var e=this,a=e._pipelineMap=j();t.eachSeries(function(n){var i=n.getProgressive(),o=n.uid;a.set(o,{id:o,head:null,tail:null,threshold:n.getProgressiveThreshold(),progressiveEnabled:i&&!(n.preventIncremental&&n.preventIncremental()),blockIndex:-1,step:Math.round(i||700),count:0}),e._pipe(n,n.dataTask)})},r.prototype.prepareStageTasks=function(){var t=this._stageTaskMap,e=this.api.getModel(),a=this.api;A(this._allHandlers,function(n){var i=t.get(n.uid)||t.set(n.uid,{}),o="";Re(!(n.reset&&n.overallReset),o),n.reset&&this._createSeriesStageTask(n,i,e,a),n.overallReset&&this._createOverallStageTask(n,i,e,a)},this)},r.prototype.prepareView=function(t,e,a,n){var i=t.renderTask,o=i.context;o.model=e,o.ecModel=a,o.api=n,i.__block=!t.incrementalPrepareRender,this._pipe(e,i)},r.prototype.performDataProcessorTasks=function(t,e){this._performStageTasks(this._dataProcessorHandlers,t,e,{block:!0})},r.prototype.performVisualTasks=function(t,e,a){this._performStageTasks(this._visualHandlers,t,e,a)},r.prototype._performStageTasks=function(t,e,a,n){n=n||{};var i=!1,o=this;A(t,function(l,u){if(!(n.visualType&&n.visualType!==l.visualType)){var f=o._stageTaskMap.get(l.uid),v=f.seriesTaskMap,h=f.overallTask;if(h){var c,p=h.agentStubMap;p.each(function(g){s(n,g)&&(g.dirty(),c=!0)}),c&&h.dirty(),o.updatePayload(h,a);var d=o.getPerformArgs(h,n.block);p.each(function(g){g.perform(d)}),h.perform(d)&&(i=!0)}else v&&v.each(function(g,y){s(n,g)&&g.dirty();var m=o.getPerformArgs(g,n.block);m.skip=!l.performRawSeries&&e.isSeriesFiltered(g.context.model),o.updatePayload(g,a),g.perform(m)&&(i=!0)})}});function s(l,u){return l.setDirty&&(!l.dirtyMap||l.dirtyMap.get(u.__pipeline.id))}this.unfinished=i||this.unfinished},r.prototype.performSeriesTasks=function(t){var e;t.eachSeries(function(a){e=a.dataTask.perform()||e}),this.unfinished=e||this.unfinished},r.prototype.plan=function(){this._pipelineMap.each(function(t){var e=t.tail;do{if(e.__block){t.blockIndex=e.__idxInPipeline;break}e=e.getUpstream()}while(e)})},r.prototype.updatePayload=function(t,e){e!=="remain"&&(t.context.payload=e)},r.prototype._createSeriesStageTask=function(t,e,a,n){var i=this,o=e.seriesTaskMap,s=e.seriesTaskMap=j(),l=t.seriesType,u=t.getTargetSeries;t.createOnAllSeries?a.eachRawSeries(f):l?a.eachRawSeriesByType(l,f):u&&u(a,n).each(f);function f(v){var h=v.uid,c=s.set(h,o&&o.get(h)||Nl({plan:Dz,reset:Lz,count:Pz}));c.context={model:v,ecModel:a,api:n,useClearVisual:t.isVisual&&!t.isLayout,plan:t.plan,reset:t.reset,scheduler:i},i._pipe(v,c)}},r.prototype._createOverallStageTask=function(t,e,a,n){var i=this,o=e.overallTask=e.overallTask||Nl({reset:Tz});o.context={ecModel:a,api:n,overallReset:t.overallReset,scheduler:i};var s=o.agentStubMap,l=o.agentStubMap=j(),u=t.seriesType,f=t.getTargetSeries,v=!0,h=!1,c="";Re(!t.createOnAllSeries,c),u?a.eachRawSeriesByType(u,p):f?f(a,n).each(p):(v=!1,A(a.getSeries(),p));function p(d){var g=d.uid,y=l.set(g,s&&s.get(g)||(h=!0,Nl({reset:Cz,onDirty:Mz})));y.context={model:d,overallProgress:v},y.agent=o,y.__block=v,i._pipe(d,y)}h&&o.dirty()},r.prototype._pipe=function(t,e){var a=t.uid,n=this._pipelineMap.get(a);!n.head&&(n.head=e),n.tail&&n.tail.pipe(e),n.tail=e,e.__idxInPipeline=n.count++,e.__pipeline=n},r.wrapStageHandler=function(t,e){return tt(t)&&(t={overallReset:t,seriesType:Rz(t)}),t.uid=bs("stageHandler"),e&&(t.visualType=e),t},r}();function Tz(r){r.overallReset(r.ecModel,r.api,r.payload)}function Cz(r){return r.overallProgress&&Az}function Az(){this.agent.dirty(),this.getDownstream().dirty()}function Mz(){this.agent&&this.agent.dirty()}function Dz(r){return r.plan?r.plan(r.model,r.ecModel,r.api,r.payload):null}function Lz(r){r.useClearVisual&&r.data.clearAllVisual();var t=r.resetDefines=Ft(r.reset(r.model,r.ecModel,r.api,r.payload));return t.length>1?U(t,function(e,a){return ZD(a)}):Iz}var Iz=ZD(0);function ZD(r){return function(t,e){var a=e.data,n=e.resetDefines[r];if(n&&n.dataEach)for(var i=t.start;i<t.end;i++)n.dataEach(a,i);else n&&n.progress&&n.progress(t,a)}}function Pz(r){return r.data.count()}function Rz(r){Uv=null;try{r(eu,XD)}catch{}return Uv}var eu={},XD={},Uv;$D(eu,Km);$D(XD,mD);eu.eachSeriesByType=eu.eachRawSeriesByType=function(r){Uv=r};eu.eachComponent=function(r){r.mainType==="series"&&r.subType&&(Uv=r.subType)};function $D(r,t){for(var e in t.prototype)r[e]=jt}var ot=N.darkColor,kz=ot.background,Ws=function(){return{axisLine:{lineStyle:{color:ot.axisLine}},splitLine:{lineStyle:{color:ot.axisSplitLine}},splitArea:{areaStyle:{color:[ot.backgroundTint,ot.backgroundTransparent]}},minorSplitLine:{lineStyle:{color:ot.axisMinorSplitLine}},axisLabel:{color:ot.axisLabel},axisName:{}}},MS={label:{color:ot.secondary},itemStyle:{borderColor:ot.borderTint},dividerLineStyle:{color:ot.border}},qD={darkMode:!0,color:ot.theme,backgroundColor:kz,axisPointer:{lineStyle:{color:ot.border},crossStyle:{color:ot.borderShade},label:{color:ot.tertiary}},legend:{textStyle:{color:ot.secondary},pageTextStyle:{color:ot.tertiary}},textStyle:{color:ot.secondary},title:{textStyle:{color:ot.primary},subtextStyle:{color:ot.quaternary}},toolbox:{iconStyle:{borderColor:ot.accent50}},tooltip:{backgroundColor:ot.neutral20,defaultBorderColor:ot.border,textStyle:{color:ot.tertiary}},dataZoom:{borderColor:ot.accent10,textStyle:{color:ot.tertiary},brushStyle:{color:ot.backgroundTint},handleStyle:{color:ot.neutral00,borderColor:ot.accent20},moveHandleStyle:{color:ot.accent40},emphasis:{handleStyle:{borderColor:ot.accent50}},dataBackground:{lineStyle:{color:ot.accent30},areaStyle:{color:ot.accent20}},selectedDataBackground:{lineStyle:{color:ot.accent50},areaStyle:{color:ot.accent30}}},visualMap:{textStyle:{color:ot.secondary},handleStyle:{borderColor:ot.neutral30}},timeline:{lineStyle:{color:ot.accent10},label:{color:ot.tertiary},controlStyle:{color:ot.accent30,borderColor:ot.accent30}},calendar:{itemStyle:{color:ot.neutral00,borderColor:ot.neutral20},dayLabel:{color:ot.tertiary},monthLabel:{color:ot.secondary},yearLabel:{color:ot.secondary}},matrix:{x:MS,y:MS,backgroundColor:{borderColor:ot.axisLine},body:{itemStyle:{borderColor:ot.borderTint}}},timeAxis:Ws(),logAxis:Ws(),valueAxis:Ws(),categoryAxis:Ws(),line:{symbol:"circle"},graph:{color:ot.theme},gauge:{title:{color:ot.secondary},axisLine:{lineStyle:{color:[[1,ot.neutral05]]}},axisLabel:{color:ot.axisLabel},detail:{color:ot.primary}},candlestick:{itemStyle:{color:"#f64e56",color0:"#54ea92",borderColor:"#f64e56",borderColor0:"#54ea92"}},funnel:{itemStyle:{borderColor:ot.background}},radar:function(){var r=Ws();return r.axisName={color:ot.axisLabel},r.axisLine.lineStyle.color=ot.neutral20,r}(),treemap:{breadcrumb:{itemStyle:{color:ot.neutral20,textStyle:{color:ot.secondary}},emphasis:{itemStyle:{color:ot.neutral30}}}},sunburst:{itemStyle:{borderColor:ot.background}},map:{itemStyle:{borderColor:ot.border,areaColor:ot.neutral10},label:{color:ot.tertiary},emphasis:{label:{color:ot.primary},itemStyle:{areaColor:ot.highlight}},select:{label:{color:ot.primary},itemStyle:{areaColor:ot.highlight}}},geo:{itemStyle:{borderColor:ot.border,areaColor:ot.neutral10},emphasis:{label:{color:ot.primary},itemStyle:{areaColor:ot.highlight}},select:{label:{color:ot.primary},itemStyle:{color:ot.highlight}}}};qD.categoryAxis.splitLine.show=!1;var Ez=function(){function r(){}return r.prototype.normalizeQuery=function(t){var e={},a={},n={};if(X(t)){var i=ua(t);e.mainType=i.main||null,e.subType=i.sub||null}else{var o=["Index","Name","Id"],s={name:1,dataIndex:1,dataType:1};A(t,function(l,u){for(var f=!1,v=0;v<o.length;v++){var h=o[v],c=u.lastIndexOf(h);if(c>0&&c===u.length-h.length){var p=u.slice(0,c);p!=="data"&&(e.mainType=p,e[h.toLowerCase()]=l,f=!0)}}s.hasOwnProperty(u)&&(a[u]=l,f=!0),f||(n[u]=l)})}return{cptQuery:e,dataQuery:a,otherQuery:n}},r.prototype.filter=function(t,e){var a=this.eventInfo;if(!a)return!0;var n=a.targetEl,i=a.packedEvent,o=a.model,s=a.view;if(!o||!s)return!0;var l=e.cptQuery,u=e.dataQuery;return f(l,o,"mainType")&&f(l,o,"subType")&&f(l,o,"index","componentIndex")&&f(l,o,"name")&&f(l,o,"id")&&f(u,i,"name")&&f(u,i,"dataIndex")&&f(u,i,"dataType")&&(!s.filterForExposedEvent||s.filterForExposedEvent(t,e.otherQuery,n,i));function f(v,h,c,p){return v[c]==null||h[p||c]===v[c]}},r.prototype.afterTrigger=function(){this.eventInfo=null},r}(),zg=["symbol","symbolSize","symbolRotate","symbolOffset"],DS=zg.concat(["symbolKeepAspect"]),Oz={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,t){var e=r.getData();if(r.legendIcon&&e.setVisual("legendIcon",r.legendIcon),!r.hasSymbolVisual)return;for(var a={},n={},i=!1,o=0;o<zg.length;o++){var s=zg[o],l=r.get(s);tt(l)?(i=!0,n[s]=l):a[s]=l}if(a.symbol=a.symbol||r.defaultSymbol,e.setVisual(G({legendIcon:r.legendIcon||a.symbol,symbolKeepAspect:r.get("symbolKeepAspect")},a)),t.isSeriesFiltered(r))return;var u=Ct(n);function f(v,h){for(var c=r.getRawValue(h),p=r.getDataParams(h),d=0;d<u.length;d++){var g=u[d];v.setItemVisual(h,g,n[g](c,p))}}return{dataEach:i?f:null}}},Nz={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,t){if(!r.hasSymbolVisual||t.isSeriesFiltered(r))return;var e=r.getData();function a(n,i){for(var o=n.getItemModel(i),s=0;s<DS.length;s++){var l=DS[s],u=o.getShallow(l,!0);u!=null&&n.setItemVisual(i,l,u)}}return{dataEach:e.hasItemOption?a:null}}};function r0(r,t,e){switch(e){case"color":var a=r.getItemVisual(t,"style");return a[r.getVisual("drawType")];case"opacity":return r.getItemVisual(t,"style").opacity;case"symbol":case"symbolSize":case"liftZ":return r.getItemVisual(t,e)}}function Pu(r,t){switch(t){case"color":var e=r.getVisual("style");return e[r.getVisual("drawType")];case"opacity":return r.getVisual("style").opacity;case"symbol":case"symbolSize":case"liftZ":return r.getVisual(t)}}function KD(r,t,e,a){switch(e){case"color":var n=r.ensureUniqueItemVisual(t,"style");n[r.getVisual("drawType")]=a,r.setItemVisual(t,"colorFromPalette",!1);break;case"opacity":r.ensureUniqueItemVisual(t,"style").opacity=a;break;case"symbol":case"symbolSize":case"liftZ":r.setItemVisual(t,e,a);break}}function jD(r,t){function e(a,n){var i=[];return a.eachComponent({mainType:"series",subType:r,query:n},function(o){i.push(o.seriesIndex)}),i}A([[r+"ToggleSelect","toggleSelect"],[r+"Select","select"],[r+"UnSelect","unselect"]],function(a){t(a[0],function(n,i,o){n=G({},n),o.dispatchAction(G(n,{type:a[1],seriesIndex:e(i,n)}))})})}function yo(r,t,e,a,n){var i=r+t;e.isSilent(i)||a.eachComponent({mainType:"series",subType:"pie"},function(o){for(var s=o.seriesIndex,l=o.option.selectedMap,u=n.selected,f=0;f<u.length;f++)if(u[f].seriesIndex===s){var v=o.getData(),h=Gi(v,n.fromActionPayload);e.trigger(i,{type:i,seriesId:o.id,name:W(h)?v.getName(h[0]):v.getName(h),selected:X(l)?l:G({},l)})}})}function Bz(r,t,e){r.on("selectchanged",function(a){var n=e.getModel();a.isFromClick?(yo("map","selectchanged",t,n,a),yo("pie","selectchanged",t,n,a)):a.fromAction==="select"?(yo("map","selected",t,n,a),yo("pie","selected",t,n,a)):a.fromAction==="unselect"&&(yo("map","unselected",t,n,a),yo("pie","unselected",t,n,a))})}function Di(r,t,e){for(var a;r&&!(t(r)&&(a=r,e));)r=r.__hostTarget||r.parent;return a}var zz=Math.round(Math.random()*9),Vz=typeof Object.defineProperty=="function",Gz=function(){function r(){this._id="__ec_inner_"+zz++}return r.prototype.get=function(t){return this._guard(t)[this._id]},r.prototype.set=function(t,e){var a=this._guard(t);return Vz?Object.defineProperty(a,this._id,{value:e,enumerable:!1,configurable:!0}):a[this._id]=e,this},r.prototype.delete=function(t){return this.has(t)?(delete this._guard(t)[this._id],!0):!1},r.prototype.has=function(t){return!!this._guard(t)[this._id]},r.prototype._guard=function(t){if(t!==Object(t))throw TypeError("Value of WeakMap is not a non-null object.");return t},r}(),Fz=bt.extend({type:"triangle",shape:{cx:0,cy:0,width:0,height:0},buildPath:function(r,t){var e=t.cx,a=t.cy,n=t.width/2,i=t.height/2;r.moveTo(e,a-i),r.lineTo(e+n,a+i),r.lineTo(e-n,a+i),r.closePath()}}),Hz=bt.extend({type:"diamond",shape:{cx:0,cy:0,width:0,height:0},buildPath:function(r,t){var e=t.cx,a=t.cy,n=t.width/2,i=t.height/2;r.moveTo(e,a-i),r.lineTo(e+n,a),r.lineTo(e,a+i),r.lineTo(e-n,a),r.closePath()}}),Wz=bt.extend({type:"pin",shape:{x:0,y:0,width:0,height:0},buildPath:function(r,t){var e=t.x,a=t.y,n=t.width/5*3,i=Math.max(n,t.height),o=n/2,s=o*o/(i-o),l=a-i+o+s,u=Math.asin(s/o),f=Math.cos(u)*o,v=Math.sin(u),h=Math.cos(u),c=o*.6,p=o*.7;r.moveTo(e-f,l+s),r.arc(e,l,o,Math.PI-u,Math.PI*2+u),r.bezierCurveTo(e+f-v*c,l+s+h*c,e,a-p,e,a),r.bezierCurveTo(e,a-p,e-f+v*c,l+s+h*c,e-f,l+s),r.closePath()}}),Uz=bt.extend({type:"arrow",shape:{x:0,y:0,width:0,height:0},buildPath:function(r,t){var e=t.height,a=t.width,n=t.x,i=t.y,o=a/3*2;r.moveTo(n,i),r.lineTo(n+o,i+e),r.lineTo(n,i+e/4*3),r.lineTo(n-o,i+e),r.lineTo(n,i),r.closePath()}}),Yz={line:ne,rect:_t,roundRect:_t,square:_t,circle:wa,diamond:Hz,pin:Wz,arrow:Uz,triangle:Fz},Zz={line:function(r,t,e,a,n){n.x1=r,n.y1=t+a/2,n.x2=r+e,n.y2=t+a/2},rect:function(r,t,e,a,n){n.x=r,n.y=t,n.width=e,n.height=a},roundRect:function(r,t,e,a,n){n.x=r,n.y=t,n.width=e,n.height=a,n.r=Math.min(e,a)/4},square:function(r,t,e,a,n){var i=Math.min(e,a);n.x=r,n.y=t,n.width=i,n.height=i},circle:function(r,t,e,a,n){n.cx=r+e/2,n.cy=t+a/2,n.r=Math.min(e,a)/2},diamond:function(r,t,e,a,n){n.cx=r+e/2,n.cy=t+a/2,n.width=e,n.height=a},pin:function(r,t,e,a,n){n.x=r+e/2,n.y=t+a/2,n.width=e,n.height=a},arrow:function(r,t,e,a,n){n.x=r+e/2,n.y=t+a/2,n.width=e,n.height=a},triangle:function(r,t,e,a,n){n.cx=r+e/2,n.cy=t+a/2,n.width=e,n.height=a}},Yv={};A(Yz,function(r,t){Yv[t]=new r});var Xz=bt.extend({type:"symbol",shape:{symbolType:"",x:0,y:0,width:0,height:0},calculateTextPosition:function(r,t,e){var a=kv(r,t,e),n=this.shape;return n&&n.symbolType==="pin"&&t.position==="inside"&&(a.y=e.y+e.height*.4),a},buildPath:function(r,t,e){var a=t.symbolType;if(a!=="none"){var n=Yv[a];n||(a="rect",n=Yv[a]),Zz[a](t.x,t.y,t.width,t.height,n.shape),n.buildPath(r,n.shape,e)}}});function $z(r,t){if(this.type!=="image"){var e=this.style;this.__isEmptyBrush?(e.stroke=r,e.fill=t||N.color.neutral00,e.lineWidth=2):this.shape.symbolType==="line"?e.stroke=r:e.fill=r,this.markRedraw()}}function ie(r,t,e,a,n,i,o){var s=r.indexOf("empty")===0;s&&(r=r.substr(5,1).toLowerCase()+r.substr(6));var l;return r.indexOf("image://")===0?l=Mm(r.slice(8),new lt(t,e,a,n),o?"center":"cover"):r.indexOf("path://")===0?l=es(r.slice(7),{},new lt(t,e,a,n),o?"center":"cover"):l=new Xz({shape:{symbolType:r,x:t,y:e,width:a,height:n}}),l.__isEmptyBrush=s,l.setColor=$z,i&&l.setColor(i),l}function Ms(r){return W(r)||(r=[+r,+r]),[r[0]||0,r[1]||0]}function to(r,t){if(r!=null)return W(r)||(r=[r,r]),[Z(r[0],t[0])||0,Z(Q(r[1],r[0]),t[1])||0]}function Li(r){return isFinite(r)}function qz(r,t,e){var a=t.x==null?0:t.x,n=t.x2==null?1:t.x2,i=t.y==null?0:t.y,o=t.y2==null?0:t.y2;t.global||(a=a*e.width+e.x,n=n*e.width+e.x,i=i*e.height+e.y,o=o*e.height+e.y),a=Li(a)?a:0,n=Li(n)?n:1,i=Li(i)?i:0,o=Li(o)?o:0;var s=r.createLinearGradient(a,i,n,o);return s}function Kz(r,t,e){var a=e.width,n=e.height,i=Math.min(a,n),o=t.x==null?.5:t.x,s=t.y==null?.5:t.y,l=t.r==null?.5:t.r;t.global||(o=o*a+e.x,s=s*n+e.y,l=l*i),o=Li(o)?o:.5,s=Li(s)?s:.5,l=l>=0&&Li(l)?l:.5;var u=r.createRadialGradient(o,s,0,o,s,l);return u}function Vg(r,t,e){for(var a=t.type==="radial"?Kz(r,t,e):qz(r,t,e),n=t.colorStops,i=0;i<n.length;i++)a.addColorStop(n[i].offset,n[i].color);return a}function jz(r,t){if(r===t||!r&&!t)return!1;if(!r||!t||r.length!==t.length)return!0;for(var e=0;e<r.length;e++)if(r[e]!==t[e])return!0;return!1}function hf(r){return parseInt(r,10)}function Ho(r,t,e){var a=["width","height"][t],n=["clientWidth","clientHeight"][t],i=["paddingLeft","paddingTop"][t],o=["paddingRight","paddingBottom"][t];if(e[a]!=null&&e[a]!=="auto")return parseFloat(e[a]);var s=document.defaultView.getComputedStyle(r);return(r[n]||hf(s[a])||hf(r.style[a]))-(hf(s[i])||0)-(hf(s[o])||0)|0}function Jz(r,t){return!r||r==="solid"||!(t>0)?null:r==="dashed"?[4*t,2*t]:r==="dotted"?[t]:Mt(r)?[r]:W(r)?r:null}function a0(r){var t=r.style,e=t.lineDash&&t.lineWidth>0&&Jz(t.lineDash,t.lineWidth),a=t.lineDashOffset;if(e){var n=t.strokeNoScale&&r.getLineScale?r.getLineScale():1;n&&n!==1&&(e=U(e,function(i){return i/n}),a/=n)}return[e,a]}var Qz=new ma(!0);function Zv(r){var t=r.stroke;return!(t==null||t==="none"||!(r.lineWidth>0))}function LS(r){return typeof r=="string"&&r!=="none"}function Xv(r){var t=r.fill;return t!=null&&t!=="none"}function IS(r,t){if(t.fillOpacity!=null&&t.fillOpacity!==1){var e=r.globalAlpha;r.globalAlpha=t.fillOpacity*t.opacity,r.fill(),r.globalAlpha=e}else r.fill()}function PS(r,t){if(t.strokeOpacity!=null&&t.strokeOpacity!==1){var e=r.globalAlpha;r.globalAlpha=t.strokeOpacity*t.opacity,r.stroke(),r.globalAlpha=e}else r.stroke()}function Gg(r,t,e){var a=gm(t.image,t.__image,e);if(Hh(a)){var n=r.createPattern(a,t.repeat||"repeat");if(typeof DOMMatrix=="function"&&n&&n.setTransform){var i=new DOMMatrix;i.translateSelf(t.x||0,t.y||0),i.rotateSelf(0,0,(t.rotation||0)*Cl),i.scaleSelf(t.scaleX||1,t.scaleY||1),n.setTransform(i)}return n}}function tV(r,t,e,a){var n,i=Zv(e),o=Xv(e),s=e.strokePercent,l=s<1,u=!t.path;(!t.silent||l)&&u&&t.createPathProxy();var f=t.path||Qz,v=t.__dirty;if(!a){var h=e.fill,c=e.stroke,p=o&&!!h.colorStops,d=i&&!!c.colorStops,g=o&&!!h.image,y=i&&!!c.image,m=void 0,_=void 0,S=void 0,x=void 0,b=void 0;(p||d)&&(b=t.getBoundingRect()),p&&(m=v?Vg(r,h,b):t.__canvasFillGradient,t.__canvasFillGradient=m),d&&(_=v?Vg(r,c,b):t.__canvasStrokeGradient,t.__canvasStrokeGradient=_),g&&(S=v||!t.__canvasFillPattern?Gg(r,h,t):t.__canvasFillPattern,t.__canvasFillPattern=S),y&&(x=v||!t.__canvasStrokePattern?Gg(r,c,t):t.__canvasStrokePattern,t.__canvasStrokePattern=x),p?r.fillStyle=m:g&&(S?r.fillStyle=S:o=!1),d?r.strokeStyle=_:y&&(x?r.strokeStyle=x:i=!1)}var w=t.getGlobalScale();f.setScale(w[0],w[1],t.segmentIgnoreThreshold);var T,C;r.setLineDash&&e.lineDash&&(n=a0(t),T=n[0],C=n[1]);var M=!0;(u||v&ko)&&(f.setDPR(r.dpr),l?f.setContext(null):(f.setContext(r),M=!1),f.reset(),t.buildPath(f,t.shape,a),f.toStatic(),t.pathUpdated()),M&&f.rebuildPath(r,l?s:1),T&&(r.setLineDash(T),r.lineDashOffset=C),a||(e.strokeFirst?(i&&PS(r,e),o&&IS(r,e)):(o&&IS(r,e),i&&PS(r,e))),T&&r.setLineDash([])}function eV(r,t,e){var a=t.__image=gm(e.image,t.__image,t,t.onload);if(!(!a||!Hh(a))){var n=e.x||0,i=e.y||0,o=t.getWidth(),s=t.getHeight(),l=a.width/a.height;if(o==null&&s!=null?o=s*l:s==null&&o!=null?s=o/l:o==null&&s==null&&(o=a.width,s=a.height),e.sWidth&&e.sHeight){var u=e.sx||0,f=e.sy||0;r.drawImage(a,u,f,e.sWidth,e.sHeight,n,i,o,s)}else if(e.sx&&e.sy){var u=e.sx,f=e.sy,v=o-u,h=s-f;r.drawImage(a,u,f,v,h,n,i,o,s)}else r.drawImage(a,n,i,o,s)}}function rV(r,t,e){var a,n=e.text;if(n!=null&&(n+=""),n){r.font=e.font||Ya,r.textAlign=e.textAlign,r.textBaseline=e.textBaseline;var i=void 0,o=void 0;r.setLineDash&&e.lineDash&&(a=a0(t),i=a[0],o=a[1]),i&&(r.setLineDash(i),r.lineDashOffset=o),e.strokeFirst?(Zv(e)&&r.strokeText(n,e.x,e.y),Xv(e)&&r.fillText(n,e.x,e.y)):(Xv(e)&&r.fillText(n,e.x,e.y),Zv(e)&&r.strokeText(n,e.x,e.y)),i&&r.setLineDash([])}}var RS=["shadowBlur","shadowOffsetX","shadowOffsetY"],kS=[["lineCap","butt"],["lineJoin","miter"],["miterLimit",10]];function JD(r,t,e,a,n){var i=!1;if(!a&&(e=e||{},t===e))return!1;if(a||t.opacity!==e.opacity){Je(r,n),i=!0;var o=Math.max(Math.min(t.opacity,1),0);r.globalAlpha=isNaN(o)?Ri.opacity:o}(a||t.blend!==e.blend)&&(i||(Je(r,n),i=!0),r.globalCompositeOperation=t.blend||Ri.blend);for(var s=0;s<RS.length;s++){var l=RS[s];(a||t[l]!==e[l])&&(i||(Je(r,n),i=!0),r[l]=r.dpr*(t[l]||0))}return(a||t.shadowColor!==e.shadowColor)&&(i||(Je(r,n),i=!0),r.shadowColor=t.shadowColor||Ri.shadowColor),i}function ES(r,t,e,a,n){var i=ru(t,n.inHover),o=a?null:e&&ru(e,n.inHover)||{};if(i===o)return!1;var s=JD(r,i,o,a,n);if((a||i.fill!==o.fill)&&(s||(Je(r,n),s=!0),LS(i.fill)&&(r.fillStyle=i.fill)),(a||i.stroke!==o.stroke)&&(s||(Je(r,n),s=!0),LS(i.stroke)&&(r.strokeStyle=i.stroke)),(a||i.opacity!==o.opacity)&&(s||(Je(r,n),s=!0),r.globalAlpha=i.opacity==null?1:i.opacity),t.hasStroke()){var l=i.lineWidth,u=l/(i.strokeNoScale&&t.getLineScale?t.getLineScale():1);r.lineWidth!==u&&(s||(Je(r,n),s=!0),r.lineWidth=u)}for(var f=0;f<kS.length;f++){var v=kS[f],h=v[0];(a||i[h]!==o[h])&&(s||(Je(r,n),s=!0),r[h]=i[h]||v[1])}return s}function aV(r,t,e,a,n){return JD(r,ru(t,n.inHover),e&&ru(e,n.inHover),a,n)}function QD(r,t){var e=t.transform,a=r.dpr||1;e?r.setTransform(a*e[0],a*e[1],a*e[2],a*e[3],a*e[4],a*e[5]):r.setTransform(a,0,0,a,0,0)}function nV(r,t,e){for(var a=!1,n=0;n<r.length;n++){var i=r[n];a=a||i.isZeroArea(),QD(t,i),t.beginPath(),i.buildPath(t,i.shape),t.clip()}e.allClipped=a}function iV(r,t){return r&&t?r[0]!==t[0]||r[1]!==t[1]||r[2]!==t[2]||r[3]!==t[3]||r[4]!==t[4]||r[5]!==t[5]:!(!r&&!t)}var OS=1,NS=2,BS=3,zS=4;function oV(r){var t=Xv(r),e=Zv(r);return!(r.lineDash||!(+t^+e)||t&&typeof r.fill!="string"||e&&typeof r.stroke!="string"||r.strokePercent<1||r.strokeOpacity<1||r.fillOpacity<1)}function Je(r,t){t.batchFill&&r.fill(),t.batchStroke&&r.stroke(),t.batchFill="",t.batchStroke=""}function ru(r,t){return t&&r.__hoverStyle||r.style}function tL(r,t){Ii(r,t,{inHover:!1,viewWidth:0,viewHeight:0},!0)}function Ii(r,t,e,a){var n=t.transform;if(!t.shouldBePainted(e.viewWidth,e.viewHeight,!1,!1)){t.__dirty&=~ir,t.__isRendered=!1;return}var i=t.__clipPaths,o=e.prevElClipPaths,s=!1,l=!1;if((!o||jz(i,o))&&(o&&o.length&&(Je(r,e),r.restore(),l=s=!0,e.prevElClipPaths=null,e.allClipped=!1,e.prevEl=null),i&&i.length&&(Je(r,e),r.save(),nV(i,r,e),s=!0),e.prevElClipPaths=i),e.allClipped){t.__isRendered=!1;return}t.beforeBrush&&t.beforeBrush(),t.innerBeforeBrush();var u=e.prevEl;u||(l=s=!0);var f=t instanceof bt&&t.autoBatch&&oV(t.style);s||iV(n,u.transform)?(Je(r,e),QD(r,t)):f||Je(r,e);var v=ru(t,e.inHover);t instanceof bt?(e.lastDrawType!==OS&&(l=!0,e.lastDrawType=OS),ES(r,t,u,l,e),(!f||!e.batchFill&&!e.batchStroke)&&r.beginPath(),tV(r,t,v,f),f&&(e.batchFill=v.fill||"",e.batchStroke=v.stroke||"")):t instanceof ts?(e.lastDrawType!==BS&&(l=!0,e.lastDrawType=BS),ES(r,t,u,l,e),rV(r,t,v)):t instanceof xe?(e.lastDrawType!==NS&&(l=!0,e.lastDrawType=NS),aV(r,t,u,l,e),eV(r,t,v)):t.getTemporalDisplayables&&(e.lastDrawType!==zS&&(l=!0,e.lastDrawType=zS),sV(r,t,e)),f&&a&&Je(r,e),t.innerAfterBrush(),t.afterBrush&&t.afterBrush(),e.prevEl=t,t.__dirty=0,t.__isRendered=!0}function sV(r,t,e){var a=t.getDisplayables(),n=t.getTemporalDisplayables();r.save();var i={prevElClipPaths:null,prevEl:null,allClipped:!1,viewWidth:e.viewWidth,viewHeight:e.viewHeight,inHover:e.inHover},o,s;for(o=t.getCursor(),s=a.length;o<s;o++){var l=a[o];l.beforeBrush&&l.beforeBrush(),l.innerBeforeBrush(),Ii(r,l,i,o===s-1),l.innerAfterBrush(),l.afterBrush&&l.afterBrush(),i.prevEl=l}for(var u=0,f=n.length;u<f;u++){var l=n[u];l.beforeBrush&&l.beforeBrush(),l.innerBeforeBrush(),Ii(r,l,i,u===f-1),l.innerAfterBrush(),l.afterBrush&&l.afterBrush(),i.prevEl=l}t.clearTemporalDisplayables(),t.notClear=!0,r.restore()}var lp=new Gz,VS=new jo(100),GS=["symbol","symbolSize","symbolKeepAspect","color","backgroundColor","dashArrayX","dashArrayY","maxTileWidth","maxTileHeight"];function ns(r,t){if(r==="none")return null;var e=t.getDevicePixelRatio(),a=t.getZr(),n=a.painter.type==="svg";r.dirty&&lp.delete(r);var i=lp.get(r);if(i)return i;var o=nt(r,{symbol:"rect",symbolSize:1,symbolKeepAspect:!0,color:"rgba(0, 0, 0, 0.2)",backgroundColor:null,dashArrayX:5,dashArrayY:5,rotation:0,maxTileWidth:512,maxTileHeight:512});o.backgroundColor==="none"&&(o.backgroundColor=null);var s={repeat:"repeat"};return l(s),s.rotation=o.rotation,s.scaleX=s.scaleY=n?1:1/e,lp.set(r,s),r.dirty=!1,s;function l(u){for(var f=[e],v=!0,h=0;h<GS.length;++h){var c=o[GS[h]];if(c!=null&&!W(c)&&!X(c)&&!Mt(c)&&typeof c!="boolean"){v=!1;break}f.push(c)}var p;if(v){p=f.join(",")+(n?"-svg":"");var d=VS.get(p);d&&(n?u.svgElement=d:u.image=d)}var g=rL(o.dashArrayX),y=lV(o.dashArrayY),m=eL(o.symbol),_=uV(g),S=aL(y),x=!n&&tr.createCanvas(),b=n&&{tag:"g",attrs:{},key:"dcl",children:[]},w=C(),T;x&&(x.width=w.width*e,x.height=w.height*e,T=x.getContext("2d")),M(),v&&VS.put(p,x||b),u.image=x,u.svgElement=b,u.svgWidth=w.width,u.svgHeight=w.height;function C(){for(var D=1,I=0,L=_.length;I<L;++I)D=r1(D,_[I]);for(var P=1,I=0,L=m.length;I<L;++I)P=r1(P,m[I].length);D*=P;var k=S*_.length*m.length;return{width:Math.max(1,Math.min(D,o.maxTileWidth)),height:Math.max(1,Math.min(k,o.maxTileHeight))}}function M(){T&&(T.clearRect(0,0,x.width,x.height),o.backgroundColor&&(T.fillStyle=o.backgroundColor,T.fillRect(0,0,x.width,x.height)));for(var D=0,I=0;I<y.length;++I)D+=y[I];if(D<=0)return;for(var L=-S,P=0,k=0,R=0;L<w.height;){if(P%2===0){for(var O=k/2%m.length,E=0,B=0,V=0;E<w.width*2;){for(var F=0,I=0;I<g[R].length;++I)F+=g[R][I];if(F<=0)break;if(B%2===0){var H=(1-o.symbolSize)*.5,Y=E+g[R][B]*H,K=L+y[P]*H,ft=g[R][B]*o.symbolSize,It=y[P]*o.symbolSize,Ot=V/2%m[O].length;vt(Y,K,ft,It,m[O][Ot])}E+=g[R][B],++V,++B,B===g[R].length&&(B=0)}++R,R===g.length&&(R=0)}L+=y[P],++k,++P,P===y.length&&(P=0)}function vt(at,dt,J,ht,zt){var Dt=n?1:e,Et=ie(zt,at*Dt,dt*Dt,J*Dt,ht*Dt,o.color,o.symbolKeepAspect);if(n){var Vt=a.painter.renderOneToVNode(Et);Vt&&b.children.push(Vt)}else tL(T,Et)}}}}function eL(r){if(!r||r.length===0)return[["rect"]];if(X(r))return[[r]];for(var t=!0,e=0;e<r.length;++e)if(!X(r[e])){t=!1;break}if(t)return eL([r]);for(var a=[],e=0;e<r.length;++e)X(r[e])?a.push([r[e]]):a.push(r[e]);return a}function rL(r){if(!r||r.length===0)return[[0,0]];if(Mt(r)){var t=Math.ceil(r);return[[t,t]]}for(var e=!0,a=0;a<r.length;++a)if(!Mt(r[a])){e=!1;break}if(e)return rL([r]);for(var n=[],a=0;a<r.length;++a)if(Mt(r[a])){var t=Math.ceil(r[a]);n.push([t,t])}else{var t=U(r[a],function(s){return Math.ceil(s)});t.length%2===1?n.push(t.concat(t)):n.push(t)}return n}function lV(r){if(!r||typeof r=="object"&&r.length===0)return[0,0];if(Mt(r)){var t=Math.ceil(r);return[t,t]}var e=U(r,function(a){return Math.ceil(a)});return r.length%2?e.concat(e):e}function uV(r){return U(r,function(t){return aL(t)})}function aL(r){for(var t=0,e=0;e<r.length;++e)t+=r[e];return r.length%2===1?t*2:t}function fV(r,t){r.eachRawSeries(function(e){if(!r.isSeriesFiltered(e)){var a=e.getData();a.hasItemVisual()&&a.each(function(o){var s=a.getItemVisual(o,"decal");if(s){var l=a.ensureUniqueItemVisual(o,"style");l.decal=ns(s,t)}});var n=a.getVisual("decal");if(n){var i=a.getVisual("style");i.decal=ns(n,t)}}})}var Nr=new Pr,nL={};function vV(r,t){nL[r]=t}function iL(r){return nL[r]}var oL={};function sL(r,t){oL[r]=t}function hV(r){return oL[r]}var mq="6.0.0",_q={zrender:"6.0.0"},cV=1,pV=800,dV=900,gV=1e3,yV=2e3,mV=5e3,lL=1e3,_V=1100,n0=2e3,uL=3e3,SV=4e3,rc=4500,xV=4600,bV=5e3,wV=6e3,fL=7e3,TV={PROCESSOR:{FILTER:gV,SERIES_FILTER:pV,STATISTIC:mV},VISUAL:{LAYOUT:lL,PROGRESSIVE_LAYOUT:_V,GLOBAL:n0,CHART:uL,POST_CHART_LAYOUT:xV,COMPONENT:SV,BRUSH:bV,CHART_ITEM:rc,ARIA:wV,DECAL:fL}},fe="__flagInMainProcess",cf="__mainProcessVersion",be="__pendingUpdate",up="__needsUpdateStatus",FS=/^[a-zA-Z0-9_]+$/,fp="__connectUpdateStatus",HS=0,CV=1,AV=2;function vL(r){return function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];if(this.isDisposed()){this.id;return}return cL(this,r,t)}}function hL(r){return function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];return cL(this,r,t)}}function cL(r,t,e){return e[0]=e[0]&&e[0].toLowerCase(),Pr.prototype[t].apply(r,e)}var pL=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t}(Pr),dL=pL.prototype;dL.on=hL("on");dL.off=hL("off");var ui,vp,pf,Da,df,hp,cp,mo,_o,WS,US,pp,YS,gf,ZS,gL,pr,XS,So,$v=function(r){z(t,r);function t(e,a,n){var i=r.call(this,new Ez)||this;i._chartsViews=[],i._chartsMap={},i._componentsViews=[],i._componentsMap={},i._pendingActions=[],n=n||{},i._dom=e;var o="canvas",s="auto",l=!1;i[cf]=1,n.ssr&&FA(function(h){var c=ut(h),p=c.dataIndex;if(p!=null){var d=j();return d.set("series_index",c.seriesIndex),d.set("data_index",p),c.ssrType&&d.set("ssr_type",c.ssrType),d}});var u=i._zr=lg(e,{renderer:n.renderer||o,devicePixelRatio:n.devicePixelRatio,width:n.width,height:n.height,ssr:n.ssr,useDirtyRect:Q(n.useDirtyRect,l),useCoarsePointer:Q(n.useCoarsePointer,s),pointerSize:n.pointerSize});i._ssr=n.ssr,i._throttledZrFlush=e0($(u.flush,u),17),i._updateTheme(a),i._locale=kN(n.locale||YM),i._coordSysMgr=new Ts;var f=i._api=ZS(i);function v(h,c){return h.__prio-c.__prio}return tv(Kv,v),tv(Wg,v),i._scheduler=new YD(i,f,Wg,Kv),i._messageCenter=new pL,i._initEvents(),i.resize=$(i.resize,i),u.animation.on("frame",i._onframe,i),WS(u,i),US(u,i),Gl(i),i}return t.prototype._onframe=function(){if(!this._disposed){XS(this);var e=this._scheduler;if(this[be]){var a=this[be].silent;this[fe]=!0,So(this);try{ui(this),Da.update.call(this,null,this[be].updateParams)}catch(l){throw this[fe]=!1,this[be]=null,l}this._zr.flush(),this[fe]=!1,this[be]=null,mo.call(this,a),_o.call(this,a)}else if(e.unfinished){var n=cV,i=this._model,o=this._api;e.unfinished=!1;do{var s=+new Date;e.performSeriesTasks(i),e.performDataProcessorTasks(i),hp(this,i),e.performVisualTasks(i),gf(this,this._model,o,"remain",{}),n-=+new Date-s}while(n>0&&e.unfinished);e.unfinished||this._zr.flush()}}},t.prototype.getDom=function(){return this._dom},t.prototype.getId=function(){return this.id},t.prototype.getZr=function(){return this._zr},t.prototype.isSSR=function(){return this._ssr},t.prototype.setOption=function(e,a,n){if(!this[fe]){if(this._disposed){this.id;return}var i,o,s;if(it(a)&&(n=a.lazyUpdate,i=a.silent,o=a.replaceMerge,s=a.transition,a=a.notMerge),this[fe]=!0,So(this),!this._model||a){var l=new gB(this._api),u=this._theme,f=this._model=new Km;f.scheduler=this._scheduler,f.ssr=this._ssr,f.init(null,null,null,u,this._locale,l)}this._model.setOption(e,{replaceMerge:o},Ug);var v={seriesTransition:s,optionChanged:!0};if(n)this[be]={silent:i,updateParams:v},this[fe]=!1,this.getZr().wakeUp();else{try{ui(this),Da.update.call(this,null,v)}catch(h){throw this[be]=null,this[fe]=!1,h}this._ssr||this._zr.flush(),this[be]=null,this[fe]=!1,mo.call(this,i),_o.call(this,i)}}},t.prototype.setTheme=function(e,a){if(!this[fe]){if(this._disposed){this.id;return}var n=this._model;if(n){var i=a&&a.silent,o=null;this[be]&&(i==null&&(i=this[be].silent),o=this[be].updateParams,this[be]=null),this[fe]=!0,So(this);try{this._updateTheme(e),n.setTheme(this._theme),ui(this),Da.update.call(this,{type:"setTheme"},o)}catch(s){throw this[fe]=!1,s}this[fe]=!1,mo.call(this,i),_o.call(this,i)}}},t.prototype._updateTheme=function(e){X(e)&&(e=yL[e]),e&&(e=et(e),e&&SD(e,!0),this._theme=e)},t.prototype.getModel=function(){return this._model},t.prototype.getOption=function(){return this._model&&this._model.getOption()},t.prototype.getWidth=function(){return this._zr.getWidth()},t.prototype.getHeight=function(){return this._zr.getHeight()},t.prototype.getDevicePixelRatio=function(){return this._zr.painter.dpr||Tt.hasGlobalWindow&&window.devicePixelRatio||1},t.prototype.getRenderedCanvas=function(e){return this.renderToCanvas(e)},t.prototype.renderToCanvas=function(e){e=e||{};var a=this._zr.painter;return a.getRenderedCanvas({backgroundColor:e.backgroundColor||this._model.get("backgroundColor"),pixelRatio:e.pixelRatio||this.getDevicePixelRatio()})},t.prototype.renderToSVGString=function(e){e=e||{};var a=this._zr.painter;return a.renderToString({useViewBox:e.useViewBox})},t.prototype.getSvgDataURL=function(){var e=this._zr,a=e.storage.getDisplayList();return A(a,function(n){n.stopAnimation(null,!0)}),e.painter.toDataURL()},t.prototype.getDataURL=function(e){if(this._disposed){this.id;return}e=e||{};var a=e.excludeComponents,n=this._model,i=[],o=this;A(a,function(l){n.eachComponent({mainType:l},function(u){var f=o._componentsMap[u.__viewId];f.group.ignore||(i.push(f),f.group.ignore=!0)})});var s=this._zr.painter.getType()==="svg"?this.getSvgDataURL():this.renderToCanvas(e).toDataURL("image/"+(e&&e.type||"png"));return A(i,function(l){l.group.ignore=!1}),s},t.prototype.getConnectedDataURL=function(e){if(this._disposed){this.id;return}var a=e.type==="svg",n=this.group,i=Math.min,o=Math.max,s=1/0;if(jv[n]){var l=s,u=s,f=-s,v=-s,h=[],c=e&&e.pixelRatio||this.getDevicePixelRatio();A(Oi,function(_,S){if(_.group===n){var x=a?_.getZr().painter.getSvgDom().innerHTML:_.renderToCanvas(et(e)),b=_.getDom().getBoundingClientRect();l=i(b.left,l),u=i(b.top,u),f=o(b.right,f),v=o(b.bottom,v),h.push({dom:x,left:b.left,top:b.top})}}),l*=c,u*=c,f*=c,v*=c;var p=f-l,d=v-u,g=tr.createCanvas(),y=lg(g,{renderer:a?"svg":"canvas"});if(y.resize({width:p,height:d}),a){var m="";return A(h,function(_){var S=_.left-l,x=_.top-u;m+='<g transform="translate('+S+","+x+')">'+_.dom+"</g>"}),y.painter.getSvgRoot().innerHTML=m,e.connectedBackgroundColor&&y.painter.setBackgroundColor(e.connectedBackgroundColor),y.refreshImmediately(),y.painter.toDataURL()}else return e.connectedBackgroundColor&&y.add(new _t({shape:{x:0,y:0,width:p,height:d},style:{fill:e.connectedBackgroundColor}})),A(h,function(_){var S=new xe({style:{x:_.left*c-l,y:_.top*c-u,image:_.dom}});y.add(S)}),y.refreshImmediately(),g.toDataURL("image/"+(e&&e.type||"png"))}else return this.getDataURL(e)},t.prototype.convertToPixel=function(e,a,n){return df(this,"convertToPixel",e,a,n)},t.prototype.convertToLayout=function(e,a,n){return df(this,"convertToLayout",e,a,n)},t.prototype.convertFromPixel=function(e,a,n){return df(this,"convertFromPixel",e,a,n)},t.prototype.containPixel=function(e,a){if(this._disposed){this.id;return}var n=this._model,i,o=Zo(n,e);return A(o,function(s,l){l.indexOf("Models")>=0&&A(s,function(u){var f=u.coordinateSystem;if(f&&f.containPoint)i=i||!!f.containPoint(a);else if(l==="seriesModels"){var v=this._chartsMap[u.__viewId];v&&v.containPoint&&(i=i||v.containPoint(a,u))}},this)},this),!!i},t.prototype.getVisual=function(e,a){var n=this._model,i=Zo(n,e,{defaultMainType:"series"}),o=i.seriesModel,s=o.getData(),l=i.hasOwnProperty("dataIndexInside")?i.dataIndexInside:i.hasOwnProperty("dataIndex")?s.indexOfRawIndex(i.dataIndex):null;return l!=null?r0(s,l,a):Pu(s,a)},t.prototype.getViewOfComponentModel=function(e){return this._componentsMap[e.__viewId]},t.prototype.getViewOfSeriesModel=function(e){return this._chartsMap[e.__viewId]},t.prototype._initEvents=function(){var e=this;A(MV,function(n){var i=function(o){var s=e.getModel(),l=o.target,u,f=n==="globalout";if(f?u={}:l&&Di(l,function(d){var g=ut(d);if(g&&g.dataIndex!=null){var y=g.dataModel||s.getSeriesByIndex(g.seriesIndex);return u=y&&y.getDataParams(g.dataIndex,g.dataType,l)||{},!0}else if(g.eventData)return u=G({},g.eventData),!0},!0),u){var v=u.componentType,h=u.componentIndex;(v==="markLine"||v==="markPoint"||v==="markArea")&&(v="series",h=u.seriesIndex);var c=v&&h!=null&&s.getComponent(v,h),p=c&&e[c.mainType==="series"?"_chartsMap":"_componentsMap"][c.__viewId];u.event=o,u.type=n,e._$eventProcessor.eventInfo={targetEl:l,packedEvent:u,model:c,view:p},e.trigger(n,u)}};i.zrEventfulCallAtLast=!0,e._zr.on(n,i,e)});var a=this._messageCenter;A(Hg,function(n,i){a.on(i,function(o){e.trigger(i,o)})}),Bz(a,this,this._api)},t.prototype.isDisposed=function(){return this._disposed},t.prototype.clear=function(){if(this._disposed){this.id;return}this.setOption({series:[]},!0)},t.prototype.dispose=function(){if(this._disposed){this.id;return}this._disposed=!0;var e=this.getDom();e&&QA(this.getDom(),o0,"");var a=this,n=a._api,i=a._model;A(a._componentsViews,function(o){o.dispose(i,n)}),A(a._chartsViews,function(o){o.dispose(i,n)}),a._zr.dispose(),a._dom=a._model=a._chartsMap=a._componentsMap=a._chartsViews=a._componentsViews=a._scheduler=a._api=a._zr=a._throttledZrFlush=a._theme=a._coordSysMgr=a._messageCenter=null,delete Oi[a.id]},t.prototype.resize=function(e){if(!this[fe]){if(this._disposed){this.id;return}this._zr.resize(e);var a=this._model;if(this._loadingFX&&this._loadingFX.resize(),!!a){var n=a.resetOption("media"),i=e&&e.silent;this[be]&&(i==null&&(i=this[be].silent),n=!0,this[be]=null),this[fe]=!0,So(this);try{n&&ui(this),Da.update.call(this,{type:"resize",animation:G({duration:0},e&&e.animation)})}catch(o){throw this[fe]=!1,o}this[fe]=!1,mo.call(this,i),_o.call(this,i)}}},t.prototype.showLoading=function(e,a){if(this._disposed){this.id;return}if(it(e)&&(a=e,e=""),e=e||"default",this.hideLoading(),!!Yg[e]){var n=Yg[e](this._api,a),i=this._zr;this._loadingFX=n,i.add(n)}},t.prototype.hideLoading=function(){if(this._disposed){this.id;return}this._loadingFX&&this._zr.remove(this._loadingFX),this._loadingFX=null},t.prototype.makeActionFromEvent=function(e){var a=G({},e);return a.type=Fg[e.type],a},t.prototype.dispatchAction=function(e,a){if(this._disposed){this.id;return}if(it(a)||(a={silent:!!a}),!!qv[e.type]&&this._model){if(this[fe]){this._pendingActions.push(e);return}var n=a.silent;cp.call(this,e,n);var i=a.flush;i?this._zr.flush():i!==!1&&Tt.browser.weChat&&this._throttledZrFlush(),mo.call(this,n),_o.call(this,n)}},t.prototype.updateLabelLayout=function(){Nr.trigger("series:layoutlabels",this._model,this._api,{updatedSeries:[]})},t.prototype.appendData=function(e){if(this._disposed){this.id;return}var a=e.seriesIndex,n=this.getModel(),i=n.getSeriesByIndex(a);i.appendData(e),this._scheduler.unfinished=!0,this.getZr().wakeUp()},t.internalField=function(){ui=function(v){var h=v._scheduler;h.restorePipelines(v._model),h.prepareStageTasks(),vp(v,!0),vp(v,!1),h.plan()},vp=function(v,h){for(var c=v._model,p=v._scheduler,d=h?v._componentsViews:v._chartsViews,g=h?v._componentsMap:v._chartsMap,y=v._zr,m=v._api,_=0;_<d.length;_++)d[_].__alive=!1;h?c.eachComponent(function(b,w){b!=="series"&&S(w)}):c.eachSeries(S);function S(b){var w=b.__requireNewView;b.__requireNewView=!1;var T="_ec_"+b.id+"_"+b.type,C=!w&&g[T];if(!C){var M=ua(b.type),D=h?Wt.getClass(M.main,M.sub):Nt.getClass(M.sub);C=new D,C.init(c,m),g[T]=C,d.push(C),y.add(C.group)}b.__viewId=C.__id=T,C.__alive=!0,C.__model=b,C.group.__ecComponentInfo={mainType:b.mainType,index:b.componentIndex},!h&&p.prepareView(C,b,c,m)}for(var _=0;_<d.length;){var x=d[_];x.__alive?_++:(!h&&x.renderTask.dispose(),y.remove(x.group),x.dispose(c,m),d.splice(_,1),g[x.__id]===x&&delete g[x.__id],x.__id=x.group.__ecComponentInfo=null)}},pf=function(v,h,c,p,d){var g=v._model;if(g.setUpdatePayload(c),!p){A([].concat(v._componentsViews).concat(v._chartsViews),x);return}var y={};y[p+"Id"]=c[p+"Id"],y[p+"Index"]=c[p+"Index"],y[p+"Name"]=c[p+"Name"];var m={mainType:p,query:y};d&&(m.subType=d);var _=c.excludeSeriesId,S;_!=null&&(S=j(),A(Ft(_),function(b){var w=ve(b,null);w!=null&&S.set(w,!0)})),g&&g.eachComponent(m,function(b){var w=S&&S.get(b.id)!=null;if(!w)if(P1(c))if(b instanceof Bt)c.type===ki&&!c.notBlur&&!b.get(["emphasis","disabled"])&&OO(b,c,v._api);else{var T=wm(b.mainType,b.componentIndex,c.name,v._api),C=T.focusSelf,M=T.dispatchers;c.type===ki&&C&&!c.notBlur&&Sg(b.mainType,b.componentIndex,v._api),M&&A(M,function(D){c.type===ki?Xa(D):$a(D)})}else bg(c)&&b instanceof Bt&&(zO(b,c,v._api),L1(b),pr(v))},v),g&&g.eachComponent(m,function(b){var w=S&&S.get(b.id)!=null;w||x(v[p==="series"?"_chartsMap":"_componentsMap"][b.__viewId])},v);function x(b){b&&b.__alive&&b[h]&&b[h](b.__model,g,v._api,c)}},Da={prepareAndUpdate:function(v){ui(this),Da.update.call(this,v,v&&{optionChanged:v.newOption!=null})},update:function(v,h){var c=this._model,p=this._api,d=this._zr,g=this._coordSysMgr,y=this._scheduler;if(c){c.setUpdatePayload(v),y.restoreData(c,v),y.performSeriesTasks(c),g.create(c,p),y.performDataProcessorTasks(c,v),hp(this,c),g.update(c,p),a(c),y.performVisualTasks(c,v);var m=c.get("backgroundColor")||"transparent";d.setBackgroundColor(m);var _=c.get("darkMode");_!=null&&_!=="auto"&&d.setDarkMode(_),pp(this,c,p,v,h),Nr.trigger("afterupdate",c,p)}},updateTransform:function(v){var h=this,c=this._model,p=this._api;if(c){c.setUpdatePayload(v);var d=[];c.eachComponent(function(y,m){if(y!=="series"){var _=h.getViewOfComponentModel(m);if(_&&_.__alive)if(_.updateTransform){var S=_.updateTransform(m,c,p,v);S&&S.update&&d.push(_)}else d.push(_)}});var g=j();c.eachSeries(function(y){var m=h._chartsMap[y.__viewId];if(m.updateTransform){var _=m.updateTransform(y,c,p,v);_&&_.update&&g.set(y.uid,1)}else g.set(y.uid,1)}),a(c),this._scheduler.performVisualTasks(c,v,{setDirty:!0,dirtyMap:g}),gf(this,c,p,v,{},g),Nr.trigger("afterupdate",c,p)}},updateView:function(v){var h=this._model;h&&(h.setUpdatePayload(v),Nt.markUpdateMethod(v,"updateView"),a(h),this._scheduler.performVisualTasks(h,v,{setDirty:!0}),pp(this,h,this._api,v,{}),Nr.trigger("afterupdate",h,this._api))},updateVisual:function(v){var h=this,c=this._model;c&&(c.setUpdatePayload(v),c.eachSeries(function(p){p.getData().clearAllVisual()}),Nt.markUpdateMethod(v,"updateVisual"),a(c),this._scheduler.performVisualTasks(c,v,{visualType:"visual",setDirty:!0}),c.eachComponent(function(p,d){if(p!=="series"){var g=h.getViewOfComponentModel(d);g&&g.__alive&&g.updateVisual(d,c,h._api,v)}}),c.eachSeries(function(p){var d=h._chartsMap[p.__viewId];d.updateVisual(p,c,h._api,v)}),Nr.trigger("afterupdate",c,this._api))},updateLayout:function(v){Da.update.call(this,v)}};function e(v,h,c,p,d){if(v._disposed){v.id;return}for(var g=v._model,y=v._coordSysMgr.getCoordinateSystems(),m,_=Zo(g,c),S=0;S<y.length;S++){var x=y[S];if(x[h]&&(m=x[h](g,_,p,d))!=null)return m}}df=e,hp=function(v,h){var c=v._chartsMap,p=v._scheduler;h.eachSeries(function(d){p.updateStreamModes(d,c[d.__viewId])})},cp=function(v,h){var c=this,p=this.getModel(),d=v.type,g=v.escapeConnect,y=qv[d],m=(y.update||"update").split(":"),_=m.pop(),S=m[0]!=null&&ua(m[0]);this[fe]=!0,So(this);var x=[v],b=!1;v.batch&&(b=!0,x=U(v.batch,function(R){return R=nt(G({},R),v),R.batch=null,R}));var w=[],T,C=[],M=y.nonRefinedEventType,D=bg(v),I=P1(v);if(I&&xM(this._api),A(x,function(R){var O=y.action(R,p,c._api);if(y.refineEvent?C.push(O):T=O,T=T||G({},R),T.type=M,w.push(T),I){var E=pm(v),B=E.queryOptionMap,V=E.mainTypeSpecified,F=V?B.keys()[0]:"series";pf(c,_,R,F),pr(c)}else D?(pf(c,_,R,"series"),pr(c)):S&&pf(c,_,R,S.main,S.sub)}),_!=="none"&&!I&&!D&&!S)try{this[be]?(ui(this),Da.update.call(this,v),this[be]=null):Da[_].call(this,v)}catch(R){throw this[fe]=!1,R}if(b?T={type:M,escapeConnect:g,batch:w}:T=w[0],this[fe]=!1,!h){var L=void 0;if(y.refineEvent){var P=y.refineEvent(C,v,p,this._api).eventContent;Re(it(P)),L=nt({type:y.refinedEventType},P),L.fromAction=v.type,L.fromActionPayload=v,L.escapeConnect=!0}var k=this._messageCenter;k.trigger(T.type,T),L&&k.trigger(L.type,L)}},mo=function(v){for(var h=this._pendingActions;h.length;){var c=h.shift();cp.call(this,c,v)}},_o=function(v){!v&&this.trigger("updated")},WS=function(v,h){v.on("rendered",function(c){h.trigger("rendered",c),v.animation.isFinished()&&!h[be]&&!h._scheduler.unfinished&&!h._pendingActions.length&&h.trigger("finished")})},US=function(v,h){v.on("mouseover",function(c){var p=c.target,d=Di(p,ql);d&&(NO(d,c,h._api),pr(h))}).on("mouseout",function(c){var p=c.target,d=Di(p,ql);d&&(BO(d,c,h._api),pr(h))}).on("click",function(c){var p=c.target,d=Di(p,function(m){return ut(m).dataIndex!=null},!0);if(d){var g=d.selected?"unselect":"select",y=ut(d);h._api.dispatchAction({type:g,dataType:y.dataType,dataIndexInside:y.dataIndex,seriesIndex:y.seriesIndex,isFromClick:!0})}})};function a(v){v.clearColorPalette(),v.eachSeries(function(h){h.clearColorPalette()})}function n(v){var h=[],c=[],p=!1;if(v.eachComponent(function(m,_){var S=_.get("zlevel")||0,x=_.get("z")||0,b=_.getZLevelKey();p=p||!!b,(m==="series"?c:h).push({zlevel:S,z:x,idx:_.componentIndex,type:m,key:b})}),p){var d=h.concat(c),g,y;tv(d,function(m,_){return m.zlevel===_.zlevel?m.z-_.z:m.zlevel-_.zlevel}),A(d,function(m){var _=v.getComponent(m.type,m.idx),S=m.zlevel,x=m.key;g!=null&&(S=Math.max(g,S)),x?(S===g&&x!==y&&S++,y=x):y&&(S===g&&S++,y=""),g=S,_.setZLevel(S)})}}pp=function(v,h,c,p,d){n(h),YS(v,h,c,p,d),A(v._chartsViews,function(g){g.__alive=!1}),gf(v,h,c,p,d),A(v._chartsViews,function(g){g.__alive||g.remove(h,c)})},YS=function(v,h,c,p,d,g){A(g||v._componentsViews,function(y){var m=y.__model;u(m,y),y.render(m,h,c,p),l(m,y),f(m,y)})},gf=function(v,h,c,p,d,g){var y=v._scheduler;d=G(d||{},{updatedSeries:h.getSeries()}),Nr.trigger("series:beforeupdate",h,c,d);var m=!1;h.eachSeries(function(_){var S=v._chartsMap[_.__viewId];S.__alive=!0;var x=S.renderTask;y.updatePayload(x,p),u(_,S),g&&g.get(_.uid)&&x.dirty(),x.perform(y.getPerformArgs(x))&&(m=!0),S.group.silent=!!_.get("silent"),s(_,S),L1(_)}),y.unfinished=m||y.unfinished,Nr.trigger("series:layoutlabels",h,c,d),Nr.trigger("series:transition",h,c,d),h.eachSeries(function(_){var S=v._chartsMap[_.__viewId];l(_,S),f(_,S)}),o(v,h),Nr.trigger("series:afterupdate",h,c,d)},pr=function(v){v[up]=!0,v.getZr().wakeUp()},So=function(v){v[cf]=(v[cf]+1)%1e3},XS=function(v){v[up]&&(v.getZr().storage.traverse(function(h){Xo(h)||i(h)}),v[up]=!1)};function i(v){for(var h=[],c=v.currentStates,p=0;p<c.length;p++){var d=c[p];d==="emphasis"||d==="blur"||d==="select"||h.push(d)}v.selected&&v.states.select&&h.push("select"),v.hoverState===Xh&&v.states.emphasis?h.push("emphasis"):v.hoverState===Tu&&v.states.blur&&h.push("blur"),v.useStates(h)}function o(v,h){var c=v._zr,p=c.storage,d=0;p.traverse(function(g){g.isGroup||d++}),d>h.get("hoverLayerThreshold")&&!Tt.node&&!Tt.worker&&h.eachSeries(function(g){if(!g.preventUsingHoverLayer){var y=v._chartsMap[g.__viewId];y.__alive&&y.eachRendered(function(m){m.states.emphasis&&(m.states.emphasis.hoverLayer=!0)})}})}function s(v,h){var c=v.get("blendMode")||null;h.eachRendered(function(p){p.isGroup||(p.style.blend=c)})}function l(v,h){if(!v.preventAutoZ){var c=Ui(v);h.eachRendered(function(p){return Kh(p,c.z,c.zlevel),!0})}}function u(v,h){h.eachRendered(function(c){if(!Xo(c)){var p=c.getTextContent(),d=c.getTextGuideLine();c.stateTransition&&(c.stateTransition=null),p&&p.stateTransition&&(p.stateTransition=null),d&&d.stateTransition&&(d.stateTransition=null),c.hasState()?(c.prevStates=c.currentStates,c.clearStates()):c.prevStates&&(c.prevStates=null)}})}function f(v,h){var c=v.getModel("stateAnimation"),p=v.isAnimationEnabled(),d=c.get("duration"),g=d>0?{duration:d,delay:c.get("delay"),easing:c.get("easing")}:null;h.eachRendered(function(y){if(y.states&&y.states.emphasis){if(Xo(y))return;if(y instanceof bt&&UO(y),y.__dirty){var m=y.prevStates;m&&y.useStates(m)}if(p){y.stateTransition=g;var _=y.getTextContent(),S=y.getTextGuideLine();_&&(_.stateTransition=g),S&&(S.stateTransition=g)}y.__dirty&&i(y)}})}ZS=function(v){return new(function(h){z(c,h);function c(){return h!==null&&h.apply(this,arguments)||this}return c.prototype.getCoordinateSystems=function(){return v._coordSysMgr.getCoordinateSystems()},c.prototype.getComponentByElement=function(p){for(;p;){var d=p.__ecComponentInfo;if(d!=null)return v._model.getComponent(d.mainType,d.index);p=p.parent}},c.prototype.enterEmphasis=function(p,d){Xa(p,d),pr(v)},c.prototype.leaveEmphasis=function(p,d){$a(p,d),pr(v)},c.prototype.enterBlur=function(p){yM(p),pr(v)},c.prototype.leaveBlur=function(p){bm(p),pr(v)},c.prototype.enterSelect=function(p){mM(p),pr(v)},c.prototype.leaveSelect=function(p){_M(p),pr(v)},c.prototype.getModel=function(){return v.getModel()},c.prototype.getViewOfComponentModel=function(p){return v.getViewOfComponentModel(p)},c.prototype.getViewOfSeriesModel=function(p){return v.getViewOfSeriesModel(p)},c.prototype.getMainProcessVersion=function(){return v[cf]},c}(mD))(v)},gL=function(v){function h(c,p){for(var d=0;d<c.length;d++){var g=c[d];g[fp]=p}}A(Fg,function(c,p){v._messageCenter.on(p,function(d){if(jv[v.group]&&v[fp]!==HS){if(d&&d.escapeConnect)return;var g=v.makeActionFromEvent(d),y=[];A(Oi,function(m){m!==v&&m.group===v.group&&y.push(m)}),h(y,HS),A(y,function(m){m[fp]!==CV&&m.dispatchAction(g)}),h(y,AV)}})})}}(),t}(Pr),i0=$v.prototype;i0.on=vL("on");i0.off=vL("off");i0.one=function(r,t,e){var a=this;function n(){for(var i=[],o=0;o<arguments.length;o++)i[o]=arguments[o];t&&t.apply&&t.apply(this,i),a.off(r,n)}this.on.call(this,r,n,e)};var MV=["click","dblclick","mouseover","mouseout","mousemove","mousedown","mouseup","globalout","contextmenu"];var qv={},Fg={},Hg={},Wg=[],Ug=[],Kv=[],yL={},Yg={},Oi={},jv={},DV=+new Date-0,LV=+new Date-0,o0="_echarts_instance_";function Sq(r,t,e){var a=!(e&&e.ssr);if(a){var n=mL(r);if(n)return n}var i=new $v(r,t,e);return i.id="ec_"+DV++,Oi[i.id]=i,a&&QA(r,o0,i.id),gL(i),Nr.trigger("afterinit",i),i}function xq(r){if(W(r)){var t=r;r=null,A(t,function(e){e.group!=null&&(r=e.group)}),r=r||"g_"+LV++,A(t,function(e){e.group=r})}return jv[r]=!0,r}function IV(r){jv[r]=!1}var bq=IV;function wq(r){X(r)?r=Oi[r]:r instanceof $v||(r=mL(r)),r instanceof $v&&!r.isDisposed()&&r.dispose()}function mL(r){return Oi[PE(r,o0)]}function Tq(r){return Oi[r]}function _L(r,t){yL[r]=t}function SL(r){gt(Ug,r)<0&&Ug.push(r)}function xL(r,t){l0(Wg,r,t,yV)}function PV(r){s0("afterinit",r)}function RV(r){s0("afterupdate",r)}function s0(r,t){Nr.on(r,t)}function Ta(r,t,e){var a,n,i,o,s;tt(t)&&(e=t,t=""),it(r)?(a=r.type,n=r.event,o=r.update,s=r.publishNonRefinedEvent,e||(e=r.action),i=r.refineEvent):(a=r,n=t);function l(f){return f.toLowerCase()}n=l(n||a);var u=i?l(a):n;qv[a]||(Re(FS.test(a)&&FS.test(n)),i&&Re(n!==a),qv[a]={actionType:a,refinedEventType:n,nonRefinedEventType:u,update:o,action:e,refineEvent:i},Hg[n]=1,i&&s&&(Hg[u]=1),Fg[u]=a)}function kV(r,t){Ts.register(r,t)}function Cq(r){var t=Ts.get(r);if(t)return t.getDimensionsInfo?t.getDimensionsInfo():t.dimensions.slice()}function Aq(r,t){sL(r,t)}function EV(r,t){l0(Kv,r,t,lL,"layout")}function eo(r,t){l0(Kv,r,t,uL,"visual")}var $S=[];function l0(r,t,e,a,n){if((tt(t)||it(t))&&(e=t,t=a),!(gt($S,e)>=0)){$S.push(e);var i=YD.wrapStageHandler(e,n);i.__prio=t,i.__raw=e,r.push(i)}}function bL(r,t){Yg[r]=t}function Mq(r){LR({createCanvas:r})}function OV(r,t,e){var a=iL("registerMap");a&&a(r,t,e)}function Dq(r){var t=iL("getMap");return t&&t(r)}var NV=$B;eo(n0,Sz);eo(rc,xz);eo(rc,bz);eo(n0,Oz);eo(rc,Nz);eo(fL,fV);SL(SD);xL(dV,DB);bL("default",wz);Ta({type:ki,event:ki,update:ki},jt);Ta({type:sv,event:sv,update:sv},jt);Ta({type:Nv,event:Sm,update:Nv,action:jt,refineEvent:u0,publishNonRefinedEvent:!0});Ta({type:mg,event:Sm,update:mg,action:jt,refineEvent:u0,publishNonRefinedEvent:!0});Ta({type:Bv,event:Sm,update:Bv,action:jt,refineEvent:u0,publishNonRefinedEvent:!0});function u0(r,t,e,a){return{eventContent:{selected:VO(e),isFromClick:t.isFromClick||!1}}}_L("default",{});_L("dark",qD);var Lq={},qS=[],BV={registerPreprocessor:SL,registerProcessor:xL,registerPostInit:PV,registerPostUpdate:RV,registerUpdateLifecycle:s0,registerAction:Ta,registerCoordinateSystem:kV,registerLayout:EV,registerVisual:eo,registerTransform:NV,registerLoading:bL,registerMap:OV,registerImpl:vV,PRIORITY:TV,ComponentModel:xt,ComponentView:Wt,SeriesModel:Bt,ChartView:Nt,registerComponentModel:function(r){xt.registerClass(r)},registerComponentView:function(r){Wt.registerClass(r)},registerSeriesModel:function(r){Bt.registerClass(r)},registerChartView:function(r){Nt.registerClass(r)},registerCustomSeries:function(r,t){sL(r,t)},registerSubTypeDefaulter:function(r,t){xt.registerSubTypeDefaulter(r,t)},registerPainter:function(r,t){VA(r,t)}};function mt(r){if(W(r)){A(r,function(t){mt(t)});return}gt(qS,r)>=0||(qS.push(r),tt(r)&&(r={install:r}),r.install(BV))}function Us(r){return r==null?0:r.length||1}function KS(r){return r}var qa=function(){function r(t,e,a,n,i,o){this._old=t,this._new=e,this._oldKeyGetter=a||KS,this._newKeyGetter=n||KS,this.context=i,this._diffModeMultiple=o==="multiple"}return r.prototype.add=function(t){return this._add=t,this},r.prototype.update=function(t){return this._update=t,this},r.prototype.updateManyToOne=function(t){return this._updateManyToOne=t,this},r.prototype.updateOneToMany=function(t){return this._updateOneToMany=t,this},r.prototype.updateManyToMany=function(t){return this._updateManyToMany=t,this},r.prototype.remove=function(t){return this._remove=t,this},r.prototype.execute=function(){this[this._diffModeMultiple?"_executeMultiple":"_executeOneToOne"]()},r.prototype._executeOneToOne=function(){var t=this._old,e=this._new,a={},n=new Array(t.length),i=new Array(e.length);this._initIndexMap(t,null,n,"_oldKeyGetter"),this._initIndexMap(e,a,i,"_newKeyGetter");for(var o=0;o<t.length;o++){var s=n[o],l=a[s],u=Us(l);if(u>1){var f=l.shift();l.length===1&&(a[s]=l[0]),this._update&&this._update(f,o)}else u===1?(a[s]=null,this._update&&this._update(l,o)):this._remove&&this._remove(o)}this._performRestAdd(i,a)},r.prototype._executeMultiple=function(){var t=this._old,e=this._new,a={},n={},i=[],o=[];this._initIndexMap(t,a,i,"_oldKeyGetter"),this._initIndexMap(e,n,o,"_newKeyGetter");for(var s=0;s<i.length;s++){var l=i[s],u=a[l],f=n[l],v=Us(u),h=Us(f);if(v>1&&h===1)this._updateManyToOne&&this._updateManyToOne(f,u),n[l]=null;else if(v===1&&h>1)this._updateOneToMany&&this._updateOneToMany(f,u),n[l]=null;else if(v===1&&h===1)this._update&&this._update(f,u),n[l]=null;else if(v>1&&h>1)this._updateManyToMany&&this._updateManyToMany(f,u),n[l]=null;else if(v>1)for(var c=0;c<v;c++)this._remove&&this._remove(u[c]);else this._remove&&this._remove(u)}this._performRestAdd(o,n)},r.prototype._performRestAdd=function(t,e){for(var a=0;a<t.length;a++){var n=t[a],i=e[n],o=Us(i);if(o>1)for(var s=0;s<o;s++)this._add&&this._add(i[s]);else o===1&&this._add&&this._add(i);e[n]=null}},r.prototype._initIndexMap=function(t,e,a,n){for(var i=this._diffModeMultiple,o=0;o<t.length;o++){var s="_ec_"+this[n](t[o],o);if(i||(a[o]=s),!!e){var l=e[s],u=Us(l);u===0?(e[s]=o,i&&a.push(s)):u===1?e[s]=[l,o]:l.push(o)}}},r}(),zV=function(){function r(t,e){this._encode=t,this._schema=e}return r.prototype.get=function(){return{fullDimensions:this._getFullDimensionNames(),encode:this._encode}},r.prototype._getFullDimensionNames=function(){return this._cachedDimNames||(this._cachedDimNames=this._schema?this._schema.makeOutputDimensionNames():[]),this._cachedDimNames},r}();function VV(r,t){var e={},a=e.encode={},n=j(),i=[],o=[],s={};A(r.dimensions,function(h){var c=r.getDimensionInfo(h),p=c.coordDim;if(p){var d=c.coordDimIndex;dp(a,p)[d]=h,c.isExtraCoord||(n.set(p,1),GV(c.type)&&(i[0]=h),dp(s,p)[d]=r.getDimensionIndex(c.name)),c.defaultTooltip&&o.push(h)}vD.each(function(g,y){var m=dp(a,y),_=c.otherDims[y];_!=null&&_!==!1&&(m[_]=c.name)})});var l=[],u={};n.each(function(h,c){var p=a[c];u[c]=p[0],l=l.concat(p)}),e.dataDimsOnCoord=l,e.dataDimIndicesOnCoord=U(l,function(h){return r.getDimensionInfo(h).storeDimIndex}),e.encodeFirstDimNotExtra=u;var f=a.label;f&&f.length&&(i=f.slice());var v=a.tooltip;return v&&v.length?o=v.slice():o.length||(o=i.slice()),a.defaultedLabel=i,a.defaultedTooltip=o,e.userOutput=new zV(s,t),e}function dp(r,t){return r.hasOwnProperty(t)||(r[t]=[]),r[t]}function Jv(r){return r==="category"?"ordinal":r==="time"?"time":"float"}function GV(r){return!(r==="ordinal"||r==="time")}var pv=function(){function r(t){this.otherDims={},t!=null&&G(this,t)}return r}(),FV=St(),HV={float:"f",int:"i",ordinal:"o",number:"n",time:"t"},wL=function(){function r(t){this.dimensions=t.dimensions,this._dimOmitted=t.dimensionOmitted,this.source=t.source,this._fullDimCount=t.fullDimensionCount,this._updateDimOmitted(t.dimensionOmitted)}return r.prototype.isDimensionOmitted=function(){return this._dimOmitted},r.prototype._updateDimOmitted=function(t){this._dimOmitted=t,t&&(this._dimNameMap||(this._dimNameMap=AL(this.source)))},r.prototype.getSourceDimensionIndex=function(t){return Q(this._dimNameMap.get(t),-1)},r.prototype.getSourceDimension=function(t){var e=this.source.dimensionsDefine;if(e)return e[t]},r.prototype.makeStoreSchema=function(){for(var t=this._fullDimCount,e=bD(this.source),a=!ML(t),n="",i=[],o=0,s=0;o<t;o++){var l=void 0,u=void 0,f=void 0,v=this.dimensions[s];if(v&&v.storeDimIndex===o)l=e?v.name:null,u=v.type,f=v.ordinalMeta,s++;else{var h=this.getSourceDimension(o);h&&(l=e?h.name:null,u=h.type)}i.push({property:l,type:u,ordinalMeta:f}),e&&l!=null&&(!v||!v.isCalculationCoord)&&(n+=a?l.replace(/\`/g,"`1").replace(/\$/g,"`2"):l),n+="$",n+=HV[u]||"f",f&&(n+=f.uid),n+="$"}var c=this.source,p=[c.seriesLayoutBy,c.startIndex,n].join("$$");return{dimensions:i,hash:p}},r.prototype.makeOutputDimensionNames=function(){for(var t=[],e=0,a=0;e<this._fullDimCount;e++){var n=void 0,i=this.dimensions[a];if(i&&i.storeDimIndex===e)i.isCalculationCoord||(n=i.name),a++;else{var o=this.getSourceDimension(e);o&&(n=o.name)}t.push(n)}return t},r.prototype.appendCalculationDimension=function(t){this.dimensions.push(t),t.isCalculationCoord=!0,this._fullDimCount++,this._updateDimOmitted(!0)},r}();function TL(r){return r instanceof wL}function CL(r){for(var t=j(),e=0;e<(r||[]).length;e++){var a=r[e],n=it(a)?a.name:a;n!=null&&t.get(n)==null&&t.set(n,e)}return t}function AL(r){var t=FV(r);return t.dimNameMap||(t.dimNameMap=CL(r.dimensionsDefine))}function ML(r){return r>30}var Ys=it,on=U,WV=typeof Int32Array>"u"?Array:Int32Array,UV="e\0\0",jS=-1,YV=["hasItemOption","_nameList","_idList","_invertedIndicesMap","_dimSummary","userOutput","_rawData","_dimValueGetter","_nameDimIdx","_idDimIdx","_nameRepeatCount"],ZV=["_approximateExtent"],JS,yf,Zs,Xs,gp,$s,yp,Ue=function(){function r(t,e){this.type="list",this._dimOmitted=!1,this._nameList=[],this._idList=[],this._visual={},this._layout={},this._itemVisuals=[],this._itemLayouts=[],this._graphicEls=[],this._approximateExtent={},this._calculationInfo={},this.hasItemOption=!1,this.TRANSFERABLE_METHODS=["cloneShallow","downSample","minmaxDownSample","lttbDownSample","map"],this.CHANGABLE_METHODS=["filterSelf","selectRange"],this.DOWNSAMPLE_METHODS=["downSample","minmaxDownSample","lttbDownSample"];var a,n=!1;TL(t)?(a=t.dimensions,this._dimOmitted=t.isDimensionOmitted(),this._schema=t):(n=!0,a=t),a=a||["x","y"];for(var i={},o=[],s={},l=!1,u={},f=0;f<a.length;f++){var v=a[f],h=X(v)?new pv({name:v}):v instanceof pv?v:new pv(v),c=h.name;h.type=h.type||"float",h.coordDim||(h.coordDim=c,h.coordDimIndex=0);var p=h.otherDims=h.otherDims||{};o.push(c),i[c]=h,u[c]!=null&&(l=!0),h.createInvertedIndices&&(s[c]=[]);var d=f;Mt(h.storeDimIndex)&&(d=h.storeDimIndex),p.itemName===0&&(this._nameDimIdx=d),p.itemId===0&&(this._idDimIdx=d),n&&(h.storeDimIndex=f)}if(this.dimensions=o,this._dimInfos=i,this._initGetDimensionInfo(l),this.hostModel=e,this._invertedIndicesMap=s,this._dimOmitted){var g=this._dimIdxToName=j();A(o,function(y){g.set(i[y].storeDimIndex,y)})}}return r.prototype.getDimension=function(t){var e=this._recognizeDimIndex(t);if(e==null)return t;if(e=t,!this._dimOmitted)return this.dimensions[e];var a=this._dimIdxToName.get(e);if(a!=null)return a;var n=this._schema.getSourceDimension(e);if(n)return n.name},r.prototype.getDimensionIndex=function(t){var e=this._recognizeDimIndex(t);if(e!=null)return e;if(t==null)return-1;var a=this._getDimInfo(t);return a?a.storeDimIndex:this._dimOmitted?this._schema.getSourceDimensionIndex(t):-1},r.prototype._recognizeDimIndex=function(t){if(Mt(t)||t!=null&&!isNaN(t)&&!this._getDimInfo(t)&&(!this._dimOmitted||this._schema.getSourceDimensionIndex(t)<0))return+t},r.prototype._getStoreDimIndex=function(t){var e=this.getDimensionIndex(t);return e},r.prototype.getDimensionInfo=function(t){return this._getDimInfo(this.getDimension(t))},r.prototype._initGetDimensionInfo=function(t){var e=this._dimInfos;this._getDimInfo=t?function(a){return e.hasOwnProperty(a)?e[a]:void 0}:function(a){return e[a]}},r.prototype.getDimensionsOnCoord=function(){return this._dimSummary.dataDimsOnCoord.slice()},r.prototype.mapDimension=function(t,e){var a=this._dimSummary;if(e==null)return a.encodeFirstDimNotExtra[t];var n=a.encode[t];return n?n[e]:null},r.prototype.mapDimensionsAll=function(t){var e=this._dimSummary,a=e.encode[t];return(a||[]).slice()},r.prototype.getStore=function(){return this._store},r.prototype.initData=function(t,e,a){var n=this,i;if(t instanceof Eg&&(i=t),!i){var o=this.dimensions,s=jm(t)||Pe(t)?new wD(t,o.length):t;i=new Eg;var l=on(o,function(u){return{type:n._dimInfos[u].type,property:u}});i.initData(s,l,a)}this._store=i,this._nameList=(e||[]).slice(),this._idList=[],this._nameRepeatCount={},this._doInit(0,i.count()),this._dimSummary=VV(this,this._schema),this.userOutput=this._dimSummary.userOutput},r.prototype.appendData=function(t){var e=this._store.appendData(t);this._doInit(e[0],e[1])},r.prototype.appendValues=function(t,e){var a=this._store.appendValues(t,e&&e.length),n=a.start,i=a.end,o=this._shouldMakeIdFromName();if(this._updateOrdinalMeta(),e)for(var s=n;s<i;s++){var l=s-n;this._nameList[s]=e[l],o&&yp(this,s)}},r.prototype._updateOrdinalMeta=function(){for(var t=this._store,e=this.dimensions,a=0;a<e.length;a++){var n=this._dimInfos[e[a]];n.ordinalMeta&&t.collectOrdinalMeta(n.storeDimIndex,n.ordinalMeta)}},r.prototype._shouldMakeIdFromName=function(){var t=this._store.getProvider();return this._idDimIdx==null&&t.getSource().sourceFormat!==Mn&&!t.fillStorage},r.prototype._doInit=function(t,e){if(!(t>=e)){var a=this._store,n=a.getProvider();this._updateOrdinalMeta();var i=this._nameList,o=this._idList,s=n.getSource().sourceFormat,l=s===hr;if(l&&!n.pure)for(var u=[],f=t;f<e;f++){var v=n.getItem(f,u);if(!this.hasItemOption&&mE(v)&&(this.hasItemOption=!0),v){var h=v.name;i[f]==null&&h!=null&&(i[f]=ve(h,null));var c=v.id;o[f]==null&&c!=null&&(o[f]=ve(c,null))}}if(this._shouldMakeIdFromName())for(var f=t;f<e;f++)yp(this,f);JS(this)}},r.prototype.getApproximateExtent=function(t){return this._approximateExtent[t]||this._store.getDataExtent(this._getStoreDimIndex(t))},r.prototype.setApproximateExtent=function(t,e){e=this.getDimension(e),this._approximateExtent[e]=t.slice()},r.prototype.getCalculationInfo=function(t){return this._calculationInfo[t]},r.prototype.setCalculationInfo=function(t,e){Ys(t)?G(this._calculationInfo,t):this._calculationInfo[t]=e},r.prototype.getName=function(t){var e=this.getRawIndex(t),a=this._nameList[e];return a==null&&this._nameDimIdx!=null&&(a=Zs(this,this._nameDimIdx,e)),a==null&&(a=""),a},r.prototype._getCategory=function(t,e){var a=this._store.get(t,e),n=this._store.getOrdinalMeta(t);return n?n.categories[a]:a},r.prototype.getId=function(t){return yf(this,this.getRawIndex(t))},r.prototype.count=function(){return this._store.count()},r.prototype.get=function(t,e){var a=this._store,n=this._dimInfos[t];if(n)return a.get(n.storeDimIndex,e)},r.prototype.getByRawIndex=function(t,e){var a=this._store,n=this._dimInfos[t];if(n)return a.getByRawIndex(n.storeDimIndex,e)},r.prototype.getIndices=function(){return this._store.getIndices()},r.prototype.getDataExtent=function(t){return this._store.getDataExtent(this._getStoreDimIndex(t))},r.prototype.getSum=function(t){return this._store.getSum(this._getStoreDimIndex(t))},r.prototype.getMedian=function(t){return this._store.getMedian(this._getStoreDimIndex(t))},r.prototype.getValues=function(t,e){var a=this,n=this._store;return W(t)?n.getValues(on(t,function(i){return a._getStoreDimIndex(i)}),e):n.getValues(t)},r.prototype.hasValue=function(t){for(var e=this._dimSummary.dataDimIndicesOnCoord,a=0,n=e.length;a<n;a++)if(isNaN(this._store.get(e[a],t)))return!1;return!0},r.prototype.indexOfName=function(t){for(var e=0,a=this._store.count();e<a;e++)if(this.getName(e)===t)return e;return-1},r.prototype.getRawIndex=function(t){return this._store.getRawIndex(t)},r.prototype.indexOfRawIndex=function(t){return this._store.indexOfRawIndex(t)},r.prototype.rawIndexOf=function(t,e){var a=t&&this._invertedIndicesMap[t],n=a&&a[e];return n==null||isNaN(n)?jS:n},r.prototype.each=function(t,e,a){tt(t)&&(a=e,e=t,t=[]);var n=a||this,i=on(Xs(t),this._getStoreDimIndex,this);this._store.each(i,n?$(e,n):e)},r.prototype.filterSelf=function(t,e,a){tt(t)&&(a=e,e=t,t=[]);var n=a||this,i=on(Xs(t),this._getStoreDimIndex,this);return this._store=this._store.filter(i,n?$(e,n):e),this},r.prototype.selectRange=function(t){var e=this,a={},n=Ct(t);return A(n,function(i){var o=e._getStoreDimIndex(i);a[o]=t[i]}),this._store=this._store.selectRange(a),this},r.prototype.mapArray=function(t,e,a){tt(t)&&(a=e,e=t,t=[]),a=a||this;var n=[];return this.each(t,function(){n.push(e&&e.apply(this,arguments))},a),n},r.prototype.map=function(t,e,a,n){var i=a||n||this,o=on(Xs(t),this._getStoreDimIndex,this),s=$s(this);return s._store=this._store.map(o,i?$(e,i):e),s},r.prototype.modify=function(t,e,a,n){var i=a||n||this,o=on(Xs(t),this._getStoreDimIndex,this);this._store.modify(o,i?$(e,i):e)},r.prototype.downSample=function(t,e,a,n){var i=$s(this);return i._store=this._store.downSample(this._getStoreDimIndex(t),e,a,n),i},r.prototype.minmaxDownSample=function(t,e){var a=$s(this);return a._store=this._store.minmaxDownSample(this._getStoreDimIndex(t),e),a},r.prototype.lttbDownSample=function(t,e){var a=$s(this);return a._store=this._store.lttbDownSample(this._getStoreDimIndex(t),e),a},r.prototype.getRawDataItem=function(t){return this._store.getRawDataItem(t)},r.prototype.getItemModel=function(t){var e=this.hostModel,a=this.getRawDataItem(t);return new wt(a,e,e&&e.ecModel)},r.prototype.diff=function(t){var e=this;return new qa(t?t.getStore().getIndices():[],this.getStore().getIndices(),function(a){return yf(t,a)},function(a){return yf(e,a)})},r.prototype.getVisual=function(t){var e=this._visual;return e&&e[t]},r.prototype.setVisual=function(t,e){this._visual=this._visual||{},Ys(t)?G(this._visual,t):this._visual[t]=e},r.prototype.getItemVisual=function(t,e){var a=this._itemVisuals[t],n=a&&a[e];return n??this.getVisual(e)},r.prototype.hasItemVisual=function(){return this._itemVisuals.length>0},r.prototype.ensureUniqueItemVisual=function(t,e){var a=this._itemVisuals,n=a[t];n||(n=a[t]={});var i=n[e];return i==null&&(i=this.getVisual(e),W(i)?i=i.slice():Ys(i)&&(i=G({},i)),n[e]=i),i},r.prototype.setItemVisual=function(t,e,a){var n=this._itemVisuals[t]||{};this._itemVisuals[t]=n,Ys(e)?G(n,e):n[e]=a},r.prototype.clearAllVisual=function(){this._visual={},this._itemVisuals=[]},r.prototype.setLayout=function(t,e){Ys(t)?G(this._layout,t):this._layout[t]=e},r.prototype.getLayout=function(t){return this._layout[t]},r.prototype.getItemLayout=function(t){return this._itemLayouts[t]},r.prototype.setItemLayout=function(t,e,a){this._itemLayouts[t]=a?G(this._itemLayouts[t]||{},e):e},r.prototype.clearItemLayouts=function(){this._itemLayouts.length=0},r.prototype.setItemGraphicEl=function(t,e){var a=this.hostModel&&this.hostModel.seriesIndex;yg(a,this.dataType,t,e),this._graphicEls[t]=e},r.prototype.getItemGraphicEl=function(t){return this._graphicEls[t]},r.prototype.eachItemGraphicEl=function(t,e){A(this._graphicEls,function(a,n){a&&t&&t.call(e,a,n)})},r.prototype.cloneShallow=function(t){return t||(t=new r(this._schema?this._schema:on(this.dimensions,this._getDimInfo,this),this.hostModel)),gp(t,this),t._store=this._store,t},r.prototype.wrapMethod=function(t,e){var a=this[t];tt(a)&&(this.__wrappedMethods=this.__wrappedMethods||[],this.__wrappedMethods.push(t),this[t]=function(){var n=a.apply(this,arguments);return e.apply(this,[n].concat(Eh(arguments)))})},r.internalField=function(){JS=function(t){var e=t._invertedIndicesMap;A(e,function(a,n){var i=t._dimInfos[n],o=i.ordinalMeta,s=t._store;if(o){a=e[n]=new WV(o.categories.length);for(var l=0;l<a.length;l++)a[l]=jS;for(var l=0;l<s.count();l++)a[s.get(i.storeDimIndex,l)]=l}})},Zs=function(t,e,a){return ve(t._getCategory(e,a),null)},yf=function(t,e){var a=t._idList[e];return a==null&&t._idDimIdx!=null&&(a=Zs(t,t._idDimIdx,e)),a==null&&(a=UV+e),a},Xs=function(t){return W(t)||(t=t!=null?[t]:[]),t},$s=function(t){var e=new r(t._schema?t._schema:on(t.dimensions,t._getDimInfo,t),t.hostModel);return gp(e,t),e},gp=function(t,e){A(YV.concat(e.__wrappedMethods||[]),function(a){e.hasOwnProperty(a)&&(t[a]=e[a])}),t.__wrappedMethods=e.__wrappedMethods,A(ZV,function(a){t[a]=et(e[a])}),t._calculationInfo=G({},e._calculationInfo)},yp=function(t,e){var a=t._nameList,n=t._idList,i=t._nameDimIdx,o=t._idDimIdx,s=a[e],l=n[e];if(s==null&&i!=null&&(a[e]=s=Zs(t,i,e)),l==null&&o!=null&&(n[e]=l=Zs(t,o,e)),l==null&&s!=null){var u=t._nameRepeatCount,f=u[s]=(u[s]||0)+1;l=s,f>1&&(l+="__ec__"+f),n[e]=l}}}(),r}();function XV(r,t){return Ds(r,t).dimensions}function Ds(r,t){jm(r)||(r=Jm(r)),t=t||{};var e=t.coordDimensions||[],a=t.dimensionsDefine||r.dimensionsDefine||[],n=j(),i=[],o=qV(r,e,a,t.dimensionsCount),s=t.canOmitUnusedDimensions&&ML(o),l=a===r.dimensionsDefine,u=l?AL(r):CL(a),f=t.encodeDefine;!f&&t.encodeDefaulter&&(f=t.encodeDefaulter(r,o));for(var v=j(f),h=new PD(o),c=0;c<h.length;c++)h[c]=-1;function p(C){var M=h[C];if(M<0){var D=a[C],I=it(D)?D:{name:D},L=new pv,P=I.name;P!=null&&u.get(P)!=null&&(L.name=L.displayName=P),I.type!=null&&(L.type=I.type),I.displayName!=null&&(L.displayName=I.displayName);var k=i.length;return h[C]=k,L.storeDimIndex=C,i.push(L),L}return i[M]}if(!s)for(var c=0;c<o;c++)p(c);v.each(function(C,M){var D=Ft(C).slice();if(D.length===1&&!X(D[0])&&D[0]<0){v.set(M,!1);return}var I=v.set(M,[]);A(D,function(L,P){var k=X(L)?u.get(L):L;k!=null&&k<o&&(I[P]=k,g(p(k),M,P))})});var d=0;A(e,function(C){var M,D,I,L;if(X(C))M=C,L={};else{L=C,M=L.name;var P=L.ordinalMeta;L.ordinalMeta=null,L=G({},L),L.ordinalMeta=P,D=L.dimsDef,I=L.otherDims,L.name=L.coordDim=L.coordDimIndex=L.dimsDef=L.otherDims=null}var k=v.get(M);if(k!==!1){if(k=Ft(k),!k.length)for(var R=0;R<(D&&D.length||1);R++){for(;d<o&&p(d).coordDim!=null;)d++;d<o&&k.push(d++)}A(k,function(O,E){var B=p(O);if(l&&L.type!=null&&(B.type=L.type),g(nt(B,L),M,E),B.name==null&&D){var V=D[E];!it(V)&&(V={name:V}),B.name=B.displayName=V.name,B.defaultTooltip=V.defaultTooltip}I&&nt(B.otherDims,I)})}});function g(C,M,D){vD.get(M)!=null?C.otherDims[M]=D:(C.coordDim=M,C.coordDimIndex=D,n.set(M,!0))}var y=t.generateCoord,m=t.generateCoordCount,_=m!=null;m=y?m||1:0;var S=y||"value";function x(C){C.name==null&&(C.name=C.coordDim)}if(s)A(i,function(C){x(C)}),i.sort(function(C,M){return C.storeDimIndex-M.storeDimIndex});else for(var b=0;b<o;b++){var w=p(b),T=w.coordDim;T==null&&(w.coordDim=KV(S,n,_),w.coordDimIndex=0,(!y||m<=0)&&(w.isExtraCoord=!0),m--),x(w),w.type==null&&(dD(r,b)===De.Must||w.isExtraCoord&&(w.otherDims.itemName!=null||w.otherDims.seriesName!=null))&&(w.type="ordinal")}return $V(i),new wL({source:r,dimensions:i,fullDimensionCount:o,dimensionOmitted:s})}function $V(r){for(var t=j(),e=0;e<r.length;e++){var a=r[e],n=a.name,i=t.get(n)||0;i>0&&(a.name=n+(i-1)),i++,t.set(n,i)}}function qV(r,t,e,a){var n=Math.max(r.dimensionsDetectedCount||1,t.length,e.length,a||0);return A(t,function(i){var o;it(i)&&(o=i.dimsDef)&&(n=Math.max(n,o.length))}),n}function KV(r,t,e){if(e||t.hasKey(r)){for(var a=0;t.hasKey(r+a);)a++;r+=a}return t.set(r,!0),r}var jV=function(){function r(t){this.coordSysDims=[],this.axisMap=j(),this.categoryAxisMap=j(),this.coordSysName=t}return r}();function JV(r){var t=r.get("coordinateSystem"),e=new jV(t),a=QV[t];if(a)return a(r,e,e.axisMap,e.categoryAxisMap),e}var QV={cartesian2d:function(r,t,e,a){var n=r.getReferringComponents("xAxis",Kt).models[0],i=r.getReferringComponents("yAxis",Kt).models[0];t.coordSysDims=["x","y"],e.set("x",n),e.set("y",i),xo(n)&&(a.set("x",n),t.firstCategoryDimIndex=0),xo(i)&&(a.set("y",i),t.firstCategoryDimIndex==null&&(t.firstCategoryDimIndex=1))},singleAxis:function(r,t,e,a){var n=r.getReferringComponents("singleAxis",Kt).models[0];t.coordSysDims=["single"],e.set("single",n),xo(n)&&(a.set("single",n),t.firstCategoryDimIndex=0)},polar:function(r,t,e,a){var n=r.getReferringComponents("polar",Kt).models[0],i=n.findAxisModel("radiusAxis"),o=n.findAxisModel("angleAxis");t.coordSysDims=["radius","angle"],e.set("radius",i),e.set("angle",o),xo(i)&&(a.set("radius",i),t.firstCategoryDimIndex=0),xo(o)&&(a.set("angle",o),t.firstCategoryDimIndex==null&&(t.firstCategoryDimIndex=1))},geo:function(r,t,e,a){t.coordSysDims=["lng","lat"]},parallel:function(r,t,e,a){var n=r.ecModel,i=n.getComponent("parallel",r.get("parallelIndex")),o=t.coordSysDims=i.dimensions.slice();A(i.parallelAxisIndex,function(s,l){var u=n.getComponent("parallelAxis",s),f=o[l];e.set(f,u),xo(u)&&(a.set(f,u),t.firstCategoryDimIndex==null&&(t.firstCategoryDimIndex=l))})},matrix:function(r,t,e,a){var n=r.getReferringComponents("matrix",Kt).models[0];t.coordSysDims=["x","y"];var i=n.getDimensionModel("x"),o=n.getDimensionModel("y");e.set("x",i),e.set("y",o),a.set("x",i),a.set("y",o)}};function xo(r){return r.get("type")==="category"}function DL(r,t,e){e=e||{};var a=e.byIndex,n=e.stackedCoordDimension,i,o,s;t5(t)?i=t:(o=t.schema,i=o.dimensions,s=t.store);var l=!!(r&&r.get("stack")),u,f,v,h;if(A(i,function(m,_){X(m)&&(i[_]=m={name:m}),l&&!m.isExtraCoord&&(!a&&!u&&m.ordinalMeta&&(u=m),!f&&m.type!=="ordinal"&&m.type!=="time"&&(!n||n===m.coordDim)&&(f=m))}),f&&!a&&!u&&(a=!0),f){v="__\0ecstackresult_"+r.id,h="__\0ecstackedover_"+r.id,u&&(u.createInvertedIndices=!0);var c=f.coordDim,p=f.type,d=0;A(i,function(m){m.coordDim===c&&d++});var g={name:v,coordDim:c,coordDimIndex:d,type:p,isExtraCoord:!0,isCalculationCoord:!0,storeDimIndex:i.length},y={name:h,coordDim:h,coordDimIndex:d+1,type:p,isExtraCoord:!0,isCalculationCoord:!0,storeDimIndex:i.length+1};o?(s&&(g.storeDimIndex=s.ensureCalculationDimension(h,p),y.storeDimIndex=s.ensureCalculationDimension(v,p)),o.appendCalculationDimension(g),o.appendCalculationDimension(y)):(i.push(g),i.push(y))}return{stackedDimension:f&&f.name,stackedByDimension:u&&u.name,isStackedByIndex:a,stackedOverDimension:h,stackResultDimension:v}}function t5(r){return!TL(r.schema)}function Ka(r,t){return!!t&&t===r.getCalculationInfo("stackedDimension")}function f0(r,t){return Ka(r,t)?r.getCalculationInfo("stackResultDimension"):t}function e5(r,t){var e=r.get("coordinateSystem"),a=Ts.get(e),n;return t&&t.coordSysDims&&(n=U(t.coordSysDims,function(i){var o={name:i},s=t.axisMap.get(i);if(s){var l=s.get("type");o.type=Jv(l)}return o})),n||(n=a&&(a.getDimensionsInfo?a.getDimensionsInfo():a.dimensions.slice())||["x","y"]),n}function r5(r,t,e){var a,n;return e&&A(r,function(i,o){var s=i.coordDim,l=e.categoryAxisMap.get(s);l&&(a==null&&(a=o),i.ordinalMeta=l.getOrdinalMeta(),t&&(i.createInvertedIndices=!0)),i.otherDims.itemName!=null&&(n=!0)}),!n&&a!=null&&(r[a].otherDims.itemName=0),a}function Ca(r,t,e){e=e||{};var a=t.getSourceManager(),n,i=!1;r?(i=!0,n=Jm(r)):(n=a.getSource(),i=n.sourceFormat===hr);var o=JV(t),s=e5(t,o),l=e.useEncodeDefaulter,u=tt(l)?l:l?pt(pD,s,t):null,f={coordDimensions:s,generateCoord:e.generateCoord,encodeDefine:t.getEncode(),encodeDefaulter:u,canOmitUnusedDimensions:!i},v=Ds(n,f),h=r5(v.dimensions,e.createInvertedIndices,o),c=i?null:a.getSharedDataStore(v),p=DL(t,{schema:v,store:c}),d=new Ue(v,t);d.setCalculationInfo(p);var g=h!=null&&a5(n)?function(y,m,_,S){return S===h?_:this.defaultDimValueGetter(y,m,_,S)}:null;return d.hasItemOption=!1,d.initData(i?n:c,null,g),d}function a5(r){if(r.sourceFormat===hr){var t=n5(r.data||[]);return!W(ps(t))}}function n5(r){for(var t=0;t<r.length&&r[t]==null;)t++;return r[t]}function Zg(r){return r.type==="interval"||r.type==="log"}function i5(r,t,e,a,n){var i={},o=i.interval=vm(t/e,!0);a!=null&&o<a&&(o=i.interval=a),n!=null&&o>n&&(o=i.interval=n);var s=i.intervalPrecision=au(o),l=i.niceTickExtent=[ae(Math.ceil(r[0]/o)*o,s),ae(Math.floor(r[1]/o)*o,s)];return o5(l,r),i}function mp(r){var t=Math.pow(10,Gh(r)),e=r/t;return e?e===2?e=3:e===3?e=5:e*=2:e=1,ae(e*t)}function au(r){return zr(r)+2}function QS(r,t,e){r[t]=Math.max(Math.min(r[t],e[1]),e[0])}function o5(r,t){!isFinite(r[0])&&(r[0]=t[0]),!isFinite(r[1])&&(r[1]=t[1]),QS(r,0,t),QS(r,1,t),r[0]>r[1]&&(r[0]=r[1])}function v0(r,t){return r>=t[0]&&r<=t[1]}var s5=function(){function r(){this.normalize=tx,this.scale=ex}return r.prototype.updateMethods=function(t){t.hasBreaks()?(this.normalize=$(t.normalize,t),this.scale=$(t.scale,t)):(this.normalize=tx,this.scale=ex)},r}();function tx(r,t){return t[1]===t[0]?.5:(r-t[0])/(t[1]-t[0])}function ex(r,t){return r*(t[1]-t[0])+t[0]}function Xg(r,t,e){var a=Math.log(r);return[Math.log(e?t[0]:Math.max(0,t[0]))/a,Math.log(e?t[1]:Math.max(0,t[1]))/a]}var Gn=function(){function r(t){this._calculator=new s5,this._setting=t||{},this._extent=[1/0,-1/0];var e=se();e&&(this._brkCtx=e.createScaleBreakContext(),this._brkCtx.update(this._extent))}return r.prototype.getSetting=function(t){return this._setting[t]},r.prototype._innerUnionExtent=function(t){var e=this._extent;this._innerSetExtent(t[0]<e[0]?t[0]:e[0],t[1]>e[1]?t[1]:e[1])},r.prototype.unionExtentFromData=function(t,e){this._innerUnionExtent(t.getApproximateExtent(e))},r.prototype.getExtent=function(){return this._extent.slice()},r.prototype.setExtent=function(t,e){this._innerSetExtent(t,e)},r.prototype._innerSetExtent=function(t,e){var a=this._extent;isNaN(t)||(a[0]=t),isNaN(e)||(a[1]=e),this._brkCtx&&this._brkCtx.update(a)},r.prototype.setBreaksFromOption=function(t){var e=se();e&&this._innerSetBreak(e.parseAxisBreakOption(t,$(this.parse,this)))},r.prototype._innerSetBreak=function(t){this._brkCtx&&(this._brkCtx.setBreaks(t),this._calculator.updateMethods(this._brkCtx),this._brkCtx.update(this._extent))},r.prototype._innerGetBreaks=function(){return this._brkCtx?this._brkCtx.breaks:[]},r.prototype.hasBreaks=function(){return this._brkCtx?this._brkCtx.hasBreaks():!1},r.prototype._getExtentSpanWithBreaks=function(){return this._brkCtx&&this._brkCtx.hasBreaks()?this._brkCtx.getExtentSpan():this._extent[1]-this._extent[0]},r.prototype.isInExtentRange=function(t){return this._extent[0]<=t&&this._extent[1]>=t},r.prototype.isBlank=function(){return this._isBlank},r.prototype.setBlank=function(t){this._isBlank=t},r}();Fh(Gn);var l5=0,nu=function(){function r(t){this.categories=t.categories||[],this._needCollect=t.needCollect,this._deduplication=t.deduplication,this.uid=++l5,this._onCollect=t.onCollect}return r.createByAxisModel=function(t){var e=t.option,a=e.data,n=a&&U(a,u5);return new r({categories:n,needCollect:!n,deduplication:e.dedplication!==!1})},r.prototype.getOrdinal=function(t){return this._getOrCreateMap().get(t)},r.prototype.parseAndCollect=function(t){var e,a=this._needCollect;if(!X(t)&&!a)return t;if(a&&!this._deduplication)return e=this.categories.length,this.categories[e]=t,this._onCollect&&this._onCollect(t,e),e;var n=this._getOrCreateMap();return e=n.get(t),e==null&&(a?(e=this.categories.length,this.categories[e]=t,n.set(t,e),this._onCollect&&this._onCollect(t,e)):e=NaN),e},r.prototype._getOrCreateMap=function(){return this._map||(this._map=j(this.categories))},r}();function u5(r){return it(r)&&r.value!=null?r.value:r+""}var is=function(r){z(t,r);function t(e){var a=r.call(this,e)||this;a.type="ordinal";var n=a.getSetting("ordinalMeta");return n||(n=new nu({})),W(n)&&(n=new nu({categories:U(n,function(i){return it(i)?i.value:i})})),a._ordinalMeta=n,a._extent=a.getSetting("extent")||[0,n.categories.length-1],a}return t.prototype.parse=function(e){return e==null?NaN:X(e)?this._ordinalMeta.getOrdinal(e):Math.round(e)},t.prototype.contain=function(e){return v0(e,this._extent)&&e>=0&&e<this._ordinalMeta.categories.length},t.prototype.normalize=function(e){return e=this._getTickNumber(e),this._calculator.normalize(e,this._extent)},t.prototype.scale=function(e){return e=Math.round(this._calculator.scale(e,this._extent)),this.getRawOrdinalNumber(e)},t.prototype.getTicks=function(){for(var e=[],a=this._extent,n=a[0];n<=a[1];)e.push({value:n}),n++;return e},t.prototype.getMinorTicks=function(e){},t.prototype.setSortInfo=function(e){if(e==null){this._ordinalNumbersByTick=this._ticksByOrdinalNumber=null;return}for(var a=e.ordinalNumbers,n=this._ordinalNumbersByTick=[],i=this._ticksByOrdinalNumber=[],o=0,s=this._ordinalMeta.categories.length,l=Math.min(s,a.length);o<l;++o){var u=a[o];n[o]=u,i[u]=o}for(var f=0;o<s;++o){for(;i[f]!=null;)f++;n.push(f),i[f]=o}},t.prototype._getTickNumber=function(e){var a=this._ticksByOrdinalNumber;return a&&e>=0&&e<a.length?a[e]:e},t.prototype.getRawOrdinalNumber=function(e){var a=this._ordinalNumbersByTick;return a&&e>=0&&e<a.length?a[e]:e},t.prototype.getLabel=function(e){if(!this.isBlank()){var a=this.getRawOrdinalNumber(e.value),n=this._ordinalMeta.categories[a];return n==null?"":n+""}},t.prototype.count=function(){return this._extent[1]-this._extent[0]+1},t.prototype.isInExtentRange=function(e){return e=this._getTickNumber(e),this._extent[0]<=e&&this._extent[1]>=e},t.prototype.getOrdinalMeta=function(){return this._ordinalMeta},t.prototype.calcNiceTicks=function(){},t.prototype.calcNiceExtent=function(){},t.type="ordinal",t}(Gn);Gn.registerClass(is);var sn=ae,ja=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="interval",e._interval=0,e._intervalPrecision=2,e}return t.prototype.parse=function(e){return e==null||e===""?NaN:Number(e)},t.prototype.contain=function(e){return v0(e,this._extent)},t.prototype.normalize=function(e){return this._calculator.normalize(e,this._extent)},t.prototype.scale=function(e){return this._calculator.scale(e,this._extent)},t.prototype.getInterval=function(){return this._interval},t.prototype.setInterval=function(e){this._interval=e,this._niceExtent=this._extent.slice(),this._intervalPrecision=au(e)},t.prototype.getTicks=function(e){e=e||{};var a=this._interval,n=this._extent,i=this._niceExtent,o=this._intervalPrecision,s=se(),l=[];if(!a)return l;if(e.breakTicks==="only_break"&&s)return s.addBreaksToTicks(l,this._brkCtx.breaks,this._extent),l;var u=1e4;n[0]<i[0]&&(e.expandToNicedExtent?l.push({value:sn(i[0]-a,o)}):l.push({value:n[0]}));for(var f=function(p,d){return Math.round((d-p)/a)},v=i[0];v<=i[1];){if(l.push({value:v}),v=sn(v+a,o),this._brkCtx){var h=this._brkCtx.calcNiceTickMultiple(v,f);h>=0&&(v=sn(v+h*a,o))}if(l.length>0&&v===l[l.length-1].value)break;if(l.length>u)return[]}var c=l.length?l[l.length-1].value:i[1];return n[1]>c&&(e.expandToNicedExtent?l.push({value:sn(c+a,o)}):l.push({value:n[1]})),s&&s.pruneTicksByBreak(e.pruneByBreak,l,this._brkCtx.breaks,function(p){return p.value},this._interval,this._extent),e.breakTicks!=="none"&&s&&s.addBreaksToTicks(l,this._brkCtx.breaks,this._extent),l},t.prototype.getMinorTicks=function(e){for(var a=this.getTicks({expandToNicedExtent:!0}),n=[],i=this.getExtent(),o=1;o<a.length;o++){var s=a[o],l=a[o-1];if(!(l.break||s.break)){for(var u=0,f=[],v=s.value-l.value,h=v/e,c=au(h);u<e-1;){var p=sn(l.value+(u+1)*h,c);p>i[0]&&p<i[1]&&f.push(p),u++}var d=se();d&&d.pruneTicksByBreak("auto",f,this._getNonTransBreaks(),function(g){return g},this._interval,i),n.push(f)}}return n},t.prototype._getNonTransBreaks=function(){return this._brkCtx?this._brkCtx.breaks:[]},t.prototype.getLabel=function(e,a){if(e==null)return"";var n=a&&a.precision;n==null?n=zr(e.value)||0:n==="auto"&&(n=this._intervalPrecision);var i=sn(e.value,n,!0);return Wm(i)},t.prototype.calcNiceTicks=function(e,a,n){e=e||5;var i=this._extent.slice(),o=this._getExtentSpanWithBreaks();if(isFinite(o)){o<0&&(o=-o,i.reverse(),this._innerSetExtent(i[0],i[1]),i=this._extent.slice());var s=i5(i,o,e,a,n);this._intervalPrecision=s.intervalPrecision,this._interval=s.interval,this._niceExtent=s.niceTickExtent}},t.prototype.calcNiceExtent=function(e){var a=this._extent.slice();if(a[0]===a[1])if(a[0]!==0){var n=Math.abs(a[0]);e.fixMax||(a[1]+=n/2),a[0]-=n/2}else a[1]=1;var i=a[1]-a[0];isFinite(i)||(a[0]=0,a[1]=1),this._innerSetExtent(a[0],a[1]),a=this._extent.slice(),this.calcNiceTicks(e.splitNumber,e.minInterval,e.maxInterval);var o=this._interval,s=this._intervalPrecision;e.fixMin||(a[0]=sn(Math.floor(a[0]/o)*o,s)),e.fixMax||(a[1]=sn(Math.ceil(a[1]/o)*o,s)),this._innerSetExtent(a[0],a[1])},t.prototype.setNiceExtent=function(e,a){this._niceExtent=[e,a]},t.type="interval",t}(Gn);Gn.registerClass(ja);var LL=typeof Float32Array<"u",f5=LL?Float32Array:Array;function fa(r){return W(r)?LL?new Float32Array(r):r:new f5(r)}var $g="__ec_stack_";function IL(r){return r.get("stack")||$g+r.seriesIndex}function h0(r){return r.dim+r.index}function v5(r){var t=[],e=r.axis,a="axis0";if(e.type==="category"){for(var n=e.getBandWidth(),i=0;i<r.count;i++)t.push(nt({bandWidth:n,axisKey:a,stackId:$g+i},r));for(var o=kL(t),s=[],i=0;i<r.count;i++){var l=o[a][$g+i];l.offsetCenter=l.offset+l.width/2,s.push(l)}return s}}function PL(r,t){var e=[];return t.eachSeriesByType(r,function(a){NL(a)&&e.push(a)}),e}function h5(r){var t={};A(r,function(l){var u=l.coordinateSystem,f=u.getBaseAxis();if(!(f.type!=="time"&&f.type!=="value"))for(var v=l.getData(),h=f.dim+"_"+f.index,c=v.getDimensionIndex(v.mapDimension(f.dim)),p=v.getStore(),d=0,g=p.count();d<g;++d){var y=p.get(c,d);t[h]?t[h].push(y):t[h]=[y]}});var e={};for(var a in t)if(t.hasOwnProperty(a)){var n=t[a];if(n){n.sort(function(l,u){return l-u});for(var i=null,o=1;o<n.length;++o){var s=n[o]-n[o-1];s>0&&(i=i===null?s:Math.min(i,s))}e[a]=i}}return e}function RL(r){var t=h5(r),e=[];return A(r,function(a){var n=a.coordinateSystem,i=n.getBaseAxis(),o=i.getExtent(),s;if(i.type==="category")s=i.getBandWidth();else if(i.type==="value"||i.type==="time"){var l=i.dim+"_"+i.index,u=t[l],f=Math.abs(o[1]-o[0]),v=i.scale.getExtent(),h=Math.abs(v[1]-v[0]);s=u?f/h*u:f}else{var c=a.getData();s=Math.abs(o[1]-o[0])/c.count()}var p=Z(a.get("barWidth"),s),d=Z(a.get("barMaxWidth"),s),g=Z(a.get("barMinWidth")||(BL(a)?.5:1),s),y=a.get("barGap"),m=a.get("barCategoryGap"),_=a.get("defaultBarGap");e.push({bandWidth:s,barWidth:p,barMaxWidth:d,barMinWidth:g,barGap:y,barCategoryGap:m,defaultBarGap:_,axisKey:h0(i),stackId:IL(a)})}),kL(e)}function kL(r){var t={};A(r,function(a,n){var i=a.axisKey,o=a.bandWidth,s=t[i]||{bandWidth:o,remainedWidth:o,autoWidthCount:0,categoryGap:null,gap:a.defaultBarGap||0,stacks:{}},l=s.stacks;t[i]=s;var u=a.stackId;l[u]||s.autoWidthCount++,l[u]=l[u]||{width:0,maxWidth:0};var f=a.barWidth;f&&!l[u].width&&(l[u].width=f,f=Math.min(s.remainedWidth,f),s.remainedWidth-=f);var v=a.barMaxWidth;v&&(l[u].maxWidth=v);var h=a.barMinWidth;h&&(l[u].minWidth=h);var c=a.barGap;c!=null&&(s.gap=c);var p=a.barCategoryGap;p!=null&&(s.categoryGap=p)});var e={};return A(t,function(a,n){e[n]={};var i=a.stacks,o=a.bandWidth,s=a.categoryGap;if(s==null){var l=Ct(i).length;s=Math.max(35-l*4,15)+"%"}var u=Z(s,o),f=Z(a.gap,1),v=a.remainedWidth,h=a.autoWidthCount,c=(v-u)/(h+(h-1)*f);c=Math.max(c,0),A(i,function(y){var m=y.maxWidth,_=y.minWidth;if(y.width){var S=y.width;m&&(S=Math.min(S,m)),_&&(S=Math.max(S,_)),y.width=S,v-=S+f*S,h--}else{var S=c;m&&m<S&&(S=Math.min(m,v)),_&&_>S&&(S=_),S!==c&&(y.width=S,v-=S+f*S,h--)}}),c=(v-u)/(h+(h-1)*f),c=Math.max(c,0);var p=0,d;A(i,function(y,m){y.width||(y.width=c),d=y,p+=y.width*(1+f)}),d&&(p-=d.width*f);var g=-p/2;A(i,function(y,m){e[n][m]=e[n][m]||{bandWidth:o,offset:g,width:y.width},g+=y.width*(1+f)})}),e}function c5(r,t,e){if(r&&t){var a=r[h0(t)];return a}}function EL(r,t){var e=PL(r,t),a=RL(e);A(e,function(n){var i=n.getData(),o=n.coordinateSystem,s=o.getBaseAxis(),l=IL(n),u=a[h0(s)][l],f=u.offset,v=u.width;i.setLayout({bandWidth:u.bandWidth,offset:f,size:v})})}function OL(r){return{seriesType:r,plan:Cs(),reset:function(t){if(NL(t)){var e=t.getData(),a=t.coordinateSystem,n=a.getBaseAxis(),i=a.getOtherAxis(n),o=e.getDimensionIndex(e.mapDimension(i.dim)),s=e.getDimensionIndex(e.mapDimension(n.dim)),l=t.get("showBackground",!0),u=e.mapDimension(i.dim),f=e.getCalculationInfo("stackResultDimension"),v=Ka(e,u)&&!!e.getCalculationInfo("stackedOnSeries"),h=i.isHorizontal(),c=p5(n,i),p=BL(t),d=t.get("barMinHeight")||0,g=f&&e.getDimensionIndex(f),y=e.getLayout("size"),m=e.getLayout("offset");return{progress:function(_,S){for(var x=_.count,b=p&&fa(x*3),w=p&&l&&fa(x*3),T=p&&fa(x),C=a.master.getRect(),M=h?C.width:C.height,D,I=S.getStore(),L=0;(D=_.next())!=null;){var P=I.get(v?g:o,D),k=I.get(s,D),R=c,O=void 0;v&&(O=+P-I.get(o,D));var E=void 0,B=void 0,V=void 0,F=void 0;if(h){var H=a.dataToPoint([P,k]);if(v){var Y=a.dataToPoint([O,k]);R=Y[0]}E=R,B=H[1]+m,V=H[0]-R,F=y,Math.abs(V)<d&&(V=(V<0?-1:1)*d)}else{var H=a.dataToPoint([k,P]);if(v){var Y=a.dataToPoint([k,O]);R=Y[1]}E=H[0]+m,B=R,V=y,F=H[1]-R,Math.abs(F)<d&&(F=(F<=0?-1:1)*d)}p?(b[L]=E,b[L+1]=B,b[L+2]=h?V:F,w&&(w[L]=h?C.x:E,w[L+1]=h?B:C.y,w[L+2]=M),T[D]=D):S.setItemLayout(D,{x:E,y:B,width:V,height:F}),L+=3}p&&S.setLayout({largePoints:b,largeDataIndices:T,largeBackgroundPoints:w,valueAxisHorizontal:h})}}}}}}function NL(r){return r.coordinateSystem&&r.coordinateSystem.type==="cartesian2d"}function BL(r){return r.pipelineContext&&r.pipelineContext.large}function p5(r,t){var e=t.model.get("startValue");return e||(e=0),t.toGlobalCoord(t.dataToCoord(t.type==="log"?e>0?e:1:e))}var d5=function(r,t,e,a){for(;e<a;){var n=e+a>>>1;r[n][1]<t?e=n+1:a=n}return e},c0=function(r){z(t,r);function t(e){var a=r.call(this,e)||this;return a.type="time",a}return t.prototype.getLabel=function(e){var a=this.getSetting("useUTC");return Lu(e.value,Z1[HN(Ol(this._minLevelUnit))]||Z1.second,a,this.getSetting("locale"))},t.prototype.getFormattedLabel=function(e,a,n){var i=this.getSetting("useUTC"),o=this.getSetting("locale");return WN(e,a,n,o,i)},t.prototype.getTicks=function(e){e=e||{};var a=this._interval,n=this._extent,i=se(),o=[];if(!a)return o;var s=this.getSetting("useUTC");if(i&&e.breakTicks==="only_break")return se().addBreaksToTicks(o,this._brkCtx.breaks,this._extent),o;var l=Fo(n[1],s);o.push({value:n[0],time:{level:0,upperTimeUnit:l,lowerTimeUnit:l}});var u=b5(this._minLevelUnit,this._approxInterval,s,n,this._getExtentSpanWithBreaks(),this._brkCtx);o=o.concat(u);var f=Fo(n[1],s);o.push({value:n[1],time:{level:0,upperTimeUnit:f,lowerTimeUnit:f}});var v=this.getSetting("useUTC"),h=ar.length-1,c=0;return A(o,function(p){h=Math.min(h,gt(ar,p.time.upperTimeUnit)),c=Math.max(c,p.time.level)}),i&&se().pruneTicksByBreak(e.pruneByBreak,o,this._brkCtx.breaks,function(p){return p.value},this._approxInterval,this._extent),i&&e.breakTicks!=="none"&&se().addBreaksToTicks(o,this._brkCtx.breaks,this._extent,function(p){for(var d=Math.max(gt(ar,Fo(p.vmin,v)),gt(ar,Fo(p.vmax,v))),g=0,y=0;y<ar.length;y++)if(!zL(ar[y],p.vmin,p.vmax,v)){g=y;break}var m=Math.min(g,h),_=Math.max(m,d);return{level:c,lowerTimeUnit:ar[_],upperTimeUnit:ar[m]}}),o},t.prototype.calcNiceExtent=function(e){var a=this.getExtent();if(a[0]===a[1]&&(a[0]-=Tr,a[1]+=Tr),a[1]===-1/0&&a[0]===1/0){var n=new Date;a[1]=+new Date(n.getFullYear(),n.getMonth(),n.getDate()),a[0]=a[1]-Tr}this._innerSetExtent(a[0],a[1]),this.calcNiceTicks(e.splitNumber,e.minInterval,e.maxInterval)},t.prototype.calcNiceTicks=function(e,a,n){e=e||10;var i=this._getExtentSpanWithBreaks();this._approxInterval=i/e,a!=null&&this._approxInterval<a&&(this._approxInterval=a),n!=null&&this._approxInterval>n&&(this._approxInterval=n);var o=mf.length,s=Math.min(d5(mf,this._approxInterval,0,o),o-1);this._interval=mf[s][1],this._intervalPrecision=au(this._interval),this._minLevelUnit=mf[Math.max(s-1,0)][0]},t.prototype.parse=function(e){return Mt(e)?e:+ba(e)},t.prototype.contain=function(e){return v0(e,this._extent)},t.prototype.normalize=function(e){return this._calculator.normalize(e,this._extent)},t.prototype.scale=function(e){return this._calculator.scale(e,this._extent)},t.type="time",t}(ja),mf=[["second",Om],["minute",Nm],["hour",El],["quarter-day",El*6],["half-day",El*12],["day",Tr*1.2],["half-week",Tr*3.5],["week",Tr*7],["month",Tr*31],["quarter",Tr*95],["half-year",Y1/2],["year",Y1]];function zL(r,t,e,a){return Fv(new Date(t),r,a).getTime()===Fv(new Date(e),r,a).getTime()}function g5(r,t){return r/=Tr,r>16?16:r>7.5?7:r>3.5?4:r>1.5?2:1}function y5(r){var t=30*Tr;return r/=t,r>6?6:r>3?3:r>2?2:1}function m5(r){return r/=El,r>12?12:r>6?6:r>3.5?4:r>2?2:1}function rx(r,t){return r/=t?Nm:Om,r>30?30:r>20?20:r>15?15:r>10?10:r>5?5:r>2?2:1}function _5(r){return vm(r,!0)}function S5(r,t,e){var a=Math.max(0,gt(ar,t)-1);return Fv(new Date(r),ar[a],e).getTime()}function x5(r,t){var e=new Date(0);e[r](1);var a=e.getTime();e[r](1+t);var n=e.getTime()-a;return function(i,o){return Math.max(0,Math.round((o-i)/n))}}function b5(r,t,e,a,n,i){var o=1e4,s=zN,l=0;function u(L,P,k,R,O,E,B){for(var V=x5(O,L),F=P,H=new Date(F);F<k&&F<=a[1]&&(B.push({value:F}),!(l++>o));)if(H[O](H[R]()+L),F=H.getTime(),i){var Y=i.calcNiceTickMultiple(F,V);Y>0&&(H[O](H[R]()+Y*L),F=H.getTime())}B.push({value:F,notAdd:!0})}function f(L,P,k){var R=[],O=!P.length;if(!zL(Ol(L),a[0],a[1],e)){O&&(P=[{value:S5(a[0],L,e)},{value:a[1]}]);for(var E=0;E<P.length-1;E++){var B=P[E].value,V=P[E+1].value;if(B!==V){var F=void 0,H=void 0,Y=void 0,K=!1;switch(L){case"year":F=Math.max(1,Math.round(t/Tr/365)),H=XM(e),Y=UN(e);break;case"half-year":case"quarter":case"month":F=y5(t),H=Bm(e),Y=$M(e);break;case"week":case"half-week":case"day":F=g5(t),H=zm(e),Y=qM(e),K=!0;break;case"half-day":case"quarter-day":case"hour":F=m5(t),H=Vm(e),Y=KM(e);break;case"minute":F=rx(t,!0),H=Gm(e),Y=jM(e);break;case"second":F=rx(t,!1),H=Fm(e),Y=JM(e);break;case"millisecond":F=_5(t),H=Hm(e),Y=QM(e);break}V>=a[0]&&B<=a[1]&&u(F,B,V,H,Y,K,R),L==="year"&&k.length>1&&E===0&&k.unshift({value:k[0].value-F})}}for(var E=0;E<R.length;E++)k.push(R[E])}}for(var v=[],h=[],c=0,p=0,d=0;d<s.length;++d){var g=Ol(s[d]);if(FN(s[d])){f(s[d],v[v.length-1]||[],h);var y=s[d+1]?Ol(s[d+1]):null;if(g!==y){if(h.length){p=c,h.sort(function(L,P){return L.value-P.value});for(var m=[],_=0;_<h.length;++_){var S=h[_].value;(_===0||h[_-1].value!==S)&&(m.push(h[_]),S>=a[0]&&S<=a[1]&&c++)}var x=n/t;if(c>x*1.5&&p>x/1.5||(v.push(m),c>x||r===s[d]))break}h=[]}}}for(var b=Pt(U(v,function(L){return Pt(L,function(P){return P.value>=a[0]&&P.value<=a[1]&&!P.notAdd})}),function(L){return L.length>0}),w=[],T=b.length-1,d=0;d<b.length;++d)for(var C=b[d],M=0;M<C.length;++M){var D=Fo(C[M].value,e);w.push({value:C[M].value,time:{level:T-d,upperTimeUnit:D,lowerTimeUnit:D}})}w.sort(function(L,P){return L.value-P.value});for(var I=[],d=0;d<w.length;++d)(d===0||w[d].value!==w[d-1].value)&&I.push(w[d]);return I}Gn.registerClass(c0);var qg=ae,w5=Math.floor,T5=Math.ceil,_f=Math.pow,Sf=Math.log,VL=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="log",e.base=10,e._originalScale=new ja,e}return t.prototype.getTicks=function(e){e=e||{};var a=this._extent.slice(),n=this._originalScale.getExtent(),i=r.prototype.getTicks.call(this,e),o=this.base,s=this._originalScale._innerGetBreaks(),l=se();return U(i,function(u){var f=u.value,v=null,h=_f(o,f);f===a[0]&&this._fixMin?v=n[0]:f===a[1]&&this._fixMax&&(v=n[1]);var c;if(l){var p=l.getTicksLogTransformBreak(u,o,s,xf);c=p.vBreak,v==null&&(v=p.brkRoundingCriterion)}return v!=null&&(h=xf(h,v)),{value:h,break:c}},this)},t.prototype._getNonTransBreaks=function(){return this._originalScale._innerGetBreaks()},t.prototype.setExtent=function(e,a){this._originalScale.setExtent(e,a);var n=Xg(this.base,[e,a]);r.prototype.setExtent.call(this,n[0],n[1])},t.prototype.getExtent=function(){var e=this.base,a=r.prototype.getExtent.call(this);a[0]=_f(e,a[0]),a[1]=_f(e,a[1]);var n=this._originalScale.getExtent();return this._fixMin&&(a[0]=xf(a[0],n[0])),this._fixMax&&(a[1]=xf(a[1],n[1])),a},t.prototype.unionExtentFromData=function(e,a){this._originalScale.unionExtentFromData(e,a);var n=Xg(this.base,e.getApproximateExtent(a),!0);this._innerUnionExtent(n)},t.prototype.calcNiceTicks=function(e){e=e||10;var a=this._extent.slice(),n=this._getExtentSpanWithBreaks();if(!(!isFinite(n)||n<=0)){var i=YA(n),o=e/n*i;for(o<=.5&&(i*=10);!isNaN(i)&&Math.abs(i)<1&&Math.abs(i)>0;)i*=10;var s=[qg(T5(a[0]/i)*i),qg(w5(a[1]/i)*i)];this._interval=i,this._intervalPrecision=au(i),this._niceExtent=s}},t.prototype.calcNiceExtent=function(e){r.prototype.calcNiceExtent.call(this,e),this._fixMin=e.fixMin,this._fixMax=e.fixMax},t.prototype.contain=function(e){return e=Sf(e)/Sf(this.base),r.prototype.contain.call(this,e)},t.prototype.normalize=function(e){return e=Sf(e)/Sf(this.base),r.prototype.normalize.call(this,e)},t.prototype.scale=function(e){return e=r.prototype.scale.call(this,e),_f(this.base,e)},t.prototype.setBreaksFromOption=function(e){var a=se();if(a){var n=a.logarithmicParseBreaksFromOption(e,this.base,$(this.parse,this)),i=n.parsedOriginal,o=n.parsedLogged;this._originalScale._innerSetBreak(i),this._innerSetBreak(o)}},t.type="log",t}(ja);function xf(r,t){return qg(r,zr(t))}Gn.registerClass(VL);var C5=function(){function r(t,e,a){this._prepareParams(t,e,a)}return r.prototype._prepareParams=function(t,e,a){a[1]<a[0]&&(a=[NaN,NaN]),this._dataMin=a[0],this._dataMax=a[1];var n=this._isOrdinal=t.type==="ordinal";this._needCrossZero=t.type==="interval"&&e.getNeedCrossZero&&e.getNeedCrossZero();var i=e.get("min",!0);i==null&&(i=e.get("startValue",!0));var o=this._modelMinRaw=i;tt(o)?this._modelMinNum=bf(t,o({min:a[0],max:a[1]})):o!=="dataMin"&&(this._modelMinNum=bf(t,o));var s=this._modelMaxRaw=e.get("max",!0);if(tt(s)?this._modelMaxNum=bf(t,s({min:a[0],max:a[1]})):s!=="dataMax"&&(this._modelMaxNum=bf(t,s)),n)this._axisDataLen=e.getCategories().length;else{var l=e.get("boundaryGap"),u=W(l)?l:[l||0,l||0];typeof u[0]=="boolean"||typeof u[1]=="boolean"?this._boundaryGapInner=[0,0]:this._boundaryGapInner=[Yr(u[0],1),Yr(u[1],1)]}},r.prototype.calculate=function(){var t=this._isOrdinal,e=this._dataMin,a=this._dataMax,n=this._axisDataLen,i=this._boundaryGapInner,o=t?null:a-e||Math.abs(e),s=this._modelMinRaw==="dataMin"?e:this._modelMinNum,l=this._modelMaxRaw==="dataMax"?a:this._modelMaxNum,u=s!=null,f=l!=null;s==null&&(s=t?n?0:NaN:e-i[0]*o),l==null&&(l=t?n?n-1:NaN:a+i[1]*o),(s==null||!isFinite(s))&&(s=NaN),(l==null||!isFinite(l))&&(l=NaN);var v=Ie(s)||Ie(l)||t&&!n;this._needCrossZero&&(s>0&&l>0&&!u&&(s=0),s<0&&l<0&&!f&&(l=0));var h=this._determinedMin,c=this._determinedMax;return h!=null&&(s=h,u=!0),c!=null&&(l=c,f=!0),{min:s,max:l,minFixed:u,maxFixed:f,isBlank:v}},r.prototype.modifyDataMinMax=function(t,e){this[M5[t]]=e},r.prototype.setDeterminedMinMax=function(t,e){var a=A5[t];this[a]=e},r.prototype.freeze=function(){this.frozen=!0},r}(),A5={min:"_determinedMin",max:"_determinedMax"},M5={min:"_dataMin",max:"_dataMax"};function GL(r,t,e){var a=r.rawExtentInfo;return a||(a=new C5(r,t,e),r.rawExtentInfo=a,a)}function bf(r,t){return t==null?null:Ie(t)?NaN:r.parse(t)}function FL(r,t){var e=r.type,a=GL(r,t,r.getExtent()).calculate();r.setBlank(a.isBlank);var n=a.min,i=a.max,o=t.ecModel;if(o&&e==="time"){var s=PL("bar",o),l=!1;if(A(s,function(v){l=l||v.getBaseAxis()===t.axis}),l){var u=RL(s),f=D5(n,i,t,u);n=f.min,i=f.max}}return{extent:[n,i],fixMin:a.minFixed,fixMax:a.maxFixed}}function D5(r,t,e,a){var n=e.axis.getExtent(),i=Math.abs(n[1]-n[0]),o=c5(a,e.axis);if(o===void 0)return{min:r,max:t};var s=1/0;A(o,function(c){s=Math.min(c.offset,s)});var l=-1/0;A(o,function(c){l=Math.max(c.offset+c.width,l)}),s=Math.abs(s),l=Math.abs(l);var u=s+l,f=t-r,v=1-(s+l)/i,h=f/v-f;return t+=h*(l/u),r-=h*(s/u),{min:r,max:t}}function Zi(r,t){var e=t,a=FL(r,e),n=a.extent,i=e.get("splitNumber");r instanceof VL&&(r.base=e.get("logBase"));var o=r.type,s=e.get("interval"),l=o==="interval"||o==="time";r.setBreaksFromOption(WL(e)),r.setExtent(n[0],n[1]),r.calcNiceExtent({splitNumber:i,fixMin:a.fixMin,fixMax:a.fixMax,minInterval:l?e.get("minInterval"):null,maxInterval:l?e.get("maxInterval"):null}),s!=null&&r.setInterval&&r.setInterval(s)}function Ru(r,t){if(t=t||r.get("type"),t)switch(t){case"category":return new is({ordinalMeta:r.getOrdinalMeta?r.getOrdinalMeta():r.getCategories(),extent:[1/0,-1/0]});case"time":return new c0({locale:r.ecModel.getLocaleModel(),useUTC:r.ecModel.get("useUTC")});default:return new(Gn.getClass(t)||ja)}}function L5(r){var t=r.scale.getExtent(),e=t[0],a=t[1];return!(e>0&&a>0||e<0&&a<0)}function Ls(r){var t=r.getLabelModel().get("formatter");if(r.type==="time"){var e=VN(t);return function(n,i){return r.scale.getFormattedLabel(n,i,e)}}else{if(X(t))return function(n){var i=r.scale.getLabel(n),o=t.replace("{value}",i??"");return o};if(tt(t)){if(r.type==="category")return function(n,i){return t(Qv(r,n),n.value-r.scale.getExtent()[0],null)};var a=se();return function(n,i){var o=null;return a&&(o=a.makeAxisLabelFormatterParamBreak(o,n.break)),t(Qv(r,n),i,o)}}else return function(n){return r.scale.getLabel(n)}}}function Qv(r,t){return r.type==="category"?r.scale.getLabel(t):t.value}function p0(r){var t=r.get("interval");return t??"auto"}function HL(r){return r.type==="category"&&p0(r.getLabelModel())===0}function th(r,t){var e={};return A(r.mapDimensionsAll(t),function(a){e[f0(r,a)]=!0}),Ct(e)}function I5(r,t,e){t&&A(th(t,e),function(a){var n=t.getApproximateExtent(a);n[0]<r[0]&&(r[0]=n[0]),n[1]>r[1]&&(r[1]=n[1])})}function os(r){return r==="middle"||r==="center"}function iu(r){return r.getShallow("show")}function WL(r){var t=r.get("breaks",!0);if(t!=null)return!se()||!P5(r.axis)?void 0:t}function P5(r){return(r.dim==="x"||r.dim==="y"||r.dim==="z"||r.dim==="single")&&r.type!=="category"}var Is=function(){function r(){}return r.prototype.getNeedCrossZero=function(){var t=this.option;return!t.scale},r.prototype.getCoordSysModel=function(){},r}();function R5(r){return Ca(null,r)}var k5={isDimensionStacked:Ka,enableDataStack:DL,getStackedDimension:f0};function E5(r,t){var e=t;t instanceof wt||(e=new wt(t));var a=Ru(e);return a.setExtent(r[0],r[1]),Zi(a,e),a}function O5(r){Qt(r,Is)}function N5(r,t){return t=t||{},Gt(r,null,null,t.state!=="normal")}const Iq=Object.freeze(Object.defineProperty({__proto__:null,createDimensions:XV,createList:R5,createScale:E5,createSymbol:ie,createTextStyle:N5,dataStack:k5,enableHoverEmphasis:Cn,getECData:ut,getLayoutRect:Xt,mixinAxisModelCommonMethods:O5},Symbol.toStringTag,{value:"Module"}));var B5=1e-8;function ax(r,t){return Math.abs(r-t)<B5}function Si(r,t,e){var a=0,n=r[0];if(!n)return!1;for(var i=1;i<r.length;i++){var o=r[i];a+=Ra(n[0],n[1],o[0],o[1],t,e),n=o}var s=r[0];return(!ax(n[0],s[0])||!ax(n[1],s[1]))&&(a+=Ra(n[0],n[1],s[0],s[1],t,e)),a!==0}var z5=[];function _p(r,t){for(var e=0;e<r.length;e++)Jt(r[e],r[e],t)}function nx(r,t,e,a){for(var n=0;n<r.length;n++){var i=r[n];a&&(i=a.project(i)),i&&isFinite(i[0])&&isFinite(i[1])&&(Oa(t,t,i),Na(e,e,i))}}function V5(r){for(var t=0,e=0,a=0,n=r.length,i=r[n-1][0],o=r[n-1][1],s=0;s<n;s++){var l=r[s][0],u=r[s][1],f=i*u-l*o;t+=f,e+=(i+l)*f,a+=(o+u)*f,i=l,o=u}return t?[e/t/3,a/t/3,t]:[r[0][0]||0,r[0][1]||0]}var UL=function(){function r(t){this.name=t}return r.prototype.setCenter=function(t){this._center=t},r.prototype.getCenter=function(){var t=this._center;return t||(t=this._center=this.calcCenter()),t},r}(),ix=function(){function r(t,e){this.type="polygon",this.exterior=t,this.interiors=e}return r}(),ox=function(){function r(t){this.type="linestring",this.points=t}return r}(),YL=function(r){z(t,r);function t(e,a,n){var i=r.call(this,e)||this;return i.type="geoJSON",i.geometries=a,i._center=n&&[n[0],n[1]],i}return t.prototype.calcCenter=function(){for(var e=this.geometries,a,n=0,i=0;i<e.length;i++){var o=e[i],s=o.exterior,l=s&&s.length;l>n&&(a=o,n=l)}if(a)return V5(a.exterior);var u=this.getBoundingRect();return[u.x+u.width/2,u.y+u.height/2]},t.prototype.getBoundingRect=function(e){var a=this._rect;if(a&&!e)return a;var n=[1/0,1/0],i=[-1/0,-1/0],o=this.geometries;return A(o,function(s){s.type==="polygon"?nx(s.exterior,n,i,e):A(s.points,function(l){nx(l,n,i,e)})}),isFinite(n[0])&&isFinite(n[1])&&isFinite(i[0])&&isFinite(i[1])||(n[0]=n[1]=i[0]=i[1]=0),a=new lt(n[0],n[1],i[0]-n[0],i[1]-n[1]),e||(this._rect=a),a},t.prototype.contain=function(e){var a=this.getBoundingRect(),n=this.geometries;if(!a.contain(e[0],e[1]))return!1;t:for(var i=0,o=n.length;i<o;i++){var s=n[i];if(s.type==="polygon"){var l=s.exterior,u=s.interiors;if(Si(l,e[0],e[1])){for(var f=0;f<(u?u.length:0);f++)if(Si(u[f],e[0],e[1]))continue t;return!0}}}return!1},t.prototype.transformTo=function(e,a,n,i){var o=this.getBoundingRect(),s=o.width/o.height;n?i||(i=n/s):n=s*i;for(var l=new lt(e,a,n,i),u=o.calculateTransform(l),f=this.geometries,v=0;v<f.length;v++){var h=f[v];h.type==="polygon"?(_p(h.exterior,u),A(h.interiors,function(c){_p(c,u)})):A(h.points,function(c){_p(c,u)})}o=this._rect,o.copy(l),this._center=[o.x+o.width/2,o.y+o.height/2]},t.prototype.cloneShallow=function(e){e==null&&(e=this.name);var a=new t(e,this.geometries,this._center);return a._rect=this._rect,a.transformTo=null,a},t}(UL),G5=function(r){z(t,r);function t(e,a){var n=r.call(this,e)||this;return n.type="geoSVG",n._elOnlyForCalculate=a,n}return t.prototype.calcCenter=function(){for(var e=this._elOnlyForCalculate,a=e.getBoundingRect(),n=[a.x+a.width/2,a.y+a.height/2],i=xu(z5),o=e;o&&!o.isGeoSVGGraphicRoot;)Gr(i,o.getLocalTransform(),i),o=o.parent;return Dr(i,i),Jt(n,n,i),n},t}(UL);function F5(r){if(!r.UTF8Encoding)return r;var t=r,e=t.UTF8Scale;e==null&&(e=1024);var a=t.features;return A(a,function(n){var i=n.geometry,o=i.encodeOffsets,s=i.coordinates;if(o)switch(i.type){case"LineString":i.coordinates=ZL(s,o,e);break;case"Polygon":Sp(s,o,e);break;case"MultiLineString":Sp(s,o,e);break;case"MultiPolygon":A(s,function(l,u){return Sp(l,o[u],e)})}}),t.UTF8Encoding=!1,t}function Sp(r,t,e){for(var a=0;a<r.length;a++)r[a]=ZL(r[a],t[a],e)}function ZL(r,t,e){for(var a=[],n=t[0],i=t[1],o=0;o<r.length;o+=2){var s=r.charCodeAt(o)-64,l=r.charCodeAt(o+1)-64;s=s>>1^-(s&1),l=l>>1^-(l&1),s+=n,l+=i,n=s,i=l,a.push([s/e,l/e])}return a}function H5(r,t){return r=F5(r),U(Pt(r.features,function(e){return e.geometry&&e.properties&&e.geometry.coordinates.length>0}),function(e){var a=e.properties,n=e.geometry,i=[];switch(n.type){case"Polygon":var o=n.coordinates;i.push(new ix(o[0],o.slice(1)));break;case"MultiPolygon":A(n.coordinates,function(l){l[0]&&i.push(new ix(l[0],l.slice(1)))});break;case"LineString":i.push(new ox([n.coordinates]));break;case"MultiLineString":i.push(new ox(n.coordinates))}var s=new YL(a[t||"name"],i,a.cp);return s.properties=a,s})}const Pq=Object.freeze(Object.defineProperty({__proto__:null,MAX_SAFE_INTEGER:fg,asc:lr,getPercentWithPrecision:hE,getPixelPrecision:um,getPrecision:zr,getPrecisionSafe:WA,isNumeric:hm,isRadianAroundZero:Qo,linearMap:Rt,nice:vm,numericToNumber:ya,parseDate:ba,parsePercent:Z,quantile:ov,quantity:YA,quantityExponent:Gh,reformIntervals:vg,remRadian:fm,round:ae},Symbol.toStringTag,{value:"Module"})),Rq=Object.freeze(Object.defineProperty({__proto__:null,format:Lu,parse:ba,roundTime:Fv},Symbol.toStringTag,{value:"Module"})),kq=Object.freeze(Object.defineProperty({__proto__:null,Arc:Au,BezierCurve:ms,BoundingRect:lt,Circle:wa,CompoundPath:Mu,Ellipse:Cu,Group:rt,Image:xe,IncrementalDisplayable:PM,Line:ne,LinearGradient:Ki,Polygon:Ee,Polyline:Ae,RadialGradient:Cm,Rect:_t,Ring:ys,Sector:ke,Text:At,clipPointsByRect:Lm,clipRectByRect:NM,createIcon:Ss,extendPath:EM,extendShape:kM,getShapeClass:Kl,getTransform:An,initProps:Yt,makeImage:Mm,makePath:es,mergePath:or,registerShape:Rr,resizePath:Dm,updateProps:Lt},Symbol.toStringTag,{value:"Module"})),Eq=Object.freeze(Object.defineProperty({__proto__:null,addCommas:Wm,capitalFirst:$N,encodeHTML:ze,formatTime:XN,formatTpl:Ym,getTextRect:YN,getTooltipMarker:tD,normalizeCssArray:ws,toCamelCase:Um,truncateText:YE},Symbol.toStringTag,{value:"Module"})),Oq=Object.freeze(Object.defineProperty({__proto__:null,bind:$,clone:et,curry:pt,defaults:nt,each:A,extend:G,filter:Pt,indexOf:gt,inherits:em,isArray:W,isFunction:tt,isObject:it,isString:X,map:U,merge:yt,reduce:Mr},Symbol.toStringTag,{value:"Module"}));var W5=St(),Bl=St(),Zr={estimate:1,determine:2};function eh(r){return{out:{noPxChangeTryDetermine:[]},kind:r}}function XL(r,t){var e=U(t,function(a){return r.scale.parse(a)});return r.type==="time"&&e.length>0&&(e.sort(),e.unshift(e[0]),e.push(e[e.length-1])),e}function U5(r,t){var e=r.getLabelModel().get("customValues");if(e){var a=Ls(r),n=r.scale.getExtent(),i=XL(r,e),o=Pt(i,function(s){return s>=n[0]&&s<=n[1]});return{labels:U(o,function(s){var l={value:s};return{formattedLabel:a(l),rawLabel:r.scale.getLabel(l),tickValue:s,time:void 0,break:void 0}})}}return r.type==="category"?Z5(r,t):$5(r)}function Y5(r,t,e){var a=r.getTickModel().get("customValues");if(a){var n=r.scale.getExtent(),i=XL(r,a);return{ticks:Pt(i,function(o){return o>=n[0]&&o<=n[1]})}}return r.type==="category"?X5(r,t):{ticks:U(r.scale.getTicks(e),function(o){return o.value})}}function Z5(r,t){var e=r.getLabelModel(),a=$L(r,e,t);return!e.get("show")||r.scale.isBlank()?{labels:[]}:a}function $L(r,t,e){var a=K5(r),n=p0(t),i=e.kind===Zr.estimate;if(!i){var o=KL(a,n);if(o)return o}var s,l;tt(n)?s=QL(r,n):(l=n==="auto"?j5(r,e):n,s=JL(r,l));var u={labels:s,labelCategoryInterval:l};return i?e.out.noPxChangeTryDetermine.push(function(){return Kg(a,n,u),!0}):Kg(a,n,u),u}function X5(r,t){var e=q5(r),a=p0(t),n=KL(e,a);if(n)return n;var i,o;if((!t.get("show")||r.scale.isBlank())&&(i=[]),tt(a))i=QL(r,a,!0);else if(a==="auto"){var s=$L(r,r.getLabelModel(),eh(Zr.determine));o=s.labelCategoryInterval,i=U(s.labels,function(l){return l.tickValue})}else o=a,i=JL(r,o,!0);return Kg(e,a,{ticks:i,tickCategoryInterval:o})}function $5(r){var t=r.scale.getTicks(),e=Ls(r);return{labels:U(t,function(a,n){return{formattedLabel:e(a,n),rawLabel:r.scale.getLabel(a),tickValue:a.value,time:a.time,break:a.break}})}}var q5=qL("axisTick"),K5=qL("axisLabel");function qL(r){return function(e){return Bl(e)[r]||(Bl(e)[r]={list:[]})}}function KL(r,t){for(var e=0;e<r.list.length;e++)if(r.list[e].key===t)return r.list[e].value}function Kg(r,t,e){return r.list.push({key:t,value:e}),e}function j5(r,t){if(t.kind===Zr.estimate){var e=r.calculateCategoryInterval(t);return t.out.noPxChangeTryDetermine.push(function(){return Bl(r).autoInterval=e,!0}),e}var a=Bl(r).autoInterval;return a??(Bl(r).autoInterval=r.calculateCategoryInterval(t))}function J5(r,t){var e=t.kind,a=tG(r),n=Ls(r),i=(a.axisRotate-a.labelRotate)/180*Math.PI,o=r.scale,s=o.getExtent(),l=o.count();if(s[1]-s[0]<1)return 0;var u=1,f=40;l>f&&(u=Math.max(1,Math.floor(l/f)));for(var v=s[0],h=r.dataToCoord(v+1)-r.dataToCoord(v),c=Math.abs(h*Math.cos(i)),p=Math.abs(h*Math.sin(i)),d=0,g=0;v<=s[1];v+=u){var y=0,m=0,_=zh(n({value:v}),a.font,"center","top");y=_.width*1.3,m=_.height*1.3,d=Math.max(d,y,7),g=Math.max(g,m,7)}var S=d/c,x=g/p;isNaN(S)&&(S=1/0),isNaN(x)&&(x=1/0);var b=Math.max(0,Math.floor(Math.min(S,x)));if(e===Zr.estimate)return t.out.noPxChangeTryDetermine.push($(Q5,null,r,b,l)),b;var w=jL(r,b,l);return w??b}function Q5(r,t,e){return jL(r,t,e)==null}function jL(r,t,e){var a=W5(r.model),n=r.getExtent(),i=a.lastAutoInterval,o=a.lastTickCount;if(i!=null&&o!=null&&Math.abs(i-t)<=1&&Math.abs(o-e)<=1&&i>t&&a.axisExtent0===n[0]&&a.axisExtent1===n[1])return i;a.lastTickCount=e,a.lastAutoInterval=t,a.axisExtent0=n[0],a.axisExtent1=n[1]}function tG(r){var t=r.getLabelModel();return{axisRotate:r.getRotate?r.getRotate():r.isHorizontal&&!r.isHorizontal()?90:0,labelRotate:t.get("rotate")||0,font:t.getFont()}}function JL(r,t,e){var a=Ls(r),n=r.scale,i=n.getExtent(),o=r.getLabelModel(),s=[],l=Math.max((t||0)+1,1),u=i[0],f=n.count();u!==0&&l>1&&f/l>2&&(u=Math.round(Math.ceil(u/l)*l));var v=HL(r),h=o.get("showMinLabel")||v,c=o.get("showMaxLabel")||v;h&&u!==i[0]&&d(i[0]);for(var p=u;p<=i[1];p+=l)d(p);c&&p-l!==i[1]&&d(i[1]);function d(g){var y={value:g};s.push(e?g:{formattedLabel:a(y),rawLabel:n.getLabel(y),tickValue:g,time:void 0,break:void 0})}return s}function QL(r,t,e){var a=r.scale,n=Ls(r),i=[];return A(a.getTicks(),function(o){var s=a.getLabel(o),l=o.value;t(o.value,s)&&i.push(e?l:{formattedLabel:n(o),rawLabel:s,tickValue:l,time:void 0,break:void 0})}),i}var sx=[0,1],$r=function(){function r(t,e,a){this.onBand=!1,this.inverse=!1,this.dim=t,this.scale=e,this._extent=a||[0,0]}return r.prototype.contain=function(t){var e=this._extent,a=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return t>=a&&t<=n},r.prototype.containData=function(t){return this.scale.contain(this.scale.parse(t))},r.prototype.getExtent=function(){return this._extent.slice()},r.prototype.getPixelPrecision=function(t){return um(t||this.scale.getExtent(),this._extent)},r.prototype.setExtent=function(t,e){var a=this._extent;a[0]=t,a[1]=e},r.prototype.dataToCoord=function(t,e){var a=this._extent,n=this.scale;return t=n.normalize(n.parse(t)),this.onBand&&n.type==="ordinal"&&(a=a.slice(),lx(a,n.count())),Rt(t,sx,a,e)},r.prototype.coordToData=function(t,e){var a=this._extent,n=this.scale;this.onBand&&n.type==="ordinal"&&(a=a.slice(),lx(a,n.count()));var i=Rt(t,a,sx,e);return this.scale.scale(i)},r.prototype.pointToData=function(t,e){},r.prototype.getTicksCoords=function(t){t=t||{};var e=t.tickModel||this.getTickModel(),a=Y5(this,e,{breakTicks:t.breakTicks,pruneByBreak:t.pruneByBreak}),n=a.ticks,i=U(n,function(s){return{coord:this.dataToCoord(this.scale.type==="ordinal"?this.scale.getRawOrdinalNumber(s):s),tickValue:s}},this),o=e.get("alignWithLabel");return eG(this,i,o,t.clamp),i},r.prototype.getMinorTicksCoords=function(){if(this.scale.type==="ordinal")return[];var t=this.model.getModel("minorTick"),e=t.get("splitNumber");e>0&&e<100||(e=5);var a=this.scale.getMinorTicks(e),n=U(a,function(i){return U(i,function(o){return{coord:this.dataToCoord(o),tickValue:o}},this)},this);return n},r.prototype.getViewLabels=function(t){return t=t||eh(Zr.determine),U5(this,t).labels},r.prototype.getLabelModel=function(){return this.model.getModel("axisLabel")},r.prototype.getTickModel=function(){return this.model.getModel("axisTick")},r.prototype.getBandWidth=function(){var t=this._extent,e=this.scale.getExtent(),a=e[1]-e[0]+(this.onBand?1:0);a===0&&(a=1);var n=Math.abs(t[1]-t[0]);return Math.abs(n)/a},r.prototype.calculateCategoryInterval=function(t){return t=t||eh(Zr.determine),J5(this,t)},r}();function lx(r,t){var e=r[1]-r[0],a=t,n=e/a/2;r[0]+=n,r[1]-=n}function eG(r,t,e,a){var n=t.length;if(!r.onBand||e||!n)return;var i=r.getExtent(),o,s;if(n===1)t[0].coord=i[0],t[0].onBand=!0,o=t[1]={coord:i[1],tickValue:t[0].tickValue,onBand:!0};else{var l=t[n-1].tickValue-t[0].tickValue,u=(t[n-1].coord-t[0].coord)/l;A(t,function(c){c.coord-=u/2,c.onBand=!0});var f=r.scale.getExtent();s=1+f[1]-t[n-1].tickValue,o={coord:t[n-1].coord+u*s,tickValue:f[1]+1,onBand:!0},t.push(o)}var v=i[0]>i[1];h(t[0].coord,i[0])&&(a?t[0].coord=i[0]:t.shift()),a&&h(i[0],t[0].coord)&&t.unshift({coord:i[0],onBand:!0}),h(i[1],o.coord)&&(a?o.coord=i[1]:t.pop()),a&&h(o.coord,i[1])&&t.push({coord:i[1],onBand:!0});function h(c,p){return c=ae(c),p=ae(p),v?c>p:c<p}}function Nq(r){var t=xt.extend(r);return xt.registerClass(t),t}function Bq(r){var t=Wt.extend(r);return Wt.registerClass(t),t}function zq(r){var t=Bt.extend(r);return Bt.registerClass(t),t}function Vq(r){var t=Nt.extend(r);return Nt.registerClass(t),t}var qs=Math.PI*2,fi=ma.CMD,rG=["top","right","bottom","left"];function aG(r,t,e,a,n){var i=e.width,o=e.height;switch(r){case"top":a.set(e.x+i/2,e.y-t),n.set(0,-1);break;case"bottom":a.set(e.x+i/2,e.y+o+t),n.set(0,1);break;case"left":a.set(e.x-t,e.y+o/2),n.set(-1,0);break;case"right":a.set(e.x+i+t,e.y+o/2),n.set(1,0);break}}function nG(r,t,e,a,n,i,o,s,l){o-=r,s-=t;var u=Math.sqrt(o*o+s*s);o/=u,s/=u;var f=o*e+r,v=s*e+t;if(Math.abs(a-n)%qs<1e-4)return l[0]=f,l[1]=v,u-e;if(i){var h=a;a=ur(n),n=ur(h)}else a=ur(a),n=ur(n);a>n&&(n+=qs);var c=Math.atan2(s,o);if(c<0&&(c+=qs),c>=a&&c<=n||c+qs>=a&&c+qs<=n)return l[0]=f,l[1]=v,u-e;var p=e*Math.cos(a)+r,d=e*Math.sin(a)+t,g=e*Math.cos(n)+r,y=e*Math.sin(n)+t,m=(p-o)*(p-o)+(d-s)*(d-s),_=(g-o)*(g-o)+(y-s)*(y-s);return m<_?(l[0]=p,l[1]=d,Math.sqrt(m)):(l[0]=g,l[1]=y,Math.sqrt(_))}function rh(r,t,e,a,n,i,o,s){var l=n-r,u=i-t,f=e-r,v=a-t,h=Math.sqrt(f*f+v*v);f/=h,v/=h;var c=l*f+u*v,p=c/h;s&&(p=Math.min(Math.max(p,0),1)),p*=h;var d=o[0]=r+p*f,g=o[1]=t+p*v;return Math.sqrt((d-n)*(d-n)+(g-i)*(g-i))}function t2(r,t,e,a,n,i,o){e<0&&(r=r+e,e=-e),a<0&&(t=t+a,a=-a);var s=r+e,l=t+a,u=o[0]=Math.min(Math.max(n,r),s),f=o[1]=Math.min(Math.max(i,t),l);return Math.sqrt((u-n)*(u-n)+(f-i)*(f-i))}var Br=[];function iG(r,t,e){var a=t2(t.x,t.y,t.width,t.height,r.x,r.y,Br);return e.set(Br[0],Br[1]),a}function oG(r,t,e){for(var a=0,n=0,i=0,o=0,s,l,u=1/0,f=t.data,v=r.x,h=r.y,c=0;c<f.length;){var p=f[c++];c===1&&(a=f[c],n=f[c+1],i=a,o=n);var d=u;switch(p){case fi.M:i=f[c++],o=f[c++],a=i,n=o;break;case fi.L:d=rh(a,n,f[c],f[c+1],v,h,Br,!0),a=f[c++],n=f[c++];break;case fi.C:d=wA(a,n,f[c++],f[c++],f[c++],f[c++],f[c],f[c+1],v,h,Br),a=f[c++],n=f[c++];break;case fi.Q:d=CA(a,n,f[c++],f[c++],f[c],f[c+1],v,h,Br),a=f[c++],n=f[c++];break;case fi.A:var g=f[c++],y=f[c++],m=f[c++],_=f[c++],S=f[c++],x=f[c++];c+=1;var b=!!(1-f[c++]);s=Math.cos(S)*m+g,l=Math.sin(S)*_+y,c<=1&&(i=s,o=l);var w=(v-g)*_/m+g;d=nG(g,y,_,S,S+x,b,w,h,Br),a=Math.cos(S+x)*m+g,n=Math.sin(S+x)*_+y;break;case fi.R:i=a=f[c++],o=n=f[c++];var T=f[c++],C=f[c++];d=t2(i,o,T,C,v,h,Br);break;case fi.Z:d=rh(a,n,i,o,v,h,Br,!0),a=i,n=o;break}d<u&&(u=d,e.set(Br[0],Br[1]))}return u}var Vr=new st,Ut=new st,ee=new st,va=new st,sa=new st;function ux(r,t){if(r){var e=r.getTextGuideLine(),a=r.getTextContent();if(a&&e){var n=r.textGuideLineConfig||{},i=[[0,0],[0,0],[0,0]],o=n.candidates||rG,s=a.getBoundingRect().clone();s.applyTransform(a.getComputedTransform());var l=1/0,u=n.anchor,f=r.getComputedTransform(),v=f&&Dr([],f),h=t.get("length2")||0;u&&ee.copy(u);for(var c=0;c<o.length;c++){var p=o[c];aG(p,0,s,Vr,va),st.scaleAndAdd(Ut,Vr,va,h),Ut.transform(v);var d=r.getBoundingRect(),g=u?u.distance(Ut):r instanceof bt?oG(Ut,r.path,ee):iG(Ut,d,ee);g<l&&(l=g,Ut.transform(f),ee.transform(f),ee.toArray(i[0]),Ut.toArray(i[1]),Vr.toArray(i[2]))}e2(i,t.get("minTurnAngle")),e.setShape({points:i})}}}var ah=[],We=new st;function e2(r,t){if(t<=180&&t>0){t=t/180*Math.PI,Vr.fromArray(r[0]),Ut.fromArray(r[1]),ee.fromArray(r[2]),st.sub(va,Vr,Ut),st.sub(sa,ee,Ut);var e=va.len(),a=sa.len();if(!(e<.001||a<.001)){va.scale(1/e),sa.scale(1/a);var n=va.dot(sa),i=Math.cos(t);if(i<n){var o=rh(Ut.x,Ut.y,ee.x,ee.y,Vr.x,Vr.y,ah,!1);We.fromArray(ah),We.scaleAndAdd(sa,o/Math.tan(Math.PI-t));var s=ee.x!==Ut.x?(We.x-Ut.x)/(ee.x-Ut.x):(We.y-Ut.y)/(ee.y-Ut.y);if(isNaN(s))return;s<0?st.copy(We,Ut):s>1&&st.copy(We,ee),We.toArray(r[1])}}}}function sG(r,t,e){if(e<=180&&e>0){e=e/180*Math.PI,Vr.fromArray(r[0]),Ut.fromArray(r[1]),ee.fromArray(r[2]),st.sub(va,Ut,Vr),st.sub(sa,ee,Ut);var a=va.len(),n=sa.len();if(!(a<.001||n<.001)){va.scale(1/a),sa.scale(1/n);var i=va.dot(t),o=Math.cos(e);if(i<o){var s=rh(Ut.x,Ut.y,ee.x,ee.y,Vr.x,Vr.y,ah,!1);We.fromArray(ah);var l=Math.PI/2,u=Math.acos(sa.dot(t)),f=l+u-e;if(f>=l)st.copy(We,ee);else{We.scaleAndAdd(sa,s/Math.tan(Math.PI/2-f));var v=ee.x!==Ut.x?(We.x-Ut.x)/(ee.x-Ut.x):(We.y-Ut.y)/(ee.y-Ut.y);if(isNaN(v))return;v<0?st.copy(We,Ut):v>1&&st.copy(We,ee)}We.toArray(r[1])}}}}function xp(r,t,e,a){var n=e==="normal",i=n?r:r.ensureState(e);i.ignore=t;var o=a.get("smooth");o&&o===!0&&(o=.3),i.shape=i.shape||{},o>0&&(i.shape.smooth=o);var s=a.getModel("lineStyle").getLineStyle();n?r.useStyle(s):i.style=s}function lG(r,t){var e=t.smooth,a=t.points;if(a)if(r.moveTo(a[0][0],a[0][1]),e>0&&a.length>=3){var n=Ea(a[0],a[1]),i=Ea(a[1],a[2]);if(!n||!i){r.lineTo(a[1][0],a[1][1]),r.lineTo(a[2][0],a[2][1]);return}var o=Math.min(n,i)*e,s=Ml([],a[1],a[0],o/n),l=Ml([],a[1],a[2],o/i),u=Ml([],s,l,.5);r.bezierCurveTo(s[0],s[1],s[0],s[1],u[0],u[1]),r.bezierCurveTo(l[0],l[1],l[0],l[1],a[2][0],a[2][1])}else for(var f=1;f<a.length;f++)r.lineTo(a[f][0],a[f][1])}function d0(r,t,e){var a=r.getTextGuideLine(),n=r.getTextContent();if(!n){a&&r.removeTextGuideLine();return}for(var i=t.normal,o=i.get("show"),s=n.ignore,l=0;l<$l.length;l++){var u=$l[l],f=t[u],v=u==="normal";if(f){var h=f.get("show"),c=v?s:Q(n.states[u]&&n.states[u].ignore,s);if(c||!Q(h,o)){var p=v?a:a&&a.states[u];p&&(p.ignore=!0),a&&xp(a,!0,u,f);continue}a||(a=new Ae,r.setTextGuideLine(a),!v&&(s||!o)&&xp(a,!0,"normal",t.normal),r.stateProxy&&(a.stateProxy=r.stateProxy)),xp(a,!1,u,f)}}if(a){nt(a.style,e),a.style.fill=null;var d=i.get("showAbove"),g=r.textGuideLineConfig=r.textGuideLineConfig||{};g.showAbove=d||!1,a.buildPath=lG}}function g0(r,t){t=t||"labelLine";for(var e={normal:r.getModel(t)},a=0;a<Xe.length;a++){var n=Xe[a];e[n]=r.getModel([n,t])}return e}var fx=["label","labelLine","layoutOption","priority","defaultAttr","marginForce","minMarginForce","marginDefault","suggestIgnore"],uG=1,nh=2,r2=uG|nh;function ih(r,t,e){e=e||r2,t?r.dirty|=e:r.dirty&=~e}function a2(r,t){return t=t||r2,r.dirty==null||!!(r.dirty&t)}function Sa(r){if(r)return a2(r)&&n2(r,r.label,r),r}function n2(r,t,e){var a=t.getComputedTransform();r.transform=Pm(r.transform,a);var n=r.localRect=jl(r.localRect,t.getBoundingRect()),i=t.style,o=i.margin,s=e&&e.marginForce,l=e&&e.minMarginForce,u=e&&e.marginDefault,f=i.__marginType;f==null&&u&&(o=u,f=Go.textMargin);for(var v=0;v<4;v++)bp[v]=f===Go.minMargin&&l&&l[v]!=null?l[v]:s&&s[v]!=null?s[v]:o?o[v]:0;f===Go.textMargin&&Wi(n,bp,!1,!1);var h=r.rect=jl(r.rect,n);return a&&h.applyTransform(a),f===Go.minMargin&&Wi(h,bp,!1,!1),r.axisAligned=Im(a),(r.label=r.label||{}).ignore=t.ignore,ih(r,!1),ih(r,!0,nh),r}var bp=[0,0,0,0];function fG(r,t,e){return r.transform=Pm(r.transform,e),r.localRect=jl(r.localRect,t),r.rect=jl(r.rect,t),e&&r.rect.applyTransform(e),r.axisAligned=Im(e),r.obb=void 0,(r.label=r.label||{}).ignore=!1,r}function jg(r,t){if(r){r.label.x+=t.x,r.label.y+=t.y,r.label.markRedraw();var e=r.transform;e&&(e[4]+=t.x,e[5]+=t.y);var a=r.rect;a&&(a.x+=t.x,a.y+=t.y);var n=r.obb;n&&n.fromBoundingRect(r.localRect,e)}}function Jg(r,t){for(var e=0;e<fx.length;e++){var a=fx[e];r[a]==null&&(r[a]=t[a])}return Sa(r)}function vx(r){var t=r.obb;return(!t||a2(r,nh))&&(r.obb=t=t||new IM,t.fromBoundingRect(r.localRect,r.transform),ih(r,!1,nh)),t}function Qg(r,t,e,a,n){var i=r.length,o=ct[t],s=le[t];if(i<2)return!1;r.sort(function(w,T){return w.rect[o]-T.rect[o]});for(var l=0,u,f=!1,v=0;v<i;v++){var h=r[v],c=h.rect;u=c[o]-l,u<0&&(c[o]-=u,h.label[o]-=u,f=!0),l=c[o]+c[s]}var p=r[0],d=r[i-1],g,y;m(),g<0&&x(-g,.8),y<0&&x(y,.8),m(),_(g,y,1),_(y,g,-1),m(),g<0&&b(-g),y<0&&b(y);function m(){g=p.rect[o]-e,y=a-d.rect[o]-d.rect[s]}function _(w,T,C){if(w<0){var M=Math.min(T,-w);if(M>0){S(M*C,0,i);var D=M+w;D<0&&x(-D*C,1)}else x(-w*C,1)}}function S(w,T,C){w!==0&&(f=!0);for(var M=T;M<C;M++){var D=r[M],I=D.rect;I[o]+=w,D.label[o]+=w}}function x(w,T){for(var C=[],M=0,D=1;D<i;D++){var I=r[D-1].rect,L=Math.max(r[D].rect[o]-I[o]-I[s],0);C.push(L),M+=L}if(M){var P=Math.min(Math.abs(w)/M,T);if(w>0)for(var D=0;D<i-1;D++){var k=C[D]*P;S(k,0,D+1)}else for(var D=i-1;D>0;D--){var k=C[D-1]*P;S(-k,D,i)}}}function b(w){var T=w<0?-1:1;w=Math.abs(w);for(var C=Math.ceil(w/(i-1)),M=0;M<i-1;M++)if(T>0?S(C,0,M+1):S(-C,i-M-1,i),w-=C,w<=0)return}return f}function vG(r){for(var t=0;t<r.length;t++){var e=r[t],a=e.defaultAttr,n=e.labelLine;e.label.attr("ignore",a.ignore),n&&n.attr("ignore",a.labelGuideIgnore)}}function i2(r){var t=[];r.sort(function(u,f){return(f.suggestIgnore?1:0)-(u.suggestIgnore?1:0)||f.priority-u.priority});function e(u){if(!u.ignore){var f=u.ensureState("emphasis");f.ignore==null&&(f.ignore=!1)}u.ignore=!0}for(var a=0;a<r.length;a++){var n=Sa(r[a]);if(!n.label.ignore){for(var i=n.label,o=n.labelLine,s=!1,l=0;l<t.length;l++)if(ac(n,t[l],null,{touchThreshold:.05})){s=!0;break}s?(e(i),o&&e(o)):t.push(n)}}}function ac(r,t,e,a){return!r||!t||r.label&&r.label.ignore||t.label&&t.label.ignore||!r.rect.intersect(t.rect,e,a)?!1:r.axisAligned&&t.axisAligned?!0:vx(r).intersect(vx(t),e,a)}function hG(r){if(r){for(var t=[],e=0;e<r.length;e++)t.push(r[e].slice());return t}}function cG(r,t){var e=r.label,a=t&&t.getTextGuideLine();return{dataIndex:r.dataIndex,dataType:r.dataType,seriesIndex:r.seriesModel.seriesIndex,text:r.label.style.text,rect:r.hostRect,labelRect:r.rect,align:e.style.align,verticalAlign:e.style.verticalAlign,labelLinePoints:hG(a&&a.shape.points)}}var hx=["align","verticalAlign","width","height","fontSize"],Ge=new Ba,wp=St(),pG=St();function wf(r,t,e){for(var a=0;a<e.length;a++){var n=e[a];t[n]!=null&&(r[n]=t[n])}}var Tf=["x","y","rotation"],dG=function(){function r(){this._labelList=[],this._chartViewList=[]}return r.prototype.clearLabels=function(){this._labelList=[],this._chartViewList=[]},r.prototype._addLabel=function(t,e,a,n,i){var o=n.style,s=n.__hostTarget,l=s.textConfig||{},u=n.getComputedTransform(),f=n.getBoundingRect().plain();lt.applyTransform(f,f,u),u?Ge.setLocalTransform(u):(Ge.x=Ge.y=Ge.rotation=Ge.originX=Ge.originY=0,Ge.scaleX=Ge.scaleY=1),Ge.rotation=ur(Ge.rotation);var v=n.__hostTarget,h;if(v){h=v.getBoundingRect().plain();var c=v.getComputedTransform();lt.applyTransform(h,h,c)}var p=h&&v.getTextGuideLine();this._labelList.push({label:n,labelLine:p,seriesModel:a,dataIndex:t,dataType:e,layoutOptionOrCb:i,layoutOption:null,rect:f,hostRect:h,priority:h?h.width*h.height:0,defaultAttr:{ignore:n.ignore,labelGuideIgnore:p&&p.ignore,x:Ge.x,y:Ge.y,scaleX:Ge.scaleX,scaleY:Ge.scaleY,rotation:Ge.rotation,style:{x:o.x,y:o.y,align:o.align,verticalAlign:o.verticalAlign,width:o.width,height:o.height,fontSize:o.fontSize},cursor:n.cursor,attachedPos:l.position,attachedRot:l.rotation}})},r.prototype.addLabelsOfSeries=function(t){var e=this;this._chartViewList.push(t);var a=t.__model,n=a.get("labelLayout");(tt(n)||Ct(n).length)&&t.group.traverse(function(i){if(i.ignore)return!0;var o=i.getTextContent(),s=ut(i);o&&!o.disableLabelLayout&&e._addLabel(s.dataIndex,s.dataType,a,o,n)})},r.prototype.updateLayoutConfig=function(t){var e=t.getWidth(),a=t.getHeight();function n(_,S){return function(){ux(_,S)}}for(var i=0;i<this._labelList.length;i++){var o=this._labelList[i],s=o.label,l=s.__hostTarget,u=o.defaultAttr,f=void 0;tt(o.layoutOptionOrCb)?f=o.layoutOptionOrCb(cG(o,l)):f=o.layoutOptionOrCb,f=f||{},o.layoutOption=f;var v=Math.PI/180;l&&l.setTextConfig({local:!1,position:f.x!=null||f.y!=null?null:u.attachedPos,rotation:f.rotate!=null?f.rotate*v:u.attachedRot,offset:[f.dx||0,f.dy||0]});var h=!1;if(f.x!=null?(s.x=Z(f.x,e),s.setStyle("x",0),h=!0):(s.x=u.x,s.setStyle("x",u.style.x)),f.y!=null?(s.y=Z(f.y,a),s.setStyle("y",0),h=!0):(s.y=u.y,s.setStyle("y",u.style.y)),f.labelLinePoints){var c=l.getTextGuideLine();c&&(c.setShape({points:f.labelLinePoints}),h=!1)}var p=wp(s);p.needsUpdateLabelLine=h,s.rotation=f.rotate!=null?f.rotate*v:u.rotation,s.scaleX=u.scaleX,s.scaleY=u.scaleY;for(var d=0;d<hx.length;d++){var g=hx[d];s.setStyle(g,f[g]!=null?f[g]:u.style[g])}if(f.draggable){if(s.draggable=!0,s.cursor="move",l){var y=o.seriesModel;if(o.dataIndex!=null){var m=o.seriesModel.getData(o.dataType);y=m.getItemModel(o.dataIndex)}s.on("drag",n(l,y.getModel("labelLine")))}}else s.off("drag"),s.cursor=u.cursor}},r.prototype.layout=function(t){var e=t.getWidth(),a=t.getHeight(),n=[];A(this._labelList,function(l){l.defaultAttr.ignore||n.push(Jg({},l))});var i=Pt(n,function(l){return l.layoutOption.moveOverlap==="shiftX"}),o=Pt(n,function(l){return l.layoutOption.moveOverlap==="shiftY"});Qg(i,0,0,e),Qg(o,1,0,a);var s=Pt(n,function(l){return l.layoutOption.hideOverlap});vG(s),i2(s)},r.prototype.processLabelsOverall=function(){var t=this;A(this._chartViewList,function(e){var a=e.__model,n=e.ignoreLabelLineUpdate,i=a.isAnimationEnabled();e.group.traverse(function(o){if(o.ignore&&!o.forceLabelAnimation)return!0;var s=!n,l=o.getTextContent();!s&&l&&(s=wp(l).needsUpdateLabelLine),s&&t._updateLabelLine(o,a),i&&t._animateLabels(o,a)})})},r.prototype._updateLabelLine=function(t,e){var a=t.getTextContent(),n=ut(t),i=n.dataIndex;if(a&&i!=null){var o=e.getData(n.dataType),s=o.getItemModel(i),l={},u=o.getItemVisual(i,"style");if(u){var f=o.getVisual("drawType");l.stroke=u[f]}var v=s.getModel("labelLine");d0(t,g0(s),l),ux(t,v)}},r.prototype._animateLabels=function(t,e){var a=t.getTextContent(),n=t.getTextGuideLine();if(a&&(t.forceLabelAnimation||!a.ignore&&!a.invisible&&!t.disableLabelAnimation&&!Xo(t))){var i=wp(a),o=i.oldLayout,s=ut(t),l=s.dataIndex,u={x:a.x,y:a.y,rotation:a.rotation},f=e.getData(s.dataType);if(o){a.attr(o);var h=t.prevStates;h&&(gt(h,"select")>=0&&a.attr(i.oldLayoutSelect),gt(h,"emphasis")>=0&&a.attr(i.oldLayoutEmphasis)),Lt(a,u,e,l)}else if(a.attr(u),!xs(a).valueAnimation){var v=Q(a.style.opacity,1);a.style.opacity=0,Yt(a,{style:{opacity:v}},e,l)}if(i.oldLayout=u,a.states.select){var c=i.oldLayoutSelect={};wf(c,u,Tf),wf(c,a.states.select,Tf)}if(a.states.emphasis){var p=i.oldLayoutEmphasis={};wf(p,u,Tf),wf(p,a.states.emphasis,Tf)}HM(a,l,f,e,e)}if(n&&!n.ignore&&!n.invisible){var i=pG(n),o=i.oldLayout,d={points:n.shape.points};o?(n.attr({shape:o}),Lt(n,{shape:d},e)):(n.setShape(d),n.style.strokePercent=0,Yt(n,{style:{strokePercent:1}},e)),i.oldLayout=d}},r}(),Tp=St();function gG(r){r.registerUpdateLifecycle("series:beforeupdate",function(t,e,a){var n=Tp(e).labelManager;n||(n=Tp(e).labelManager=new dG),n.clearLabels()}),r.registerUpdateLifecycle("series:layoutlabels",function(t,e,a){var n=Tp(e).labelManager;a.updatedSeries.forEach(function(i){n.addLabelsOfSeries(e.getViewOfSeriesModel(i))}),n.updateLayoutConfig(e),n.layout(e),n.processLabelsOverall()})}var Cp=Math.sin,Ap=Math.cos,o2=Math.PI,vi=Math.PI*2,yG=180/o2,s2=function(){function r(){}return r.prototype.reset=function(t){this._start=!0,this._d=[],this._str="",this._p=Math.pow(10,t||4)},r.prototype.moveTo=function(t,e){this._add("M",t,e)},r.prototype.lineTo=function(t,e){this._add("L",t,e)},r.prototype.bezierCurveTo=function(t,e,a,n,i,o){this._add("C",t,e,a,n,i,o)},r.prototype.quadraticCurveTo=function(t,e,a,n){this._add("Q",t,e,a,n)},r.prototype.arc=function(t,e,a,n,i,o){this.ellipse(t,e,a,a,0,n,i,o)},r.prototype.ellipse=function(t,e,a,n,i,o,s,l){var u=s-o,f=!l,v=Math.abs(u),h=mn(v-vi)||(f?u>=vi:-u>=vi),c=u>0?u%vi:u%vi+vi,p=!1;h?p=!0:mn(v)?p=!1:p=c>=o2==!!f;var d=t+a*Ap(o),g=e+n*Cp(o);this._start&&this._add("M",d,g);var y=Math.round(i*yG);if(h){var m=1/this._p,_=(f?1:-1)*(vi-m);this._add("A",a,n,y,1,+f,t+a*Ap(o+_),e+n*Cp(o+_)),m>.01&&this._add("A",a,n,y,0,+f,d,g)}else{var S=t+a*Ap(s),x=e+n*Cp(s);this._add("A",a,n,y,+p,+f,S,x)}},r.prototype.rect=function(t,e,a,n){this._add("M",t,e),this._add("l",a,0),this._add("l",0,n),this._add("l",-a,0),this._add("Z")},r.prototype.closePath=function(){this._d.length>0&&this._add("Z")},r.prototype._add=function(t,e,a,n,i,o,s,l,u){for(var f=[],v=this._p,h=1;h<arguments.length;h++){var c=arguments[h];if(isNaN(c)){this._invalid=!0;return}f.push(Math.round(c*v)/v)}this._d.push(t+f.join(" ")),this._start=t==="Z"},r.prototype.generateStr=function(){this._str=this._invalid?"":this._d.join(""),this._d=[]},r.prototype.getStr=function(){return this._str},r}(),y0="none",mG=Math.round;function _G(r){var t=r.fill;return t!=null&&t!==y0}function SG(r){var t=r.stroke;return t!=null&&t!==y0}var ty=["lineCap","miterLimit","lineJoin"],xG=U(ty,function(r){return"stroke-"+r.toLowerCase()});function bG(r,t,e,a){var n=t.opacity==null?1:t.opacity;if(e instanceof xe){r("opacity",n);return}if(_G(t)){var i=Zl(t.fill);r("fill",i.color);var o=t.fillOpacity!=null?t.fillOpacity*i.opacity*n:i.opacity*n;o<1&&r("fill-opacity",o)}else r("fill",y0);if(SG(t)){var s=Zl(t.stroke);r("stroke",s.color);var l=t.strokeNoScale?e.getLineScale():1,u=l?(t.lineWidth||0)/l:0,f=t.strokeOpacity!=null?t.strokeOpacity*s.opacity*n:s.opacity*n,v=t.strokeFirst;if(u!==1&&r("stroke-width",u),v&&r("paint-order",v?"stroke":"fill"),f<1&&r("stroke-opacity",f),t.lineDash){var h=a0(e),c=h[0],p=h[1];c&&(p=mG(p||0),r("stroke-dasharray",c.join(",")),(p||a)&&r("stroke-dashoffset",p))}for(var d=0;d<ty.length;d++){var g=ty[d];if(t[g]!==Ov[g]){var y=t[g]||Ov[g];y&&r(xG[d],y)}}}}var l2="http://www.w3.org/2000/svg",u2="http://www.w3.org/1999/xlink",wG="http://www.w3.org/2000/xmlns/",TG="http://www.w3.org/XML/1998/namespace",cx="ecmeta_";function f2(r){return document.createElementNS(l2,r)}function ye(r,t,e,a,n){return{tag:r,attrs:e||{},children:a,text:n,key:t}}function CG(r,t){var e=[];if(t)for(var a in t){var n=t[a],i=a;n!==!1&&(n!==!0&&n!=null&&(i+='="'+n+'"'),e.push(i))}return"<"+r+" "+e.join(" ")+">"}function AG(r){return"</"+r+">"}function m0(r,t){t=t||{};var e=t.newline?`
`:"";function a(n){var i=n.children,o=n.tag,s=n.attrs,l=n.text;return CG(o,s)+(o!=="style"?ze(l):l||"")+(i?""+e+U(i,function(u){return a(u)}).join(e)+e:"")+AG(o)}return a(r)}function MG(r,t,e){e=e||{};var a=e.newline?`
`:"",n=" {"+a,i=a+"}",o=U(Ct(r),function(l){return l+n+U(Ct(r[l]),function(u){return u+":"+r[l][u]+";"}).join(a)+i}).join(a),s=U(Ct(t),function(l){return"@keyframes "+l+n+U(Ct(t[l]),function(u){return u+n+U(Ct(t[l][u]),function(f){var v=t[l][u][f];return f==="d"&&(v='path("'+v+'")'),f+":"+v+";"}).join(a)+i}).join(a)+i}).join(a);return!o&&!s?"":["<![CDATA[",o,s,"]]>"].join(a)}function ey(r){return{zrId:r,shadowCache:{},patternCache:{},gradientCache:{},clipPathCache:{},defs:{},cssNodes:{},cssAnims:{},cssStyleCache:{},cssAnimIdx:0,shadowIdx:0,gradientIdx:0,patternIdx:0,clipPathIdx:0}}function px(r,t,e,a){return ye("svg","root",{width:r,height:t,xmlns:l2,"xmlns:xlink":u2,version:"1.1",baseProfile:"full",viewBox:a?"0 0 "+r+" "+t:!1},e)}var DG=0;function v2(){return DG++}var dx={cubicIn:"0.32,0,0.67,0",cubicOut:"0.33,1,0.68,1",cubicInOut:"0.65,0,0.35,1",quadraticIn:"0.11,0,0.5,0",quadraticOut:"0.5,1,0.89,1",quadraticInOut:"0.45,0,0.55,1",quarticIn:"0.5,0,0.75,0",quarticOut:"0.25,1,0.5,1",quarticInOut:"0.76,0,0.24,1",quinticIn:"0.64,0,0.78,0",quinticOut:"0.22,1,0.36,1",quinticInOut:"0.83,0,0.17,1",sinusoidalIn:"0.12,0,0.39,0",sinusoidalOut:"0.61,1,0.88,1",sinusoidalInOut:"0.37,0,0.63,1",exponentialIn:"0.7,0,0.84,0",exponentialOut:"0.16,1,0.3,1",exponentialInOut:"0.87,0,0.13,1",circularIn:"0.55,0,1,0.45",circularOut:"0,0.55,0.45,1",circularInOut:"0.85,0,0.15,1"},pi="transform-origin";function LG(r,t,e){var a=G({},r.shape);G(a,t),r.buildPath(e,a);var n=new s2;return n.reset(RA(r)),e.rebuildPath(n,1),n.generateStr(),n.getStr()}function IG(r,t){var e=t.originX,a=t.originY;(e||a)&&(r[pi]=e+"px "+a+"px")}var PG={fill:"fill",opacity:"opacity",lineWidth:"stroke-width",lineDashOffset:"stroke-dashoffset"};function h2(r,t){var e=t.zrId+"-ani-"+t.cssAnimIdx++;return t.cssAnims[e]=r,e}function RG(r,t,e){var a=r.shape.paths,n={},i,o;if(A(a,function(l){var u=ey(e.zrId);u.animation=!0,nc(l,{},u,!0);var f=u.cssAnims,v=u.cssNodes,h=Ct(f),c=h.length;if(c){o=h[c-1];var p=f[o];for(var d in p){var g=p[d];n[d]=n[d]||{d:""},n[d].d+=g.d||""}for(var y in v){var m=v[y].animation;m.indexOf(o)>=0&&(i=m)}}}),!!i){t.d=!1;var s=h2(n,e);return i.replace(o,s)}}function gx(r){return X(r)?dx[r]?"cubic-bezier("+dx[r]+")":im(r)?r:"":""}function nc(r,t,e,a){var n=r.animators,i=n.length,o=[];if(r instanceof Mu){var s=RG(r,t,e);if(s)o.push(s);else if(!i)return}else if(!i)return;for(var l={},u=0;u<i;u++){var f=n[u],v=[f.getMaxTime()/1e3+"s"],h=gx(f.getClip().easing),c=f.getDelay();h?v.push(h):v.push("linear"),c&&v.push(c/1e3+"s"),f.getLoop()&&v.push("infinite");var p=v.join(" ");l[p]=l[p]||[p,[]],l[p][1].push(f)}function d(m){var _=m[1],S=_.length,x={},b={},w={},T="animation-timing-function";function C(vt,at,dt){for(var J=vt.getTracks(),ht=vt.getMaxTime(),zt=0;zt<J.length;zt++){var Dt=J[zt];if(Dt.needsAnimate()){var Et=Dt.keyframes,Vt=Dt.propName;if(dt&&(Vt=dt(Vt)),Vt)for(var de=0;de<Et.length;de++){var er=Et[de],$e=Math.round(er.time/ht*100)+"%",Fn=gx(er.easing),io=er.rawValue;(X(io)||Mt(io))&&(at[$e]=at[$e]||{},at[$e][Vt]=er.rawValue,Fn&&(at[$e][T]=Fn))}}}}for(var M=0;M<S;M++){var D=_[M],I=D.targetName;I?I==="shape"&&C(D,b):!a&&C(D,x)}for(var L in x){var P={};Rv(P,r),G(P,x[L]);var k=kA(P),R=x[L][T];w[L]=k?{transform:k}:{},IG(w[L],P),R&&(w[L][T]=R)}var O,E=!0;for(var L in b){w[L]=w[L]||{};var B=!O,R=b[L][T];B&&(O=new ma);var V=O.len();O.reset(),w[L].d=LG(r,b[L],O);var F=O.len();if(!B&&V!==F){E=!1;break}R&&(w[L][T]=R)}if(!E)for(var L in w)delete w[L].d;if(!a)for(var M=0;M<S;M++){var D=_[M],I=D.targetName;I==="style"&&C(D,w,function(J){return PG[J]})}for(var H=Ct(w),Y=!0,K,M=1;M<H.length;M++){var ft=H[M-1],It=H[M];if(w[ft][pi]!==w[It][pi]){Y=!1;break}K=w[ft][pi]}if(Y&&K){for(var L in w)w[L][pi]&&delete w[L][pi];t[pi]=K}if(Pt(H,function(vt){return Ct(w[vt]).length>0}).length){var Ot=h2(w,e);return Ot+" "+m[0]+" both"}}for(var g in l){var s=d(l[g]);s&&o.push(s)}if(o.length){var y=e.zrId+"-cls-"+v2();e.cssNodes["."+y]={animation:o.join(",")},t.class=y}}function kG(r,t,e){if(!r.ignore)if(r.isSilent()){var a={"pointer-events":"none"};yx(a,t,e)}else{var n=r.states.emphasis&&r.states.emphasis.style?r.states.emphasis.style:{},i=n.fill;if(!i){var o=r.style&&r.style.fill,s=r.states.select&&r.states.select.style&&r.states.select.style.fill,l=r.currentStates.indexOf("select")>=0&&s||o;l&&(i=Lv(l))}var u=n.lineWidth;if(u){var f=!n.strokeNoScale&&r.transform?r.transform[0]:1;u=u/f}var a={cursor:"pointer"};i&&(a.fill=i),n.stroke&&(a.stroke=n.stroke),u&&(a["stroke-width"]=u),yx(a,t,e)}}function yx(r,t,e,a){var n=JSON.stringify(r),i=e.cssStyleCache[n];i||(i=e.zrId+"-cls-"+v2(),e.cssStyleCache[n]=i,e.cssNodes["."+i+":hover"]=r),t.class=t.class?t.class+" "+i:i}var ou=Math.round;function c2(r){return r&&X(r.src)}function p2(r){return r&&tt(r.toDataURL)}function _0(r,t,e,a){bG(function(n,i){var o=n==="fill"||n==="stroke";o&&PA(i)?g2(t,r,n,a):o&&sm(i)?y2(e,r,n,a):r[n]=i,o&&a.ssr&&i==="none"&&(r["pointer-events"]="visible")},t,e,!1),GG(e,r,a)}function S0(r,t){var e=GA(t);e&&(e.each(function(a,n){a!=null&&(r[(cx+n).toLowerCase()]=a+"")}),t.isSilent()&&(r[cx+"silent"]="true"))}function mx(r){return mn(r[0]-1)&&mn(r[1])&&mn(r[2])&&mn(r[3]-1)}function EG(r){return mn(r[4])&&mn(r[5])}function x0(r,t,e){if(t&&!(EG(t)&&mx(t))){var a=1e4;r.transform=mx(t)?"translate("+ou(t[4]*a)/a+" "+ou(t[5]*a)/a+")":Lk(t)}}function _x(r,t,e){for(var a=r.points,n=[],i=0;i<a.length;i++)n.push(ou(a[i][0]*e)/e),n.push(ou(a[i][1]*e)/e);t.points=n.join(" ")}function Sx(r){return!r.smooth}function OG(r){var t=U(r,function(e){return typeof e=="string"?[e,e]:e});return function(e,a,n){for(var i=0;i<t.length;i++){var o=t[i],s=e[o[0]];s!=null&&(a[o[1]]=ou(s*n)/n)}}}var NG={circle:[OG(["cx","cy","r"])],polyline:[_x,Sx],polygon:[_x,Sx]};function BG(r){for(var t=r.animators,e=0;e<t.length;e++)if(t[e].targetName==="shape")return!0;return!1}function d2(r,t){var e=r.style,a=r.shape,n=NG[r.type],i={},o=t.animation,s="path",l=r.style.strokePercent,u=t.compress&&RA(r)||4;if(n&&!t.willUpdate&&!(n[1]&&!n[1](a))&&!(o&&BG(r))&&!(l<1)){s=r.type;var f=Math.pow(10,u);n[0](a,i,f)}else{var v=!r.path||r.shapeChanged();r.path||r.createPathProxy();var h=r.path;v&&(h.beginPath(),r.buildPath(h,r.shape),r.pathUpdated());var c=h.getVersion(),p=r,d=p.__svgPathBuilder;(p.__svgPathVersion!==c||!d||l!==p.__svgPathStrokePercent)&&(d||(d=p.__svgPathBuilder=new s2),d.reset(u),h.rebuildPath(d,l),d.generateStr(),p.__svgPathVersion=c,p.__svgPathStrokePercent=l),i.d=d.getStr()}return x0(i,r.transform),_0(i,e,r,t),S0(i,r),t.animation&&nc(r,i,t),t.emphasis&&kG(r,i,t),ye(s,r.id+"",i)}function zG(r,t){var e=r.style,a=e.image;if(a&&!X(a)&&(c2(a)?a=a.src:p2(a)&&(a=a.toDataURL())),!!a){var n=e.x||0,i=e.y||0,o=e.width,s=e.height,l={href:a,width:o,height:s};return n&&(l.x=n),i&&(l.y=i),x0(l,r.transform),_0(l,e,r,t),S0(l,r),t.animation&&nc(r,l,t),ye("image",r.id+"",l)}}function VG(r,t){var e=r.style,a=e.text;if(a!=null&&(a+=""),!(!a||isNaN(e.x)||isNaN(e.y))){var n=e.font||Ya,i=e.x||0,o=Pk(e.y||0,wu(n),e.textBaseline),s=Ik[e.textAlign]||e.textAlign,l={"dominant-baseline":"central","text-anchor":s};if(hM(e)){var u="",f=e.fontStyle,v=vM(e.fontSize);if(!parseFloat(v))return;var h=e.fontFamily||nA,c=e.fontWeight;u+="font-size:"+v+";font-family:"+h+";",f&&f!=="normal"&&(u+="font-style:"+f+";"),c&&c!=="normal"&&(u+="font-weight:"+c+";"),l.style=u}else l.style="font: "+n;return a.match(/\s/)&&(l["xml:space"]="preserve"),i&&(l.x=i),o&&(l.y=o),x0(l,r.transform),_0(l,e,r,t),S0(l,r),t.animation&&nc(r,l,t),ye("text",r.id+"",l,void 0,a)}}function xx(r,t){if(r instanceof bt)return d2(r,t);if(r instanceof xe)return zG(r,t);if(r instanceof ts)return VG(r,t)}function GG(r,t,e){var a=r.style;if(Rk(a)){var n=kk(r),i=e.shadowCache,o=i[n];if(!o){var s=r.getGlobalScale(),l=s[0],u=s[1];if(!l||!u)return;var f=a.shadowOffsetX||0,v=a.shadowOffsetY||0,h=a.shadowBlur,c=Zl(a.shadowColor),p=c.opacity,d=c.color,g=h/2/l,y=h/2/u,m=g+" "+y;o=e.zrId+"-s"+e.shadowIdx++,e.defs[o]=ye("filter",o,{id:o,x:"-100%",y:"-100%",width:"300%",height:"300%"},[ye("feDropShadow","",{dx:f/l,dy:v/u,stdDeviation:m,"flood-color":d,"flood-opacity":p})]),i[n]=o}t.filter=Bh(o)}}function g2(r,t,e,a){var n=r[e],i,o={gradientUnits:n.global?"userSpaceOnUse":"objectBoundingBox"};if(LA(n))i="linearGradient",o.x1=n.x,o.y1=n.y,o.x2=n.x2,o.y2=n.y2;else if(IA(n))i="radialGradient",o.cx=Q(n.x,.5),o.cy=Q(n.y,.5),o.r=Q(n.r,.5);else return;for(var s=n.colorStops,l=[],u=0,f=s.length;u<f;++u){var v=Qd(s[u].offset)*100+"%",h=s[u].color,c=Zl(h),p=c.color,d=c.opacity,g={offset:v};g["stop-color"]=p,d<1&&(g["stop-opacity"]=d),l.push(ye("stop",u+"",g))}var y=ye(i,"",o,l),m=m0(y),_=a.gradientCache,S=_[m];S||(S=a.zrId+"-g"+a.gradientIdx++,_[m]=S,o.id=S,a.defs[S]=ye(i,S,o,l)),t[e]=Bh(S)}function y2(r,t,e,a){var n=r.style[e],i=r.getBoundingRect(),o={},s=n.repeat,l=s==="no-repeat",u=s==="repeat-x",f=s==="repeat-y",v;if(DA(n)){var h=n.imageWidth,c=n.imageHeight,p=void 0,d=n.image;if(X(d)?p=d:c2(d)?p=d.src:p2(d)&&(p=d.toDataURL()),typeof Image>"u"){var g="Image width/height must been given explictly in svg-ssr renderer.";Re(h,g),Re(c,g)}else if(h==null||c==null){var y=function(M,D){if(M){var I=M.elm,L=h||D.width,P=c||D.height;M.tag==="pattern"&&(u?(P=1,L/=i.width):f&&(L=1,P/=i.height)),M.attrs.width=L,M.attrs.height=P,I&&(I.setAttribute("width",L),I.setAttribute("height",P))}},m=gm(p,null,r,function(M){l||y(b,M),y(v,M)});m&&m.width&&m.height&&(h=h||m.width,c=c||m.height)}v=ye("image","img",{href:p,width:h,height:c}),o.width=h,o.height=c}else n.svgElement&&(v=et(n.svgElement),o.width=n.svgWidth,o.height=n.svgHeight);if(v){var _,S;l?_=S=1:u?(S=1,_=o.width/i.width):f?(_=1,S=o.height/i.height):o.patternUnits="userSpaceOnUse",_!=null&&!isNaN(_)&&(o.width=_),S!=null&&!isNaN(S)&&(o.height=S);var x=kA(n);x&&(o.patternTransform=x);var b=ye("pattern","",o,[v]),w=m0(b),T=a.patternCache,C=T[w];C||(C=a.zrId+"-p"+a.patternIdx++,T[w]=C,o.id=C,b=a.defs[C]=ye("pattern",C,o,[v])),t[e]=Bh(C)}}function FG(r,t,e){var a=e.clipPathCache,n=e.defs,i=a[r.id];if(!i){i=e.zrId+"-c"+e.clipPathIdx++;var o={id:i};a[r.id]=i,n[i]=ye("clipPath",i,o,[d2(r,e)])}t["clip-path"]=Bh(i)}function bx(r){return document.createTextNode(r)}function xi(r,t,e){r.insertBefore(t,e)}function Tx(r,t){r.removeChild(t)}function Cx(r,t){r.appendChild(t)}function m2(r){return r.parentNode}function _2(r){return r.nextSibling}function Mp(r,t){r.textContent=t}var Ax=58,HG=120,WG=ye("","");function ry(r){return r===void 0}function na(r){return r!==void 0}function UG(r,t,e){for(var a={},n=t;n<=e;++n){var i=r[n].key;i!==void 0&&(a[i]=n)}return a}function _l(r,t){var e=r.key===t.key,a=r.tag===t.tag;return a&&e}function su(r){var t,e=r.children,a=r.tag;if(na(a)){var n=r.elm=f2(a);if(b0(WG,r),W(e))for(t=0;t<e.length;++t){var i=e[t];i!=null&&Cx(n,su(i))}else na(r.text)&&!it(r.text)&&Cx(n,bx(r.text))}else r.elm=bx(r.text);return r.elm}function S2(r,t,e,a,n){for(;a<=n;++a){var i=e[a];i!=null&&xi(r,su(i),t)}}function oh(r,t,e,a){for(;e<=a;++e){var n=t[e];if(n!=null)if(na(n.tag)){var i=m2(n.elm);Tx(i,n.elm)}else Tx(r,n.elm)}}function b0(r,t){var e,a=t.elm,n=r&&r.attrs||{},i=t.attrs||{};if(n!==i){for(e in i){var o=i[e],s=n[e];s!==o&&(o===!0?a.setAttribute(e,""):o===!1?a.removeAttribute(e):e==="style"?a.style.cssText=o:e.charCodeAt(0)!==HG?a.setAttribute(e,o):e==="xmlns:xlink"||e==="xmlns"?a.setAttributeNS(wG,e,o):e.charCodeAt(3)===Ax?a.setAttributeNS(TG,e,o):e.charCodeAt(5)===Ax?a.setAttributeNS(u2,e,o):a.setAttribute(e,o))}for(e in n)e in i||a.removeAttribute(e)}}function YG(r,t,e){for(var a=0,n=0,i=t.length-1,o=t[0],s=t[i],l=e.length-1,u=e[0],f=e[l],v,h,c,p;a<=i&&n<=l;)o==null?o=t[++a]:s==null?s=t[--i]:u==null?u=e[++n]:f==null?f=e[--l]:_l(o,u)?(Eo(o,u),o=t[++a],u=e[++n]):_l(s,f)?(Eo(s,f),s=t[--i],f=e[--l]):_l(o,f)?(Eo(o,f),xi(r,o.elm,_2(s.elm)),o=t[++a],f=e[--l]):_l(s,u)?(Eo(s,u),xi(r,s.elm,o.elm),s=t[--i],u=e[++n]):(ry(v)&&(v=UG(t,a,i)),h=v[u.key],ry(h)?xi(r,su(u),o.elm):(c=t[h],c.tag!==u.tag?xi(r,su(u),o.elm):(Eo(c,u),t[h]=void 0,xi(r,c.elm,o.elm))),u=e[++n]);(a<=i||n<=l)&&(a>i?(p=e[l+1]==null?null:e[l+1].elm,S2(r,p,e,n,l)):oh(r,t,a,i))}function Eo(r,t){var e=t.elm=r.elm,a=r.children,n=t.children;r!==t&&(b0(r,t),ry(t.text)?na(a)&&na(n)?a!==n&&YG(e,a,n):na(n)?(na(r.text)&&Mp(e,""),S2(e,null,n,0,n.length-1)):na(a)?oh(e,a,0,a.length-1):na(r.text)&&Mp(e,""):r.text!==t.text&&(na(a)&&oh(e,a,0,a.length-1),Mp(e,t.text)))}function ZG(r,t){if(_l(r,t))Eo(r,t);else{var e=r.elm,a=m2(e);su(t),a!==null&&(xi(a,t.elm,_2(e)),oh(a,[r],0,0))}return t}var XG=0,$G=function(){function r(t,e,a){if(this.type="svg",this.refreshHover=Mx(),this.configLayer=Mx(),this.storage=e,this._opts=a=G({},a),this.root=t,this._id="zr"+XG++,this._oldVNode=px(a.width,a.height),t&&!a.ssr){var n=this._viewport=document.createElement("div");n.style.cssText="position:relative;overflow:hidden";var i=this._svgDom=this._oldVNode.elm=f2("svg");b0(null,this._oldVNode),n.appendChild(i),t.appendChild(n)}this.resize(a.width,a.height)}return r.prototype.getType=function(){return this.type},r.prototype.getViewportRoot=function(){return this._viewport},r.prototype.getViewportRootOffset=function(){var t=this.getViewportRoot();if(t)return{offsetLeft:t.offsetLeft||0,offsetTop:t.offsetTop||0}},r.prototype.getSvgDom=function(){return this._svgDom},r.prototype.refresh=function(){if(this.root){var t=this.renderToVNode({willUpdate:!0});t.attrs.style="position:absolute;left:0;top:0;user-select:none",ZG(this._oldVNode,t),this._oldVNode=t}},r.prototype.renderOneToVNode=function(t){return xx(t,ey(this._id))},r.prototype.renderToVNode=function(t){t=t||{};var e=this.storage.getDisplayList(!0),a=this._width,n=this._height,i=ey(this._id);i.animation=t.animation,i.willUpdate=t.willUpdate,i.compress=t.compress,i.emphasis=t.emphasis,i.ssr=this._opts.ssr;var o=[],s=this._bgVNode=qG(a,n,this._backgroundColor,i);s&&o.push(s);var l=t.compress?null:this._mainVNode=ye("g","main",{},[]);this._paintList(e,i,l?l.children:o),l&&o.push(l);var u=U(Ct(i.defs),function(h){return i.defs[h]});if(u.length&&o.push(ye("defs","defs",{},u)),t.animation){var f=MG(i.cssNodes,i.cssAnims,{newline:!0});if(f){var v=ye("style","stl",{},[],f);o.push(v)}}return px(a,n,o,t.useViewBox)},r.prototype.renderToString=function(t){return t=t||{},m0(this.renderToVNode({animation:Q(t.cssAnimation,!0),emphasis:Q(t.cssEmphasis,!0),willUpdate:!1,compress:!0,useViewBox:Q(t.useViewBox,!0)}),{newline:!0})},r.prototype.setBackgroundColor=function(t){this._backgroundColor=t},r.prototype.getSvgRoot=function(){return this._mainVNode&&this._mainVNode.elm},r.prototype._paintList=function(t,e,a){for(var n=t.length,i=[],o=0,s,l,u=0,f=0;f<n;f++){var v=t[f];if(!v.invisible){var h=v.__clipPaths,c=h&&h.length||0,p=l&&l.length||0,d=void 0;for(d=Math.max(c-1,p-1);d>=0&&!(h&&l&&h[d]===l[d]);d--);for(var g=p-1;g>d;g--)o--,s=i[o-1];for(var y=d+1;y<c;y++){var m={};FG(h[y],m,e);var _=ye("g","clip-g-"+u++,m,[]);(s?s.children:a).push(_),i[o++]=_,s=_}l=h;var S=xx(v,e);S&&(s?s.children:a).push(S)}}},r.prototype.resize=function(t,e){var a=this._opts,n=this.root,i=this._viewport;if(t!=null&&(a.width=t),e!=null&&(a.height=e),n&&i&&(i.style.display="none",t=Ho(n,0,a),e=Ho(n,1,a),i.style.display=""),this._width!==t||this._height!==e){if(this._width=t,this._height=e,i){var o=i.style;o.width=t+"px",o.height=e+"px"}if(sm(this._backgroundColor))this.refresh();else{var s=this._svgDom;s&&(s.setAttribute("width",t),s.setAttribute("height",e));var l=this._bgVNode&&this._bgVNode.elm;l&&(l.setAttribute("width",t),l.setAttribute("height",e))}}},r.prototype.getWidth=function(){return this._width},r.prototype.getHeight=function(){return this._height},r.prototype.dispose=function(){this.root&&(this.root.innerHTML=""),this._svgDom=this._viewport=this.storage=this._oldVNode=this._bgVNode=this._mainVNode=null},r.prototype.clear=function(){this._svgDom&&(this._svgDom.innerHTML=null),this._oldVNode=null},r.prototype.toDataURL=function(t){var e=this.renderToString(),a="data:image/svg+xml;";return t?(e=Ok(e),e&&a+"base64,"+e):a+"charset=UTF-8,"+encodeURIComponent(e)},r}();function Mx(r){return function(){}}function qG(r,t,e,a){var n;if(e&&e!=="none")if(n=ye("rect","bg",{width:r,height:t,x:"0",y:"0"}),PA(e))g2({fill:e},n.attrs,"fill",a);else if(sm(e))y2({style:{fill:e},dirty:jt,getBoundingRect:function(){return{width:r,height:t}}},n.attrs,"fill",a);else{var i=Zl(e),o=i.color,s=i.opacity;n.attrs.fill=o,s<1&&(n.attrs["fill-opacity"]=s)}return n}function KG(r){r.registerPainter("svg",$G)}function Dx(r,t,e){var a=tr.createCanvas(),n=t.getWidth(),i=t.getHeight(),o=a.style;return o&&(o.position="absolute",o.left="0",o.top="0",o.width=n+"px",o.height=i+"px",a.setAttribute("data-zr-dom-id",r)),a.width=n*e,a.height=i*e,a}var Dp=function(r){Zt(t,r);function t(e,a,n){var i=r.call(this)||this;i.motionBlur=!1,i.lastFrameAlpha=.7,i.dpr=1,i.virtual=!1,i.config={},i.incremental=!1,i.zlevel=0,i.maxRepaintRectCount=5,i.__dirty=!0,i.__firstTimePaint=!0,i.__used=!1,i.__drawIndex=0,i.__startIndex=0,i.__endIndex=0,i.__prevStartIndex=null,i.__prevEndIndex=null;var o;n=n||Pv,typeof e=="string"?o=Dx(e,a,n):it(e)&&(o=e,e=o.id),i.id=e,i.dom=o;var s=o.style;return s&&(rm(o),o.onselectstart=function(){return!1},s.padding="0",s.margin="0",s.borderWidth="0"),i.painter=a,i.dpr=n,i}return t.prototype.getElementCount=function(){return this.__endIndex-this.__startIndex},t.prototype.afterBrush=function(){this.__prevStartIndex=this.__startIndex,this.__prevEndIndex=this.__endIndex},t.prototype.initContext=function(){this.ctx=this.dom.getContext("2d"),this.ctx.dpr=this.dpr},t.prototype.setUnpainted=function(){this.__firstTimePaint=!0},t.prototype.createBackBuffer=function(){var e=this.dpr;this.domBack=Dx("back-"+this.id,this.painter,e),this.ctxBack=this.domBack.getContext("2d"),e!==1&&this.ctxBack.scale(e,e)},t.prototype.createRepaintRects=function(e,a,n,i){if(this.__firstTimePaint)return this.__firstTimePaint=!1,null;var o=[],s=this.maxRepaintRectCount,l=!1,u=new lt(0,0,0,0);function f(m){if(!(!m.isFinite()||m.isZero()))if(o.length===0){var _=new lt(0,0,0,0);_.copy(m),o.push(_)}else{for(var S=!1,x=1/0,b=0,w=0;w<o.length;++w){var T=o[w];if(T.intersect(m)){var C=new lt(0,0,0,0);C.copy(T),C.union(m),o[w]=C,S=!0;break}else if(l){u.copy(m),u.union(T);var M=m.width*m.height,D=T.width*T.height,I=u.width*u.height,L=I-M-D;L<x&&(x=L,b=w)}}if(l&&(o[b].union(m),S=!0),!S){var _=new lt(0,0,0,0);_.copy(m),o.push(_)}l||(l=o.length>=s)}}for(var v=this.__startIndex;v<this.__endIndex;++v){var h=e[v];if(h){var c=h.shouldBePainted(n,i,!0,!0),p=h.__isRendered&&(h.__dirty&ir||!c)?h.getPrevPaintRect():null;p&&f(p);var d=c&&(h.__dirty&ir||!h.__isRendered)?h.getPaintRect():null;d&&f(d)}}for(var v=this.__prevStartIndex;v<this.__prevEndIndex;++v){var h=a[v],c=h&&h.shouldBePainted(n,i,!0,!0);if(h&&(!c||!h.__zr)&&h.__isRendered){var p=h.getPrevPaintRect();p&&f(p)}}var g;do{g=!1;for(var v=0;v<o.length;){if(o[v].isZero()){o.splice(v,1);continue}for(var y=v+1;y<o.length;)o[v].intersect(o[y])?(g=!0,o[v].union(o[y]),o.splice(y,1)):y++;v++}}while(g);return this._paintRects=o,o},t.prototype.debugGetPaintRects=function(){return(this._paintRects||[]).slice()},t.prototype.resize=function(e,a){var n=this.dpr,i=this.dom,o=i.style,s=this.domBack;o&&(o.width=e+"px",o.height=a+"px"),i.width=e*n,i.height=a*n,s&&(s.width=e*n,s.height=a*n,n!==1&&this.ctxBack.scale(n,n))},t.prototype.clear=function(e,a,n){var i=this.dom,o=this.ctx,s=i.width,l=i.height;a=a||this.clearColor;var u=this.motionBlur&&!e,f=this.lastFrameAlpha,v=this.dpr,h=this;u&&(this.domBack||this.createBackBuffer(),this.ctxBack.globalCompositeOperation="copy",this.ctxBack.drawImage(i,0,0,s/v,l/v));var c=this.domBack;function p(d,g,y,m){if(o.clearRect(d,g,y,m),a&&a!=="transparent"){var _=void 0;if(mu(a)){var S=a.global||a.__width===y&&a.__height===m;_=S&&a.__canvasGradient||Vg(o,a,{x:0,y:0,width:y,height:m}),a.__canvasGradient=_,a.__width=y,a.__height=m}else sA(a)&&(a.scaleX=a.scaleX||v,a.scaleY=a.scaleY||v,_=Gg(o,a,{dirty:function(){h.setUnpainted(),h.painter.refresh()}}));o.save(),o.fillStyle=_||a,o.fillRect(d,g,y,m),o.restore()}u&&(o.save(),o.globalAlpha=f,o.drawImage(c,d,g,y,m),o.restore())}!n||u?p(0,0,s,l):n.length&&A(n,function(d){p(d.x*v,d.y*v,d.width*v,d.height*v)})},t}(Pr),Lx=1e5,hi=314159,Cf=.01,jG=.001;function JG(r){return r?r.__builtin__?!0:!(typeof r.resize!="function"||typeof r.refresh!="function"):!1}function QG(r,t){var e=document.createElement("div");return e.style.cssText=["position:relative","width:"+r+"px","height:"+t+"px","padding:0","margin:0","border-width:0"].join(";")+";",e}var t3=function(){function r(t,e,a,n){this.type="canvas",this._zlevelList=[],this._prevDisplayList=[],this._layers={},this._layerConfig={},this._needsManuallyCompositing=!1,this.type="canvas";var i=!t.nodeName||t.nodeName.toUpperCase()==="CANVAS";this._opts=a=G({},a||{}),this.dpr=a.devicePixelRatio||Pv,this._singleCanvas=i,this.root=t;var o=t.style;o&&(rm(t),t.innerHTML=""),this.storage=e;var s=this._zlevelList;this._prevDisplayList=[];var l=this._layers;if(i){var f=t,v=f.width,h=f.height;a.width!=null&&(v=a.width),a.height!=null&&(h=a.height),this.dpr=a.devicePixelRatio||1,f.width=v*this.dpr,f.height=h*this.dpr,this._width=v,this._height=h;var c=new Dp(f,this,this.dpr);c.__builtin__=!0,c.initContext(),l[hi]=c,c.zlevel=hi,s.push(hi),this._domRoot=t}else{this._width=Ho(t,0,a),this._height=Ho(t,1,a);var u=this._domRoot=QG(this._width,this._height);t.appendChild(u)}}return r.prototype.getType=function(){return"canvas"},r.prototype.isSingleCanvas=function(){return this._singleCanvas},r.prototype.getViewportRoot=function(){return this._domRoot},r.prototype.getViewportRootOffset=function(){var t=this.getViewportRoot();if(t)return{offsetLeft:t.offsetLeft||0,offsetTop:t.offsetTop||0}},r.prototype.refresh=function(t){var e=this.storage.getDisplayList(!0),a=this._prevDisplayList,n=this._zlevelList;this._redrawId=Math.random(),this._paintList(e,a,t,this._redrawId);for(var i=0;i<n.length;i++){var o=n[i],s=this._layers[o];if(!s.__builtin__&&s.refresh){var l=i===0?this._backgroundColor:null;s.refresh(l)}}return this._opts.useDirtyRect&&(this._prevDisplayList=e.slice()),this},r.prototype.refreshHover=function(){this._paintHoverList(this.storage.getDisplayList(!1))},r.prototype._paintHoverList=function(t){var e=t.length,a=this._hoverlayer;if(a&&a.clear(),!!e){for(var n={inHover:!0,viewWidth:this._width,viewHeight:this._height},i,o=0;o<e;o++){var s=t[o];s.__inHover&&(a||(a=this._hoverlayer=this.getLayer(Lx)),i||(i=a.ctx,i.save()),Ii(i,s,n,o===e-1))}i&&i.restore()}},r.prototype.getHoverLayer=function(){return this.getLayer(Lx)},r.prototype.paintOne=function(t,e){tL(t,e)},r.prototype._paintList=function(t,e,a,n){if(this._redrawId===n){a=a||!1,this._updateLayerStatus(t);var i=this._doPaintList(t,e,a),o=i.finished,s=i.needsRefreshHover;if(this._needsManuallyCompositing&&this._compositeManually(),s&&this._paintHoverList(t),o)this.eachLayer(function(u){u.afterBrush&&u.afterBrush()});else{var l=this;Cv(function(){l._paintList(t,e,a,n)})}}},r.prototype._compositeManually=function(){var t=this.getLayer(hi).ctx,e=this._domRoot.width,a=this._domRoot.height;t.clearRect(0,0,e,a),this.eachBuiltinLayer(function(n){n.virtual&&t.drawImage(n.dom,0,0,e,a)})},r.prototype._doPaintList=function(t,e,a){for(var n=this,i=[],o=this._opts.useDirtyRect,s=0;s<this._zlevelList.length;s++){var l=this._zlevelList[s],u=this._layers[l];u.__builtin__&&u!==this._hoverlayer&&(u.__dirty||a)&&i.push(u)}for(var f=!0,v=!1,h=function(d){var g=i[d],y=g.ctx,m=o&&g.createRepaintRects(t,e,c._width,c._height),_=a?g.__startIndex:g.__drawIndex,S=!a&&g.incremental&&Date.now,x=S&&Date.now(),b=g.zlevel===c._zlevelList[0]?c._backgroundColor:null;if(g.__startIndex===g.__endIndex)g.clear(!1,b,m);else if(_===g.__startIndex){var w=t[_];(!w.incremental||!w.notClear||a)&&g.clear(!1,b,m)}_===-1&&(console.error("For some unknown reason. drawIndex is -1"),_=g.__startIndex);var T,C=function(L){var P={inHover:!1,allClipped:!1,prevEl:null,viewWidth:n._width,viewHeight:n._height};for(T=_;T<g.__endIndex;T++){var k=t[T];if(k.__inHover&&(v=!0),n._doPaintEl(k,g,o,L,P,T===g.__endIndex-1),S){var R=Date.now()-x;if(R>15)break}}P.prevElClipPaths&&y.restore()};if(m)if(m.length===0)T=g.__endIndex;else for(var M=c.dpr,D=0;D<m.length;++D){var I=m[D];y.save(),y.beginPath(),y.rect(I.x*M,I.y*M,I.width*M,I.height*M),y.clip(),C(I),y.restore()}else y.save(),C(),y.restore();g.__drawIndex=T,g.__drawIndex<g.__endIndex&&(f=!1)},c=this,p=0;p<i.length;p++)h(p);return Tt.wxa&&A(this._layers,function(d){d&&d.ctx&&d.ctx.draw&&d.ctx.draw()}),{finished:f,needsRefreshHover:v}},r.prototype._doPaintEl=function(t,e,a,n,i,o){var s=e.ctx;if(a){var l=t.getPaintRect();(!n||l&&l.intersect(n))&&(Ii(s,t,i,o),t.setPrevPaintRect(l))}else Ii(s,t,i,o)},r.prototype.getLayer=function(t,e){this._singleCanvas&&!this._needsManuallyCompositing&&(t=hi);var a=this._layers[t];return a||(a=new Dp("zr_"+t,this,this.dpr),a.zlevel=t,a.__builtin__=!0,this._layerConfig[t]?yt(a,this._layerConfig[t],!0):this._layerConfig[t-Cf]&&yt(a,this._layerConfig[t-Cf],!0),e&&(a.virtual=e),this.insertLayer(t,a),a.initContext()),a},r.prototype.insertLayer=function(t,e){var a=this._layers,n=this._zlevelList,i=n.length,o=this._domRoot,s=null,l=-1;if(!a[t]&&JG(e)){if(i>0&&t>n[0]){for(l=0;l<i-1&&!(n[l]<t&&n[l+1]>t);l++);s=a[n[l]]}if(n.splice(l+1,0,t),a[t]=e,!e.virtual)if(s){var u=s.dom;u.nextSibling?o.insertBefore(e.dom,u.nextSibling):o.appendChild(e.dom)}else o.firstChild?o.insertBefore(e.dom,o.firstChild):o.appendChild(e.dom);e.painter||(e.painter=this)}},r.prototype.eachLayer=function(t,e){for(var a=this._zlevelList,n=0;n<a.length;n++){var i=a[n];t.call(e,this._layers[i],i)}},r.prototype.eachBuiltinLayer=function(t,e){for(var a=this._zlevelList,n=0;n<a.length;n++){var i=a[n],o=this._layers[i];o.__builtin__&&t.call(e,o,i)}},r.prototype.eachOtherLayer=function(t,e){for(var a=this._zlevelList,n=0;n<a.length;n++){var i=a[n],o=this._layers[i];o.__builtin__||t.call(e,o,i)}},r.prototype.getLayers=function(){return this._layers},r.prototype._updateLayerStatus=function(t){this.eachBuiltinLayer(function(v,h){v.__dirty=v.__used=!1});function e(v){i&&(i.__endIndex!==v&&(i.__dirty=!0),i.__endIndex=v)}if(this._singleCanvas)for(var a=1;a<t.length;a++){var n=t[a];if(n.zlevel!==t[a-1].zlevel||n.incremental){this._needsManuallyCompositing=!0;break}}var i=null,o=0,s,l;for(l=0;l<t.length;l++){var n=t[l],u=n.zlevel,f=void 0;s!==u&&(s=u,o=0),n.incremental?(f=this.getLayer(u+jG,this._needsManuallyCompositing),f.incremental=!0,o=1):f=this.getLayer(u+(o>0?Cf:0),this._needsManuallyCompositing),f.__builtin__||Rh("ZLevel "+u+" has been used by unkown layer "+f.id),f!==i&&(f.__used=!0,f.__startIndex!==l&&(f.__dirty=!0),f.__startIndex=l,f.incremental?f.__drawIndex=-1:f.__drawIndex=l,e(l),i=f),n.__dirty&ir&&!n.__inHover&&(f.__dirty=!0,f.incremental&&f.__drawIndex<0&&(f.__drawIndex=l))}e(l),this.eachBuiltinLayer(function(v,h){!v.__used&&v.getElementCount()>0&&(v.__dirty=!0,v.__startIndex=v.__endIndex=v.__drawIndex=0),v.__dirty&&v.__drawIndex<0&&(v.__drawIndex=v.__startIndex)})},r.prototype.clear=function(){return this.eachBuiltinLayer(this._clearLayer),this},r.prototype._clearLayer=function(t){t.clear()},r.prototype.setBackgroundColor=function(t){this._backgroundColor=t,A(this._layers,function(e){e.setUnpainted()})},r.prototype.configLayer=function(t,e){if(e){var a=this._layerConfig;a[t]?yt(a[t],e,!0):a[t]=e;for(var n=0;n<this._zlevelList.length;n++){var i=this._zlevelList[n];if(i===t||i===t+Cf){var o=this._layers[i];yt(o,a[t],!0)}}}},r.prototype.delLayer=function(t){var e=this._layers,a=this._zlevelList,n=e[t];n&&(n.dom.parentNode.removeChild(n.dom),delete e[t],a.splice(gt(a,t),1))},r.prototype.resize=function(t,e){if(this._domRoot.style){var a=this._domRoot;a.style.display="none";var n=this._opts,i=this.root;if(t!=null&&(n.width=t),e!=null&&(n.height=e),t=Ho(i,0,n),e=Ho(i,1,n),a.style.display="",this._width!==t||e!==this._height){a.style.width=t+"px",a.style.height=e+"px";for(var o in this._layers)this._layers.hasOwnProperty(o)&&this._layers[o].resize(t,e);this.refresh(!0)}this._width=t,this._height=e}else{if(t==null||e==null)return;this._width=t,this._height=e,this.getLayer(hi).resize(t,e)}return this},r.prototype.clearLayer=function(t){var e=this._layers[t];e&&e.clear()},r.prototype.dispose=function(){this.root.innerHTML="",this.root=this.storage=this._domRoot=this._layers=null},r.prototype.getRenderedCanvas=function(t){if(t=t||{},this._singleCanvas&&!this._compositeManually)return this._layers[hi].dom;var e=new Dp("image",this,t.pixelRatio||this.dpr);e.initContext(),e.clear(!1,t.backgroundColor||this._backgroundColor);var a=e.ctx;if(t.pixelRatio<=this.dpr){this.refresh();var n=e.dom.width,i=e.dom.height;this.eachLayer(function(v){v.__builtin__?a.drawImage(v.dom,0,0,n,i):v.renderToCanvas&&(a.save(),v.renderToCanvas(a),a.restore())})}else for(var o={inHover:!1,viewWidth:this._width,viewHeight:this._height},s=this.storage.getDisplayList(!0),l=0,u=s.length;l<u;l++){var f=s[l];Ii(a,f,o,l===u-1)}return e.dom},r.prototype.getWidth=function(){return this._width},r.prototype.getHeight=function(){return this._height},r}();function e3(r){r.registerPainter("canvas",t3)}var r3=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.hasSymbolVisual=!0,e}return t.prototype.getInitialData=function(e){return Ca(null,this,{useEncodeDefaulter:!0})},t.prototype.getLegendIcon=function(e){var a=new rt,n=ie("line",0,e.itemHeight/2,e.itemWidth,0,e.lineStyle.stroke,!1);a.add(n),n.setStyle(e.lineStyle);var i=this.getData().getVisual("symbol"),o=this.getData().getVisual("symbolRotate"),s=i==="none"?"circle":i,l=e.itemHeight*.8,u=ie(s,(e.itemWidth-l)/2,(e.itemHeight-l)/2,l,l,e.itemStyle.fill);a.add(u),u.setStyle(e.itemStyle);var f=e.iconRotate==="inherit"?o:e.iconRotate||0;return u.rotation=f*Math.PI/180,u.setOrigin([e.itemWidth/2,e.itemHeight/2]),s.indexOf("empty")>-1&&(u.style.stroke=u.style.fill,u.style.fill=N.color.neutral00,u.style.lineWidth=2),a},t.type="series.line",t.dependencies=["grid","polar"],t.defaultOption={z:3,coordinateSystem:"cartesian2d",legendHoverLink:!0,clip:!0,label:{position:"top"},endLabel:{show:!1,valueAnimation:!0,distance:8},lineStyle:{width:2,type:"solid"},emphasis:{scale:!0},step:!1,smooth:!1,smoothMonotone:null,symbol:"emptyCircle",symbolSize:6,symbolRotate:null,showSymbol:!0,showAllSymbol:"auto",connectNulls:!1,sampling:"none",animationEasing:"linear",progressive:0,hoverLayerThreshold:1/0,universalTransition:{divideShape:"clone"},triggerLineEvent:!1},t}(Bt);function ss(r,t){var e=r.mapDimensionsAll("defaultedLabel"),a=e.length;if(a===1){var n=as(r,t,e[0]);return n!=null?n+"":null}else if(a){for(var i=[],o=0;o<e.length;o++)i.push(as(r,t,e[o]));return i.join(" ")}}function x2(r,t){var e=r.mapDimensionsAll("defaultedLabel");if(!W(t))return t+"";for(var a=[],n=0;n<e.length;n++){var i=r.getDimensionIndex(e[n]);i>=0&&a.push(t[i])}return a.join(" ")}var ku=function(r){z(t,r);function t(e,a,n,i){var o=r.call(this)||this;return o.updateData(e,a,n,i),o}return t.prototype._createSymbol=function(e,a,n,i,o,s){this.removeAll();var l=ie(e,-1,-1,2,2,null,s);l.attr({z2:Q(o,100),culling:!0,scaleX:i[0]/2,scaleY:i[1]/2}),l.drift=a3,this._symbolType=e,this.add(l)},t.prototype.stopSymbolAnimation=function(e){this.childAt(0).stopAnimation(null,e)},t.prototype.getSymbolType=function(){return this._symbolType},t.prototype.getSymbolPath=function(){return this.childAt(0)},t.prototype.highlight=function(){Xa(this.childAt(0))},t.prototype.downplay=function(){$a(this.childAt(0))},t.prototype.setZ=function(e,a){var n=this.childAt(0);n.zlevel=e,n.z=a},t.prototype.setDraggable=function(e,a){var n=this.childAt(0);n.draggable=e,n.cursor=!a&&e?"move":n.cursor},t.prototype.updateData=function(e,a,n,i){this.silent=!1;var o=e.getItemVisual(a,"symbol")||"circle",s=e.hostModel,l=t.getSymbolSize(e,a),u=t.getSymbolZ2(e,a),f=o!==this._symbolType,v=i&&i.disableAnimation;if(f){var h=e.getItemVisual(a,"symbolKeepAspect");this._createSymbol(o,e,a,l,u,h)}else{var c=this.childAt(0);c.silent=!1;var p={scaleX:l[0]/2,scaleY:l[1]/2};v?c.attr(p):Lt(c,p,s,a),Ir(c)}if(this._updateCommon(e,a,l,n,i),f){var c=this.childAt(0);if(!v){var p={scaleX:this._sizeX,scaleY:this._sizeY,style:{opacity:c.style.opacity}};c.scaleX=c.scaleY=0,c.style.opacity=0,Yt(c,p,s,a)}}v&&this.childAt(0).stopAnimation("leave")},t.prototype._updateCommon=function(e,a,n,i,o){var s=this.childAt(0),l=e.hostModel,u,f,v,h,c,p,d,g,y;if(i&&(u=i.emphasisItemStyle,f=i.blurItemStyle,v=i.selectItemStyle,h=i.focus,c=i.blurScope,d=i.labelStatesModels,g=i.hoverScale,y=i.cursorStyle,p=i.emphasisDisabled),!i||e.hasItemOption){var m=i&&i.itemModel?i.itemModel:e.getItemModel(a),_=m.getModel("emphasis");u=_.getModel("itemStyle").getItemStyle(),v=m.getModel(["select","itemStyle"]).getItemStyle(),f=m.getModel(["blur","itemStyle"]).getItemStyle(),h=_.get("focus"),c=_.get("blurScope"),p=_.get("disabled"),d=ce(m),g=_.getShallow("scale"),y=m.getShallow("cursor")}var S=e.getItemVisual(a,"symbolRotate");s.attr("rotation",(S||0)*Math.PI/180||0);var x=to(e.getItemVisual(a,"symbolOffset"),n);x&&(s.x=x[0],s.y=x[1]),y&&s.attr("cursor",y);var b=e.getItemVisual(a,"style"),w=b.fill;if(s instanceof xe){var T=s.style;s.useStyle(G({image:T.image,x:T.x,y:T.y,width:T.width,height:T.height},b))}else s.__isEmptyBrush?s.useStyle(G({},b)):s.useStyle(b),s.style.decal=null,s.setColor(w,o&&o.symbolInnerColor),s.style.strokeNoScale=!0;var C=e.getItemVisual(a,"liftZ"),M=this._z2;C!=null?M==null&&(this._z2=s.z2,s.z2+=C):M!=null&&(s.z2=M,this._z2=null);var D=o&&o.useNameLabel;Se(s,d,{labelFetcher:l,labelDataIndex:a,defaultText:I,inheritColor:w,defaultOpacity:b.opacity});function I(k){return D?e.getName(k):ss(e,k)}this._sizeX=n[0]/2,this._sizeY=n[1]/2;var L=s.ensureState("emphasis");L.style=u,s.ensureState("select").style=v,s.ensureState("blur").style=f;var P=g==null||g===!0?Math.max(1.1,3/this._sizeY):isFinite(g)&&g>0?+g:1;L.scaleX=this._sizeX*P,L.scaleY=this._sizeY*P,this.setSymbolScale(1),$t(this,h,c,p)},t.prototype.setSymbolScale=function(e){this.scaleX=this.scaleY=e},t.prototype.fadeOut=function(e,a,n){var i=this.childAt(0),o=ut(this).dataIndex,s=n&&n.animation;if(this.silent=i.silent=!0,n&&n.fadeLabel){var l=i.getTextContent();l&&Pn(l,{style:{opacity:0}},a,{dataIndex:o,removeOpt:s,cb:function(){i.removeTextContent()}})}else i.removeTextContent();Pn(i,{style:{opacity:0},scaleX:0,scaleY:0},a,{dataIndex:o,cb:e,removeOpt:s})},t.getSymbolSize=function(e,a){return Ms(e.getItemVisual(a,"symbolSize"))},t.getSymbolZ2=function(e,a){return e.getItemVisual(a,"z2")},t}(rt);function a3(r,t){this.parent.drift(r,t)}function Lp(r,t,e,a){return t&&!isNaN(t[0])&&!isNaN(t[1])&&!(a.isIgnore&&a.isIgnore(e))&&!(a.clipShape&&!a.clipShape.contain(t[0],t[1]))&&r.getItemVisual(e,"symbol")!=="none"}function Ix(r){return r!=null&&!it(r)&&(r={isIgnore:r}),r||{}}function Px(r){var t=r.hostModel,e=t.getModel("emphasis");return{emphasisItemStyle:e.getModel("itemStyle").getItemStyle(),blurItemStyle:t.getModel(["blur","itemStyle"]).getItemStyle(),selectItemStyle:t.getModel(["select","itemStyle"]).getItemStyle(),focus:e.get("focus"),blurScope:e.get("blurScope"),emphasisDisabled:e.get("disabled"),hoverScale:e.get("scale"),labelStatesModels:ce(t),cursorStyle:t.get("cursor")}}var Eu=function(){function r(t){this.group=new rt,this._SymbolCtor=t||ku}return r.prototype.updateData=function(t,e){this._progressiveEls=null,e=Ix(e);var a=this.group,n=t.hostModel,i=this._data,o=this._SymbolCtor,s=e.disableAnimation,l=Px(t),u={disableAnimation:s},f=e.getSymbolPoint||function(v){return t.getItemLayout(v)};i||a.removeAll(),t.diff(i).add(function(v){var h=f(v);if(Lp(t,h,v,e)){var c=new o(t,v,l,u);c.setPosition(h),t.setItemGraphicEl(v,c),a.add(c)}}).update(function(v,h){var c=i.getItemGraphicEl(h),p=f(v);if(!Lp(t,p,v,e)){a.remove(c);return}var d=t.getItemVisual(v,"symbol")||"circle",g=c&&c.getSymbolType&&c.getSymbolType();if(!c||g&&g!==d)a.remove(c),c=new o(t,v,l,u),c.setPosition(p);else{c.updateData(t,v,l,u);var y={x:p[0],y:p[1]};s?c.attr(y):Lt(c,y,n)}a.add(c),t.setItemGraphicEl(v,c)}).remove(function(v){var h=i.getItemGraphicEl(v);h&&h.fadeOut(function(){a.remove(h)},n)}).execute(),this._getSymbolPoint=f,this._data=t},r.prototype.updateLayout=function(){var t=this,e=this._data;e&&e.eachItemGraphicEl(function(a,n){var i=t._getSymbolPoint(n);a.setPosition(i),a.markRedraw()})},r.prototype.incrementalPrepareUpdate=function(t){this._seriesScope=Px(t),this._data=null,this.group.removeAll()},r.prototype.incrementalUpdate=function(t,e,a){this._progressiveEls=[],a=Ix(a);function n(l){l.isGroup||(l.incremental=!0,l.ensureState("emphasis").hoverLayer=!0)}for(var i=t.start;i<t.end;i++){var o=e.getItemLayout(i);if(Lp(e,o,i,a)){var s=new this._SymbolCtor(e,i,this._seriesScope);s.traverse(n),s.setPosition(o),this.group.add(s),e.setItemGraphicEl(i,s),this._progressiveEls.push(s)}}},r.prototype.eachRendered=function(t){zn(this._progressiveEls||this.group,t)},r.prototype.remove=function(t){var e=this.group,a=this._data;a&&t?a.eachItemGraphicEl(function(n){n.fadeOut(function(){e.remove(n)},a.hostModel)}):e.removeAll()},r}();function b2(r,t,e){var a=r.getBaseAxis(),n=r.getOtherAxis(a),i=n3(n,e),o=a.dim,s=n.dim,l=t.mapDimension(s),u=t.mapDimension(o),f=s==="x"||s==="radius"?1:0,v=U(r.dimensions,function(p){return t.mapDimension(p)}),h=!1,c=t.getCalculationInfo("stackResultDimension");return Ka(t,v[0])&&(h=!0,v[0]=c),Ka(t,v[1])&&(h=!0,v[1]=c),{dataDimsForPoint:v,valueStart:i,valueAxisDim:s,baseAxisDim:o,stacked:!!h,valueDim:l,baseDim:u,baseDataOffset:f,stackedOverDimension:t.getCalculationInfo("stackedOverDimension")}}function n3(r,t){var e=0,a=r.scale.getExtent();return t==="start"?e=a[0]:t==="end"?e=a[1]:Mt(t)&&!isNaN(t)?e=t:a[0]>0?e=a[0]:a[1]<0&&(e=a[1]),e}function w2(r,t,e,a){var n=NaN;r.stacked&&(n=e.get(e.getCalculationInfo("stackedOverDimension"),a)),isNaN(n)&&(n=r.valueStart);var i=r.baseDataOffset,o=[];return o[i]=e.get(r.baseDim,a),o[1-i]=n,t.dataToPoint(o)}function i3(r,t){var e=[];return t.diff(r).add(function(a){e.push({cmd:"+",idx:a})}).update(function(a,n){e.push({cmd:"=",idx:n,idx1:a})}).remove(function(a){e.push({cmd:"-",idx:a})}).execute(),e}function o3(r,t,e,a,n,i,o,s){for(var l=i3(r,t),u=[],f=[],v=[],h=[],c=[],p=[],d=[],g=b2(n,t,o),y=r.getLayout("points")||[],m=t.getLayout("points")||[],_=0;_<l.length;_++){var S=l[_],x=!0,b=void 0,w=void 0;switch(S.cmd){case"=":b=S.idx*2,w=S.idx1*2;var T=y[b],C=y[b+1],M=m[w],D=m[w+1];(isNaN(T)||isNaN(C))&&(T=M,C=D),u.push(T,C),f.push(M,D),v.push(e[b],e[b+1]),h.push(a[w],a[w+1]),d.push(t.getRawIndex(S.idx1));break;case"+":var I=S.idx,L=g.dataDimsForPoint,P=n.dataToPoint([t.get(L[0],I),t.get(L[1],I)]);w=I*2,u.push(P[0],P[1]),f.push(m[w],m[w+1]);var k=w2(g,n,t,I);v.push(k[0],k[1]),h.push(a[w],a[w+1]),d.push(t.getRawIndex(I));break;case"-":x=!1}x&&(c.push(S),p.push(p.length))}p.sort(function(ft,It){return d[ft]-d[It]});for(var R=u.length,O=fa(R),E=fa(R),B=fa(R),V=fa(R),F=[],_=0;_<p.length;_++){var H=p[_],Y=_*2,K=H*2;O[Y]=u[K],O[Y+1]=u[K+1],E[Y]=f[K],E[Y+1]=f[K+1],B[Y]=v[K],B[Y+1]=v[K+1],V[Y]=h[K],V[Y+1]=h[K+1],F[_]=c[H]}return{current:O,next:E,stackedOnCurrent:B,stackedOnNext:V,status:F}}var ln=Math.min,un=Math.max;function Ni(r,t){return isNaN(r)||isNaN(t)}function ay(r,t,e,a,n,i,o,s,l){for(var u,f,v,h,c,p,d=e,g=0;g<a;g++){var y=t[d*2],m=t[d*2+1];if(d>=n||d<0)break;if(Ni(y,m)){if(l){d+=i;continue}break}if(d===e)r[i>0?"moveTo":"lineTo"](y,m),v=y,h=m;else{var _=y-u,S=m-f;if(_*_+S*S<.5){d+=i;continue}if(o>0){for(var x=d+i,b=t[x*2],w=t[x*2+1];b===y&&w===m&&g<a;)g++,x+=i,d+=i,b=t[x*2],w=t[x*2+1],y=t[d*2],m=t[d*2+1],_=y-u,S=m-f;var T=g+1;if(l)for(;Ni(b,w)&&T<a;)T++,x+=i,b=t[x*2],w=t[x*2+1];var C=.5,M=0,D=0,I=void 0,L=void 0;if(T>=a||Ni(b,w))c=y,p=m;else{M=b-u,D=w-f;var P=y-u,k=b-y,R=m-f,O=w-m,E=void 0,B=void 0;if(s==="x"){E=Math.abs(P),B=Math.abs(k);var V=M>0?1:-1;c=y-V*E*o,p=m,I=y+V*B*o,L=m}else if(s==="y"){E=Math.abs(R),B=Math.abs(O);var F=D>0?1:-1;c=y,p=m-F*E*o,I=y,L=m+F*B*o}else E=Math.sqrt(P*P+R*R),B=Math.sqrt(k*k+O*O),C=B/(B+E),c=y-M*o*(1-C),p=m-D*o*(1-C),I=y+M*o*C,L=m+D*o*C,I=ln(I,un(b,y)),L=ln(L,un(w,m)),I=un(I,ln(b,y)),L=un(L,ln(w,m)),M=I-y,D=L-m,c=y-M*E/B,p=m-D*E/B,c=ln(c,un(u,y)),p=ln(p,un(f,m)),c=un(c,ln(u,y)),p=un(p,ln(f,m)),M=y-c,D=m-p,I=y+M*B/E,L=m+D*B/E}r.bezierCurveTo(v,h,c,p,y,m),v=I,h=L}else r.lineTo(y,m)}u=y,f=m,d+=i}return g}var T2=function(){function r(){this.smooth=0,this.smoothConstraint=!0}return r}(),s3=function(r){z(t,r);function t(e){var a=r.call(this,e)||this;return a.type="ec-polyline",a}return t.prototype.getDefaultStyle=function(){return{stroke:N.color.neutral99,fill:null}},t.prototype.getDefaultShape=function(){return new T2},t.prototype.buildPath=function(e,a){var n=a.points,i=0,o=n.length/2;if(a.connectNulls){for(;o>0&&Ni(n[o*2-2],n[o*2-1]);o--);for(;i<o&&Ni(n[i*2],n[i*2+1]);i++);}for(;i<o;)i+=ay(e,n,i,o,o,1,a.smooth,a.smoothMonotone,a.connectNulls)+1},t.prototype.getPointOn=function(e,a){this.path||(this.createPathProxy(),this.buildPath(this.path,this.shape));for(var n=this.path,i=n.data,o=ma.CMD,s,l,u=a==="x",f=[],v=0;v<i.length;){var h=i[v++],c=void 0,p=void 0,d=void 0,g=void 0,y=void 0,m=void 0,_=void 0;switch(h){case o.M:s=i[v++],l=i[v++];break;case o.L:if(c=i[v++],p=i[v++],_=u?(e-s)/(c-s):(e-l)/(p-l),_<=1&&_>=0){var S=u?(p-l)*_+l:(c-s)*_+s;return u?[e,S]:[S,e]}s=c,l=p;break;case o.C:c=i[v++],p=i[v++],d=i[v++],g=i[v++],y=i[v++],m=i[v++];var x=u?Mv(s,c,d,y,e,f):Mv(l,p,g,m,e,f);if(x>0)for(var b=0;b<x;b++){var w=f[b];if(w<=1&&w>=0){var S=u?ge(l,p,g,m,w):ge(s,c,d,y,w);return u?[e,S]:[S,e]}}s=y,l=m;break}}},t}(bt),l3=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t}(T2),C2=function(r){z(t,r);function t(e){var a=r.call(this,e)||this;return a.type="ec-polygon",a}return t.prototype.getDefaultShape=function(){return new l3},t.prototype.buildPath=function(e,a){var n=a.points,i=a.stackedOnPoints,o=0,s=n.length/2,l=a.smoothMonotone;if(a.connectNulls){for(;s>0&&Ni(n[s*2-2],n[s*2-1]);s--);for(;o<s&&Ni(n[o*2],n[o*2+1]);o++);}for(;o<s;){var u=ay(e,n,o,s,s,1,a.smooth,l,a.connectNulls);ay(e,i,o+u-1,u,s,-1,a.stackedOnSmooth,l,a.connectNulls),o+=u+1,e.closePath()}},t}(bt);function A2(r,t,e,a,n){var i=r.getArea(),o=i.x,s=i.y,l=i.width,u=i.height,f=e.get(["lineStyle","width"])||0;o-=f/2,s-=f/2,l+=f,u+=f,l=Math.ceil(l),o!==Math.floor(o)&&(o=Math.floor(o),l++);var v=new _t({shape:{x:o,y:s,width:l,height:u}});if(t){var h=r.getBaseAxis(),c=h.isHorizontal(),p=h.inverse;c?(p&&(v.shape.x+=l),v.shape.width=0):(p||(v.shape.y+=u),v.shape.height=0);var d=tt(n)?function(g){n(g,v)}:null;Yt(v,{shape:{width:l,height:u,x:o,y:s}},e,null,a,d)}return v}function M2(r,t,e){var a=r.getArea(),n=ae(a.r0,1),i=ae(a.r,1),o=new ke({shape:{cx:ae(r.cx,1),cy:ae(r.cy,1),r0:n,r:i,startAngle:a.startAngle,endAngle:a.endAngle,clockwise:a.clockwise}});if(t){var s=r.getBaseAxis().dim==="angle";s?o.shape.endAngle=a.startAngle:o.shape.r=n,Yt(o,{shape:{endAngle:a.endAngle,r:i}},e)}return o}function Ou(r,t,e,a,n){if(r){if(r.type==="polar")return M2(r,t,e);if(r.type==="cartesian2d")return A2(r,t,e,a,n)}else return null;return null}function Rn(r,t){return r.type===t}function Rx(r,t){if(r.length===t.length){for(var e=0;e<r.length;e++)if(r[e]!==t[e])return;return!0}}function kx(r){for(var t=1/0,e=1/0,a=-1/0,n=-1/0,i=0;i<r.length;){var o=r[i++],s=r[i++];isNaN(o)||(t=Math.min(o,t),a=Math.max(o,a)),isNaN(s)||(e=Math.min(s,e),n=Math.max(s,n))}return[[t,e],[a,n]]}function Ex(r,t){var e=kx(r),a=e[0],n=e[1],i=kx(t),o=i[0],s=i[1];return Math.max(Math.abs(a[0]-o[0]),Math.abs(a[1]-o[1]),Math.abs(n[0]-s[0]),Math.abs(n[1]-s[1]))}function Ox(r){return Mt(r)?r:r?.5:0}function u3(r,t,e){if(!e.valueDim)return[];for(var a=t.count(),n=fa(a*2),i=0;i<a;i++){var o=w2(e,r,t,i);n[i*2]=o[0],n[i*2+1]=o[1]}return n}function fn(r,t,e,a,n){var i=e.getBaseAxis(),o=i.dim==="x"||i.dim==="radius"?0:1,s=[],l=0,u=[],f=[],v=[],h=[];if(n){for(l=0;l<r.length;l+=2){var c=t||r;!isNaN(c[l])&&!isNaN(c[l+1])&&h.push(r[l],r[l+1])}r=h}for(l=0;l<r.length-2;l+=2)switch(v[0]=r[l+2],v[1]=r[l+3],f[0]=r[l],f[1]=r[l+1],s.push(f[0],f[1]),a){case"end":u[o]=v[o],u[1-o]=f[1-o],s.push(u[0],u[1]);break;case"middle":var p=(f[o]+v[o])/2,d=[];u[o]=d[o]=p,u[1-o]=f[1-o],d[1-o]=v[1-o],s.push(u[0],u[1]),s.push(d[0],d[1]);break;default:u[o]=f[o],u[1-o]=v[1-o],s.push(u[0],u[1])}return s.push(r[l++],r[l++]),s}function f3(r,t){var e=[],a=r.length,n,i;function o(f,v,h){var c=f.coord,p=(h-c)/(v.coord-c),d=om(p,[f.color,v.color]);return{coord:h,color:d}}for(var s=0;s<a;s++){var l=r[s],u=l.coord;if(u<0)n=l;else if(u>t){i?e.push(o(i,l,t)):n&&e.push(o(n,l,0),o(n,l,t));break}else n&&(e.push(o(n,l,0)),n=null),e.push(l),i=l}return e}function v3(r,t,e){var a=r.getVisual("visualMeta");if(!(!a||!a.length||!r.count())&&t.type==="cartesian2d"){for(var n,i,o=a.length-1;o>=0;o--){var s=r.getDimensionInfo(a[o].dimension);if(n=s&&s.coordDim,n==="x"||n==="y"){i=a[o];break}}if(i){var l=t.getAxis(n),u=U(i.stops,function(_){return{coord:l.toGlobalCoord(l.dataToCoord(_.value)),color:_.color}}),f=u.length,v=i.outerColors.slice();f&&u[0].coord>u[f-1].coord&&(u.reverse(),v.reverse());var h=f3(u,n==="x"?e.getWidth():e.getHeight()),c=h.length;if(!c&&f)return u[0].coord<0?v[1]?v[1]:u[f-1].color:v[0]?v[0]:u[0].color;var p=10,d=h[0].coord-p,g=h[c-1].coord+p,y=g-d;if(y<.001)return"transparent";A(h,function(_){_.offset=(_.coord-d)/y}),h.push({offset:c?h[c-1].offset:.5,color:v[1]||"transparent"}),h.unshift({offset:c?h[0].offset:.5,color:v[0]||"transparent"});var m=new Ki(0,0,0,0,h,!0);return m[n]=d,m[n+"2"]=g,m}}}function h3(r,t,e){var a=r.get("showAllSymbol"),n=a==="auto";if(!(a&&!n)){var i=e.getAxesByScale("ordinal")[0];if(i&&!(n&&c3(i,t))){var o=t.mapDimension(i.dim),s={};return A(i.getViewLabels(),function(l){var u=i.scale.getRawOrdinalNumber(l.tickValue);s[u]=1}),function(l){return!s.hasOwnProperty(t.get(o,l))}}}}function c3(r,t){var e=r.getExtent(),a=Math.abs(e[1]-e[0])/r.scale.count();isNaN(a)&&(a=0);for(var n=t.count(),i=Math.max(1,Math.round(n/5)),o=0;o<n;o+=i)if(ku.getSymbolSize(t,o)[r.isHorizontal()?1:0]*1.5>a)return!1;return!0}function p3(r,t){return isNaN(r)||isNaN(t)}function d3(r){for(var t=r.length/2;t>0&&p3(r[t*2-2],r[t*2-1]);t--);return t-1}function Nx(r,t){return[r[t*2],r[t*2+1]]}function g3(r,t,e){for(var a=r.length/2,n=e==="x"?0:1,i,o,s=0,l=-1,u=0;u<a;u++)if(o=r[u*2+n],!(isNaN(o)||isNaN(r[u*2+1-n]))){if(u===0){i=o;continue}if(i<=t&&o>=t||i>=t&&o<=t){l=u;break}s=u,i=o}return{range:[s,l],t:(t-i)/(o-i)}}function D2(r){if(r.get(["endLabel","show"]))return!0;for(var t=0;t<Xe.length;t++)if(r.get([Xe[t],"endLabel","show"]))return!0;return!1}function Ip(r,t,e,a){if(Rn(t,"cartesian2d")){var n=a.getModel("endLabel"),i=n.get("valueAnimation"),o=a.getData(),s={lastFrameIndex:0},l=D2(a)?function(c,p){r._endLabelOnDuring(c,p,o,s,i,n,t)}:null,u=t.getBaseAxis().isHorizontal(),f=A2(t,e,a,function(){var c=r._endLabel;c&&e&&s.originalX!=null&&c.attr({x:s.originalX,y:s.originalY})},l);if(!a.get("clip",!0)){var v=f.shape,h=Math.max(v.width,v.height);u?(v.y-=h,v.height+=h*2):(v.x-=h,v.width+=h*2)}return l&&l(1,f),f}else return M2(t,e,a)}function y3(r,t){var e=t.getBaseAxis(),a=e.isHorizontal(),n=e.inverse,i=a?n?"right":"left":"center",o=a?"middle":n?"top":"bottom";return{normal:{align:r.get("align")||i,verticalAlign:r.get("verticalAlign")||o}}}var m3=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.init=function(){var e=new rt,a=new Eu;this.group.add(a.group),this._symbolDraw=a,this._lineGroup=e,this._changePolyState=$(this._changePolyState,this)},t.prototype.render=function(e,a,n){var i=e.coordinateSystem,o=this.group,s=e.getData(),l=e.getModel("lineStyle"),u=e.getModel("areaStyle"),f=s.getLayout("points")||[],v=i.type==="polar",h=this._coordSys,c=this._symbolDraw,p=this._polyline,d=this._polygon,g=this._lineGroup,y=!a.ssr&&e.get("animation"),m=!u.isEmpty(),_=u.get("origin"),S=b2(i,s,_),x=m&&u3(i,s,S),b=e.get("showSymbol"),w=e.get("connectNulls"),T=b&&!v&&h3(e,s,i),C=this._data;C&&C.eachItemGraphicEl(function(ft,It){ft.__temp&&(o.remove(ft),C.setItemGraphicEl(It,null))}),b||c.remove(),o.add(g);var M=v?!1:e.get("step"),D;i&&i.getArea&&e.get("clip",!0)&&(D=i.getArea(),D.width!=null?(D.x-=.1,D.y-=.1,D.width+=.2,D.height+=.2):D.r0&&(D.r0-=.5,D.r+=.5)),this._clipShapeForSymbol=D;var I=v3(s,i,n)||s.getVisual("style")[s.getVisual("drawType")];if(!(p&&h.type===i.type&&M===this._step))b&&c.updateData(s,{isIgnore:T,clipShape:D,disableAnimation:!0,getSymbolPoint:function(ft){return[f[ft*2],f[ft*2+1]]}}),y&&this._initSymbolLabelAnimation(s,i,D),M&&(x&&(x=fn(x,f,i,M,w)),f=fn(f,null,i,M,w)),p=this._newPolyline(f),m?d=this._newPolygon(f,x):d&&(g.remove(d),d=this._polygon=null),v||this._initOrUpdateEndLabel(e,i,Yi(I)),g.setClipPath(Ip(this,i,!0,e));else{m&&!d?d=this._newPolygon(f,x):d&&!m&&(g.remove(d),d=this._polygon=null),v||this._initOrUpdateEndLabel(e,i,Yi(I));var L=g.getClipPath();if(L){var P=Ip(this,i,!1,e);Yt(L,{shape:P.shape},e)}else g.setClipPath(Ip(this,i,!0,e));b&&c.updateData(s,{isIgnore:T,clipShape:D,disableAnimation:!0,getSymbolPoint:function(ft){return[f[ft*2],f[ft*2+1]]}}),(!Rx(this._stackedOnPoints,x)||!Rx(this._points,f))&&(y?this._doUpdateAnimation(s,x,i,n,M,_,w):(M&&(x&&(x=fn(x,f,i,M,w)),f=fn(f,null,i,M,w)),p.setShape({points:f}),d&&d.setShape({points:f,stackedOnPoints:x})))}var k=e.getModel("emphasis"),R=k.get("focus"),O=k.get("blurScope"),E=k.get("disabled");if(p.useStyle(nt(l.getLineStyle(),{fill:"none",stroke:I,lineJoin:"bevel"})),he(p,e,"lineStyle"),p.style.lineWidth>0&&e.get(["emphasis","lineStyle","width"])==="bolder"){var B=p.getState("emphasis").style;B.lineWidth=+p.style.lineWidth+1}ut(p).seriesIndex=e.seriesIndex,$t(p,R,O,E);var V=Ox(e.get("smooth")),F=e.get("smoothMonotone");if(p.setShape({smooth:V,smoothMonotone:F,connectNulls:w}),d){var H=s.getCalculationInfo("stackedOnSeries"),Y=0;d.useStyle(nt(u.getAreaStyle(),{fill:I,opacity:.7,lineJoin:"bevel",decal:s.getVisual("style").decal})),H&&(Y=Ox(H.get("smooth"))),d.setShape({smooth:V,stackedOnSmooth:Y,smoothMonotone:F,connectNulls:w}),he(d,e,"areaStyle"),ut(d).seriesIndex=e.seriesIndex,$t(d,R,O,E)}var K=this._changePolyState;s.eachItemGraphicEl(function(ft){ft&&(ft.onHoverStateChange=K)}),this._polyline.onHoverStateChange=K,this._data=s,this._coordSys=i,this._stackedOnPoints=x,this._points=f,this._step=M,this._valueOrigin=_,e.get("triggerLineEvent")&&(this.packEventData(e,p),d&&this.packEventData(e,d))},t.prototype.packEventData=function(e,a){ut(a).eventData={componentType:"series",componentSubType:"line",componentIndex:e.componentIndex,seriesIndex:e.seriesIndex,seriesName:e.name,seriesType:"line"}},t.prototype.highlight=function(e,a,n,i){var o=e.getData(),s=Gi(o,i);if(this._changePolyState("emphasis"),!(s instanceof Array)&&s!=null&&s>=0){var l=o.getLayout("points"),u=o.getItemGraphicEl(s);if(!u){var f=l[s*2],v=l[s*2+1];if(isNaN(f)||isNaN(v)||this._clipShapeForSymbol&&!this._clipShapeForSymbol.contain(f,v))return;var h=e.get("zlevel")||0,c=e.get("z")||0;u=new ku(o,s),u.x=f,u.y=v,u.setZ(h,c);var p=u.getSymbolPath().getTextContent();p&&(p.zlevel=h,p.z=c,p.z2=this._polyline.z2+1),u.__temp=!0,o.setItemGraphicEl(s,u),u.stopSymbolAnimation(!0),this.group.add(u)}u.highlight()}else Nt.prototype.highlight.call(this,e,a,n,i)},t.prototype.downplay=function(e,a,n,i){var o=e.getData(),s=Gi(o,i);if(this._changePolyState("normal"),s!=null&&s>=0){var l=o.getItemGraphicEl(s);l&&(l.__temp?(o.setItemGraphicEl(s,null),this.group.remove(l)):l.downplay())}else Nt.prototype.downplay.call(this,e,a,n,i)},t.prototype._changePolyState=function(e){var a=this._polygon;zv(this._polyline,e),a&&zv(a,e)},t.prototype._newPolyline=function(e){var a=this._polyline;return a&&this._lineGroup.remove(a),a=new s3({shape:{points:e},segmentIgnoreThreshold:2,z2:10}),this._lineGroup.add(a),this._polyline=a,a},t.prototype._newPolygon=function(e,a){var n=this._polygon;return n&&this._lineGroup.remove(n),n=new C2({shape:{points:e,stackedOnPoints:a},segmentIgnoreThreshold:2}),this._lineGroup.add(n),this._polygon=n,n},t.prototype._initSymbolLabelAnimation=function(e,a,n){var i,o,s=a.getBaseAxis(),l=s.inverse;a.type==="cartesian2d"?(i=s.isHorizontal(),o=!1):a.type==="polar"&&(i=s.dim==="angle",o=!0);var u=e.hostModel,f=u.get("animationDuration");tt(f)&&(f=f(null));var v=u.get("animationDelay")||0,h=tt(v)?v(null):v;e.eachItemGraphicEl(function(c,p){var d=c;if(d){var g=[c.x,c.y],y=void 0,m=void 0,_=void 0;if(n)if(o){var S=n,x=a.pointToCoord(g);i?(y=S.startAngle,m=S.endAngle,_=-x[1]/180*Math.PI):(y=S.r0,m=S.r,_=x[0])}else{var b=n;i?(y=b.x,m=b.x+b.width,_=c.x):(y=b.y+b.height,m=b.y,_=c.y)}var w=m===y?0:(_-y)/(m-y);l&&(w=1-w);var T=tt(v)?v(p):f*w+h,C=d.getSymbolPath(),M=C.getTextContent();d.attr({scaleX:0,scaleY:0}),d.animateTo({scaleX:1,scaleY:1},{duration:200,setToFinal:!0,delay:T}),M&&M.animateFrom({style:{opacity:0}},{duration:300,delay:T}),C.disableLabelAnimation=!0}})},t.prototype._initOrUpdateEndLabel=function(e,a,n){var i=e.getModel("endLabel");if(D2(e)){var o=e.getData(),s=this._polyline,l=o.getLayout("points");if(!l){s.removeTextContent(),this._endLabel=null;return}var u=this._endLabel;u||(u=this._endLabel=new At({z2:200}),u.ignoreClip=!0,s.setTextContent(this._endLabel),s.disableLabelAnimation=!0);var f=d3(l);f>=0&&(Se(s,ce(e,"endLabel"),{inheritColor:n,labelFetcher:e,labelDataIndex:f,defaultText:function(v,h,c){return c!=null?x2(o,c):ss(o,v)},enableTextSetter:!0},y3(i,a)),s.textConfig.position=null)}else this._endLabel&&(this._polyline.removeTextContent(),this._endLabel=null)},t.prototype._endLabelOnDuring=function(e,a,n,i,o,s,l){var u=this._endLabel,f=this._polyline;if(u){e<1&&i.originalX==null&&(i.originalX=u.x,i.originalY=u.y);var v=n.getLayout("points"),h=n.hostModel,c=h.get("connectNulls"),p=s.get("precision"),d=s.get("distance")||0,g=l.getBaseAxis(),y=g.isHorizontal(),m=g.inverse,_=a.shape,S=m?y?_.x:_.y+_.height:y?_.x+_.width:_.y,x=(y?d:0)*(m?-1:1),b=(y?0:-d)*(m?-1:1),w=y?"x":"y",T=g3(v,S,w),C=T.range,M=C[1]-C[0],D=void 0;if(M>=1){if(M>1&&!c){var I=Nx(v,C[0]);u.attr({x:I[0]+x,y:I[1]+b}),o&&(D=h.getRawValue(C[0]))}else{var I=f.getPointOn(S,w);I&&u.attr({x:I[0]+x,y:I[1]+b});var L=h.getRawValue(C[0]),P=h.getRawValue(C[1]);o&&(D=tM(n,p,L,P,T.t))}i.lastFrameIndex=C[0]}else{var k=e===1||i.lastFrameIndex>0?C[0]:0,I=Nx(v,k);o&&(D=h.getRawValue(k)),u.attr({x:I[0]+x,y:I[1]+b})}if(o){var R=xs(u);typeof R.setLabelText=="function"&&R.setLabelText(D)}}},t.prototype._doUpdateAnimation=function(e,a,n,i,o,s,l){var u=this._polyline,f=this._polygon,v=e.hostModel,h=o3(this._data,e,this._stackedOnPoints,a,this._coordSys,n,this._valueOrigin),c=h.current,p=h.stackedOnCurrent,d=h.next,g=h.stackedOnNext;if(o&&(p=fn(h.stackedOnCurrent,h.current,n,o,l),c=fn(h.current,null,n,o,l),g=fn(h.stackedOnNext,h.next,n,o,l),d=fn(h.next,null,n,o,l)),Ex(c,d)>3e3||f&&Ex(p,g)>3e3){u.stopAnimation(),u.setShape({points:d}),f&&(f.stopAnimation(),f.setShape({points:d,stackedOnPoints:g}));return}u.shape.__points=h.current,u.shape.points=c;var y={shape:{points:d}};h.current!==c&&(y.shape.__points=h.next),u.stopAnimation(),Lt(u,y,v),f&&(f.setShape({points:c,stackedOnPoints:p}),f.stopAnimation(),Lt(f,{shape:{stackedOnPoints:g}},v),u.shape.points!==f.shape.points&&(f.shape.points=u.shape.points));for(var m=[],_=h.status,S=0;S<_.length;S++){var x=_[S].cmd;if(x==="="){var b=e.getItemGraphicEl(_[S].idx1);b&&m.push({el:b,ptIdx:S})}}u.animators&&u.animators.length&&u.animators[0].during(function(){f&&f.dirtyShape();for(var w=u.shape.__points,T=0;T<m.length;T++){var C=m[T].el,M=m[T].ptIdx*2;C.x=w[M],C.y=w[M+1],C.markRedraw()}})},t.prototype.remove=function(e){var a=this.group,n=this._data;this._lineGroup.removeAll(),this._symbolDraw.remove(!0),n&&n.eachItemGraphicEl(function(i,o){i.__temp&&(a.remove(i),n.setItemGraphicEl(o,null))}),this._polyline=this._polygon=this._coordSys=this._points=this._stackedOnPoints=this._endLabel=this._data=null},t.type="line",t}(Nt);function Nu(r,t){return{seriesType:r,plan:Cs(),reset:function(e){var a=e.getData(),n=e.coordinateSystem,i=e.pipelineContext,o=t||i.large;if(n){var s=U(n.dimensions,function(c){return a.mapDimension(c)}).slice(0,2),l=s.length,u=a.getCalculationInfo("stackResultDimension");Ka(a,s[0])&&(s[0]=u),Ka(a,s[1])&&(s[1]=u);var f=a.getStore(),v=a.getDimensionIndex(s[0]),h=a.getDimensionIndex(s[1]);return l&&{progress:function(c,p){for(var d=c.end-c.start,g=o&&fa(d*l),y=[],m=[],_=c.start,S=0;_<c.end;_++){var x=void 0;if(l===1){var b=f.get(v,_);x=n.dataToPoint(b,null,m)}else y[0]=f.get(v,_),y[1]=f.get(h,_),x=n.dataToPoint(y,null,m);o?(g[S++]=x[0],g[S++]=x[1]):p.setItemLayout(_,x.slice())}o&&p.setLayout("points",g)}}}}}}var _3={average:function(r){for(var t=0,e=0,a=0;a<r.length;a++)isNaN(r[a])||(t+=r[a],e++);return e===0?NaN:t/e},sum:function(r){for(var t=0,e=0;e<r.length;e++)t+=r[e]||0;return t},max:function(r){for(var t=-1/0,e=0;e<r.length;e++)r[e]>t&&(t=r[e]);return isFinite(t)?t:NaN},min:function(r){for(var t=1/0,e=0;e<r.length;e++)r[e]<t&&(t=r[e]);return isFinite(t)?t:NaN},nearest:function(r){return r[0]}},S3=function(r){return Math.round(r.length/2)};function L2(r){return{seriesType:r,reset:function(t,e,a){var n=t.getData(),i=t.get("sampling"),o=t.coordinateSystem,s=n.count();if(s>10&&o.type==="cartesian2d"&&i){var l=o.getBaseAxis(),u=o.getOtherAxis(l),f=l.getExtent(),v=a.getDevicePixelRatio(),h=Math.abs(f[1]-f[0])*(v||1),c=Math.round(s/h);if(isFinite(c)&&c>1){i==="lttb"?t.setData(n.lttbDownSample(n.mapDimension(u.dim),1/c)):i==="minmax"&&t.setData(n.minmaxDownSample(n.mapDimension(u.dim),1/c));var p=void 0;X(i)?p=_3[i]:tt(i)&&(p=i),p&&t.setData(n.downSample(n.mapDimension(u.dim),1/c,p,S3))}}}}}function x3(r){r.registerChartView(m3),r.registerSeriesModel(r3),r.registerLayout(Nu("line",!0)),r.registerVisual({seriesType:"line",reset:function(t){var e=t.getData(),a=t.getModel("lineStyle").getLineStyle();a&&!a.stroke&&(a.stroke=e.getVisual("style").fill),e.setVisual("legendLineStyle",a)}}),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,L2("line"))}var lu=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.getInitialData=function(e,a){return Ca(null,this,{useEncodeDefaulter:!0})},t.prototype.getMarkerPosition=function(e,a,n){var i=this.coordinateSystem;if(i&&i.clampData){var o=i.clampData(e),s=i.dataToPoint(o);if(n)A(i.getAxes(),function(h,c){if(h.type==="category"&&a!=null){var p=h.getTicksCoords(),d=h.getTickModel().get("alignWithLabel"),g=o[c],y=a[c]==="x1"||a[c]==="y1";if(y&&!d&&(g+=1),p.length<2)return;if(p.length===2){s[c]=h.toGlobalCoord(h.getExtent()[y?1:0]);return}for(var m=void 0,_=void 0,S=1,x=0;x<p.length;x++){var b=p[x].coord,w=x===p.length-1?p[x-1].tickValue+S:p[x].tickValue;if(w===g){_=b;break}else if(w<g)m=b;else if(m!=null&&w>g){_=(b+m)/2;break}x===1&&(S=w-p[0].tickValue)}_==null&&(m?m&&(_=p[p.length-1].coord):_=p[0].coord),s[c]=h.toGlobalCoord(_)}});else{var l=this.getData(),u=l.getLayout("offset"),f=l.getLayout("size"),v=i.getBaseAxis().isHorizontal()?0:1;s[v]+=u+f/2}return s}return[NaN,NaN]},t.type="series.__base_bar__",t.defaultOption={z:2,coordinateSystem:"cartesian2d",legendHoverLink:!0,barMinHeight:0,barMinAngle:0,large:!1,largeThreshold:400,progressive:3e3,progressiveChunkMode:"mod",defaultBarGap:"10%"},t}(Bt);Bt.registerClass(lu);var b3=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.getInitialData=function(){return Ca(null,this,{useEncodeDefaulter:!0,createInvertedIndices:!!this.get("realtimeSort",!0)||null})},t.prototype.getProgressive=function(){return this.get("large")?this.get("progressive"):!1},t.prototype.getProgressiveThreshold=function(){var e=this.get("progressiveThreshold"),a=this.get("largeThreshold");return a>e&&(e=a),e},t.prototype.brushSelector=function(e,a,n){return n.rect(a.getItemLayout(e))},t.type="series.bar",t.dependencies=["grid","polar"],t.defaultOption=Vn(lu.defaultOption,{clip:!0,roundCap:!1,showBackground:!1,backgroundStyle:{color:"rgba(180, 180, 180, 0.2)",borderColor:null,borderWidth:0,borderType:"solid",borderRadius:0,shadowBlur:0,shadowColor:null,shadowOffsetX:0,shadowOffsetY:0,opacity:1},select:{itemStyle:{borderColor:N.color.primary,borderWidth:2}},realtimeSort:!1}),t}(lu),w3=function(){function r(){this.cx=0,this.cy=0,this.r0=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0}return r}(),sh=function(r){z(t,r);function t(e){var a=r.call(this,e)||this;return a.type="sausage",a}return t.prototype.getDefaultShape=function(){return new w3},t.prototype.buildPath=function(e,a){var n=a.cx,i=a.cy,o=Math.max(a.r0||0,0),s=Math.max(a.r,0),l=(s-o)*.5,u=o+l,f=a.startAngle,v=a.endAngle,h=a.clockwise,c=Math.PI*2,p=h?v-f<c:f-v<c;p||(f=v-(h?c:-c));var d=Math.cos(f),g=Math.sin(f),y=Math.cos(v),m=Math.sin(v);p?(e.moveTo(d*o+n,g*o+i),e.arc(d*u+n,g*u+i,l,-Math.PI+f,f,!h)):e.moveTo(d*s+n,g*s+i),e.arc(n,i,s,f,v,!h),e.arc(y*u+n,m*u+i,l,v-Math.PI*2,v-Math.PI,!h),o!==0&&e.arc(n,i,o,v,f,h)},t}(bt);function T3(r,t){t=t||{};var e=t.isRoundCap;return function(a,n,i){var o=n.position;if(!o||o instanceof Array)return kv(a,n,i);var s=r(o),l=n.distance!=null?n.distance:5,u=this.shape,f=u.cx,v=u.cy,h=u.r,c=u.r0,p=(h+c)/2,d=u.startAngle,g=u.endAngle,y=(d+g)/2,m=e?Math.abs(h-c)/2:0,_=Math.cos,S=Math.sin,x=f+h*_(d),b=v+h*S(d),w="left",T="top";switch(s){case"startArc":x=f+(c-l)*_(y),b=v+(c-l)*S(y),w="center",T="top";break;case"insideStartArc":x=f+(c+l)*_(y),b=v+(c+l)*S(y),w="center",T="bottom";break;case"startAngle":x=f+p*_(d)+Af(d,l+m,!1),b=v+p*S(d)+Mf(d,l+m,!1),w="right",T="middle";break;case"insideStartAngle":x=f+p*_(d)+Af(d,-l+m,!1),b=v+p*S(d)+Mf(d,-l+m,!1),w="left",T="middle";break;case"middle":x=f+p*_(y),b=v+p*S(y),w="center",T="middle";break;case"endArc":x=f+(h+l)*_(y),b=v+(h+l)*S(y),w="center",T="bottom";break;case"insideEndArc":x=f+(h-l)*_(y),b=v+(h-l)*S(y),w="center",T="top";break;case"endAngle":x=f+p*_(g)+Af(g,l+m,!0),b=v+p*S(g)+Mf(g,l+m,!0),w="left",T="middle";break;case"insideEndAngle":x=f+p*_(g)+Af(g,-l+m,!0),b=v+p*S(g)+Mf(g,-l+m,!0),w="right",T="middle";break;default:return kv(a,n,i)}return a=a||{},a.x=x,a.y=b,a.align=w,a.verticalAlign=T,a}}function C3(r,t,e,a){if(Mt(a)){r.setTextConfig({rotation:a});return}else if(W(t)){r.setTextConfig({rotation:0});return}var n=r.shape,i=n.clockwise?n.startAngle:n.endAngle,o=n.clockwise?n.endAngle:n.startAngle,s=(i+o)/2,l,u=e(t);switch(u){case"startArc":case"insideStartArc":case"middle":case"insideEndArc":case"endArc":l=s;break;case"startAngle":case"insideStartAngle":l=i;break;case"endAngle":case"insideEndAngle":l=o;break;default:r.setTextConfig({rotation:0});return}var f=Math.PI*1.5-l;u==="middle"&&f>Math.PI/2&&f<Math.PI*1.5&&(f-=Math.PI),r.setTextConfig({rotation:f})}function Af(r,t,e){return t*Math.sin(r)*(e?-1:1)}function Mf(r,t,e){return t*Math.cos(r)*(e?1:-1)}function ha(r,t,e){var a=r.get("borderRadius");if(a==null)return e?{cornerRadius:0}:null;W(a)||(a=[a,a,a,a]);var n=Math.abs(t.r||0-t.r0||0);return{cornerRadius:U(a,function(i){return Yr(i,n)})}}var Pp=Math.max,Rp=Math.min;function A3(r,t){var e=r.getArea&&r.getArea();if(Rn(r,"cartesian2d")){var a=r.getBaseAxis();if(a.type!=="category"||!a.onBand){var n=t.getLayout("bandWidth");a.isHorizontal()?(e.x-=n,e.width+=n*2):(e.y-=n,e.height+=n*2)}}return e}var M3=function(r){z(t,r);function t(){var e=r.call(this)||this;return e.type=t.type,e._isFirstFrame=!0,e}return t.prototype.render=function(e,a,n,i){this._model=e,this._removeOnRenderedListener(n),this._updateDrawMode(e);var o=e.get("coordinateSystem");(o==="cartesian2d"||o==="polar")&&(this._progressiveEls=null,this._isLargeDraw?this._renderLarge(e,a,n):this._renderNormal(e,a,n,i))},t.prototype.incrementalPrepareRender=function(e){this._clear(),this._updateDrawMode(e),this._updateLargeClip(e)},t.prototype.incrementalRender=function(e,a){this._progressiveEls=[],this._incrementalRenderLarge(e,a)},t.prototype.eachRendered=function(e){zn(this._progressiveEls||this.group,e)},t.prototype._updateDrawMode=function(e){var a=e.pipelineContext.large;(this._isLargeDraw==null||a!==this._isLargeDraw)&&(this._isLargeDraw=a,this._clear())},t.prototype._renderNormal=function(e,a,n,i){var o=this.group,s=e.getData(),l=this._data,u=e.coordinateSystem,f=u.getBaseAxis(),v;u.type==="cartesian2d"?v=f.isHorizontal():u.type==="polar"&&(v=f.dim==="angle");var h=e.isAnimationEnabled()?e:null,c=D3(e,u);c&&this._enableRealtimeSort(c,s,n);var p=e.get("clip",!0)||c,d=A3(u,s);o.removeClipPath();var g=e.get("roundCap",!0),y=e.get("showBackground",!0),m=e.getModel("backgroundStyle"),_=m.get("borderRadius")||0,S=[],x=this._backgroundEls,b=i&&i.isInitSort,w=i&&i.type==="changeAxisOrder";function T(D){var I=Df[u.type](s,D);if(!I)return null;var L=O3(u,v,I);return L.useStyle(m.getItemStyle()),u.type==="cartesian2d"?L.setShape("r",_):L.setShape("cornerRadius",_),S[D]=L,L}s.diff(l).add(function(D){var I=s.getItemModel(D),L=Df[u.type](s,D,I);if(L&&(y&&T(D),!(!s.hasValue(D)||!Fx[u.type](L)))){var P=!1;p&&(P=Bx[u.type](d,L));var k=zx[u.type](e,s,D,L,v,h,f.model,!1,g);c&&(k.forceLabelAnimation=!0),Hx(k,s,D,I,L,e,v,u.type==="polar"),b?k.attr({shape:L}):c?Vx(c,h,k,L,D,v,!1,!1):Yt(k,{shape:L},e,D),s.setItemGraphicEl(D,k),o.add(k),k.ignore=P}}).update(function(D,I){var L=s.getItemModel(D),P=Df[u.type](s,D,L);if(P){if(y){var k=void 0;x.length===0?k=T(I):(k=x[I],k.useStyle(m.getItemStyle()),u.type==="cartesian2d"?k.setShape("r",_):k.setShape("cornerRadius",_),S[D]=k);var R=Df[u.type](s,D),O=P2(v,R,u);Lt(k,{shape:O},h,D)}var E=l.getItemGraphicEl(I);if(!s.hasValue(D)||!Fx[u.type](P)){o.remove(E);return}var B=!1;p&&(B=Bx[u.type](d,P),B&&o.remove(E));var V=E&&(E.type==="sector"&&g||E.type==="sausage"&&!g);if(V&&(E&&Fa(E,e,I),E=null),E?Ir(E):E=zx[u.type](e,s,D,P,v,h,f.model,!0,g),c&&(E.forceLabelAnimation=!0),w){var F=E.getTextContent();if(F){var H=xs(F);H.prevValue!=null&&(H.prevValue=H.value)}}else Hx(E,s,D,L,P,e,v,u.type==="polar");b?E.attr({shape:P}):c?Vx(c,h,E,P,D,v,!0,w):Lt(E,{shape:P},e,D,null),s.setItemGraphicEl(D,E),E.ignore=B,o.add(E)}}).remove(function(D){var I=l.getItemGraphicEl(D);I&&Fa(I,e,D)}).execute();var C=this._backgroundGroup||(this._backgroundGroup=new rt);C.removeAll();for(var M=0;M<S.length;++M)C.add(S[M]);o.add(C),this._backgroundEls=S,this._data=s},t.prototype._renderLarge=function(e,a,n){this._clear(),Ux(e,this.group),this._updateLargeClip(e)},t.prototype._incrementalRenderLarge=function(e,a){this._removeBackground(),Ux(a,this.group,this._progressiveEls,!0)},t.prototype._updateLargeClip=function(e){var a=e.get("clip",!0)&&Ou(e.coordinateSystem,!1,e),n=this.group;a?n.setClipPath(a):n.removeClipPath()},t.prototype._enableRealtimeSort=function(e,a,n){var i=this;if(a.count()){var o=e.baseAxis;if(this._isFirstFrame)this._dispatchInitSort(a,e,n),this._isFirstFrame=!1;else{var s=function(l){var u=a.getItemGraphicEl(l),f=u&&u.shape;return f&&Math.abs(o.isHorizontal()?f.height:f.width)||0};this._onRendered=function(){i._updateSortWithinSameData(a,s,o,n)},n.getZr().on("rendered",this._onRendered)}}},t.prototype._dataSort=function(e,a,n){var i=[];return e.each(e.mapDimension(a.dim),function(o,s){var l=n(s);l=l??NaN,i.push({dataIndex:s,mappedValue:l,ordinalNumber:o})}),i.sort(function(o,s){return s.mappedValue-o.mappedValue}),{ordinalNumbers:U(i,function(o){return o.ordinalNumber})}},t.prototype._isOrderChangedWithinSameData=function(e,a,n){for(var i=n.scale,o=e.mapDimension(n.dim),s=Number.MAX_VALUE,l=0,u=i.getOrdinalMeta().categories.length;l<u;++l){var f=e.rawIndexOf(o,i.getRawOrdinalNumber(l)),v=f<0?Number.MIN_VALUE:a(e.indexOfRawIndex(f));if(v>s)return!0;s=v}return!1},t.prototype._isOrderDifferentInView=function(e,a){for(var n=a.scale,i=n.getExtent(),o=Math.max(0,i[0]),s=Math.min(i[1],n.getOrdinalMeta().categories.length-1);o<=s;++o)if(e.ordinalNumbers[o]!==n.getRawOrdinalNumber(o))return!0},t.prototype._updateSortWithinSameData=function(e,a,n,i){if(this._isOrderChangedWithinSameData(e,a,n)){var o=this._dataSort(e,n,a);this._isOrderDifferentInView(o,n)&&(this._removeOnRenderedListener(i),i.dispatchAction({type:"changeAxisOrder",componentType:n.dim+"Axis",axisId:n.index,sortInfo:o}))}},t.prototype._dispatchInitSort=function(e,a,n){var i=a.baseAxis,o=this._dataSort(e,i,function(s){return e.get(e.mapDimension(a.otherAxis.dim),s)});n.dispatchAction({type:"changeAxisOrder",componentType:i.dim+"Axis",isInitSort:!0,axisId:i.index,sortInfo:o})},t.prototype.remove=function(e,a){this._clear(this._model),this._removeOnRenderedListener(a)},t.prototype.dispose=function(e,a){this._removeOnRenderedListener(a)},t.prototype._removeOnRenderedListener=function(e){this._onRendered&&(e.getZr().off("rendered",this._onRendered),this._onRendered=null)},t.prototype._clear=function(e){var a=this.group,n=this._data;e&&e.isAnimationEnabled()&&n&&!this._isLargeDraw?(this._removeBackground(),this._backgroundEls=[],n.eachItemGraphicEl(function(i){Fa(i,e,ut(i).dataIndex)})):a.removeAll(),this._data=null,this._isFirstFrame=!0},t.prototype._removeBackground=function(){this.group.remove(this._backgroundGroup),this._backgroundGroup=null},t.type="bar",t}(Nt),Bx={cartesian2d:function(r,t){var e=t.width<0?-1:1,a=t.height<0?-1:1;e<0&&(t.x+=t.width,t.width=-t.width),a<0&&(t.y+=t.height,t.height=-t.height);var n=r.x+r.width,i=r.y+r.height,o=Pp(t.x,r.x),s=Rp(t.x+t.width,n),l=Pp(t.y,r.y),u=Rp(t.y+t.height,i),f=s<o,v=u<l;return t.x=f&&o>n?s:o,t.y=v&&l>i?u:l,t.width=f?0:s-o,t.height=v?0:u-l,e<0&&(t.x+=t.width,t.width=-t.width),a<0&&(t.y+=t.height,t.height=-t.height),f||v},polar:function(r,t){var e=t.r0<=t.r?1:-1;if(e<0){var a=t.r;t.r=t.r0,t.r0=a}var n=Rp(t.r,r.r),i=Pp(t.r0,r.r0);t.r=n,t.r0=i;var o=n-i<0;if(e<0){var a=t.r;t.r=t.r0,t.r0=a}return o}},zx={cartesian2d:function(r,t,e,a,n,i,o,s,l){var u=new _t({shape:G({},a),z2:1});if(u.__dataIndex=e,u.name="item",i){var f=u.shape,v=n?"height":"width";f[v]=0}return u},polar:function(r,t,e,a,n,i,o,s,l){var u=!n&&l?sh:ke,f=new u({shape:a,z2:1});f.name="item";var v=I2(n);if(f.calculateTextPosition=T3(v,{isRoundCap:u===sh}),i){var h=f.shape,c=n?"r":"endAngle",p={};h[c]=n?a.r0:a.startAngle,p[c]=a[c],(s?Lt:Yt)(f,{shape:p},i)}return f}};function D3(r,t){var e=r.get("realtimeSort",!0),a=t.getBaseAxis();if(e&&a.type==="category"&&t.type==="cartesian2d")return{baseAxis:a,otherAxis:t.getOtherAxis(a)}}function Vx(r,t,e,a,n,i,o,s){var l,u;i?(u={x:a.x,width:a.width},l={y:a.y,height:a.height}):(u={y:a.y,height:a.height},l={x:a.x,width:a.width}),s||(o?Lt:Yt)(e,{shape:l},t,n,null);var f=t?r.baseAxis.model:null;(o?Lt:Yt)(e,{shape:u},f,n)}function Gx(r,t){for(var e=0;e<t.length;e++)if(!isFinite(r[t[e]]))return!0;return!1}var L3=["x","y","width","height"],I3=["cx","cy","r","startAngle","endAngle"],Fx={cartesian2d:function(r){return!Gx(r,L3)},polar:function(r){return!Gx(r,I3)}},Df={cartesian2d:function(r,t,e){var a=r.getItemLayout(t);if(!a)return null;var n=e?R3(e,a):0,i=a.width>0?1:-1,o=a.height>0?1:-1;return{x:a.x+i*n/2,y:a.y+o*n/2,width:a.width-i*n,height:a.height-o*n}},polar:function(r,t,e){var a=r.getItemLayout(t);return{cx:a.cx,cy:a.cy,r0:a.r0,r:a.r,startAngle:a.startAngle,endAngle:a.endAngle,clockwise:a.clockwise}}};function P3(r){return r.startAngle!=null&&r.endAngle!=null&&r.startAngle===r.endAngle}function I2(r){return function(t){var e=t?"Arc":"Angle";return function(a){switch(a){case"start":case"insideStart":case"end":case"insideEnd":return a+e;default:return a}}}(r)}function Hx(r,t,e,a,n,i,o,s){var l=t.getItemVisual(e,"style");if(s){if(!i.get("roundCap")){var f=r.shape,v=ha(a.getModel("itemStyle"),f,!0);G(f,v),r.setShape(f)}}else{var u=a.get(["itemStyle","borderRadius"])||0;r.setShape("r",u)}r.useStyle(l);var h=a.getShallow("cursor");h&&r.attr("cursor",h);var c=s?o?n.r>=n.r0?"endArc":"startArc":n.endAngle>=n.startAngle?"endAngle":"startAngle":o?n.height>=0?"bottom":"top":n.width>=0?"right":"left",p=ce(a);Se(r,p,{labelFetcher:i,labelDataIndex:e,defaultText:ss(i.getData(),e),inheritColor:l.fill,defaultOpacity:l.opacity,defaultOutsidePosition:c});var d=r.getTextContent();if(s&&d){var g=a.get(["label","position"]);r.textConfig.inside=g==="middle"?!0:null,C3(r,g==="outside"?c:g,I2(o),a.get(["label","rotate"]))}FM(d,p,i.getRawValue(e),function(m){return x2(t,m)});var y=a.getModel(["emphasis"]);$t(r,y.get("focus"),y.get("blurScope"),y.get("disabled")),he(r,a),P3(n)&&(r.style.fill="none",r.style.stroke="none",A(r.states,function(m){m.style&&(m.style.fill=m.style.stroke="none")}))}function R3(r,t){var e=r.get(["itemStyle","borderColor"]);if(!e||e==="none")return 0;var a=r.get(["itemStyle","borderWidth"])||0,n=isNaN(t.width)?Number.MAX_VALUE:Math.abs(t.width),i=isNaN(t.height)?Number.MAX_VALUE:Math.abs(t.height);return Math.min(a,n,i)}var k3=function(){function r(){}return r}(),Wx=function(r){z(t,r);function t(e){var a=r.call(this,e)||this;return a.type="largeBar",a}return t.prototype.getDefaultShape=function(){return new k3},t.prototype.buildPath=function(e,a){for(var n=a.points,i=this.baseDimIdx,o=1-this.baseDimIdx,s=[],l=[],u=this.barWidth,f=0;f<n.length;f+=3)l[i]=u,l[o]=n[f+2],s[i]=n[f+i],s[o]=n[f+o],e.rect(s[0],s[1],l[0],l[1])},t}(bt);function Ux(r,t,e,a){var n=r.getData(),i=n.getLayout("valueAxisHorizontal")?1:0,o=n.getLayout("largeDataIndices"),s=n.getLayout("size"),l=r.getModel("backgroundStyle"),u=n.getLayout("largeBackgroundPoints");if(u){var f=new Wx({shape:{points:u},incremental:!!a,silent:!0,z2:0});f.baseDimIdx=i,f.largeDataIndices=o,f.barWidth=s,f.useStyle(l.getItemStyle()),t.add(f),e&&e.push(f)}var v=new Wx({shape:{points:n.getLayout("largePoints")},incremental:!!a,ignoreCoarsePointer:!0,z2:1});v.baseDimIdx=i,v.largeDataIndices=o,v.barWidth=s,t.add(v),v.useStyle(n.getVisual("style")),v.style.stroke=null,ut(v).seriesIndex=r.seriesIndex,r.get("silent")||(v.on("mousedown",Yx),v.on("mousemove",Yx)),e&&e.push(v)}var Yx=e0(function(r){var t=this,e=E3(t,r.offsetX,r.offsetY);ut(t).dataIndex=e>=0?e:null},30,!1);function E3(r,t,e){for(var a=r.baseDimIdx,n=1-a,i=r.shape.points,o=r.largeDataIndices,s=[],l=[],u=r.barWidth,f=0,v=i.length/3;f<v;f++){var h=f*3;if(l[a]=u,l[n]=i[h+2],s[a]=i[h+a],s[n]=i[h+n],l[n]<0&&(s[n]+=l[n],l[n]=-l[n]),t>=s[0]&&t<=s[0]+l[0]&&e>=s[1]&&e<=s[1]+l[1])return o[f]}return-1}function P2(r,t,e){if(Rn(e,"cartesian2d")){var a=t,n=e.getArea();return{x:r?a.x:n.x,y:r?n.y:a.y,width:r?a.width:n.width,height:r?n.height:a.height}}else{var n=e.getArea(),i=t;return{cx:n.cx,cy:n.cy,r0:r?n.r0:i.r0,r:r?n.r:i.r,startAngle:r?i.startAngle:0,endAngle:r?i.endAngle:Math.PI*2}}}function O3(r,t,e){var a=r.type==="polar"?ke:_t;return new a({shape:P2(t,e,r),silent:!0,z2:0})}function N3(r){r.registerChartView(M3),r.registerSeriesModel(b3),r.registerLayout(r.PRIORITY.VISUAL.LAYOUT,pt(EL,"bar")),r.registerLayout(r.PRIORITY.VISUAL.PROGRESSIVE_LAYOUT,OL("bar")),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,L2("bar")),r.registerAction({type:"changeAxisOrder",event:"changeAxisOrder",update:"update"},function(t,e){var a=t.componentType||"series";e.eachComponent({mainType:a,query:t},function(n){t.sortInfo&&n.axis.setCategorySortInfo(t.sortInfo)})})}var Zx=Math.PI*2,Lf=Math.PI/180;function B3(r,t,e){t.eachSeriesByType(r,function(a){var n=a.getData(),i=n.mapDimension("value"),o=oD(a,e),s=o.cx,l=o.cy,u=o.r,f=o.r0,v=o.viewRect,h=-a.get("startAngle")*Lf,c=a.get("endAngle"),p=a.get("padAngle")*Lf;c=c==="auto"?h-Zx:-c*Lf;var d=a.get("minAngle")*Lf,g=d+p,y=0;n.each(i,function(O){!isNaN(O)&&y++});var m=n.getSum(i),_=Math.PI/(m||y)*2,S=a.get("clockwise"),x=a.get("roseType"),b=a.get("stillShowZeroSum"),w=n.getDataExtent(i);w[0]=0;var T=S?1:-1,C=[h,c],M=T*p/2;Yh(C,!S),h=C[0],c=C[1];var D=R2(a);D.startAngle=h,D.endAngle=c,D.clockwise=S,D.cx=s,D.cy=l,D.r=u,D.r0=f;var I=Math.abs(c-h),L=I,P=0,k=h;if(n.setLayout({viewRect:v,r:u}),n.each(i,function(O,E){var B;if(isNaN(O)){n.setItemLayout(E,{angle:NaN,startAngle:NaN,endAngle:NaN,clockwise:S,cx:s,cy:l,r0:f,r:x?NaN:u});return}x!=="area"?B=m===0&&b?_:O*_:B=I/y,B<g?(B=g,L-=g):P+=O;var V=k+T*B,F=0,H=0;p>B?(F=k+T*B/2,H=F):(F=k+M,H=V-M),n.setItemLayout(E,{angle:B,startAngle:F,endAngle:H,clockwise:S,cx:s,cy:l,r0:f,r:x?Rt(O,w,[f,u]):u}),k=V}),L<Zx&&y)if(L<=.001){var R=I/y;n.each(i,function(O,E){if(!isNaN(O)){var B=n.getItemLayout(E);B.angle=R;var V=0,F=0;R<p?(V=h+T*(E+1/2)*R,F=V):(V=h+T*E*R+M,F=h+T*(E+1)*R-M),B.startAngle=V,B.endAngle=F}})}else _=L/P,k=h,n.each(i,function(O,E){if(!isNaN(O)){var B=n.getItemLayout(E),V=B.angle===g?g:O*_,F=0,H=0;V<p?(F=k+T*V/2,H=F):(F=k+M,H=k+T*V-M),B.startAngle=F,B.endAngle=H,k+=T*V}})})}var R2=St();function Ps(r){return{seriesType:r,reset:function(t,e){var a=e.findComponents({mainType:"legend"});if(!(!a||!a.length)){var n=t.getData();n.filterSelf(function(i){for(var o=n.getName(i),s=0;s<a.length;s++)if(!a[s].isSelected(o))return!1;return!0})}}}}var z3=Math.PI/180;function Xx(r,t,e,a,n,i,o,s,l,u){if(r.length<2)return;function f(d){for(var g=d.rB,y=g*g,m=0;m<d.list.length;m++){var _=d.list[m],S=Math.abs(_.label.y-e),x=a+_.len,b=x*x,w=Math.sqrt(Math.abs((1-S*S/y)*b)),T=t+(w+_.len2)*n,C=T-_.label.x,M=_.targetTextWidth-C*n;k2(_,M,!0),_.label.x=T}}function v(d){for(var g={list:[],maxY:0},y={list:[],maxY:0},m=0;m<d.length;m++)if(d[m].labelAlignTo==="none"){var _=d[m],S=_.label.y>e?y:g,x=Math.abs(_.label.y-e);if(x>=S.maxY){var b=_.label.x-t-_.len2*n,w=a+_.len,T=Math.abs(b)<w?Math.sqrt(x*x/(1-b*b/w/w)):w;S.rB=T,S.maxY=x}S.list.push(_)}f(g),f(y)}for(var h=r.length,c=0;c<h;c++)if(r[c].position==="outer"&&r[c].labelAlignTo==="labelLine"){var p=r[c].label.x-u;r[c].linePoints[1][0]+=p,r[c].label.x=u}Qg(r,1,l,l+o)&&v(r)}function V3(r,t,e,a,n,i,o,s){for(var l=[],u=[],f=Number.MAX_VALUE,v=-Number.MAX_VALUE,h=0;h<r.length;h++){var c=r[h].label;kp(r[h])||(c.x<t?(f=Math.min(f,c.x),l.push(r[h])):(v=Math.max(v,c.x),u.push(r[h])))}for(var h=0;h<r.length;h++){var p=r[h];if(!kp(p)&&p.linePoints){if(p.labelStyleWidth!=null)continue;var c=p.label,d=p.linePoints,g=void 0;p.labelAlignTo==="edge"?c.x<t?g=d[2][0]-p.labelDistance-o-p.edgeDistance:g=o+n-p.edgeDistance-d[2][0]-p.labelDistance:p.labelAlignTo==="labelLine"?c.x<t?g=f-o-p.bleedMargin:g=o+n-v-p.bleedMargin:c.x<t?g=c.x-o-p.bleedMargin:g=o+n-c.x-p.bleedMargin,p.targetTextWidth=g,k2(p,g,!1)}}Xx(u,t,e,a,1,n,i,o,s,v),Xx(l,t,e,a,-1,n,i,o,s,f);for(var h=0;h<r.length;h++){var p=r[h];if(!kp(p)&&p.linePoints){var c=p.label,d=p.linePoints,y=p.labelAlignTo==="edge",m=c.style.padding,_=m?m[1]+m[3]:0,S=c.style.backgroundColor?0:_,x=p.rect.width+S,b=d[1][0]-d[2][0];y?c.x<t?d[2][0]=o+p.edgeDistance+x+p.labelDistance:d[2][0]=o+n-p.edgeDistance-x-p.labelDistance:(c.x<t?d[2][0]=c.x+p.labelDistance:d[2][0]=c.x-p.labelDistance,d[1][0]=d[2][0]+b),d[1][1]=d[2][1]=c.y}}}function k2(r,t,e){if(r.labelStyleWidth==null){var a=r.label,n=a.style,i=r.rect,o=n.backgroundColor,s=n.padding,l=s?s[1]+s[3]:0,u=n.overflow,f=i.width+(o?0:l);if(t<f||e){if(u&&u.match("break")){a.setStyle("backgroundColor",null),a.setStyle("width",t-l);var v=a.getBoundingRect();a.setStyle("width",Math.ceil(v.width)),a.setStyle("backgroundColor",o)}else{var h=t-l,c=t<f?h:e?h>r.unconstrainedWidth?null:h:null;a.setStyle("width",c)}E2(i,a)}}}function E2(r,t){$x.rect=r,n2($x,t,G3)}var G3={minMarginForce:[null,0,null,0],marginDefault:[1,0,1,0]},$x={};function kp(r){return r.position==="center"}function F3(r){var t=r.getData(),e=[],a,n,i=!1,o=(r.get("minShowLabelAngle")||0)*z3,s=t.getLayout("viewRect"),l=t.getLayout("r"),u=s.width,f=s.x,v=s.y,h=s.height;function c(b){b.ignore=!0}function p(b){if(!b.ignore)return!0;for(var w in b.states)if(b.states[w].ignore===!1)return!0;return!1}t.each(function(b){var w=t.getItemGraphicEl(b),T=w.shape,C=w.getTextContent(),M=w.getTextGuideLine(),D=t.getItemModel(b),I=D.getModel("label"),L=I.get("position")||D.get(["emphasis","label","position"]),P=I.get("distanceToLabelLine"),k=I.get("alignTo"),R=Z(I.get("edgeDistance"),u),O=I.get("bleedMargin");O==null&&(O=Math.min(u,h)>200?10:2);var E=D.getModel("labelLine"),B=E.get("length");B=Z(B,u);var V=E.get("length2");if(V=Z(V,u),Math.abs(T.endAngle-T.startAngle)<o){A(C.states,c),C.ignore=!0,M&&(A(M.states,c),M.ignore=!0);return}if(p(C)){var F=(T.startAngle+T.endAngle)/2,H=Math.cos(F),Y=Math.sin(F),K,ft,It,Ot;a=T.cx,n=T.cy;var vt=L==="inside"||L==="inner";if(L==="center")K=T.cx,ft=T.cy,Ot="center";else{var at=(vt?(T.r+T.r0)/2*H:T.r*H)+a,dt=(vt?(T.r+T.r0)/2*Y:T.r*Y)+n;if(K=at+H*3,ft=dt+Y*3,!vt){var J=at+H*(B+l-T.r),ht=dt+Y*(B+l-T.r),zt=J+(H<0?-1:1)*V,Dt=ht;k==="edge"?K=H<0?f+R:f+u-R:K=zt+(H<0?-P:P),ft=Dt,It=[[at,dt],[J,ht],[zt,Dt]]}Ot=vt?"center":k==="edge"?H>0?"right":"left":H>0?"left":"right"}var Et=Math.PI,Vt=0,de=I.get("rotate");if(Mt(de))Vt=de*(Et/180);else if(L==="center")Vt=0;else if(de==="radial"||de===!0){var er=H<0?-F+Et:-F;Vt=er}else if(de==="tangential"&&L!=="outside"&&L!=="outer"){var $e=Math.atan2(H,Y);$e<0&&($e=Et*2+$e);var Fn=Y>0;Fn&&($e=Et+$e),Vt=$e-Et}if(i=!!Vt,C.x=K,C.y=ft,C.rotation=Vt,C.setStyle({verticalAlign:"middle"}),vt){C.setStyle({align:Ot});var pc=C.states.select;pc&&(pc.x+=C.x,pc.y+=C.y)}else{var io=new lt(0,0,0,0);E2(io,C),e.push({label:C,labelLine:M,position:L,len:B,len2:V,minTurnAngle:E.get("minTurnAngle"),maxSurfaceAngle:E.get("maxSurfaceAngle"),surfaceNormal:new st(H,Y),linePoints:It,textAlign:Ot,labelDistance:P,labelAlignTo:k,edgeDistance:R,bleedMargin:O,rect:io,unconstrainedWidth:io.width,labelStyleWidth:C.style.width})}w.setTextConfig({inside:vt})}}),!i&&r.get("avoidLabelOverlap")&&V3(e,a,n,l,u,h,f,v);for(var d=0;d<e.length;d++){var g=e[d],y=g.label,m=g.labelLine,_=isNaN(y.x)||isNaN(y.y);if(y){y.setStyle({align:g.textAlign}),_&&(A(y.states,c),y.ignore=!0);var S=y.states.select;S&&(S.x+=y.x,S.y+=y.y)}if(m){var x=g.linePoints;_||!x?(A(m.states,c),m.ignore=!0):(e2(x,g.minTurnAngle),sG(x,g.surfaceNormal,g.maxSurfaceAngle),m.setShape({points:x}),y.__hostTarget.textGuideLineConfig={anchor:new st(x[0][0],x[0][1])})}}}var H3=function(r){z(t,r);function t(e,a,n){var i=r.call(this)||this;i.z2=2;var o=new At;return i.setTextContent(o),i.updateData(e,a,n,!0),i}return t.prototype.updateData=function(e,a,n,i){var o=this,s=e.hostModel,l=e.getItemModel(a),u=l.getModel("emphasis"),f=e.getItemLayout(a),v=G(ha(l.getModel("itemStyle"),f,!0),f);if(isNaN(v.startAngle)){o.setShape(v);return}if(i){o.setShape(v);var h=s.getShallow("animationType");s.ecModel.ssr?(Yt(o,{scaleX:0,scaleY:0},s,{dataIndex:a,isFrom:!0}),o.originX=v.cx,o.originY=v.cy):h==="scale"?(o.shape.r=f.r0,Yt(o,{shape:{r:f.r}},s,a)):n!=null?(o.setShape({startAngle:n,endAngle:n}),Yt(o,{shape:{startAngle:f.startAngle,endAngle:f.endAngle}},s,a)):(o.shape.endAngle=f.startAngle,Lt(o,{shape:{endAngle:f.endAngle}},s,a))}else Ir(o),Lt(o,{shape:v},s,a);o.useStyle(e.getItemVisual(a,"style")),he(o,l);var c=(f.startAngle+f.endAngle)/2,p=s.get("selectedOffset"),d=Math.cos(c)*p,g=Math.sin(c)*p,y=l.getShallow("cursor");y&&o.attr("cursor",y),this._updateLabel(s,e,a),o.ensureState("emphasis").shape=G({r:f.r+(u.get("scale")&&u.get("scaleSize")||0)},ha(u.getModel("itemStyle"),f)),G(o.ensureState("select"),{x:d,y:g,shape:ha(l.getModel(["select","itemStyle"]),f)}),G(o.ensureState("blur"),{shape:ha(l.getModel(["blur","itemStyle"]),f)});var m=o.getTextGuideLine(),_=o.getTextContent();m&&G(m.ensureState("select"),{x:d,y:g}),G(_.ensureState("select"),{x:d,y:g}),$t(this,u.get("focus"),u.get("blurScope"),u.get("disabled"))},t.prototype._updateLabel=function(e,a,n){var i=this,o=a.getItemModel(n),s=o.getModel("labelLine"),l=a.getItemVisual(n,"style"),u=l&&l.fill,f=l&&l.opacity;Se(i,ce(o),{labelFetcher:a.hostModel,labelDataIndex:n,inheritColor:u,defaultOpacity:f,defaultText:e.getFormattedLabel(n,"normal")||a.getName(n)});var v=i.getTextContent();i.setTextConfig({position:null,rotation:null}),v.attr({z2:10});var h=o.get(["label","position"]);if(h!=="outside"&&h!=="outer")i.removeTextGuideLine();else{var c=this.getTextGuideLine();c||(c=new Ae,this.setTextGuideLine(c)),d0(this,g0(o),{stroke:u,opacity:Qe(s.get(["lineStyle","opacity"]),f,1)})}},t}(ke),W3=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.ignoreLabelLineUpdate=!0,e}return t.prototype.render=function(e,a,n,i){var o=e.getData(),s=this._data,l=this.group,u;if(!s&&o.count()>0){for(var f=o.getItemLayout(0),v=1;isNaN(f&&f.startAngle)&&v<o.count();++v)f=o.getItemLayout(v);f&&(u=f.startAngle)}if(this._emptyCircleSector&&l.remove(this._emptyCircleSector),o.count()===0&&e.get("showEmptyCircle")){var h=R2(e),c=new ke({shape:et(h)});c.useStyle(e.getModel("emptyCircleStyle").getItemStyle()),this._emptyCircleSector=c,l.add(c)}o.diff(s).add(function(p){var d=new H3(o,p,u);o.setItemGraphicEl(p,d),l.add(d)}).update(function(p,d){var g=s.getItemGraphicEl(d);g.updateData(o,p,u),g.off("click"),l.add(g),o.setItemGraphicEl(p,g)}).remove(function(p){var d=s.getItemGraphicEl(p);Fa(d,e,p)}).execute(),F3(e),e.get("animationTypeUpdate")!=="expansion"&&(this._data=o)},t.prototype.dispose=function(){},t.prototype.containPoint=function(e,a){var n=a.getData(),i=n.getItemLayout(0);if(i){var o=e[0]-i.cx,s=e[1]-i.cy,l=Math.sqrt(o*o+s*s);return l<=i.r&&l>=i.r0}},t.type="pie",t}(Nt);function Rs(r,t,e){t=W(t)&&{coordDimensions:t}||G({encodeDefine:r.getEncode()},t);var a=r.getSource(),n=Ds(a,t).dimensions,i=new Ue(n,r);return i.initData(a,e),i}var ks=function(){function r(t,e){this._getDataWithEncodedVisual=t,this._getRawData=e}return r.prototype.getAllNames=function(){var t=this._getRawData();return t.mapArray(t.getName)},r.prototype.containName=function(t){var e=this._getRawData();return e.indexOfName(t)>=0},r.prototype.indexOfName=function(t){var e=this._getDataWithEncodedVisual();return e.indexOfName(t)},r.prototype.getItemVisual=function(t,e){var a=this._getDataWithEncodedVisual();return a.getItemVisual(t,e)},r}(),U3=St(),O2=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.init=function(e){r.prototype.init.apply(this,arguments),this.legendVisualProvider=new ks($(this.getData,this),$(this.getRawData,this)),this._defaultLabelLine(e)},t.prototype.mergeOption=function(){r.prototype.mergeOption.apply(this,arguments)},t.prototype.getInitialData=function(){return Rs(this,{coordDimensions:["value"],encodeDefaulter:pt(Xm,this)})},t.prototype.getDataParams=function(e){var a=this.getData(),n=U3(a),i=n.seats;if(!i){var o=[];a.each(a.mapDimension("value"),function(l){o.push(l)}),i=n.seats=UA(o,a.hostModel.get("percentPrecision"))}var s=r.prototype.getDataParams.call(this,e);return s.percent=i[e]||0,s.$vars.push("percent"),s},t.prototype._defaultLabelLine=function(e){Vi(e,"labelLine",["show"]);var a=e.labelLine,n=e.emphasis.labelLine;a.show=a.show&&e.label.show,n.show=n.show&&e.emphasis.label.show},t.type="series.pie",t.defaultOption={z:2,legendHoverLink:!0,colorBy:"data",center:["50%","50%"],radius:[0,"50%"],clockwise:!0,startAngle:90,endAngle:"auto",padAngle:0,minAngle:0,minShowLabelAngle:0,selectedOffset:10,percentPrecision:2,stillShowZeroSum:!0,coordinateSystemUsage:"box",left:0,top:0,right:0,bottom:0,width:null,height:null,label:{rotate:0,show:!0,overflow:"truncate",position:"outer",alignTo:"none",edgeDistance:"25%",distanceToLabelLine:5},labelLine:{show:!0,length:15,length2:30,smooth:!1,minTurnAngle:90,maxSurfaceAngle:90,lineStyle:{width:1,type:"solid"}},itemStyle:{borderWidth:1,borderJoin:"round"},showEmptyCircle:!0,emptyCircleStyle:{color:"lightgray",opacity:1},labelLayout:{hideOverlap:!0},emphasis:{scale:!0,scaleSize:5},avoidLabelOverlap:!0,animationType:"expansion",animationDuration:1e3,animationTypeUpdate:"transition",animationEasingUpdate:"cubicInOut",animationDurationUpdate:500,animationEasing:"cubicInOut"},t}(Bt);KN({fullType:O2.type,getCoord2:function(r){return r.getShallow("center")}});function Y3(r){return{seriesType:r,reset:function(t,e){var a=t.getData();a.filterSelf(function(n){var i=a.mapDimension("value"),o=a.get(i,n);return!(Mt(o)&&!isNaN(o)&&o<0)})}}}function Z3(r){r.registerChartView(W3),r.registerSeriesModel(O2),jD("pie",r.registerAction),r.registerLayout(pt(B3,"pie")),r.registerProcessor(Ps("pie")),r.registerProcessor(Y3("pie"))}var X3=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.hasSymbolVisual=!0,e}return t.prototype.getInitialData=function(e,a){return Ca(null,this,{useEncodeDefaulter:!0})},t.prototype.getProgressive=function(){var e=this.option.progressive;return e??(this.option.large?5e3:this.get("progressive"))},t.prototype.getProgressiveThreshold=function(){var e=this.option.progressiveThreshold;return e??(this.option.large?1e4:this.get("progressiveThreshold"))},t.prototype.brushSelector=function(e,a,n){return n.point(a.getItemLayout(e))},t.prototype.getZLevelKey=function(){return this.getData().count()>this.getProgressiveThreshold()?this.id:""},t.type="series.scatter",t.dependencies=["grid","polar","geo","singleAxis","calendar","matrix"],t.defaultOption={coordinateSystem:"cartesian2d",z:2,legendHoverLink:!0,symbolSize:10,large:!1,largeThreshold:2e3,itemStyle:{opacity:.8},emphasis:{scale:!0},clip:!0,select:{itemStyle:{borderColor:N.color.primary}},universalTransition:{divideShape:"clone"}},t}(Bt),N2=4,$3=function(){function r(){}return r}(),q3=function(r){z(t,r);function t(e){var a=r.call(this,e)||this;return a._off=0,a.hoverDataIdx=-1,a}return t.prototype.getDefaultShape=function(){return new $3},t.prototype.reset=function(){this.notClear=!1,this._off=0},t.prototype.buildPath=function(e,a){var n=a.points,i=a.size,o=this.symbolProxy,s=o.shape,l=e.getContext?e.getContext():e,u=l&&i[0]<N2,f=this.softClipShape,v;if(u){this._ctx=l;return}for(this._ctx=null,v=this._off;v<n.length;){var h=n[v++],c=n[v++];isNaN(h)||isNaN(c)||f&&!f.contain(h,c)||(s.x=h-i[0]/2,s.y=c-i[1]/2,s.width=i[0],s.height=i[1],o.buildPath(e,s,!0))}this.incremental&&(this._off=v,this.notClear=!0)},t.prototype.afterBrush=function(){var e=this.shape,a=e.points,n=e.size,i=this._ctx,o=this.softClipShape,s;if(i){for(s=this._off;s<a.length;){var l=a[s++],u=a[s++];isNaN(l)||isNaN(u)||o&&!o.contain(l,u)||i.fillRect(l-n[0]/2,u-n[1]/2,n[0],n[1])}this.incremental&&(this._off=s,this.notClear=!0)}},t.prototype.findDataIndex=function(e,a){for(var n=this.shape,i=n.points,o=n.size,s=Math.max(o[0],4),l=Math.max(o[1],4),u=i.length/2-1;u>=0;u--){var f=u*2,v=i[f]-s/2,h=i[f+1]-l/2;if(e>=v&&a>=h&&e<=v+s&&a<=h+l)return u}return-1},t.prototype.contain=function(e,a){var n=this.transformCoordToLocal(e,a),i=this.getBoundingRect();if(e=n[0],a=n[1],i.contain(e,a)){var o=this.hoverDataIdx=this.findDataIndex(e,a);return o>=0}return this.hoverDataIdx=-1,!1},t.prototype.getBoundingRect=function(){var e=this._rect;if(!e){for(var a=this.shape,n=a.points,i=a.size,o=i[0],s=i[1],l=1/0,u=1/0,f=-1/0,v=-1/0,h=0;h<n.length;){var c=n[h++],p=n[h++];l=Math.min(c,l),f=Math.max(c,f),u=Math.min(p,u),v=Math.max(p,v)}e=this._rect=new lt(l-o/2,u-s/2,f-l+o,v-u+s)}return e},t}(bt),K3=function(){function r(){this.group=new rt}return r.prototype.updateData=function(t,e){this._clear();var a=this._create();a.setShape({points:t.getLayout("points")}),this._setCommon(a,t,e)},r.prototype.updateLayout=function(t){var e=t.getLayout("points");this.group.eachChild(function(a){if(a.startIndex!=null){var n=(a.endIndex-a.startIndex)*2,i=a.startIndex*4*2;e=new Float32Array(e.buffer,i,n)}a.setShape("points",e),a.reset()})},r.prototype.incrementalPrepareUpdate=function(t){this._clear()},r.prototype.incrementalUpdate=function(t,e,a){var n=this._newAdded[0],i=e.getLayout("points"),o=n&&n.shape.points;if(o&&o.length<2e4){var s=o.length,l=new Float32Array(s+i.length);l.set(o),l.set(i,s),n.endIndex=t.end,n.setShape({points:l})}else{this._newAdded=[];var u=this._create();u.startIndex=t.start,u.endIndex=t.end,u.incremental=!0,u.setShape({points:i}),this._setCommon(u,e,a)}},r.prototype.eachRendered=function(t){this._newAdded[0]&&t(this._newAdded[0])},r.prototype._create=function(){var t=new q3({cursor:"default"});return t.ignoreCoarsePointer=!0,this.group.add(t),this._newAdded.push(t),t},r.prototype._setCommon=function(t,e,a){var n=e.hostModel;a=a||{};var i=e.getVisual("symbolSize");t.setShape("size",i instanceof Array?i:[i,i]),t.softClipShape=a.clipShape||null,t.symbolProxy=ie(e.getVisual("symbol"),0,0,0,0),t.setColor=t.symbolProxy.setColor;var o=t.shape.size[0]<N2;t.useStyle(n.getModel("itemStyle").getItemStyle(o?["color","shadowBlur","shadowColor"]:["color"]));var s=e.getVisual("style"),l=s&&s.fill;l&&t.setColor(l);var u=ut(t);u.seriesIndex=n.seriesIndex,t.on("mousemove",function(f){u.dataIndex=null;var v=t.hoverDataIdx;v>=0&&(u.dataIndex=v+(t.startIndex||0))})},r.prototype.remove=function(){this._clear()},r.prototype._clear=function(){this._newAdded=[],this.group.removeAll()},r}(),j3=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n){var i=e.getData(),o=this._updateSymbolDraw(i,e);o.updateData(i,{clipShape:this._getClipShape(e)}),this._finished=!0},t.prototype.incrementalPrepareRender=function(e,a,n){var i=e.getData(),o=this._updateSymbolDraw(i,e);o.incrementalPrepareUpdate(i),this._finished=!1},t.prototype.incrementalRender=function(e,a,n){this._symbolDraw.incrementalUpdate(e,a.getData(),{clipShape:this._getClipShape(a)}),this._finished=e.end===a.getData().count()},t.prototype.updateTransform=function(e,a,n){var i=e.getData();if(this.group.dirty(),!this._finished||i.count()>1e4)return{update:!0};var o=Nu("").reset(e,a,n);o.progress&&o.progress({start:0,end:i.count(),count:i.count()},i),this._symbolDraw.updateLayout(i)},t.prototype.eachRendered=function(e){this._symbolDraw&&this._symbolDraw.eachRendered(e)},t.prototype._getClipShape=function(e){if(e.get("clip",!0)){var a=e.coordinateSystem;return a&&a.getArea&&a.getArea(.1)}},t.prototype._updateSymbolDraw=function(e,a){var n=this._symbolDraw,i=a.pipelineContext,o=i.large;return(!n||o!==this._isLargeDraw)&&(n&&n.remove(),n=this._symbolDraw=o?new K3:new Eu,this._isLargeDraw=o,this.group.removeAll()),this.group.add(n.group),n},t.prototype.remove=function(e,a){this._symbolDraw&&this._symbolDraw.remove(!0),this._symbolDraw=null},t.prototype.dispose=function(){},t.type="scatter",t}(Nt),B2={left:0,right:0,top:0,bottom:0},lh=["25%","25%"],J3=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.mergeDefaultAndTheme=function(e,a){var n=Ji(e.outerBounds);r.prototype.mergeDefaultAndTheme.apply(this,arguments),n&&e.outerBounds&&_a(e.outerBounds,n)},t.prototype.mergeOption=function(e,a){r.prototype.mergeOption.apply(this,arguments),this.option.outerBounds&&e.outerBounds&&_a(this.option.outerBounds,e.outerBounds)},t.type="grid",t.dependencies=["xAxis","yAxis"],t.layoutMode="box",t.defaultOption={show:!1,z:0,left:"15%",top:65,right:"10%",bottom:80,containLabel:!1,outerBoundsMode:"auto",outerBounds:B2,outerBoundsContain:"all",outerBoundsClampWidth:lh[0],outerBoundsClampHeight:lh[1],backgroundColor:N.color.transparent,borderWidth:1,borderColor:N.color.neutral30},t}(xt),ny=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.getCoordSysModel=function(){return this.getReferringComponents("grid",Kt).models[0]},t.type="cartesian2dAxis",t}(xt);Qt(ny,Is);var z2={show:!0,z:0,inverse:!1,name:"",nameLocation:"end",nameRotate:null,nameTruncate:{maxWidth:null,ellipsis:"...",placeholder:"."},nameTextStyle:{},nameGap:15,silent:!1,triggerEvent:!1,tooltip:{show:!1},axisPointer:{},axisLine:{show:!0,onZero:!0,onZeroAxisIndex:null,lineStyle:{color:N.color.axisLine,width:1,type:"solid"},symbol:["none","none"],symbolSize:[10,15],breakLine:!0},axisTick:{show:!0,inside:!1,length:5,lineStyle:{width:1}},axisLabel:{show:!0,inside:!1,rotate:0,showMinLabel:null,showMaxLabel:null,margin:8,fontSize:12,color:N.color.axisLabel,textMargin:[0,3]},splitLine:{show:!0,showMinLine:!0,showMaxLine:!0,lineStyle:{color:N.color.axisSplitLine,width:1,type:"solid"}},splitArea:{show:!1,areaStyle:{color:[N.color.backgroundTint,N.color.backgroundTransparent]}},breakArea:{show:!0,itemStyle:{color:N.color.neutral00,borderColor:N.color.border,borderWidth:1,borderType:[3,3],opacity:.6},zigzagAmplitude:4,zigzagMinSpan:4,zigzagMaxSpan:20,zigzagZ:100,expandOnClick:!0},breakLabelLayout:{moveOverlap:"auto"}},Q3=yt({boundaryGap:!0,deduplication:null,jitter:0,jitterOverlap:!0,jitterMargin:2,splitLine:{show:!1},axisTick:{alignWithLabel:!1,interval:"auto",show:"auto"},axisLabel:{interval:"auto"}},z2),w0=yt({boundaryGap:[0,0],axisLine:{show:"auto"},axisTick:{show:"auto"},splitNumber:5,minorTick:{show:!1,splitNumber:5,length:3,lineStyle:{}},minorSplitLine:{show:!1,lineStyle:{color:N.color.axisMinorSplitLine,width:1}}},z2),tF=yt({splitNumber:6,axisLabel:{showMinLabel:!1,showMaxLabel:!1,rich:{primary:{fontWeight:"bold"}}},splitLine:{show:!1}},w0),eF=nt({logBase:10},w0);const V2={category:Q3,value:w0,time:tF,log:eF};var rF={value:1,category:1,time:1,log:1},iy=null;function aF(r){iy||(iy=r)}function Bu(){return iy}function ls(r,t,e,a){A(rF,function(n,i){var o=yt(yt({},V2[i],!0),a,!0),s=function(l){z(u,l);function u(){var f=l!==null&&l.apply(this,arguments)||this;return f.type=t+"Axis."+i,f}return u.prototype.mergeDefaultAndTheme=function(f,v){var h=Jl(this),c=h?Ji(f):{},p=v.getTheme();yt(f,p.get(i+"Axis")),yt(f,this.getDefaultOption()),f.type=qx(f),h&&_a(f,c,h)},u.prototype.optionUpdated=function(){var f=this.option;f.type==="category"&&(this.__ordinalMeta=nu.createByAxisModel(this))},u.prototype.getCategories=function(f){var v=this.option;if(v.type==="category")return f?v.data:this.__ordinalMeta.categories},u.prototype.getOrdinalMeta=function(){return this.__ordinalMeta},u.prototype.updateAxisBreaks=function(f){var v=Bu();return v?v.updateModelAxisBreak(this,f):{breaks:[]}},u.type=t+"Axis."+i,u.defaultOption=o,u}(e);r.registerComponentModel(s)}),r.registerSubTypeDefaulter(t+"Axis",qx)}function qx(r){return r.type||(r.data?"category":"value")}var nF=function(){function r(t){this.type="cartesian",this._dimList=[],this._axes={},this.name=t||""}return r.prototype.getAxis=function(t){return this._axes[t]},r.prototype.getAxes=function(){return U(this._dimList,function(t){return this._axes[t]},this)},r.prototype.getAxesByScale=function(t){return t=t.toLowerCase(),Pt(this.getAxes(),function(e){return e.scale.type===t})},r.prototype.addAxis=function(t){var e=t.dim;this._axes[e]=t,this._dimList.push(e)},r}(),oy=["x","y"];function Kx(r){return(r.type==="interval"||r.type==="time")&&!r.hasBreaks()}var iF=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="cartesian2d",e.dimensions=oy,e}return t.prototype.calcAffineTransform=function(){this._transform=this._invTransform=null;var e=this.getAxis("x").scale,a=this.getAxis("y").scale;if(!(!Kx(e)||!Kx(a))){var n=e.getExtent(),i=a.getExtent(),o=this.dataToPoint([n[0],i[0]]),s=this.dataToPoint([n[1],i[1]]),l=n[1]-n[0],u=i[1]-i[0];if(!(!l||!u)){var f=(s[0]-o[0])/l,v=(s[1]-o[1])/u,h=o[0]-n[0]*f,c=o[1]-i[0]*v,p=this._transform=[f,0,0,v,h,c];this._invTransform=Dr([],p)}}},t.prototype.getBaseAxis=function(){return this.getAxesByScale("ordinal")[0]||this.getAxesByScale("time")[0]||this.getAxis("x")},t.prototype.containPoint=function(e){var a=this.getAxis("x"),n=this.getAxis("y");return a.contain(a.toLocalCoord(e[0]))&&n.contain(n.toLocalCoord(e[1]))},t.prototype.containData=function(e){return this.getAxis("x").containData(e[0])&&this.getAxis("y").containData(e[1])},t.prototype.containZone=function(e,a){var n=this.dataToPoint(e),i=this.dataToPoint(a),o=this.getArea(),s=new lt(n[0],n[1],i[0]-n[0],i[1]-n[1]);return o.intersect(s)},t.prototype.dataToPoint=function(e,a,n){n=n||[];var i=e[0],o=e[1];if(this._transform&&i!=null&&isFinite(i)&&o!=null&&isFinite(o))return Jt(n,e,this._transform);var s=this.getAxis("x"),l=this.getAxis("y");return n[0]=s.toGlobalCoord(s.dataToCoord(i,a)),n[1]=l.toGlobalCoord(l.dataToCoord(o,a)),n},t.prototype.clampData=function(e,a){var n=this.getAxis("x").scale,i=this.getAxis("y").scale,o=n.getExtent(),s=i.getExtent(),l=n.parse(e[0]),u=i.parse(e[1]);return a=a||[],a[0]=Math.min(Math.max(Math.min(o[0],o[1]),l),Math.max(o[0],o[1])),a[1]=Math.min(Math.max(Math.min(s[0],s[1]),u),Math.max(s[0],s[1])),a},t.prototype.pointToData=function(e,a,n){if(n=n||[],this._invTransform)return Jt(n,e,this._invTransform);var i=this.getAxis("x"),o=this.getAxis("y");return n[0]=i.coordToData(i.toLocalCoord(e[0]),a),n[1]=o.coordToData(o.toLocalCoord(e[1]),a),n},t.prototype.getOtherAxis=function(e){return this.getAxis(e.dim==="x"?"y":"x")},t.prototype.getArea=function(e){e=e||0;var a=this.getAxis("x").getGlobalExtent(),n=this.getAxis("y").getGlobalExtent(),i=Math.min(a[0],a[1])-e,o=Math.min(n[0],n[1])-e,s=Math.max(a[0],a[1])-i+e,l=Math.max(n[0],n[1])-o+e;return new lt(i,o,s,l)},t}(nF),G2=function(r){z(t,r);function t(e,a,n,i,o){var s=r.call(this,e,a,n)||this;return s.index=0,s.type=i||"value",s.position=o||"bottom",s}return t.prototype.isHorizontal=function(){var e=this.position;return e==="top"||e==="bottom"},t.prototype.getGlobalExtent=function(e){var a=this.getExtent();return a[0]=this.toGlobalCoord(a[0]),a[1]=this.toGlobalCoord(a[1]),e&&a[0]>a[1]&&a.reverse(),a},t.prototype.pointToData=function(e,a){return this.coordToData(this.toLocalCoord(e[this.dim==="x"?0:1]),a)},t.prototype.setCategorySortInfo=function(e){if(this.type!=="category")return!1;this.model.option.categorySortInfo=e,this.scale.setSortInfo(e)},t}($r),ic="expandAxisBreak",F2="collapseAxisBreak",H2="toggleAxisBreak",T0="axisbreakchanged",oF={type:ic,event:T0,update:"update",refineEvent:C0},sF={type:F2,event:T0,update:"update",refineEvent:C0},lF={type:H2,event:T0,update:"update",refineEvent:C0};function C0(r,t,e,a){var n=[];return A(r,function(i){n=n.concat(i.eventBreaks)}),{eventContent:{breaks:n}}}function uF(r){r.registerAction(oF,t),r.registerAction(sF,t),r.registerAction(lF,t);function t(e,a){var n=[],i=Zo(a,e);function o(s,l){A(i[s],function(u){var f=u.updateAxisBreaks(e);A(f.breaks,function(v){var h;n.push(nt((h={},h[l]=u.componentIndex,h),v))})})}return o("xAxisModels","xAxisIndex"),o("yAxisModels","yAxisIndex"),o("singleAxisModels","singleAxisIndex"),{eventBreaks:n}}}var _n=Math.PI,fF=[[1,2,1,2],[5,3,5,3],[8,3,8,3]],vF=[[0,1,0,1],[0,3,0,3],[0,3,0,3]],us=St(),W2=St(),U2=function(){function r(t){this.recordMap={},this.resolveAxisNameOverlap=t}return r.prototype.ensureRecord=function(t){var e=t.axis.dim,a=t.componentIndex,n=this.recordMap,i=n[e]||(n[e]=[]);return i[a]||(i[a]={ready:{}})},r}();function hF(r,t,e,a){var n=e.axis,i=t.ensureRecord(e),o=[],s,l=A0(r.axisName)&&os(r.nameLocation);A(a,function(p){var d=Sa(p);if(!(!d||d.label.ignore)){o.push(d);var g=i.transGroup;l&&(g.transform?Dr(Ks,g.transform):xu(Ks),d.transform&&Gr(Ks,Ks,d.transform),lt.copy(If,d.localRect),If.applyTransform(Ks),s?s.union(If):lt.copy(s=new lt(0,0,0,0),If))}});var u=Math.abs(i.dirVec.x)>.1?"x":"y",f=i.transGroup[u];if(o.sort(function(p,d){return Math.abs(p.label[u]-f)-Math.abs(d.label[u]-f)}),l&&s){var v=n.getExtent(),h=Math.min(v[0],v[1]),c=Math.max(v[0],v[1])-h;s.union(new lt(h,0,c,1))}i.stOccupiedRect=s,i.labelInfoList=o}var Ks=me(),If=new lt(0,0,0,0),Y2=function(r,t,e,a,n,i){if(os(r.nameLocation)){var o=i.stOccupiedRect;o&&Z2(fG({},o,i.transGroup.transform),a,n)}else X2(i.labelInfoList,i.dirVec,a,n)};function Z2(r,t,e){var a=new st;ac(r,t,a,{direction:Math.atan2(e.y,e.x),bidirectional:!1,touchThreshold:.05})&&jg(t,a)}function X2(r,t,e,a){for(var n=st.dot(a,t)>=0,i=0,o=r.length;i<o;i++){var s=r[n?i:o-1-i];s.label.ignore||Z2(s,e,a)}}var Ye=function(){function r(t,e,a,n){this.group=new rt,this._axisModel=t,this._api=e,this._local={},this._shared=n||new U2(Y2),this._resetCfgDetermined(a)}return r.prototype.updateCfg=function(t){var e=this._cfg.raw;e.position=t.position,e.labelOffset=t.labelOffset,this._resetCfgDetermined(e)},r.prototype.__getRawCfg=function(){return this._cfg.raw},r.prototype._resetCfgDetermined=function(t){var e=this._axisModel,a=e.getDefaultOption?e.getDefaultOption():{},n=Q(t.axisName,e.get("name")),i=e.get("nameMoveOverlap");(i==null||i==="auto")&&(i=Q(t.defaultNameMoveOverlap,!0));var o={raw:t,position:t.position,rotation:t.rotation,nameDirection:Q(t.nameDirection,1),tickDirection:Q(t.tickDirection,1),labelDirection:Q(t.labelDirection,1),labelOffset:Q(t.labelOffset,0),silent:Q(t.silent,!0),axisName:n,nameLocation:Qe(e.get("nameLocation"),a.nameLocation,"end"),shouldNameMoveOverlap:A0(n)&&i,optionHideOverlap:e.get(["axisLabel","hideOverlap"]),showMinorTicks:e.get(["minorTick","show"])};this._cfg=o;var s=new rt({x:o.position[0],y:o.position[1],rotation:o.rotation});s.updateTransform(),this._transformGroup=s;var l=this._shared.ensureRecord(e);l.transGroup=this._transformGroup,l.dirVec=new st(Math.cos(-o.rotation),Math.sin(-o.rotation))},r.prototype.build=function(t,e){var a=this;return t||(t={axisLine:!0,axisTickLabelEstimate:!1,axisTickLabelDetermine:!0,axisName:!0}),A(cF,function(n){t[n]&&pF[n](a._cfg,a._local,a._shared,a._axisModel,a.group,a._transformGroup,a._api,e||{})}),this},r.innerTextLayout=function(t,e,a){var n=fm(e-t),i,o;return Qo(n)?(o=a>0?"top":"bottom",i="center"):Qo(n-_n)?(o=a>0?"bottom":"top",i="center"):(o="middle",n>0&&n<_n?i=a>0?"right":"left":i=a>0?"left":"right"),{rotation:n,textAlign:i,textVerticalAlign:o}},r.makeAxisEventDataBase=function(t){var e={componentType:t.mainType,componentIndex:t.componentIndex};return e[t.mainType+"Index"]=t.componentIndex,e},r.isLabelSilent=function(t){var e=t.get("tooltip");return t.get("silent")||!(t.get("triggerEvent")||e&&e.show)},r}(),cF=["axisLine","axisTickLabelEstimate","axisTickLabelDetermine","axisName"],pF={axisLine:function(r,t,e,a,n,i,o){var s=a.get(["axisLine","show"]);if(s==="auto"&&(s=!0,r.raw.axisLineAutoShow!=null&&(s=!!r.raw.axisLineAutoShow)),!!s){var l=a.axis.getExtent(),u=i.transform,f=[l[0],0],v=[l[1],0],h=f[0]>v[0];u&&(Jt(f,f,u),Jt(v,v,u));var c=G({lineCap:"round"},a.getModel(["axisLine","lineStyle"]).getLineStyle()),p={strokeContainThreshold:r.raw.strokeContainThreshold||5,silent:!0,z2:1,style:c};if(a.get(["axisLine","breakLine"])&&a.axis.scale.hasBreaks())Bu().buildAxisBreakLine(a,n,i,p);else{var d=new ne(G({shape:{x1:f[0],y1:f[1],x2:v[0],y2:v[1]}},p));rs(d.shape,d.style.lineWidth),d.anid="line",n.add(d)}var g=a.get(["axisLine","symbol"]);if(g!=null){var y=a.get(["axisLine","symbolSize"]);X(g)&&(g=[g,g]),(X(y)||Mt(y))&&(y=[y,y]);var m=to(a.get(["axisLine","symbolOffset"])||0,y),_=y[0],S=y[1];A([{rotate:r.rotation+Math.PI/2,offset:m[0],r:0},{rotate:r.rotation-Math.PI/2,offset:m[1],r:Math.sqrt((f[0]-v[0])*(f[0]-v[0])+(f[1]-v[1])*(f[1]-v[1]))}],function(x,b){if(g[b]!=="none"&&g[b]!=null){var w=ie(g[b],-_/2,-S/2,_,S,c.stroke,!0),T=x.r+x.offset,C=h?v:f;w.attr({rotation:x.rotate,x:C[0]+T*Math.cos(r.rotation),y:C[1]-T*Math.sin(r.rotation),silent:!0,z2:11}),n.add(w)}})}}},axisTickLabelEstimate:function(r,t,e,a,n,i,o,s){var l=Jx(t,n,s);l&&jx(r,t,e,a,n,i,o,Zr.estimate)},axisTickLabelDetermine:function(r,t,e,a,n,i,o,s){var l=Jx(t,n,s);l&&jx(r,t,e,a,n,i,o,Zr.determine);var u=mF(r,n,i,a);yF(r,t.labelLayoutList,u),_F(r,n,i,a,r.tickDirection)},axisName:function(r,t,e,a,n,i,o,s){var l=e.ensureRecord(a);t.nameEl&&(n.remove(t.nameEl),t.nameEl=l.nameLayout=l.nameLocation=null);var u=r.axisName;if(A0(u)){var f=r.nameLocation,v=r.nameDirection,h=a.getModel("nameTextStyle"),c=a.get("nameGap")||0,p=a.axis.getExtent(),d=a.axis.inverse?-1:1,g=new st(0,0),y=new st(0,0);f==="start"?(g.x=p[0]-d*c,y.x=-d):f==="end"?(g.x=p[1]+d*c,y.x=d):(g.x=(p[0]+p[1])/2,g.y=r.labelOffset+v*c,y.y=v);var m=me();y.transform(Qa(m,m,r.rotation));var _=a.get("nameRotate");_!=null&&(_=_*_n/180);var S,x;os(f)?S=Ye.innerTextLayout(r.rotation,_??r.rotation,v):(S=dF(r.rotation,f,_||0,p),x=r.raw.axisNameAvailableWidth,x!=null&&(x=Math.abs(x/Math.sin(S.rotation)),!isFinite(x)&&(x=null)));var b=h.getFont(),w=a.get("nameTruncate",!0)||{},T=w.ellipsis,C=Ce(r.raw.nameTruncateMaxWidth,w.maxWidth,x),M=s.nameMarginLevel||0,D=new At({x:g.x,y:g.y,rotation:S.rotation,silent:Ye.isLabelSilent(a),style:Gt(h,{text:u,font:b,overflow:"truncate",width:C,ellipsis:T,fill:h.getTextColor()||a.get(["axisLine","lineStyle","color"]),align:h.get("align")||S.textAlign,verticalAlign:h.get("verticalAlign")||S.textVerticalAlign}),z2:1});if(en({el:D,componentModel:a,itemName:u}),D.__fullText=u,D.anid="name",a.get("triggerEvent")){var I=Ye.makeAxisEventDataBase(a);I.targetType="axisName",I.name=u,ut(D).eventData=I}i.add(D),D.updateTransform(),t.nameEl=D;var L=l.nameLayout=Sa({label:D,priority:D.z2,defaultAttr:{ignore:D.ignore},marginDefault:os(f)?fF[M]:vF[M]});if(l.nameLocation=f,n.add(D),D.decomposeTransform(),r.shouldNameMoveOverlap&&L){var P=e.ensureRecord(a);e.resolveAxisNameOverlap(r,e,a,L,y,P)}}}};function jx(r,t,e,a,n,i,o,s){q2(t)||SF(r,t,n,s,a,o);var l=t.labelLayoutList;xF(r,a,l,i),TF(a,r.rotation,l);var u=r.optionHideOverlap;gF(a,l,u),u&&i2(Pt(l,function(f){return f&&!f.label.ignore})),hF(r,e,a,l)}function dF(r,t,e,a){var n=fm(e-r),i,o,s=a[0]>a[1],l=t==="start"&&!s||t!=="start"&&s;return Qo(n-_n/2)?(o=l?"bottom":"top",i="center"):Qo(n-_n*1.5)?(o=l?"top":"bottom",i="center"):(o="middle",n<_n*1.5&&n>_n/2?i=l?"left":"right":i=l?"right":"left"),{rotation:n,textAlign:i,textVerticalAlign:o}}function gF(r,t,e){if(HL(r.axis))return;function a(s,l,u){var f=Sa(t[l]),v=Sa(t[u]);if(!(!f||!v)){if(s===!1||f.suggestIgnore){Sl(f.label);return}if(v.suggestIgnore){Sl(v.label);return}var h=.1;if(!e){var c=[0,0,0,0];f=Jg({marginForce:c},f),v=Jg({marginForce:c},v)}ac(f,v,null,{touchThreshold:h})&&Sl(s?v.label:f.label)}}var n=r.get(["axisLabel","showMinLabel"]),i=r.get(["axisLabel","showMaxLabel"]),o=t.length;a(n,0,1),a(i,o-1,o-2)}function yF(r,t,e){r.showMinorTicks||A(t,function(a){if(a&&a.label.ignore)for(var n=0;n<e.length;n++){var i=e[n],o=W2(i),s=us(a.label);if(o.tickValue!=null&&!o.onBand&&o.tickValue===s.tickValue){Sl(i);return}}})}function Sl(r){r&&(r.ignore=!0)}function $2(r,t,e,a,n){for(var i=[],o=[],s=[],l=0;l<r.length;l++){var u=r[l].coord;o[0]=u,o[1]=0,s[0]=u,s[1]=e,t&&(Jt(o,o,t),Jt(s,s,t));var f=new ne({shape:{x1:o[0],y1:o[1],x2:s[0],y2:s[1]},style:a,z2:2,autoBatch:!0,silent:!0});rs(f.shape,f.style.lineWidth),f.anid=n+"_"+r[l].tickValue,i.push(f);var v=W2(f);v.onBand=!!r[l].onBand,v.tickValue=r[l].tickValue}return i}function mF(r,t,e,a){var n=a.axis,i=a.getModel("axisTick"),o=i.get("show");if(o==="auto"&&(o=!0,r.raw.axisTickAutoShow!=null&&(o=!!r.raw.axisTickAutoShow)),!o||n.scale.isBlank())return[];for(var s=i.getModel("lineStyle"),l=r.tickDirection*i.get("length"),u=n.getTicksCoords(),f=$2(u,e.transform,l,nt(s.getLineStyle(),{stroke:a.get(["axisLine","lineStyle","color"])}),"ticks"),v=0;v<f.length;v++)t.add(f[v]);return f}function _F(r,t,e,a,n){var i=a.axis,o=a.getModel("minorTick");if(!(!r.showMinorTicks||i.scale.isBlank())){var s=i.getMinorTicksCoords();if(s.length)for(var l=o.getModel("lineStyle"),u=n*o.get("length"),f=nt(l.getLineStyle(),nt(a.getModel("axisTick").getLineStyle(),{stroke:a.get(["axisLine","lineStyle","color"])})),v=0;v<s.length;v++)for(var h=$2(s[v],e.transform,u,f,"minorticks_"+v),c=0;c<h.length;c++)t.add(h[c])}}function Jx(r,t,e){if(q2(r)){var a=r.axisLabelsCreationContext,n=a.out.noPxChangeTryDetermine;if(e.noPxChange){for(var i=!0,o=0;o<n.length;o++)i=i&&n[o]();if(i)return!1}n.length&&(t.remove(r.labelGroup),sy(r,null,null,null))}return!0}function SF(r,t,e,a,n,i){var o=n.axis,s=Ce(r.raw.axisLabelShow,n.get(["axisLabel","show"])),l=new rt;e.add(l);var u=eh(a);if(!s||o.scale.isBlank()){sy(t,[],l,u);return}var f=n.getModel("axisLabel"),v=o.getViewLabels(u),h=(Ce(r.raw.labelRotate,f.get("rotate"))||0)*_n/180,c=Ye.innerTextLayout(r.rotation,h,r.labelDirection),p=n.getCategories&&n.getCategories(!0),d=[],g=n.get("triggerEvent"),y=1/0,m=-1/0;A(v,function(S,x){var b,w=o.scale.type==="ordinal"?o.scale.getRawOrdinalNumber(S.tickValue):S.tickValue,T=S.formattedLabel,C=S.rawLabel,M=f;if(p&&p[w]){var D=p[w];it(D)&&D.textStyle&&(M=new wt(D.textStyle,f,n.ecModel))}var I=M.getTextColor()||n.get(["axisLine","lineStyle","color"]),L=M.getShallow("align",!0)||c.textAlign,P=Q(M.getShallow("alignMinLabel",!0),L),k=Q(M.getShallow("alignMaxLabel",!0),L),R=M.getShallow("verticalAlign",!0)||M.getShallow("baseline",!0)||c.textVerticalAlign,O=Q(M.getShallow("verticalAlignMinLabel",!0),R),E=Q(M.getShallow("verticalAlignMaxLabel",!0),R),B=10+(((b=S.time)===null||b===void 0?void 0:b.level)||0);y=Math.min(y,B),m=Math.max(m,B);var V=new At({x:0,y:0,rotation:0,silent:Ye.isLabelSilent(n),z2:B,style:Gt(M,{text:T,align:x===0?P:x===v.length-1?k:L,verticalAlign:x===0?O:x===v.length-1?E:R,fill:tt(I)?I(o.type==="category"?C:o.type==="value"?w+"":w,x):I})});V.anid="label_"+w;var F=us(V);if(F.break=S.break,F.tickValue=w,F.layoutRotation=c.rotation,en({el:V,componentModel:n,itemName:T,formatterParamsExtra:{isTruncated:function(){return V.isTruncated},value:C,tickIndex:x}}),g){var H=Ye.makeAxisEventDataBase(n);H.targetType="axisLabel",H.value=C,H.tickIndex=x,S.break&&(H.break={start:S.break.parsedBreak.vmin,end:S.break.parsedBreak.vmax}),o.type==="category"&&(H.dataIndex=w),ut(V).eventData=H,S.break&&wF(n,i,V,S.break)}d.push(V),l.add(V)});var _=U(d,function(S){return{label:S,priority:us(S).break?S.z2+(m-y+1):S.z2,defaultAttr:{ignore:S.ignore}}});sy(t,_,l,u)}function q2(r){return!!r.labelLayoutList}function sy(r,t,e,a){r.labelLayoutList=t,r.labelGroup=e,r.axisLabelsCreationContext=a}function xF(r,t,e,a){var n=t.get(["axisLabel","margin"]);A(e,function(i,o){var s=Sa(i);if(s){var l=s.label,u=us(l);s.suggestIgnore=l.ignore,l.ignore=!1,Rv(La,bF),La.x=t.axis.dataToCoord(u.tickValue),La.y=r.labelOffset+r.labelDirection*n,La.rotation=u.layoutRotation,a.add(La),La.updateTransform(),a.remove(La),La.decomposeTransform(),Rv(l,La),l.markRedraw(),ih(s,!0),Sa(s)}})}var La=new _t,bF=new _t;function A0(r){return!!r}function wF(r,t,e,a){e.on("click",function(n){var i={type:ic,breaks:[{start:a.parsedBreak.breakOption.start,end:a.parsedBreak.breakOption.end}]};i[r.axis.dim+"AxisIndex"]=r.componentIndex,t.dispatchAction(i)})}function TF(r,t,e){var a=se();if(a){var n=a.retrieveAxisBreakPairs(e,function(o){return o&&us(o.label).break},!0),i=r.get(["breakLabelLayout","moveOverlap"],!0);(i===!0||i==="auto")&&A(n,function(o){Bu().adjustBreakLabelPair(r.axis.inverse,t,[Sa(e[o[0]]),Sa(e[o[1]])])})}}function uh(r,t,e){e=e||{};var a=t.axis,n={},i=a.getAxesOnZeroOf()[0],o=a.position,s=i?"onZero":o,l=a.dim,u=[r.x,r.x+r.width,r.y,r.y+r.height],f={left:0,right:1,top:0,bottom:1,onZero:2},v=t.get("offset")||0,h=l==="x"?[u[2]-v,u[3]+v]:[u[0]-v,u[1]+v];if(i){var c=i.toGlobalCoord(i.dataToCoord(0));h[f.onZero]=Math.max(Math.min(c,h[1]),h[0])}n.position=[l==="y"?h[f[s]]:u[0],l==="x"?h[f[s]]:u[3]],n.rotation=Math.PI/2*(l==="x"?0:1);var p={top:-1,bottom:1,left:-1,right:1};n.labelDirection=n.tickDirection=n.nameDirection=p[o],n.labelOffset=i?h[f[o]]-h[f.onZero]:0,t.get(["axisTick","inside"])&&(n.tickDirection=-n.tickDirection),Ce(e.labelInside,t.get(["axisLabel","inside"]))&&(n.labelDirection=-n.labelDirection);var d=t.get(["axisLabel","rotate"]);return n.labelRotate=s==="top"?-d:d,n.z2=1,n}function CF(r){return r.coordinateSystem&&r.coordinateSystem.type==="cartesian2d"}function Qx(r){var t={xAxisModel:null,yAxisModel:null};return A(t,function(e,a){var n=a.replace(/Model$/,""),i=r.getReferringComponents(n,Kt).models[0];t[a]=i}),t}function AF(r,t,e,a,n,i){for(var o=uh(r,e),s=!1,l=!1,u=0;u<t.length;u++)Zg(t[u].getOtherAxis(e.axis).scale)&&(s=l=!0,e.axis.type==="category"&&e.axis.onBand&&(l=!1));return o.axisLineAutoShow=s,o.axisTickAutoShow=l,o.defaultNameMoveOverlap=i,new Ye(e,a,o,n)}function MF(r,t,e){var a=uh(t,e);r.updateCfg(a)}function K2(r,t,e){var a=ja.prototype,n=a.getTicks.call(e),i=a.getTicks.call(e,{expandToNicedExtent:!0}),o=n.length-1,s=a.getInterval.call(e),l=FL(r,t),u=l.extent,f=l.fixMin,v=l.fixMax;r.type==="log"&&(u=Xg(r.base,u,!0)),r.setBreaksFromOption(WL(t)),r.setExtent(u[0],u[1]),r.calcNiceExtent({splitNumber:o,fixMin:f,fixMax:v});var h=a.getExtent.call(r);f&&(u[0]=h[0]),v&&(u[1]=h[1]);var c=a.getInterval.call(r),p=u[0],d=u[1];if(f&&v)c=(d-p)/o;else if(f)for(d=u[0]+c*o;d<u[1]&&isFinite(d)&&isFinite(u[1]);)c=mp(c),d=u[0]+c*o;else if(v)for(p=u[1]-c*o;p>u[0]&&isFinite(p)&&isFinite(u[0]);)c=mp(c),p=u[1]-c*o;else{var g=r.getTicks().length-1;g>o&&(c=mp(c));var y=c*o;d=Math.ceil(u[1]/c)*c,p=ae(d-y),p<0&&u[0]>=0?(p=0,d=ae(y)):d>0&&u[1]<=0&&(d=0,p=-ae(y))}var m=(n[0].value-i[0].value)/s,_=(n[o].value-i[o].value)/s;a.setExtent.call(r,p+c*m,d+c*_),a.setInterval.call(r,c),(m||_)&&a.setNiceExtent.call(r,p+c,d-c)}var tb=[[3,1],[0,2]],DF=function(){function r(t,e,a){this.type="grid",this._coordsMap={},this._coordsList=[],this._axesMap={},this._axesList=[],this.axisPointerEnabled=!0,this.dimensions=oy,this._initCartesian(t,e,a),this.model=t}return r.prototype.getRect=function(){return this._rect},r.prototype.update=function(t,e){var a=this._axesMap;this._updateScale(t,this.model);function n(o){var s,l=Ct(o),u=l.length;if(u){for(var f=[],v=u-1;v>=0;v--){var h=+l[v],c=o[h],p=c.model,d=c.scale;Zg(d)&&p.get("alignTicks")&&p.get("interval")==null?f.push(c):(Zi(d,p),Zg(d)&&(s=c))}f.length&&(s||(s=f.pop(),Zi(s.scale,s.model)),A(f,function(g){K2(g.scale,g.model,s.scale)}))}}n(a.x),n(a.y);var i={};A(a.x,function(o){eb(a,"y",o,i)}),A(a.y,function(o){eb(a,"x",o,i)}),this.resize(this.model,e)},r.prototype.resize=function(t,e,a){var n=pe(t,e),i=this._rect=Xt(t.getBoxLayoutParams(),n.refContainer),o=this._axesMap,s=this._coordsList,l=t.get("containLabel");if(ly(o,i),!a){var u=PF(i,s,o,l,e),f=void 0;if(l)uy?(uy(this._axesList,i),ly(o,i)):f=nb(i.clone(),"axisLabel",null,i,o,u,n);else{var v=RF(t,i,n),h=v.outerBoundsRect,c=v.parsedOuterBoundsContain,p=v.outerBoundsClamp;h&&(f=nb(h,c,p,i,o,u,n))}j2(i,o,Zr.determine,null,f,n)}A(this._coordsList,function(d){d.calcAffineTransform()})},r.prototype.getAxis=function(t,e){var a=this._axesMap[t];if(a!=null)return a[e||0]},r.prototype.getAxes=function(){return this._axesList.slice()},r.prototype.getCartesian=function(t,e){if(t!=null&&e!=null){var a="x"+t+"y"+e;return this._coordsMap[a]}it(t)&&(e=t.yAxisIndex,t=t.xAxisIndex);for(var n=0,i=this._coordsList;n<i.length;n++)if(i[n].getAxis("x").index===t||i[n].getAxis("y").index===e)return i[n]},r.prototype.getCartesians=function(){return this._coordsList.slice()},r.prototype.convertToPixel=function(t,e,a){var n=this._findConvertTarget(e);return n.cartesian?n.cartesian.dataToPoint(a):n.axis?n.axis.toGlobalCoord(n.axis.dataToCoord(a)):null},r.prototype.convertFromPixel=function(t,e,a){var n=this._findConvertTarget(e);return n.cartesian?n.cartesian.pointToData(a):n.axis?n.axis.coordToData(n.axis.toLocalCoord(a)):null},r.prototype._findConvertTarget=function(t){var e=t.seriesModel,a=t.xAxisModel||e&&e.getReferringComponents("xAxis",Kt).models[0],n=t.yAxisModel||e&&e.getReferringComponents("yAxis",Kt).models[0],i=t.gridModel,o=this._coordsList,s,l;if(e)s=e.coordinateSystem,gt(o,s)<0&&(s=null);else if(a&&n)s=this.getCartesian(a.componentIndex,n.componentIndex);else if(a)l=this.getAxis("x",a.componentIndex);else if(n)l=this.getAxis("y",n.componentIndex);else if(i){var u=i.coordinateSystem;u===this&&(s=this._coordsList[0])}return{cartesian:s,axis:l}},r.prototype.containPoint=function(t){var e=this._coordsList[0];if(e)return e.containPoint(t)},r.prototype._initCartesian=function(t,e,a){var n=this,i=this,o={left:!1,right:!1,top:!1,bottom:!1},s={x:{},y:{}},l={x:0,y:0};if(e.eachComponent("xAxis",u("x"),this),e.eachComponent("yAxis",u("y"),this),!l.x||!l.y){this._axesMap={},this._axesList=[];return}this._axesMap=s,A(s.x,function(f,v){A(s.y,function(h,c){var p="x"+v+"y"+c,d=new iF(p);d.master=n,d.model=t,n._coordsMap[p]=d,n._coordsList.push(d),d.addAxis(f),d.addAxis(h)})});function u(f){return function(v,h){if(Ep(v,t)){var c=v.get("position");f==="x"?c!=="top"&&c!=="bottom"&&(c=o.bottom?"top":"bottom"):c!=="left"&&c!=="right"&&(c=o.left?"right":"left"),o[c]=!0;var p=new G2(f,Ru(v),[0,0],v.get("type"),c),d=p.type==="category";p.onBand=d&&v.get("boundaryGap"),p.inverse=v.get("inverse"),v.axis=p,p.model=v,p.grid=i,p.index=h,i._axesList.push(p),s[f][h]=p,l[f]++}}}},r.prototype._updateScale=function(t,e){A(this._axesList,function(n){if(n.scale.setExtent(1/0,-1/0),n.type==="category"){var i=n.model.get("categorySortInfo");n.scale.setSortInfo(i)}}),t.eachSeries(function(n){if(CF(n)){var i=Qx(n),o=i.xAxisModel,s=i.yAxisModel;if(!Ep(o,e)||!Ep(s,e))return;var l=this.getCartesian(o.componentIndex,s.componentIndex),u=n.getData(),f=l.getAxis("x"),v=l.getAxis("y");a(u,f),a(u,v)}},this);function a(n,i){A(th(n,i.dim),function(o){i.scale.unionExtentFromData(n,o)})}},r.prototype.getTooltipAxes=function(t){var e=[],a=[];return A(this.getCartesians(),function(n){var i=t!=null&&t!=="auto"?n.getAxis(t):n.getBaseAxis(),o=n.getOtherAxis(i);gt(e,i)<0&&e.push(i),gt(a,o)<0&&a.push(o)}),{baseAxes:e,otherAxes:a}},r.create=function(t,e){var a=[];return t.eachComponent("grid",function(n,i){var o=new r(n,t,e);o.name="grid_"+i,o.resize(n,e,!0),n.coordinateSystem=o,a.push(o)}),t.eachSeries(function(n){Iu({targetModel:n,coordSysType:"cartesian2d",coordSysProvider:i});function i(){var o=Qx(n),s=o.xAxisModel,l=o.yAxisModel,u=s.getCoordSysModel(),f=u.coordinateSystem;return f.getCartesian(s.componentIndex,l.componentIndex)}}),a},r.dimensions=oy,r}();function Ep(r,t){return r.getCoordSysModel()===t}function eb(r,t,e,a){e.getAxesOnZeroOf=function(){return i?[i]:[]};var n=r[t],i,o=e.model,s=o.get(["axisLine","onZero"]),l=o.get(["axisLine","onZeroAxisIndex"]);if(!s)return;if(l!=null)rb(n[l])&&(i=n[l]);else for(var u in n)if(n.hasOwnProperty(u)&&rb(n[u])&&!a[f(n[u])]){i=n[u];break}i&&(a[f(i)]=!0);function f(v){return v.dim+"_"+v.index}}function rb(r){return r&&r.type!=="category"&&r.type!=="time"&&L5(r)}function LF(r,t){var e=r.getExtent(),a=e[0]+e[1];r.toGlobalCoord=r.dim==="x"?function(n){return n+t}:function(n){return a-n+t},r.toLocalCoord=r.dim==="x"?function(n){return n-t}:function(n){return a-n+t}}function ly(r,t){A(r.x,function(e){return ab(e,t.x,t.width)}),A(r.y,function(e){return ab(e,t.y,t.height)})}function ab(r,t,e){var a=[0,e],n=r.inverse?1:0;r.setExtent(a[n],a[1-n]),LF(r,t)}var uy;function IF(r){uy=r}function nb(r,t,e,a,n,i,o){j2(a,n,Zr.estimate,t,!1,o);var s=[0,0,0,0];u(0),u(1),f(a,0,NaN),f(a,1,NaN);var l=Nn(s,function(h){return h>0})==null;return Wi(a,s,!0,!0,e),ly(n,a),l;function u(h){A(n[ct[h]],function(c){if(iu(c.model)){var p=i.ensureRecord(c.model),d=p.labelInfoList;if(d)for(var g=0;g<d.length;g++){var y=d[g],m=c.scale.normalize(us(y.label).tickValue);m=h===1?1-m:m,f(y.rect,h,m),f(y.rect,1-h,NaN)}var _=p.nameLayout;if(_){var m=os(p.nameLocation)?.5:NaN;f(_.rect,h,m),f(_.rect,1-h,NaN)}}})}function f(h,c,p){var d=r[ct[c]]-h[ct[c]],g=h[le[c]]+h[ct[c]]-(r[le[c]]+r[ct[c]]);d=v(d,1-p),g=v(g,p);var y=tb[c][0],m=tb[c][1];s[y]=re(s[y],d),s[m]=re(s[m],g)}function v(h,c){return h>0&&!Ie(c)&&c>1e-4&&(h/=c),h}}function PF(r,t,e,a,n){var i=new U2(kF);return A(e,function(o){return A(o,function(s){if(iu(s.model)){var l=!a;s.axisBuilder=AF(r,t,s.model,n,i,l)}})}),i}function j2(r,t,e,a,n,i){var o=e===Zr.determine;A(t,function(u){return A(u,function(f){iu(f.model)&&(MF(f.axisBuilder,r,f.model),f.axisBuilder.build(o?{axisTickLabelDetermine:!0}:{axisTickLabelEstimate:!0},{noPxChange:n}))})});var s={x:0,y:0};l(0),l(1);function l(u){s[ct[1-u]]=r[le[u]]<=i.refContainer[le[u]]*.5?0:1-u===1?2:1}A(t,function(u,f){return A(u,function(v){iu(v.model)&&((a==="all"||o)&&v.axisBuilder.build({axisName:!0},{nameMarginLevel:s[f]}),o&&v.axisBuilder.build({axisLine:!0}))})})}function RF(r,t,e){var a,n=r.get("outerBoundsMode",!0);n==="same"?a=t.clone():(n==null||n==="auto")&&(a=Xt(r.get("outerBounds",!0)||B2,e.refContainer));var i=r.get("outerBoundsContain",!0),o;i==null||i==="auto"||gt(["all","axisLabel"],i)<0?o="all":o=i;var s=[Ev(Q(r.get("outerBoundsClampWidth",!0),lh[0]),t.width),Ev(Q(r.get("outerBoundsClampHeight",!0),lh[1]),t.height)];return{outerBoundsRect:a,parsedOuterBoundsContain:o,outerBoundsClamp:s}}var kF=function(r,t,e,a,n,i){var o=e.axis.dim==="x"?"y":"x";Y2(r,t,e,a,n,i),os(r.nameLocation)||A(t.recordMap[o],function(s){s&&s.labelInfoList&&s.dirVec&&X2(s.labelInfoList,s.dirVec,a,n)})};function EF(r,t){var e={axesInfo:{},seriesInvolved:!1,coordSysAxesInfo:{},coordSysMap:{}};return OF(e,r,t),e.seriesInvolved&&BF(e,r),e}function OF(r,t,e){var a=t.getComponent("tooltip"),n=t.getComponent("axisPointer"),i=n.get("link",!0)||[],o=[];A(e.getCoordinateSystems(),function(s){if(!s.axisPointerEnabled)return;var l=uu(s.model),u=r.coordSysAxesInfo[l]={};r.coordSysMap[l]=s;var f=s.model,v=f.getModel("tooltip",a);if(A(s.getAxes(),pt(d,!1,null)),s.getTooltipAxes&&a&&v.get("show")){var h=v.get("trigger")==="axis",c=v.get(["axisPointer","type"])==="cross",p=s.getTooltipAxes(v.get(["axisPointer","axis"]));(h||c)&&A(p.baseAxes,pt(d,c?"cross":!0,h)),c&&A(p.otherAxes,pt(d,"cross",!1))}function d(g,y,m){var _=m.model.getModel("axisPointer",n),S=_.get("show");if(!(!S||S==="auto"&&!g&&!fy(_))){y==null&&(y=_.get("triggerTooltip")),_=g?NF(m,v,n,t,g,y):_;var x=_.get("snap"),b=_.get("triggerEmphasis"),w=uu(m.model),T=y||x||m.type==="category",C=r.axesInfo[w]={key:w,axis:m,coordSys:s,axisPointerModel:_,triggerTooltip:y,triggerEmphasis:b,involveSeries:T,snap:x,useHandle:fy(_),seriesModels:[],linkGroup:null};u[w]=C,r.seriesInvolved=r.seriesInvolved||T;var M=zF(i,m);if(M!=null){var D=o[M]||(o[M]={axesInfo:{}});D.axesInfo[w]=C,D.mapper=i[M].mapper,C.linkGroup=D}}}})}function NF(r,t,e,a,n,i){var o=t.getModel("axisPointer"),s=["type","snap","lineStyle","shadowStyle","label","animation","animationDurationUpdate","animationEasingUpdate","z"],l={};A(s,function(h){l[h]=et(o.get(h))}),l.snap=r.type!=="category"&&!!i,o.get("type")==="cross"&&(l.type="line");var u=l.label||(l.label={});if(u.show==null&&(u.show=!1),n==="cross"){var f=o.get(["label","show"]);if(u.show=f??!0,!i){var v=l.lineStyle=o.get("crossStyle");v&&nt(u,v.textStyle)}}return r.model.getModel("axisPointer",new wt(l,e,a))}function BF(r,t){t.eachSeries(function(e){var a=e.coordinateSystem,n=e.get(["tooltip","trigger"],!0),i=e.get(["tooltip","show"],!0);!a||!a.model||n==="none"||n===!1||n==="item"||i===!1||e.get(["axisPointer","show"],!0)===!1||A(r.coordSysAxesInfo[uu(a.model)],function(o){var s=o.axis;a.getAxis(s.dim)===s&&(o.seriesModels.push(e),o.seriesDataCount==null&&(o.seriesDataCount=0),o.seriesDataCount+=e.getData().count())})})}function zF(r,t){for(var e=t.model,a=t.dim,n=0;n<r.length;n++){var i=r[n]||{};if(Op(i[a+"AxisId"],e.id)||Op(i[a+"AxisIndex"],e.componentIndex)||Op(i[a+"AxisName"],e.name))return n}}function Op(r,t){return r==="all"||W(r)&&gt(r,t)>=0||r===t}function VF(r){var t=M0(r);if(t){var e=t.axisPointerModel,a=t.axis.scale,n=e.option,i=e.get("status"),o=e.get("value");o!=null&&(o=a.parse(o));var s=fy(e);i==null&&(n.status=s?"show":"hide");var l=a.getExtent().slice();l[0]>l[1]&&l.reverse(),(o==null||o>l[1])&&(o=l[1]),o<l[0]&&(o=l[0]),n.value=o,s&&(n.status=t.axis.scale.isBlank()?"hide":"show")}}function M0(r){var t=(r.ecModel.getComponent("axisPointer")||{}).coordSysAxesInfo;return t&&t.axesInfo[uu(r)]}function GF(r){var t=M0(r);return t&&t.axisPointerModel}function fy(r){return!!r.get(["handle","show"])}function uu(r){return r.type+"||"+r.id}var ib={},ro=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n,i){this.axisPointerClass&&VF(e),r.prototype.render.apply(this,arguments),this._doUpdateAxisPointerClass(e,n,!0)},t.prototype.updateAxisPointer=function(e,a,n,i){this._doUpdateAxisPointerClass(e,n,!1)},t.prototype.remove=function(e,a){var n=this._axisPointer;n&&n.remove(a)},t.prototype.dispose=function(e,a){this._disposeAxisPointer(a),r.prototype.dispose.apply(this,arguments)},t.prototype._doUpdateAxisPointerClass=function(e,a,n){var i=t.getAxisPointerClass(this.axisPointerClass);if(i){var o=GF(e);o?(this._axisPointer||(this._axisPointer=new i)).render(e,o,a,n):this._disposeAxisPointer(a)}},t.prototype._disposeAxisPointer=function(e){this._axisPointer&&this._axisPointer.dispose(e),this._axisPointer=null},t.registerAxisPointerClass=function(e,a){ib[e]=a},t.getAxisPointerClass=function(e){return e&&ib[e]},t.type="axis",t}(Wt),vy=St();function J2(r,t,e,a){var n=e.axis;if(!n.scale.isBlank()){var i=e.getModel("splitArea"),o=i.getModel("areaStyle"),s=o.get("color"),l=a.coordinateSystem.getRect(),u=n.getTicksCoords({tickModel:i,clamp:!0,breakTicks:"none",pruneByBreak:"preserve_extent_bound"});if(u.length){var f=s.length,v=vy(r).splitAreaColors,h=j(),c=0;if(v)for(var p=0;p<u.length;p++){var d=v.get(u[p].tickValue);if(d!=null){c=(d+(f-1)*p)%f;break}}var g=n.toGlobalCoord(u[0].coord),y=o.getAreaStyle();s=W(s)?s:[s];for(var p=1;p<u.length;p++){var m=n.toGlobalCoord(u[p].coord),_=void 0,S=void 0,x=void 0,b=void 0;n.isHorizontal()?(_=g,S=l.y,x=m-_,b=l.height,g=_+x):(_=l.x,S=g,x=l.width,b=m-S,g=S+b);var w=u[p-1].tickValue;w!=null&&h.set(w,c),t.add(new _t({anid:w!=null?"area_"+w:null,shape:{x:_,y:S,width:x,height:b},style:nt({fill:s[c]},y),autoBatch:!0,silent:!0})),c=(c+1)%f}vy(r).splitAreaColors=h}}}function Q2(r){vy(r).splitAreaColors=null}var FF=["splitArea","splitLine","minorSplitLine","breakArea"],tI=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.axisPointerClass="CartesianAxisPointer",e}return t.prototype.render=function(e,a,n,i){this.group.removeAll();var o=this._axisGroup;if(this._axisGroup=new rt,this.group.add(this._axisGroup),!!iu(e)){this._axisGroup.add(e.axis.axisBuilder.group),A(FF,function(l){e.get([l,"show"])&&HF[l](this,this._axisGroup,e,e.getCoordSysModel(),n)},this);var s=i&&i.type==="changeAxisOrder"&&i.isInitSort;s||Du(o,this._axisGroup,e),r.prototype.render.call(this,e,a,n,i)}},t.prototype.remove=function(){Q2(this)},t.type="cartesianAxis",t}(ro),HF={splitLine:function(r,t,e,a,n){var i=e.axis;if(!i.scale.isBlank()){var o=e.getModel("splitLine"),s=o.getModel("lineStyle"),l=s.get("color"),u=o.get("showMinLine")!==!1,f=o.get("showMaxLine")!==!1;l=W(l)?l:[l];for(var v=a.coordinateSystem.getRect(),h=i.isHorizontal(),c=0,p=i.getTicksCoords({tickModel:o,breakTicks:"none",pruneByBreak:"preserve_extent_bound"}),d=[],g=[],y=s.getLineStyle(),m=0;m<p.length;m++){var _=i.toGlobalCoord(p[m].coord);if(!(m===0&&!u||m===p.length-1&&!f)){var S=p[m].tickValue;h?(d[0]=_,d[1]=v.y,g[0]=_,g[1]=v.y+v.height):(d[0]=v.x,d[1]=_,g[0]=v.x+v.width,g[1]=_);var x=c++%l.length,b=new ne({anid:S!=null?"line_"+S:null,autoBatch:!0,shape:{x1:d[0],y1:d[1],x2:g[0],y2:g[1]},style:nt({stroke:l[x]},y),silent:!0});rs(b.shape,y.lineWidth),t.add(b)}}}},minorSplitLine:function(r,t,e,a,n){var i=e.axis,o=e.getModel("minorSplitLine"),s=o.getModel("lineStyle"),l=a.coordinateSystem.getRect(),u=i.isHorizontal(),f=i.getMinorTicksCoords();if(f.length)for(var v=[],h=[],c=s.getLineStyle(),p=0;p<f.length;p++)for(var d=0;d<f[p].length;d++){var g=i.toGlobalCoord(f[p][d].coord);u?(v[0]=g,v[1]=l.y,h[0]=g,h[1]=l.y+l.height):(v[0]=l.x,v[1]=g,h[0]=l.x+l.width,h[1]=g);var y=new ne({anid:"minor_line_"+f[p][d].tickValue,autoBatch:!0,shape:{x1:v[0],y1:v[1],x2:h[0],y2:h[1]},style:c,silent:!0});rs(y.shape,c.lineWidth),t.add(y)}},splitArea:function(r,t,e,a,n){J2(r,t,e,a)},breakArea:function(r,t,e,a,n){var i=Bu(),o=e.axis.scale;i&&o.type!=="ordinal"&&i.rectCoordBuildBreakAxis(t,r,e,a.coordinateSystem.getRect(),n)}},eI=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="xAxis",t}(tI),WF=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=eI.type,e}return t.type="yAxis",t}(tI),UF=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="grid",e}return t.prototype.render=function(e,a){this.group.removeAll(),e.get("show")&&this.group.add(new _t({shape:e.coordinateSystem.getRect(),style:nt({fill:e.get("backgroundColor")},e.getItemStyle()),silent:!0,z2:-1}))},t.type="grid",t}(Wt),ob={offset:0};function rI(r){r.registerComponentView(UF),r.registerComponentModel(J3),r.registerCoordinateSystem("cartesian2d",DF),ls(r,"x",ny,ob),ls(r,"y",ny,ob),r.registerComponentView(eI),r.registerComponentView(WF),r.registerPreprocessor(function(t){t.xAxis&&t.yAxis&&!t.grid&&(t.grid={})})}function YF(r,t){var e=r.coordinateSystem,a=e&&e.type,n=e&&e.getBaseAxis&&e.getBaseAxis(),i=n&&n.scale&&n.scale.type,o=a==="cartesian2d"&&i==="ordinal"||a==="single",s=t.model.get("jitter")>0;return o&&s}var ZF=St();function sb(r,t,e,a){if(r instanceof G2){var n=r.scale.type;if(n!=="category"&&n!=="ordinal")return e}var i=r.model,o=i.get("jitter"),s=i.get("jitterOverlap"),l=i.get("jitterMargin")||0,u=r.scale.type==="ordinal"?r.getBandWidth():null;return o>0?s?aI(e,o,u,a):XF(r,t,e,a,o,l):e}function aI(r,t,e,a){if(e===null)return r+(Math.random()-.5)*t;var n=e-a*2,i=Math.min(Math.max(0,t),n);return r+(Math.random()-.5)*i}function XF(r,t,e,a,n,i){var o=ZF(r);o.items||(o.items=[]);var s=o.items,l=lb(s,t,e,a,n,i,1),u=lb(s,t,e,a,n,i,-1),f=Math.abs(l-e)<Math.abs(u-e)?l:u,v=r.scale.type==="ordinal"?r.getBandWidth():null,h=Math.abs(f-e);return h>n/2||v&&h>v/2-a?aI(e,n,v,a):(s.push({fixedCoord:t,floatCoord:f,r:a}),f)}function lb(r,t,e,a,n,i,o){for(var s=e,l=0;l<r.length;l++){var u=r[l],f=t-u.fixedCoord,v=s-u.floatCoord,h=f*f+v*v,c=a+u.r+i;if(h<c*c){var p=u.floatCoord+Math.sqrt(c*c-f*f)*o;if(Math.abs(p-e)>n/2)return Number.MAX_VALUE;if(o===1&&p>s||o===-1&&p<s){s=p,l=-1;continue}}}return s}function $F(r){r.eachSeriesByType("scatter",function(t){var e=t.coordinateSystem;if(e&&(e.type==="cartesian2d"||e.type==="single")){var a=e.getBaseAxis?e.getBaseAxis():null,n=a&&YF(t,a);if(n){var i=t.getData();i.each(function(o){var s=a.dim,l=a.orient,u=l==="horizontal"&&a.type!=="category"||l==="vertical"&&a.type==="category",f=i.getItemLayout(o),v=i.getItemVisual(o,"symbolSize"),h=v instanceof Array?(v[1]+v[0])/2:v;if(s==="y"||s==="single"&&u){var c=sb(a,f[0],f[1],h/2);i.setItemLayout(o,[f[0],c])}else if(s==="x"||s==="single"&&!u){var c=sb(a,f[1],f[0],h/2);i.setItemLayout(o,[c,f[1]])}})}}})}function qF(r){mt(rI),r.registerSeriesModel(X3),r.registerChartView(j3),r.registerLayout(Nu("scatter"))}function KF(r){r.registerLayout(r.PRIORITY.VISUAL.POST_CHART_LAYOUT,$F)}function jF(r){r.eachSeriesByType("radar",function(t){var e=t.getData(),a=[],n=t.coordinateSystem;if(n){var i=n.getIndicatorAxes();A(i,function(o,s){e.each(e.mapDimension(i[s].dim),function(l,u){a[u]=a[u]||[];var f=n.dataToPoint(l,s);a[u][s]=ub(f)?f:fb(n)})}),e.each(function(o){var s=Nn(a[o],function(l){return ub(l)})||fb(n);a[o].push(s.slice()),e.setItemLayout(o,a[o])})}})}function ub(r){return!isNaN(r[0])&&!isNaN(r[1])}function fb(r){return[r.cx,r.cy]}function JF(r){var t=r.polar;if(t){W(t)||(t=[t]);var e=[];A(t,function(a,n){a.indicator?(a.type&&!a.shape&&(a.shape=a.type),r.radar=r.radar||[],W(r.radar)||(r.radar=[r.radar]),r.radar.push(a)):e.push(a)}),r.polar=e}A(r.series,function(a){a&&a.type==="radar"&&a.polarIndex&&(a.radarIndex=a.polarIndex)})}var QF=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n){var i=e.coordinateSystem,o=this.group,s=e.getData(),l=this._data;function u(h,c){var p=h.getItemVisual(c,"symbol")||"circle";if(p!=="none"){var d=Ms(h.getItemVisual(c,"symbolSize")),g=ie(p,-1,-1,2,2),y=h.getItemVisual(c,"symbolRotate")||0;return g.attr({style:{strokeNoScale:!0},z2:100,scaleX:d[0]/2,scaleY:d[1]/2,rotation:y*Math.PI/180||0}),g}}function f(h,c,p,d,g,y){p.removeAll();for(var m=0;m<c.length-1;m++){var _=u(d,g);_&&(_.__dimIdx=m,h[m]?(_.setPosition(h[m]),ji[y?"initProps":"updateProps"](_,{x:c[m][0],y:c[m][1]},e,g)):_.setPosition(c[m]),p.add(_))}}function v(h){return U(h,function(c){return[i.cx,i.cy]})}s.diff(l).add(function(h){var c=s.getItemLayout(h);if(c){var p=new Ee,d=new Ae,g={shape:{points:c}};p.shape.points=v(c),d.shape.points=v(c),Yt(p,g,e,h),Yt(d,g,e,h);var y=new rt,m=new rt;y.add(d),y.add(p),y.add(m),f(d.shape.points,c,m,s,h,!0),s.setItemGraphicEl(h,y)}}).update(function(h,c){var p=l.getItemGraphicEl(c),d=p.childAt(0),g=p.childAt(1),y=p.childAt(2),m={shape:{points:s.getItemLayout(h)}};m.shape.points&&(f(d.shape.points,m.shape.points,y,s,h,!1),Ir(g),Ir(d),Lt(d,m,e),Lt(g,m,e),s.setItemGraphicEl(h,p))}).remove(function(h){o.remove(l.getItemGraphicEl(h))}).execute(),s.eachItemGraphicEl(function(h,c){var p=s.getItemModel(c),d=h.childAt(0),g=h.childAt(1),y=h.childAt(2),m=s.getItemVisual(c,"style"),_=m.fill;o.add(h),d.useStyle(nt(p.getModel("lineStyle").getLineStyle(),{fill:"none",stroke:_})),he(d,p,"lineStyle"),he(g,p,"areaStyle");var S=p.getModel("areaStyle"),x=S.isEmpty()&&S.parentModel.isEmpty();g.ignore=x,A(["emphasis","select","blur"],function(w){var T=p.getModel([w,"areaStyle"]),C=T.isEmpty()&&T.parentModel.isEmpty();g.ensureState(w).ignore=C&&x;var M=p.getModel([w,"lineStyle"]).getLineStyle();d.ensureState(w).style=M;var D=T.getAreaStyle();g.ensureState(w).style=D;var I=p.getModel([w,"itemStyle"]).getItemStyle();y.eachChild(function(L){L.ensureState(w).style=et(I)})}),g.useStyle(nt(p.getModel("areaStyle").getAreaStyle(),{fill:_,opacity:.7,decal:m.decal}));var b=p.getModel("emphasis");y.eachChild(function(w){if(w instanceof xe){var T=w.style;w.useStyle(G({image:T.image,x:T.x,y:T.y,width:T.width,height:T.height},m))}else w.useStyle(m),w.setColor(_),w.style.strokeNoScale=!0;var C=s.getStore().get(s.getDimensionIndex(w.__dimIdx),c);(C==null||isNaN(C))&&(C=""),Se(w,ce(p),{labelFetcher:s.hostModel,labelDataIndex:c,labelDimIndex:w.__dimIdx,defaultText:C,inheritColor:_,defaultOpacity:m.opacity})}),$t(h,b.get("focus"),b.get("blurScope"),b.get("disabled"))}),this._data=s},t.prototype.remove=function(){this.group.removeAll(),this._data=null},t.type="radar",t}(Nt),tH=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.hasSymbolVisual=!0,e}return t.prototype.init=function(e){r.prototype.init.apply(this,arguments),this.legendVisualProvider=new ks($(this.getData,this),$(this.getRawData,this))},t.prototype.getInitialData=function(e,a){return Rs(this,{generateCoord:"indicator_",generateCoordCount:1/0})},t.prototype.formatTooltip=function(e,a,n){var i=this.getData(),o=this.coordinateSystem,s=o.getIndicatorAxes(),l=this.getData().getName(e),u=l===""?this.name:l,f=VD(this,e);return ue("section",{header:u,sortBlocks:!0,blocks:U(s,function(v){var h=i.get(i.mapDimension(v.dim),e);return ue("nameValue",{markerType:"subItem",markerColor:f,name:v.name,value:h,sortParam:h})})})},t.prototype.getTooltipPosition=function(e){if(e!=null){for(var a=this.getData(),n=this.coordinateSystem,i=a.getValues(U(n.dimensions,function(u){return a.mapDimension(u)}),e),o=0,s=i.length;o<s;o++)if(!isNaN(i[o])){var l=n.getIndicatorAxes();return n.coordToPoint(l[o].dataToCoord(i[o]),o)}}},t.type="series.radar",t.dependencies=["radar"],t.defaultOption={z:2,colorBy:"data",coordinateSystem:"radar",legendHoverLink:!0,radarIndex:0,lineStyle:{width:2,type:"solid",join:"round"},label:{position:"top"},symbolSize:8},t}(Bt),js=V2.value;function Pf(r,t){return nt({show:t},r)}var eH=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.optionUpdated=function(){var e=this.get("boundaryGap"),a=this.get("splitNumber"),n=this.get("scale"),i=this.get("axisLine"),o=this.get("axisTick"),s=this.get("axisLabel"),l=this.get("axisName"),u=this.get(["axisName","show"]),f=this.get(["axisName","formatter"]),v=this.get("axisNameGap"),h=this.get("triggerEvent"),c=U(this.get("indicator")||[],function(p){p.max!=null&&p.max>0&&!p.min?p.min=0:p.min!=null&&p.min<0&&!p.max&&(p.max=0);var d=l;p.color!=null&&(d=nt({color:p.color},l));var g=yt(et(p),{boundaryGap:e,splitNumber:a,scale:n,axisLine:i,axisTick:o,axisLabel:s,name:p.text,showName:u,nameLocation:"end",nameGap:v,nameTextStyle:d,triggerEvent:h},!1);if(X(f)){var y=g.name;g.name=f.replace("{value}",y??"")}else tt(f)&&(g.name=f(g.name,g));var m=new wt(g,null,this.ecModel);return Qt(m,Is.prototype),m.mainType="radar",m.componentIndex=this.componentIndex,m},this);this._indicatorModels=c},t.prototype.getIndicatorModels=function(){return this._indicatorModels},t.type="radar",t.defaultOption={z:0,center:["50%","50%"],radius:"50%",startAngle:90,axisName:{show:!0,color:N.color.axisLabel},boundaryGap:[0,0],splitNumber:5,axisNameGap:15,scale:!1,shape:"polygon",axisLine:yt({lineStyle:{color:N.color.neutral20}},js.axisLine),axisLabel:Pf(js.axisLabel,!1),axisTick:Pf(js.axisTick,!1),splitLine:Pf(js.splitLine,!0),splitArea:Pf(js.splitArea,!0),indicator:[]},t}(xt),rH=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n){var i=this.group;i.removeAll(),this._buildAxes(e,n),this._buildSplitLineAndArea(e)},t.prototype._buildAxes=function(e,a){var n=e.coordinateSystem,i=n.getIndicatorAxes(),o=U(i,function(s){var l=s.model.get("showName")?s.name:"",u=new Ye(s.model,a,{axisName:l,position:[n.cx,n.cy],rotation:s.angle,labelDirection:-1,tickDirection:-1,nameDirection:1});return u});A(o,function(s){s.build(),this.group.add(s.group)},this)},t.prototype._buildSplitLineAndArea=function(e){var a=e.coordinateSystem,n=a.getIndicatorAxes();if(!n.length)return;var i=e.get("shape"),o=e.getModel("splitLine"),s=e.getModel("splitArea"),l=o.getModel("lineStyle"),u=s.getModel("areaStyle"),f=o.get("show"),v=s.get("show"),h=l.get("color"),c=u.get("color"),p=W(h)?h:[h],d=W(c)?c:[c],g=[],y=[];function m(k,R,O){var E=O%R.length;return k[E]=k[E]||[],E}if(i==="circle")for(var _=n[0].getTicksCoords(),S=a.cx,x=a.cy,b=0;b<_.length;b++){if(f){var w=m(g,p,b);g[w].push(new wa({shape:{cx:S,cy:x,r:_[b].coord}}))}if(v&&b<_.length-1){var w=m(y,d,b);y[w].push(new ys({shape:{cx:S,cy:x,r0:_[b].coord,r:_[b+1].coord}}))}}else for(var T,C=U(n,function(k,R){var O=k.getTicksCoords();return T=T==null?O.length-1:Math.min(O.length-1,T),U(O,function(E){return a.coordToPoint(E.coord,R)})}),M=[],b=0;b<=T;b++){for(var D=[],I=0;I<n.length;I++)D.push(C[I][b]);if(D[0]&&D.push(D[0].slice()),f){var w=m(g,p,b);g[w].push(new Ae({shape:{points:D}}))}if(v&&M){var w=m(y,d,b-1);y[w].push(new Ee({shape:{points:D.concat(M)}}))}M=D.slice().reverse()}var L=l.getLineStyle(),P=u.getAreaStyle();A(y,function(k,R){this.group.add(or(k,{style:nt({stroke:"none",fill:d[R%d.length]},P),silent:!0}))},this),A(g,function(k,R){this.group.add(or(k,{style:nt({fill:"none",stroke:p[R%p.length]},L),silent:!0}))},this)},t.type="radar",t}(Wt),aH=function(r){z(t,r);function t(e,a,n){var i=r.call(this,e,a,n)||this;return i.type="value",i.angle=0,i.name="",i}return t}($r),nH=function(){function r(t,e,a){this.dimensions=[],this._model=t,this._indicatorAxes=U(t.getIndicatorModels(),function(n,i){var o="indicator_"+i,s=new aH(o,new ja);return s.name=n.get("name"),s.model=n,n.axis=s,this.dimensions.push(o),s},this),this.resize(t,a)}return r.prototype.getIndicatorAxes=function(){return this._indicatorAxes},r.prototype.dataToPoint=function(t,e){var a=this._indicatorAxes[e];return this.coordToPoint(a.dataToCoord(t),e)},r.prototype.coordToPoint=function(t,e){var a=this._indicatorAxes[e],n=a.angle,i=this.cx+t*Math.cos(n),o=this.cy-t*Math.sin(n);return[i,o]},r.prototype.pointToData=function(t){var e=t[0]-this.cx,a=t[1]-this.cy,n=Math.sqrt(e*e+a*a);e/=n,a/=n;for(var i=Math.atan2(-a,e),o=1/0,s,l=-1,u=0;u<this._indicatorAxes.length;u++){var f=this._indicatorAxes[u],v=Math.abs(i-f.angle);v<o&&(s=f,l=u,o=v)}return[l,+(s&&s.coordToData(n))]},r.prototype.resize=function(t,e){var a=pe(t,e).refContainer,n=t.get("center"),i=Math.min(a.width,a.height)/2;this.cx=Z(n[0],a.width)+a.x,this.cy=Z(n[1],a.height)+a.y,this.startAngle=t.get("startAngle")*Math.PI/180;var o=t.get("radius");(X(o)||Mt(o))&&(o=[0,o]),this.r0=Z(o[0],i),this.r=Z(o[1],i),A(this._indicatorAxes,function(s,l){s.setExtent(this.r0,this.r);var u=this.startAngle+l*Math.PI*2/this._indicatorAxes.length;u=Math.atan2(Math.sin(u),Math.cos(u)),s.angle=u},this)},r.prototype.update=function(t,e){var a=this._indicatorAxes,n=this._model;A(a,function(s){s.scale.setExtent(1/0,-1/0)}),t.eachSeriesByType("radar",function(s,l){if(!(s.get("coordinateSystem")!=="radar"||t.getComponent("radar",s.get("radarIndex"))!==n)){var u=s.getData();A(a,function(f){f.scale.unionExtentFromData(u,u.mapDimension(f.dim))})}},this);var i=n.get("splitNumber"),o=new ja;o.setExtent(0,i),o.setInterval(1),A(a,function(s,l){K2(s.scale,s.model,o)})},r.prototype.convertToPixel=function(t,e,a){return console.warn("Not implemented."),null},r.prototype.convertFromPixel=function(t,e,a){return console.warn("Not implemented."),null},r.prototype.containPoint=function(t){return console.warn("Not implemented."),!1},r.create=function(t,e){var a=[];return t.eachComponent("radar",function(n){var i=new r(n,t,e);a.push(i),n.coordinateSystem=i}),t.eachSeriesByType("radar",function(n){n.get("coordinateSystem")==="radar"&&(n.coordinateSystem=a[n.get("radarIndex")||0])}),a},r.dimensions=[],r}();function iH(r){r.registerCoordinateSystem("radar",nH),r.registerComponentModel(eH),r.registerComponentView(rH),r.registerVisual({seriesType:"radar",reset:function(t){var e=t.getData();e.each(function(a){e.setItemVisual(a,"legendIcon","roundRect")}),e.setVisual("legendIcon","roundRect")}})}function oH(r){mt(iH),r.registerChartView(QF),r.registerSeriesModel(tH),r.registerLayout(jF),r.registerProcessor(Ps("radar")),r.registerPreprocessor(JF)}var D0=St();function sH(r,t,e){D0(r)[t]=e}function lH(r,t,e){var a=D0(r),n=a[t];n===e&&(a[t]=null)}function vb(r,t){return!!D0(r)[t]}Ta({type:"takeGlobalCursor",event:"globalCursorTaken",update:"update"},jt);var uH={axisPointer:1,tooltip:1,brush:1};function nI(r,t,e){var a=t.getComponentByElement(r.topTarget);if(!a||a===e||uH.hasOwnProperty(a.mainType))return!1;var n=a.coordinateSystem;if(!n||n.model===e)return!1;var i=Ui(a),o=Ui(e);return!((i.zlevel-o.zlevel||i.z-o.z)<=0)}var ao=function(r){z(t,r);function t(e){var a=r.call(this)||this;a._zr=e;var n=$(a._mousedownHandler,a),i=$(a._mousemoveHandler,a),o=$(a._mouseupHandler,a),s=$(a._mousewheelHandler,a),l=$(a._pinchHandler,a);return a.enable=function(u,f){var v=f.zInfo,h=Ui(v.component),c=h.z,p=h.zlevel,d={component:v.component,z:c,zlevel:p,z2:Q(v.z2,-1/0)},g=G({},f.triggerInfo);this._opt=nt(G({},f),{zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!1,preventDefaultMouseMove:!0,zInfoParsed:d,triggerInfo:g}),u==null&&(u=!0),(!this._enabled||this._controlType!==u)&&(this._enabled=!0,this.disable(),(u===!0||u==="move"||u==="pan")&&(Qs(e,"mousedown",n,d),Qs(e,"mousemove",i,d),Qs(e,"mouseup",o,d)),(u===!0||u==="scale"||u==="zoom")&&(Qs(e,"mousewheel",s,d),Qs(e,"pinch",l,d)))},a.disable=function(){this._enabled=!1,tl(e,"mousedown",n),tl(e,"mousemove",i),tl(e,"mouseup",o),tl(e,"mousewheel",s),tl(e,"pinch",l)},a}return t.prototype.isDragging=function(){return this._dragging},t.prototype.isPinching=function(){return this._pinching},t.prototype._checkPointer=function(e,a,n){var i=this._opt,o=i.zInfoParsed;if(nI(e,i.api,o.component))return!1;var s=i.triggerInfo,l=s.roamTrigger,u=!1;return l==="global"&&(u=!0),u||(u=s.isInSelf(e,a,n)),u&&s.isInClip&&!s.isInClip(e,a,n)&&(u=!1),u},t.prototype._decideCursorStyle=function(e,a,n,i){var o=e.target;if(!o&&this._checkPointer(e,a,n))return"grab";if(i)return o&&o.cursor||"default"},t.prototype.dispose=function(){this.disable()},t.prototype._mousedownHandler=function(e){if(!(P_(e)||Js(e))){for(var a=e.target;a;){if(a.draggable)return;a=a.__hostTarget||a.parent}var n=e.offsetX,i=e.offsetY;this._checkPointer(e,n,i)&&(this._x=n,this._y=i,this._dragging=!0)}},t.prototype._mousemoveHandler=function(e){var a=this._zr;if(!(e.gestureEvent==="pinch"||vb(a,"globalPan")||Js(e))){var n=e.offsetX,i=e.offsetY;if(!this._dragging||!dv("moveOnMouseMove",e,this._opt)){var o=this._decideCursorStyle(e,n,i,!1);o&&a.setCursorStyle(o);return}a.setCursorStyle("grabbing");var s=this._x,l=this._y,u=n-s,f=i-l;this._x=n,this._y=i,this._opt.preventDefaultMouseMove&&Za(e.event),e.__ecRoamConsumed=!0,hb(this,"pan","moveOnMouseMove",e,{dx:u,dy:f,oldX:s,oldY:l,newX:n,newY:i,isAvailableBehavior:null})}},t.prototype._mouseupHandler=function(e){if(!Js(e)){var a=this._zr;if(!P_(e)){this._dragging=!1;var n=this._decideCursorStyle(e,e.offsetX,e.offsetY,!0);n&&a.setCursorStyle(n)}}},t.prototype._mousewheelHandler=function(e){if(!Js(e)){var a=dv("zoomOnMouseWheel",e,this._opt),n=dv("moveOnMouseWheel",e,this._opt),i=e.wheelDelta,o=Math.abs(i),s=e.offsetX,l=e.offsetY;if(!(i===0||!a&&!n)){if(a){var u=o>3?1.4:o>1?1.2:1.1,f=i>0?u:1/u;this._checkTriggerMoveZoom(this,"zoom","zoomOnMouseWheel",e,{scale:f,originX:s,originY:l,isAvailableBehavior:null})}if(n){var v=Math.abs(i),h=(i>0?1:-1)*(v>3?.4:v>1?.15:.05);this._checkTriggerMoveZoom(this,"scrollMove","moveOnMouseWheel",e,{scrollDelta:h,originX:s,originY:l,isAvailableBehavior:null})}}}},t.prototype._pinchHandler=function(e){if(!(vb(this._zr,"globalPan")||Js(e))){var a=e.pinchScale>1?1.1:1/1.1;this._checkTriggerMoveZoom(this,"zoom",null,e,{scale:a,originX:e.pinchX,originY:e.pinchY,isAvailableBehavior:null})}},t.prototype._checkTriggerMoveZoom=function(e,a,n,i,o){e._checkPointer(i,o.originX,o.originY)&&(Za(i.event),i.__ecRoamConsumed=!0,hb(e,a,n,i,o))},t}(Pr);function Js(r){return r.__ecRoamConsumed}var fH=St();function oc(r){var t=fH(r);return t.roam=t.roam||{},t.uniform=t.uniform||{},t}function Qs(r,t,e,a){for(var n=oc(r),i=n.roam,o=i[t]=i[t]||[],s=0;s<o.length;s++){var l=o[s].zInfoParsed;if((l.zlevel-a.zlevel||l.z-a.z||l.z2-a.z2)<=0)break}o.splice(s,0,{listener:e,zInfoParsed:a}),vH(r,t)}function tl(r,t,e){for(var a=oc(r),n=a.roam[t]||[],i=0;i<n.length;i++)if(n[i].listener===e){n.splice(i,1),n.length||hH(r,t);return}}function vH(r,t){var e=oc(r);e.uniform[t]||r.on(t,e.uniform[t]=function(a){var n=e.roam[t];if(n)for(var i=0;i<n.length;i++)n[i].listener(a)})}function hH(r,t){var e=oc(r),a=e.uniform;a[t]&&(r.off(t,a[t]),a[t]=null)}function hb(r,t,e,a,n){n.isAvailableBehavior=$(dv,null,e,a),r.trigger(t,n)}function dv(r,t,e){var a=e[r];return!r||a&&(!X(a)||t.event[a+"Key"])}function L0(r,t,e){var a=r.target;a.x+=t,a.y+=e,a.dirty()}function I0(r,t,e,a){var n=r.target,i=r.zoomLimit,o=r.zoom=r.zoom||1;o*=t,o=P0(o,i);var s=o/r.zoom;r.zoom=o,oI(n,e,a,s),n.dirty()}function iI(r,t,e,a,n,i){var o=new lt(0,0,0,0);a.enable(r.get("roam"),{api:t,zInfo:{component:r},triggerInfo:{roamTrigger:r.get("roamTrigger"),isInSelf:function(u,f,v){return o.copy(e.getBoundingRect()),o.applyTransform(e.getComputedTransform()),o.contain(f,v)},isInClip:function(u,f,v){return!i||i.contain(f,v)}}}),n.zoomLimit=r.get("scaleLimit");var s=r.coordinateSystem;n.zoom=s?s.getZoom():1;var l=r.subType+"Roam";a.off("pan").off("zoom").on("pan",function(u){L0(n,u.dx,u.dy),t.dispatchAction({seriesId:r.id,type:l,dx:u.dx,dy:u.dy})}).on("zoom",function(u){I0(n,u.scale,u.originX,u.originY),t.dispatchAction({seriesId:r.id,type:l,zoom:u.scale,originX:u.originX,originY:u.originY}),t.updateLabelLayout()})}function cb(r,t){return r.pointToProjected?r.pointToProjected(t):r.pointToData(t)}function sc(r,t,e){var a=r.getZoom(),n=r.getCenter(),i=t.zoom,o=r.projectedToPoint?r.projectedToPoint(n):r.dataToPoint(n);return t.dx!=null&&t.dy!=null&&(o[0]-=t.dx,o[1]-=t.dy,r.setCenter(cb(r,o))),i!=null&&(i=P0(a*i,e)/a,oI(r,t.originX,t.originY,i),r.updateTransform(),r.setCenter(cb(r,o)),r.setZoom(i*a)),{center:r.getCenter(),zoom:r.getZoom()}}function oI(r,t,e,a){r.x-=(t-r.x)*(a-1),r.y-=(e-r.y)*(a-1),r.scaleX*=a,r.scaleY*=a}function P0(r,t){if(t){var e=t.min||0,a=t.max||1/0;r=Math.max(Math.min(a,r),e)}return r}function sI(r){if(X(r)){var t=new DOMParser;r=t.parseFromString(r,"text/xml")}var e=r;for(e.nodeType===9&&(e=e.firstChild);e.nodeName.toLowerCase()!=="svg"||e.nodeType!==1;)e=e.nextSibling;return e}var Np,fh={fill:"fill",stroke:"stroke","stroke-width":"lineWidth",opacity:"opacity","fill-opacity":"fillOpacity","stroke-opacity":"strokeOpacity","stroke-dasharray":"lineDash","stroke-dashoffset":"lineDashOffset","stroke-linecap":"lineCap","stroke-linejoin":"lineJoin","stroke-miterlimit":"miterLimit","font-family":"fontFamily","font-size":"fontSize","font-style":"fontStyle","font-weight":"fontWeight","text-anchor":"textAlign",visibility:"visibility",display:"display"},pb=Ct(fh),vh={"alignment-baseline":"textBaseline","stop-color":"stopColor"},db=Ct(vh),cH=function(){function r(){this._defs={},this._root=null}return r.prototype.parse=function(t,e){e=e||{};var a=sI(t);this._defsUsePending=[];var n=new rt;this._root=n;var i=[],o=a.getAttribute("viewBox")||"",s=parseFloat(a.getAttribute("width")||e.width),l=parseFloat(a.getAttribute("height")||e.height);isNaN(s)&&(s=null),isNaN(l)&&(l=null),rr(a,n,null,!0,!1);for(var u=a.firstChild;u;)this._parseNode(u,n,i,null,!1,!1),u=u.nextSibling;gH(this._defs,this._defsUsePending),this._defsUsePending=[];var f,v;if(o){var h=lc(o);h.length>=4&&(f={x:parseFloat(h[0]||0),y:parseFloat(h[1]||0),width:parseFloat(h[2]),height:parseFloat(h[3])})}if(f&&s!=null&&l!=null&&(v=uI(f,{x:0,y:0,width:s,height:l}),!e.ignoreViewBox)){var c=n;n=new rt,n.add(c),c.scaleX=c.scaleY=v.scale,c.x=v.x,c.y=v.y}return!e.ignoreRootClip&&s!=null&&l!=null&&n.setClipPath(new _t({shape:{x:0,y:0,width:s,height:l}})),{root:n,width:s,height:l,viewBoxRect:f,viewBoxTransform:v,named:i}},r.prototype._parseNode=function(t,e,a,n,i,o){var s=t.nodeName.toLowerCase(),l,u=n;if(s==="defs"&&(i=!0),s==="text"&&(o=!0),s==="defs"||s==="switch")l=e;else{if(!i){var f=Np[s];if(f&&q(Np,s)){l=f.call(this,t,e);var v=t.getAttribute("name");if(v){var h={name:v,namedFrom:null,svgNodeTagLower:s,el:l};a.push(h),s==="g"&&(u=h)}else n&&a.push({name:n.name,namedFrom:n,svgNodeTagLower:s,el:l});e.add(l)}}var c=gb[s];if(c&&q(gb,s)){var p=c.call(this,t),d=t.getAttribute("id");d&&(this._defs[d]=p)}}if(l&&l.isGroup)for(var g=t.firstChild;g;)g.nodeType===1?this._parseNode(g,l,a,u,i,o):g.nodeType===3&&o&&this._parseText(g,l),g=g.nextSibling},r.prototype._parseText=function(t,e){var a=new ts({style:{text:t.textContent},silent:!0,x:this._textX||0,y:this._textY||0});dr(e,a),rr(t,a,this._defsUsePending,!1,!1),pH(a,e);var n=a.style,i=n.fontSize;i&&i<9&&(n.fontSize=9,a.scaleX*=i/9,a.scaleY*=i/9);var o=(n.fontSize||n.fontFamily)&&[n.fontStyle,n.fontWeight,(n.fontSize||12)+"px",n.fontFamily||"sans-serif"].join(" ");n.font=o;var s=a.getBoundingRect();return this._textX+=s.width,e.add(a),a},r.internalField=function(){Np={g:function(t,e){var a=new rt;return dr(e,a),rr(t,a,this._defsUsePending,!1,!1),a},rect:function(t,e){var a=new _t;return dr(e,a),rr(t,a,this._defsUsePending,!1,!1),a.setShape({x:parseFloat(t.getAttribute("x")||"0"),y:parseFloat(t.getAttribute("y")||"0"),width:parseFloat(t.getAttribute("width")||"0"),height:parseFloat(t.getAttribute("height")||"0")}),a.silent=!0,a},circle:function(t,e){var a=new wa;return dr(e,a),rr(t,a,this._defsUsePending,!1,!1),a.setShape({cx:parseFloat(t.getAttribute("cx")||"0"),cy:parseFloat(t.getAttribute("cy")||"0"),r:parseFloat(t.getAttribute("r")||"0")}),a.silent=!0,a},line:function(t,e){var a=new ne;return dr(e,a),rr(t,a,this._defsUsePending,!1,!1),a.setShape({x1:parseFloat(t.getAttribute("x1")||"0"),y1:parseFloat(t.getAttribute("y1")||"0"),x2:parseFloat(t.getAttribute("x2")||"0"),y2:parseFloat(t.getAttribute("y2")||"0")}),a.silent=!0,a},ellipse:function(t,e){var a=new Cu;return dr(e,a),rr(t,a,this._defsUsePending,!1,!1),a.setShape({cx:parseFloat(t.getAttribute("cx")||"0"),cy:parseFloat(t.getAttribute("cy")||"0"),rx:parseFloat(t.getAttribute("rx")||"0"),ry:parseFloat(t.getAttribute("ry")||"0")}),a.silent=!0,a},polygon:function(t,e){var a=t.getAttribute("points"),n;a&&(n=_b(a));var i=new Ee({shape:{points:n||[]},silent:!0});return dr(e,i),rr(t,i,this._defsUsePending,!1,!1),i},polyline:function(t,e){var a=t.getAttribute("points"),n;a&&(n=_b(a));var i=new Ae({shape:{points:n||[]},silent:!0});return dr(e,i),rr(t,i,this._defsUsePending,!1,!1),i},image:function(t,e){var a=new xe;return dr(e,a),rr(t,a,this._defsUsePending,!1,!1),a.setStyle({image:t.getAttribute("xlink:href")||t.getAttribute("href"),x:+t.getAttribute("x"),y:+t.getAttribute("y"),width:+t.getAttribute("width"),height:+t.getAttribute("height")}),a.silent=!0,a},text:function(t,e){var a=t.getAttribute("x")||"0",n=t.getAttribute("y")||"0",i=t.getAttribute("dx")||"0",o=t.getAttribute("dy")||"0";this._textX=parseFloat(a)+parseFloat(i),this._textY=parseFloat(n)+parseFloat(o);var s=new rt;return dr(e,s),rr(t,s,this._defsUsePending,!1,!0),s},tspan:function(t,e){var a=t.getAttribute("x"),n=t.getAttribute("y");a!=null&&(this._textX=parseFloat(a)),n!=null&&(this._textY=parseFloat(n));var i=t.getAttribute("dx")||"0",o=t.getAttribute("dy")||"0",s=new rt;return dr(e,s),rr(t,s,this._defsUsePending,!1,!0),this._textX+=parseFloat(i),this._textY+=parseFloat(o),s},path:function(t,e){var a=t.getAttribute("d")||"",n=AM(a);return dr(e,n),rr(t,n,this._defsUsePending,!1,!1),n.silent=!0,n}}}(),r}(),gb={lineargradient:function(r){var t=parseInt(r.getAttribute("x1")||"0",10),e=parseInt(r.getAttribute("y1")||"0",10),a=parseInt(r.getAttribute("x2")||"10",10),n=parseInt(r.getAttribute("y2")||"0",10),i=new Ki(t,e,a,n);return yb(r,i),mb(r,i),i},radialgradient:function(r){var t=parseInt(r.getAttribute("cx")||"0",10),e=parseInt(r.getAttribute("cy")||"0",10),a=parseInt(r.getAttribute("r")||"0",10),n=new Cm(t,e,a);return yb(r,n),mb(r,n),n}};function yb(r,t){var e=r.getAttribute("gradientUnits");e==="userSpaceOnUse"&&(t.global=!0)}function mb(r,t){for(var e=r.firstChild;e;){if(e.nodeType===1&&e.nodeName.toLocaleLowerCase()==="stop"){var a=e.getAttribute("offset"),n=void 0;a&&a.indexOf("%")>0?n=parseInt(a,10)/100:a?n=parseFloat(a):n=0;var i={};lI(e,i,i);var o=i.stopColor||e.getAttribute("stop-color")||"#000000",s=i.stopOpacity||e.getAttribute("stop-opacity");if(s){var l=Ve(o),u=l&&l[3];u&&(l[3]*=Va(s),o=Cr(l,"rgba"))}t.colorStops.push({offset:n,color:o})}e=e.nextSibling}}function dr(r,t){r&&r.__inheritedStyle&&(t.__inheritedStyle||(t.__inheritedStyle={}),nt(t.__inheritedStyle,r.__inheritedStyle))}function _b(r){for(var t=lc(r),e=[],a=0;a<t.length;a+=2){var n=parseFloat(t[a]),i=parseFloat(t[a+1]);e.push([n,i])}return e}function rr(r,t,e,a,n){var i=t,o=i.__inheritedStyle=i.__inheritedStyle||{},s={};r.nodeType===1&&(_H(r,t),lI(r,o,s),a||SH(r,o,s)),i.style=i.style||{},o.fill!=null&&(i.style.fill=Sb(i,"fill",o.fill,e)),o.stroke!=null&&(i.style.stroke=Sb(i,"stroke",o.stroke,e)),A(["lineWidth","opacity","fillOpacity","strokeOpacity","miterLimit","fontSize"],function(l){o[l]!=null&&(i.style[l]=parseFloat(o[l]))}),A(["lineDashOffset","lineCap","lineJoin","fontWeight","fontFamily","fontStyle","textAlign"],function(l){o[l]!=null&&(i.style[l]=o[l])}),n&&(i.__selfStyle=s),o.lineDash&&(i.style.lineDash=U(lc(o.lineDash),function(l){return parseFloat(l)})),(o.visibility==="hidden"||o.visibility==="collapse")&&(i.invisible=!0),o.display==="none"&&(i.ignore=!0)}function pH(r,t){var e=t.__selfStyle;if(e){var a=e.textBaseline,n=a;!a||a==="auto"||a==="baseline"?n="alphabetic":a==="before-edge"||a==="text-before-edge"?n="top":a==="after-edge"||a==="text-after-edge"?n="bottom":(a==="central"||a==="mathematical")&&(n="middle"),r.style.textBaseline=n}var i=t.__inheritedStyle;if(i){var o=i.textAlign,s=o;o&&(o==="middle"&&(s="center"),r.style.textAlign=s)}}var dH=/^url\(\s*#(.*?)\)/;function Sb(r,t,e,a){var n=e&&e.match(dH);if(n){var i=sr(n[1]);a.push([r,t,i]);return}return e==="none"&&(e=null),e}function gH(r,t){for(var e=0;e<t.length;e++){var a=t[e];a[0].style[a[1]]=r[a[2]]}}var yH=/-?([0-9]*\.)?[0-9]+([eE]-?[0-9]+)?/g;function lc(r){return r.match(yH)||[]}var mH=/(translate|scale|rotate|skewX|skewY|matrix)\(([\-\s0-9\.eE,]*)\)/g,Bp=Math.PI/180;function _H(r,t){var e=r.getAttribute("transform");if(e){e=e.replace(/,/g," ");var a=[],n=null;e.replace(mH,function(v,h,c){return a.push(h,c),""});for(var i=a.length-1;i>0;i-=2){var o=a[i],s=a[i-1],l=lc(o);switch(n=n||me(),s){case"translate":Ur(n,n,[parseFloat(l[0]),parseFloat(l[1]||"0")]);break;case"scale":Nh(n,n,[parseFloat(l[0]),parseFloat(l[1]||l[0])]);break;case"rotate":Qa(n,n,-parseFloat(l[0])*Bp,[parseFloat(l[1]||"0"),parseFloat(l[2]||"0")]);break;case"skewX":var u=Math.tan(parseFloat(l[0])*Bp);Gr(n,[1,0,u,1,0,0],n);break;case"skewY":var f=Math.tan(parseFloat(l[0])*Bp);Gr(n,[1,f,0,1,0,0],n);break;case"matrix":n[0]=parseFloat(l[0]),n[1]=parseFloat(l[1]),n[2]=parseFloat(l[2]),n[3]=parseFloat(l[3]),n[4]=parseFloat(l[4]),n[5]=parseFloat(l[5]);break}}t.setLocalTransform(n)}}var xb=/([^\s:;]+)\s*:\s*([^:;]+)/g;function lI(r,t,e){var a=r.getAttribute("style");if(a){xb.lastIndex=0;for(var n;(n=xb.exec(a))!=null;){var i=n[1],o=q(fh,i)?fh[i]:null;o&&(t[o]=n[2]);var s=q(vh,i)?vh[i]:null;s&&(e[s]=n[2])}}}function SH(r,t,e){for(var a=0;a<pb.length;a++){var n=pb[a],i=r.getAttribute(n);i!=null&&(t[fh[n]]=i)}for(var a=0;a<db.length;a++){var n=db[a],i=r.getAttribute(n);i!=null&&(e[vh[n]]=i)}}function uI(r,t){var e=t.width/r.width,a=t.height/r.height,n=Math.min(e,a);return{scale:n,x:-(r.x+r.width/2)*n+(t.x+t.width/2),y:-(r.y+r.height/2)*n+(t.y+t.height/2)}}function xH(r,t){var e=new cH;return e.parse(r,t)}var bH=j(["rect","circle","line","ellipse","polygon","polyline","path","text","tspan","g"]),wH=function(){function r(t,e){this.type="geoSVG",this._usedGraphicMap=j(),this._freedGraphics=[],this._mapName=t,this._parsedXML=sI(e)}return r.prototype.load=function(){var t=this._firstGraphic;if(!t){t=this._firstGraphic=this._buildGraphic(this._parsedXML),this._freedGraphics.push(t),this._boundingRect=this._firstGraphic.boundingRect.clone();var e=CH(t.named),a=e.regions,n=e.regionsMap;this._regions=a,this._regionsMap=n}return{boundingRect:this._boundingRect,regions:this._regions,regionsMap:this._regionsMap}},r.prototype._buildGraphic=function(t){var e,a;try{e=t&&xH(t,{ignoreViewBox:!0,ignoreRootClip:!0})||{},a=e.root,Re(a!=null)}catch(g){throw new Error(`Invalid svg format
`+g.message)}var n=new rt;n.add(a),n.isGeoSVGGraphicRoot=!0;var i=e.width,o=e.height,s=e.viewBoxRect,l=this._boundingRect;if(!l){var u=void 0,f=void 0,v=void 0,h=void 0;if(i!=null?(u=0,v=i):s&&(u=s.x,v=s.width),o!=null?(f=0,h=o):s&&(f=s.y,h=s.height),u==null||f==null){var c=a.getBoundingRect();u==null&&(u=c.x,v=c.width),f==null&&(f=c.y,h=c.height)}l=this._boundingRect=new lt(u,f,v,h)}if(s){var p=uI(s,l);a.scaleX=a.scaleY=p.scale,a.x=p.x,a.y=p.y}n.setClipPath(new _t({shape:l.plain()}));var d=[];return A(e.named,function(g){bH.get(g.svgNodeTagLower)!=null&&(d.push(g),TH(g.el))}),{root:n,boundingRect:l,named:d}},r.prototype.useGraphic=function(t){var e=this._usedGraphicMap,a=e.get(t);return a||(a=this._freedGraphics.pop()||this._buildGraphic(this._parsedXML),e.set(t,a),a)},r.prototype.freeGraphic=function(t){var e=this._usedGraphicMap,a=e.get(t);a&&(e.removeKey(t),this._freedGraphics.push(a))},r}();function TH(r){r.silent=!1,r.isGroup&&r.traverse(function(t){t.silent=!1})}function CH(r){var t=[],e=j();return A(r,function(a){if(a.namedFrom==null){var n=new G5(a.name,a.el);t.push(n),e.set(a.name,n)}}),{regions:t,regionsMap:e}}var hy=[126,25],bb="南海诸岛",di=[[[0,3.5],[7,11.2],[15,11.9],[30,7],[42,.7],[52,.7],[56,7.7],[59,.7],[64,.7],[64,0],[5,0],[0,3.5]],[[13,16.1],[19,14.7],[16,21.7],[11,23.1],[13,16.1]],[[12,32.2],[14,38.5],[15,38.5],[13,32.2],[12,32.2]],[[16,47.6],[12,53.2],[13,53.2],[18,47.6],[16,47.6]],[[6,64.4],[8,70],[9,70],[8,64.4],[6,64.4]],[[23,82.6],[29,79.8],[30,79.8],[25,82.6],[23,82.6]],[[37,70.7],[43,62.3],[44,62.3],[39,70.7],[37,70.7]],[[48,51.1],[51,45.5],[53,45.5],[50,51.1],[48,51.1]],[[51,35],[51,28.7],[53,28.7],[53,35],[51,35]],[[52,22.4],[55,17.5],[56,17.5],[53,22.4],[52,22.4]],[[58,12.6],[62,7],[63,7],[60,12.6],[58,12.6]],[[0,3.5],[0,93.1],[64,93.1],[64,0],[63,0],[63,92.4],[1,92.4],[1,3.5],[0,3.5]]];for(var ci=0;ci<di.length;ci++)for(var bo=0;bo<di[ci].length;bo++)di[ci][bo][0]/=10.5,di[ci][bo][1]/=-10.5/.75,di[ci][bo][0]+=hy[0],di[ci][bo][1]+=hy[1];function AH(r,t){if(r==="china"){for(var e=0;e<t.length;e++)if(t[e].name===bb)return;t.push(new YL(bb,U(di,function(a){return{type:"polygon",exterior:a}}),hy))}}var MH={南海诸岛:[32,80],广东:[0,-10],香港:[10,5],澳门:[-10,10],天津:[5,5]};function DH(r,t){if(r==="china"){var e=MH[t.name];if(e){var a=t.getCenter();a[0]+=e[0]/10.5,a[1]+=-e[1]/(10.5/.75),t.setCenter(a)}}}var LH=[[[123.45165252685547,25.73527164402261],[123.49731445312499,25.73527164402261],[123.49731445312499,25.750734064600884],[123.45165252685547,25.750734064600884],[123.45165252685547,25.73527164402261]]];function IH(r,t){r==="china"&&t.name==="台湾"&&t.geometries.push({type:"polygon",exterior:LH[0]})}var PH="name",RH=function(){function r(t,e,a){this.type="geoJSON",this._parsedMap=j(),this._mapName=t,this._specialAreas=a,this._geoJSON=EH(e)}return r.prototype.load=function(t,e){e=e||PH;var a=this._parsedMap.get(e);if(!a){var n=this._parseToRegions(e);a=this._parsedMap.set(e,{regions:n,boundingRect:kH(n)})}var i=j(),o=[];return A(a.regions,function(s){var l=s.name;t&&q(t,l)&&(s=s.cloneShallow(l=t[l])),o.push(s),i.set(l,s)}),{regions:o,boundingRect:a.boundingRect||new lt(0,0,0,0),regionsMap:i}},r.prototype._parseToRegions=function(t){var e=this._mapName,a=this._geoJSON,n;try{n=a?H5(a,t):[]}catch(i){throw new Error(`Invalid geoJson format
`+i.message)}return AH(e,n),A(n,function(i){var o=i.name;DH(e,i),IH(e,i);var s=this._specialAreas&&this._specialAreas[o];s&&i.transformTo(s.left,s.top,s.width,s.height)},this),n},r.prototype.getMapForUser=function(){return{geoJson:this._geoJSON,geoJSON:this._geoJSON,specialAreas:this._specialAreas}},r}();function kH(r){for(var t,e=0;e<r.length;e++){var a=r[e].getBoundingRect();t=t||a.clone(),t.union(a)}return t}function EH(r){return X(r)?typeof JSON<"u"&&JSON.parse?JSON.parse(r):new Function("return ("+r+");")():r}var el=j();const Ja={registerMap:function(r,t,e){if(t.svg){var a=new wH(r,t.svg);el.set(r,a)}else{var n=t.geoJson||t.geoJSON;n&&!t.features?e=t.specialAreas:n=t;var a=new RH(r,n,e);el.set(r,a)}},getGeoResource:function(r){return el.get(r)},getMapForUser:function(r){var t=el.get(r);return t&&t.type==="geoJSON"&&t.getMapForUser()},load:function(r,t,e){var a=el.get(r);if(a)return a.load(t,e)}};var R0=["rect","circle","line","ellipse","polygon","polyline","path"],OH=j(R0),NH=j(R0.concat(["g"])),BH=j(R0.concat(["g"])),fI=St();function Rf(r){var t=r.getItemStyle(),e=r.get("areaColor");return e!=null&&(t.fill=e),t}function wb(r){var t=r.style;t&&(t.stroke=t.stroke||t.fill,t.fill=null)}var vI=function(){function r(t){var e=this.group=new rt,a=this._transformGroup=new rt;e.add(a),this.uid=bs("ec_map_draw"),this._controller=new ao(t.getZr()),this._controllerHost={target:a},a.add(this._regionsGroup=new rt),a.add(this._svgGroup=new rt)}return r.prototype.draw=function(t,e,a,n,i){var o=t.mainType==="geo",s=t.getData&&t.getData();o&&e.eachComponent({mainType:"series",subType:"map"},function(_){!s&&_.getHostGeoModel()===t&&(s=_.getData())});var l=t.coordinateSystem,u=this._regionsGroup,f=this._transformGroup,v=l.getTransformInfo(),h=v.raw,c=v.roam,p=!u.childAt(0)||i,d=t.getShallow("clip",!0),g;d?(g=l.getViewRect().clone(),this.group.setClipPath(new _t({shape:g.clone()}))):this.group.removeClipPath(),p?(f.x=c.x,f.y=c.y,f.scaleX=c.scaleX,f.scaleY=c.scaleY,f.dirty()):Lt(f,c,t);var y=s&&s.getVisual("visualMeta")&&s.getVisual("visualMeta").length>0,m={api:a,geo:l,mapOrGeoModel:t,data:s,isVisualEncodedByVisualMap:y,isGeo:o,transformInfoRaw:h};l.resourceType==="geoJSON"?this._buildGeoJSON(m):l.resourceType==="geoSVG"&&this._buildSVG(m),this._updateController(t,g,e,a),this._updateMapSelectHandler(t,u,a,n)},r.prototype._buildGeoJSON=function(t){var e=this._regionsGroupByName=j(),a=j(),n=this._regionsGroup,i=t.transformInfoRaw,o=t.mapOrGeoModel,s=t.data,l=t.geo.projection,u=l&&l.stream;function f(c,p){return p&&(c=p(c)),c&&[c[0]*i.scaleX+i.x,c[1]*i.scaleY+i.y]}function v(c){for(var p=[],d=!u&&l&&l.project,g=0;g<c.length;++g){var y=f(c[g],d);y&&p.push(y)}return p}function h(c){return{shape:{points:v(c)}}}n.removeAll(),A(t.geo.regions,function(c){var p=c.name,d=e.get(p),g=a.get(p)||{},y=g.dataIdx,m=g.regionModel;if(!d){d=e.set(p,new rt),n.add(d),y=s?s.indexOfName(p):null,m=t.isGeo?o.getRegionModel(p):s?s.getItemModel(y):null;var _=m.get("silent",!0);_!=null&&(d.silent=_),a.set(p,{dataIdx:y,regionModel:m})}var S=[],x=[];A(c.geometries,function(T){if(T.type==="polygon"){var C=[T.exterior].concat(T.interiors||[]);u&&(C=Lb(C,u)),A(C,function(D){S.push(new Ee(h(D)))})}else{var M=T.points;u&&(M=Lb(M,u,!0)),A(M,function(D){x.push(new Ae(h(D)))})}});var b=f(c.getCenter(),l&&l.project);function w(T,C){if(T.length){var M=new Mu({culling:!0,segmentIgnoreThreshold:1,shape:{paths:T}});d.add(M),Tb(t,M,y,m),Cb(t,M,p,m,o,y,b),C&&(wb(M),A(M.states,wb))}}w(S),w(x,!0)}),e.each(function(c,p){var d=a.get(p),g=d.dataIdx,y=d.regionModel;Ab(t,c,p,y,o,g),Mb(t,c,p,y,o),Db(t,c,p,y,o)},this)},r.prototype._buildSVG=function(t){var e=t.geo.map,a=t.transformInfoRaw;this._svgGroup.x=a.x,this._svgGroup.y=a.y,this._svgGroup.scaleX=a.scaleX,this._svgGroup.scaleY=a.scaleY,this._svgResourceChanged(e)&&(this._freeSVG(),this._useSVG(e));var n=this._svgDispatcherMap=j(),i=!1;A(this._svgGraphicRecord.named,function(o){var s=o.name,l=t.mapOrGeoModel,u=t.data,f=o.svgNodeTagLower,v=o.el,h=u?u.indexOfName(s):null,c=l.getRegionModel(s);OH.get(f)!=null&&v instanceof Lr&&Tb(t,v,h,c),v instanceof Lr&&(v.culling=!0);var p=c.get("silent",!0);if(p!=null&&(v.silent=p),v.z2EmphasisLift=0,!o.namedFrom&&(BH.get(f)!=null&&Cb(t,v,s,c,l,h,null),Ab(t,v,s,c,l,h),Mb(t,v,s,c,l),NH.get(f)!=null)){var d=Db(t,v,s,c,l);d==="self"&&(i=!0);var g=n.get(s)||n.set(s,[]);g.push(v)}},this),this._enableBlurEntireSVG(i,t)},r.prototype._enableBlurEntireSVG=function(t,e){if(t&&e.isGeo){var a=e.mapOrGeoModel.getModel(["blur","itemStyle"]).getItemStyle(),n=a.opacity;this._svgGraphicRecord.root.traverse(function(i){if(!i.isGroup){Hi(i);var o=i.ensureState("blur").style||{};o.opacity==null&&n!=null&&(o.opacity=n),i.ensureState("emphasis")}})}},r.prototype.remove=function(){this._regionsGroup.removeAll(),this._regionsGroupByName=null,this._svgGroup.removeAll(),this._freeSVG(),this._controller.dispose(),this._controllerHost=null},r.prototype.findHighDownDispatchers=function(t,e){if(t==null)return[];var a=e.coordinateSystem;if(a.resourceType==="geoJSON"){var n=this._regionsGroupByName;if(n){var i=n.get(t);return i?[i]:[]}}else if(a.resourceType==="geoSVG")return this._svgDispatcherMap&&this._svgDispatcherMap.get(t)||[]},r.prototype._svgResourceChanged=function(t){return this._svgMapName!==t},r.prototype._useSVG=function(t){var e=Ja.getGeoResource(t);if(e&&e.type==="geoSVG"){var a=e.useGraphic(this.uid);this._svgGroup.add(a.root),this._svgGraphicRecord=a,this._svgMapName=t}},r.prototype._freeSVG=function(){var t=this._svgMapName;if(t!=null){var e=Ja.getGeoResource(t);e&&e.type==="geoSVG"&&e.freeGraphic(this.uid),this._svgGraphicRecord=null,this._svgDispatcherMap=null,this._svgGroup.removeAll(),this._svgMapName=null}},r.prototype._updateController=function(t,e,a,n){var i=t.coordinateSystem,o=this._controller,s=this._controllerHost;s.zoomLimit=t.get("scaleLimit"),s.zoom=i.getZoom(),o.enable(t.get("roam")||!1,{api:n,zInfo:{component:t},triggerInfo:{roamTrigger:t.get("roamTrigger"),isInSelf:function(f,v,h){return i.containPoint([v,h])},isInClip:function(f,v,h){return!e||e.contain(v,h)}}});var l=t.mainType;function u(){var f={type:"geoRoam",componentType:l};return f[l+"Id"]=t.id,f}o.off("pan").on("pan",function(f){this._mouseDownFlag=!1,L0(s,f.dx,f.dy),n.dispatchAction(G(u(),{dx:f.dx,dy:f.dy,animation:{duration:0}}))},this),o.off("zoom").on("zoom",function(f){this._mouseDownFlag=!1,I0(s,f.scale,f.originX,f.originY),n.dispatchAction(G(u(),{totalZoom:s.zoom,zoom:f.scale,originX:f.originX,originY:f.originY,animation:{duration:0}}))},this)},r.prototype.resetForLabelLayout=function(){this.group.traverse(function(t){var e=t.getTextContent();e&&(e.ignore=fI(e).ignore)})},r.prototype._updateMapSelectHandler=function(t,e,a,n){var i=this;e.off("mousedown"),e.off("click"),t.get("selectedMode")&&(e.on("mousedown",function(){i._mouseDownFlag=!0}),e.on("click",function(o){i._mouseDownFlag&&(i._mouseDownFlag=!1)}))},r}();function Tb(r,t,e,a){var n=a.getModel("itemStyle"),i=a.getModel(["emphasis","itemStyle"]),o=a.getModel(["blur","itemStyle"]),s=a.getModel(["select","itemStyle"]),l=Rf(n),u=Rf(i),f=Rf(s),v=Rf(o),h=r.data;if(h){var c=h.getItemVisual(e,"style"),p=h.getItemVisual(e,"decal");r.isVisualEncodedByVisualMap&&c.fill&&(l.fill=c.fill),p&&(l.decal=ns(p,r.api))}t.setStyle(l),t.style.strokeNoScale=!0,t.ensureState("emphasis").style=u,t.ensureState("select").style=f,t.ensureState("blur").style=v,Hi(t)}function Cb(r,t,e,a,n,i,o){var s=r.data,l=r.isGeo,u=s&&isNaN(s.get(s.mapDimension("value"),i)),f=s&&s.getItemLayout(i);if(l||u||f&&f.showLabel){var v=l?e:i,h=void 0;(!s||i>=0)&&(h=n);var c=o?{normal:{align:"center",verticalAlign:"middle"}}:null;Se(t,ce(a),{labelFetcher:h,labelDataIndex:v,defaultText:e},c);var p=t.getTextContent();if(p&&(fI(p).ignore=p.ignore,t.textConfig&&o)){var d=t.getBoundingRect().clone();t.textConfig.layoutRect=d,t.textConfig.position=[(o[0]-d.x)/d.width*100+"%",(o[1]-d.y)/d.height*100+"%"]}t.disableLabelAnimation=!0}else t.removeTextContent(),t.removeTextConfig(),t.disableLabelAnimation=null}function Ab(r,t,e,a,n,i){r.data?r.data.setItemGraphicEl(i,t):ut(t).eventData={componentType:"geo",componentIndex:n.componentIndex,geoIndex:n.componentIndex,name:e,region:a&&a.option||{}}}function Mb(r,t,e,a,n){r.data||en({el:t,componentModel:n,itemName:e,itemTooltipOption:a.get("tooltip")})}function Db(r,t,e,a,n){t.highDownSilentOnTouch=!!n.get("selectedMode");var i=a.getModel("emphasis"),o=i.get("focus");return $t(t,o,i.get("blurScope"),i.get("disabled")),r.isGeo&&HO(t,n,e),o}function Lb(r,t,e){var a=[],n;function i(){n=[]}function o(){n.length&&(a.push(n),n=[])}var s=t({polygonStart:i,polygonEnd:o,lineStart:i,lineEnd:o,point:function(l,u){isFinite(l)&&isFinite(u)&&n.push([l,u])},sphere:function(){}});return!e&&s.polygonStart(),A(r,function(l){s.lineStart();for(var u=0;u<l.length;u++)s.point(l[u][0],l[u][1]);s.lineEnd()}),!e&&s.polygonEnd(),a}var zH=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n,i){if(!(i&&i.type==="mapToggleSelect"&&i.from===this.uid)){var o=this.group;if(o.removeAll(),!e.getHostGeoModel()){if(this._mapDraw&&i&&i.type==="geoRoam"&&this._mapDraw.resetForLabelLayout(),i&&i.type==="geoRoam"&&i.componentType==="series"&&i.seriesId===e.id){var s=this._mapDraw;s&&o.add(s.group)}else if(e.needsDrawMap){var s=this._mapDraw||new vI(n);o.add(s.group),s.draw(e,a,n,this,i),this._mapDraw=s}else this._mapDraw&&this._mapDraw.remove(),this._mapDraw=null;e.get("showLegendSymbol")&&a.getComponent("legend")&&this._renderSymbols(e,a,n)}}},t.prototype.remove=function(){this._mapDraw&&this._mapDraw.remove(),this._mapDraw=null,this.group.removeAll()},t.prototype.dispose=function(){this._mapDraw&&this._mapDraw.remove(),this._mapDraw=null},t.prototype._renderSymbols=function(e,a,n){var i=e.originalData,o=this.group;i.each(i.mapDimension("value"),function(s,l){if(!isNaN(s)){var u=i.getItemLayout(l);if(!(!u||!u.point)){var f=u.point,v=u.offset,h=new wa({style:{fill:e.getData().getVisual("style").fill},shape:{cx:f[0]+v*9,cy:f[1],r:3},silent:!0,z2:8+(v?0:gs+1)});if(!v){var c=e.mainSeries.getData(),p=i.getName(l),d=c.indexOfName(p),g=i.getItemModel(l),y=g.getModel("label"),m=c.getItemGraphicEl(d);Se(h,ce(g),{labelFetcher:{getFormattedLabel:function(_,S){return e.getFormattedLabel(d,S)}},defaultText:p}),h.disableLabelAnimation=!0,y.get("position")||h.setTextConfig({position:"bottom"}),m.onHoverStateChange=function(_){zv(h,_)}}o.add(h)}}})},t.type="map",t}(Nt),VH=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.needsDrawMap=!1,e.seriesGroup=[],e.getTooltipPosition=function(a){if(a!=null){var n=this.getData().getName(a),i=this.coordinateSystem,o=i.getRegion(n);return o&&i.dataToPoint(o.getCenter())}},e}return t.prototype.getInitialData=function(e){for(var a=Rs(this,{coordDimensions:["value"],encodeDefaulter:pt(Xm,this)}),n=j(),i=[],o=0,s=a.count();o<s;o++){var l=a.getName(o);n.set(l,o)}var u=Ja.load(this.getMapType(),this.option.nameMap,this.option.nameProperty);return A(u.regions,function(f){var v=f.name,h=n.get(v),c=f.properties&&f.properties.echartsStyle,p;h==null?(p={name:v},i.push(p)):p=a.getRawDataItem(h),c&&yt(p,c)}),a.appendData(i),a},t.prototype.getHostGeoModel=function(){if(rD(this).kind!==oa.boxCoordSys)return this.getReferringComponents("geo",{useDefault:!1,enableAll:!1,enableNone:!1}).models[0]},t.prototype.getMapType=function(){return(this.getHostGeoModel()||this).option.map},t.prototype.getRawValue=function(e){var a=this.getData();return a.get(a.mapDimension("value"),e)},t.prototype.getRegionModel=function(e){var a=this.getData();return a.getItemModel(a.indexOfName(e))},t.prototype.formatTooltip=function(e,a,n){for(var i=this.getData(),o=this.getRawValue(e),s=i.getName(e),l=this.seriesGroup,u=[],f=0;f<l.length;f++){var v=l[f].originalData.indexOfName(s),h=i.mapDimension("value");isNaN(l[f].originalData.get(h,v))||u.push(l[f].name)}return ue("section",{header:u.join(", "),noHeader:!u.length,blocks:[ue("nameValue",{name:s,value:o})]})},t.prototype.setZoom=function(e){this.option.zoom=e},t.prototype.setCenter=function(e){this.option.center=e},t.prototype.getLegendIcon=function(e){var a=e.icon||"roundRect",n=ie(a,0,0,e.itemWidth,e.itemHeight,e.itemStyle.fill);return n.setStyle(e.itemStyle),n.style.stroke="none",a.indexOf("empty")>-1&&(n.style.stroke=n.style.fill,n.style.fill=N.color.neutral00,n.style.lineWidth=2),n},t.type="series.map",t.dependencies=["geo"],t.layoutMode="box",t.defaultOption={z:2,coordinateSystem:"geo",map:"",left:"center",top:"center",aspectScale:null,showLegendSymbol:!0,boundingCoords:null,center:null,zoom:1,scaleLimit:null,selectedMode:!0,label:{show:!1,color:N.color.tertiary},itemStyle:{borderWidth:.5,borderColor:N.color.border,areaColor:N.color.background},emphasis:{label:{show:!0,color:N.color.primary},itemStyle:{areaColor:N.color.highlight}},select:{label:{show:!0,color:N.color.primary},itemStyle:{color:N.color.highlight}},nameProperty:"name"},t}(Bt);function GH(r,t){var e={};return A(r,function(a){a.each(a.mapDimension("value"),function(n,i){var o="ec-"+a.getName(i);e[o]=e[o]||[],isNaN(n)||e[o].push(n)})}),r[0].map(r[0].mapDimension("value"),function(a,n){for(var i="ec-"+r[0].getName(n),o=0,s=1/0,l=-1/0,u=e[i].length,f=0;f<u;f++)s=Math.min(s,e[i][f]),l=Math.max(l,e[i][f]),o+=e[i][f];var v;return t==="min"?v=s:t==="max"?v=l:t==="average"?v=o/u:v=o,u===0?NaN:v})}function FH(r){var t={};r.eachSeriesByType("map",function(e){var a=e.getHostGeoModel(),n=a?"o"+a.id:"i"+e.getMapType();(t[n]=t[n]||[]).push(e)}),A(t,function(e,a){for(var n=GH(U(e,function(o){return o.getData()}),e[0].get("mapValueCalculation")),i=0;i<e.length;i++)e[i].originalData=e[i].getData();for(var i=0;i<e.length;i++)e[i].seriesGroup=e,e[i].needsDrawMap=i===0&&!e[i].getHostGeoModel(),e[i].setData(n.cloneShallow()),e[i].mainSeries=e[0]})}function HH(r){var t={};r.eachSeriesByType("map",function(e){var a=e.getMapType();if(!(e.getHostGeoModel()||t[a])){var n={};A(e.seriesGroup,function(o){var s=o.coordinateSystem,l=o.originalData;o.get("showLegendSymbol")&&r.getComponent("legend")&&l.each(l.mapDimension("value"),function(u,f){var v=l.getName(f),h=s.getRegion(v);if(!(!h||isNaN(u))){var c=n[v]||0,p=s.dataToPoint(h.getCenter());n[v]=c+1,l.setItemLayout(f,{point:p,offset:c})}})});var i=e.getData();i.each(function(o){var s=i.getName(o),l=i.getItemLayout(o)||{};l.showLabel=!n[s],i.setItemLayout(o,l)}),t[a]=!0}})}var Ib=Jt,no=function(r){z(t,r);function t(e,a){var n=r.call(this)||this;return n.type="view",n.dimensions=["x","y"],n._roamTransformable=new Ba,n._rawTransformable=new Ba,n.name=e,n._opt=a,n}return t.prototype.setBoundingRect=function(e,a,n,i){return this._rect=new lt(e,a,n,i),this._updateCenterAndZoom(),this._rect},t.prototype.getBoundingRect=function(){return this._rect},t.prototype.setViewRect=function(e,a,n,i){this._transformTo(e,a,n,i),this._viewRect=new lt(e,a,n,i)},t.prototype._transformTo=function(e,a,n,i){var o=this.getBoundingRect(),s=this._rawTransformable;s.transform=o.calculateTransform(new lt(e,a,n,i));var l=s.parent;s.parent=null,s.decomposeTransform(),s.parent=l,this._updateTransform()},t.prototype.setCenter=function(e){var a=this._opt;a&&a.api&&a.ecModel&&a.ecModel.getShallow("legacyViewCoordSysCenterBase")&&e&&(e=[Z(e[0],a.api.getWidth()),Z(e[1],a.api.getWidth())]),this._centerOption=et(e),this._updateCenterAndZoom()},t.prototype.setZoom=function(e){this._zoom=P0(e||1,this.zoomLimit),this._updateCenterAndZoom()},t.prototype.getDefaultCenter=function(){var e=this.getBoundingRect(),a=e.x+e.width/2,n=e.y+e.height/2;return[a,n]},t.prototype.getCenter=function(){return this._center||this.getDefaultCenter()},t.prototype.getZoom=function(){return this._zoom||1},t.prototype.getRoamTransform=function(){return this._roamTransformable.getLocalTransform()},t.prototype._updateCenterAndZoom=function(){var e=this._centerOption,a=this._rect;e&&a&&(this._center=[Z(e[0],a.width,a.x),Z(e[1],a.height,a.y)]);var n=this._rawTransformable.getLocalTransform(),i=this._roamTransformable,o=this.getDefaultCenter(),s=this.getCenter(),l=this.getZoom();s=Jt([],s,n),o=Jt([],o,n),i.originX=s[0],i.originY=s[1],i.x=o[0]-s[0],i.y=o[1]-s[1],i.scaleX=i.scaleY=l,this._updateTransform()},t.prototype._updateTransform=function(){var e=this._roamTransformable,a=this._rawTransformable;a.parent=e,e.updateTransform(),a.updateTransform(),bu(this.transform||(this.transform=[]),a.transform||me()),this._rawTransform=a.getLocalTransform(),this.invTransform=this.invTransform||[],Dr(this.invTransform,this.transform),this.decomposeTransform()},t.prototype.getTransformInfo=function(){var e=this._rawTransformable,a=this._roamTransformable,n=new Ba;return n.transform=a.transform,n.decomposeTransform(),{roam:{x:n.x,y:n.y,scaleX:n.scaleX,scaleY:n.scaleY},raw:{x:e.x,y:e.y,scaleX:e.scaleX,scaleY:e.scaleY}}},t.prototype.getViewRect=function(){return this._viewRect},t.prototype.getViewRectAfterRoam=function(){var e=this.getBoundingRect().clone();return e.applyTransform(this.transform),e},t.prototype.dataToPoint=function(e,a,n){var i=a?this._rawTransform:this.transform;return n=n||[],i?Ib(n,e,i):Ne(n,e)},t.prototype.pointToData=function(e,a,n){n=n||[];var i=this.invTransform;return i?Ib(n,e,i):(n[0]=e[0],n[1]=e[1],n)},t.prototype.convertToPixel=function(e,a,n){var i=Pb(a);return i===this?i.dataToPoint(n):null},t.prototype.convertFromPixel=function(e,a,n){var i=Pb(a);return i===this?i.pointToData(n):null},t.prototype.containPoint=function(e){return this.getViewRectAfterRoam().contain(e[0],e[1])},t.dimensions=["x","y"],t}(Ba);function Pb(r){var t=r.seriesModel;return t?t.coordinateSystem:null}var WH={geoJSON:{aspectScale:.75,invertLongitute:!0},geoSVG:{aspectScale:1,invertLongitute:!1}},hI=["lng","lat"],cy=function(r){z(t,r);function t(e,a,n){var i=r.call(this,e,{api:n.api,ecModel:n.ecModel})||this;i.dimensions=hI,i.type="geo",i._nameCoordMap=j(),i.map=a;var o=n.projection,s=Ja.load(a,n.nameMap,n.nameProperty),l=Ja.getGeoResource(a);i.resourceType=l?l.type:null;var u=i.regions=s.regions,f=WH[l.type];i._regionsMap=s.regionsMap,i.regions=s.regions,i.projection=o;var v;if(o)for(var h=0;h<u.length;h++){var c=u[h].getBoundingRect(o);v=v||c.clone(),v.union(c)}else v=s.boundingRect;return i.setBoundingRect(v.x,v.y,v.width,v.height),i.aspectScale=o?1:Q(n.aspectScale,f.aspectScale),i._invertLongitute=o?!1:f.invertLongitute,i}return t.prototype._transformTo=function(e,a,n,i){var o=this.getBoundingRect(),s=this._invertLongitute;o=o.clone(),s&&(o.y=-o.y-o.height);var l=this._rawTransformable;l.transform=o.calculateTransform(new lt(e,a,n,i));var u=l.parent;l.parent=null,l.decomposeTransform(),l.parent=u,s&&(l.scaleY=-l.scaleY),this._updateTransform()},t.prototype.getRegion=function(e){return this._regionsMap.get(e)},t.prototype.getRegionByCoord=function(e){for(var a=this.regions,n=0;n<a.length;n++){var i=a[n];if(i.type==="geoJSON"&&i.contain(e))return a[n]}},t.prototype.addGeoCoord=function(e,a){this._nameCoordMap.set(e,a)},t.prototype.getGeoCoord=function(e){var a=this._regionsMap.get(e);return this._nameCoordMap.get(e)||a&&a.getCenter()},t.prototype.dataToPoint=function(e,a,n){if(X(e)&&(e=this.getGeoCoord(e)),e){var i=this.projection;return i&&(e=i.project(e)),e&&this.projectedToPoint(e,a,n)}},t.prototype.pointToData=function(e,a,n){var i=this.projection;return i&&(e=i.unproject(e)),e&&this.pointToProjected(e,n)},t.prototype.pointToProjected=function(e,a){return r.prototype.pointToData.call(this,e,0,a)},t.prototype.projectedToPoint=function(e,a,n){return r.prototype.dataToPoint.call(this,e,a,n)},t.prototype.convertToPixel=function(e,a,n){var i=Rb(a);return i===this?i.dataToPoint(n):null},t.prototype.convertFromPixel=function(e,a,n){var i=Rb(a);return i===this?i.pointToData(n):null},t}(no);Qt(cy,no);function Rb(r){var t=r.geoModel,e=r.seriesModel;return t?t.coordinateSystem:e?e.coordinateSystem||(e.getReferringComponents("geo",Kt).models[0]||{}).coordinateSystem:null}function kb(r,t){var e=r.get("boundingCoords");if(e!=null){var a=e[0],n=e[1];if(isFinite(a[0])&&isFinite(a[1])&&isFinite(n[0])&&isFinite(n[1])){var i=this.projection;if(i){var o=a[0],s=a[1],l=n[0],u=n[1];a=[1/0,1/0],n=[-1/0,-1/0];var f=function(x,b,w,T){for(var C=w-x,M=T-b,D=0;D<=100;D++){var I=D/100,L=i.project([x+C*I,b+M*I]);Oa(a,a,L),Na(n,n,L)}};f(o,s,l,s),f(l,s,l,u),f(l,u,o,u),f(o,u,l,s)}this.setBoundingRect(a[0],a[1],n[0]-a[0],n[1]-a[1])}}var v=this.getBoundingRect(),h=r.get("layoutCenter"),c=r.get("layoutSize"),p=pe(r,t).refContainer,d=v.width/v.height*this.aspectScale,g=!1,y,m;h&&c&&(y=[Z(h[0],p.width)+p.x,Z(h[1],p.height)+p.y],m=Z(c,Math.min(p.width,p.height)),!isNaN(y[0])&&!isNaN(y[1])&&!isNaN(m)&&(g=!0));var _;if(g)_={},d>1?(_.width=m,_.height=m/d):(_.height=m,_.width=m*d),_.y=y[1]-_.height/2,_.x=y[0]-_.width/2;else{var S=r.getBoxLayoutParams();S.aspect=d,_=Xt(S,p),_=sD(r,_,d)}this.setViewRect(_.x,_.y,_.width,_.height),this.setCenter(r.get("center")),this.setZoom(r.get("zoom"))}function UH(r,t){A(t.get("geoCoord"),function(e,a){r.addGeoCoord(a,e)})}var YH=function(){function r(){this.dimensions=hI}return r.prototype.create=function(t,e){var a=[];function n(o){return{nameProperty:o.get("nameProperty"),aspectScale:o.get("aspectScale"),projection:o.get("projection")}}t.eachComponent("geo",function(o,s){var l=o.get("map"),u=new cy(l+s,l,G({nameMap:o.get("nameMap"),api:e,ecModel:t},n(o)));u.zoomLimit=o.get("scaleLimit"),a.push(u),o.coordinateSystem=u,u.model=o,u.resize=kb,u.resize(o,e)}),t.eachSeries(function(o){Iu({targetModel:o,coordSysType:"geo",coordSysProvider:function(){var s=o.subType==="map"?o.getHostGeoModel():o.getReferringComponents("geo",Kt).models[0];return s&&s.coordinateSystem},allowNotFound:!0})});var i={};return t.eachSeriesByType("map",function(o){if(!o.getHostGeoModel()){var s=o.getMapType();i[s]=i[s]||[],i[s].push(o)}}),A(i,function(o,s){var l=U(o,function(f){return f.get("nameMap")}),u=new cy(s,s,G({nameMap:kh(l),api:e,ecModel:t},n(o[0])));u.zoomLimit=Ce.apply(null,U(o,function(f){return f.get("scaleLimit")})),a.push(u),u.resize=kb,u.resize(o[0],e),A(o,function(f){f.coordinateSystem=u,UH(u,f)})}),a},r.prototype.getFilledRegions=function(t,e,a,n){for(var i=(t||[]).slice(),o=j(),s=0;s<i.length;s++)o.set(i[s].name,i[s]);var l=Ja.load(e,a,n);return A(l.regions,function(u){var f=u.name,v=o.get(f),h=u.properties&&u.properties.echartsStyle;v||(v={name:f},i.push(v)),h&&yt(v,h)}),i},r}(),cI=new YH,ZH=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(e,a,n){this.mergeDefaultAndTheme(e,n);var i=Ja.getGeoResource(e.map);if(i&&i.type==="geoJSON"){var o=e.itemStyle=e.itemStyle||{};"color"in o||(o.color=e.defaultItemStyleColor||N.color.backgroundTint)}Vi(e,"label",["show"])},t.prototype.optionUpdated=function(){var e=this,a=this.option;a.regions=cI.getFilledRegions(a.regions,a.map,a.nameMap,a.nameProperty);var n={};this._optionModelMap=Mr(a.regions||[],function(i,o){var s=o.name;return s&&(i.set(s,new wt(o,e,e.ecModel)),o.selected&&(n[s]=!0)),i},j()),a.selectedMap||(a.selectedMap=n)},t.prototype.getRegionModel=function(e){return this._optionModelMap.get(e)||new wt(null,this,this.ecModel)},t.prototype.getFormattedLabel=function(e,a){var n=this.getRegionModel(e),i=a==="normal"?n.get(["label","formatter"]):n.get(["emphasis","label","formatter"]),o={name:e};if(tt(i))return o.status=a,i(o);if(X(i))return i.replace("{a}",e??"")},t.prototype.setZoom=function(e){this.option.zoom=e},t.prototype.setCenter=function(e){this.option.center=e},t.prototype.select=function(e){var a=this.option,n=a.selectedMode;if(n){n!=="multiple"&&(a.selectedMap=null);var i=a.selectedMap||(a.selectedMap={});i[e]=!0}},t.prototype.unSelect=function(e){var a=this.option.selectedMap;a&&(a[e]=!1)},t.prototype.toggleSelected=function(e){this[this.isSelected(e)?"unSelect":"select"](e)},t.prototype.isSelected=function(e){var a=this.option.selectedMap;return!!(a&&a[e])},t.type="geo",t.layoutMode="box",t.defaultOption={z:0,show:!0,left:"center",top:"center",aspectScale:null,silent:!1,map:"",boundingCoords:null,center:null,zoom:1,scaleLimit:null,label:{show:!1,color:N.color.tertiary},itemStyle:{borderWidth:.5,borderColor:N.color.border},emphasis:{label:{show:!0,color:N.color.primary},itemStyle:{color:N.color.highlight}},select:{label:{show:!0,color:N.color.primary},itemStyle:{color:N.color.highlight}},regions:[]},t}(xt),XH=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.focusBlurEnabled=!0,e}return t.prototype.init=function(e,a){this._api=a},t.prototype.render=function(e,a,n,i){if(this._model=e,!e.get("show")){this._mapDraw&&this._mapDraw.remove(),this._mapDraw=null;return}this._mapDraw||(this._mapDraw=new vI(n));var o=this._mapDraw;o.draw(e,a,n,this,i),o.group.on("click",this._handleRegionClick,this),o.group.silent=e.get("silent"),this.group.add(o.group),this.updateSelectStatus(e,a,n)},t.prototype._handleRegionClick=function(e){var a;Di(e.target,function(n){return(a=ut(n).eventData)!=null},!0),a&&this._api.dispatchAction({type:"geoToggleSelect",geoId:this._model.id,name:a.name})},t.prototype.updateSelectStatus=function(e,a,n){var i=this;this._mapDraw.group.traverse(function(o){var s=ut(o).eventData;if(s)return i._model.isSelected(s.name)?n.enterSelect(o):n.leaveSelect(o),!0})},t.prototype.findHighDownDispatchers=function(e){return this._mapDraw&&this._mapDraw.findHighDownDispatchers(e,this._model)},t.prototype.dispose=function(){this._mapDraw&&this._mapDraw.remove()},t.type="geo",t}(Wt);function $H(r,t,e){Ja.registerMap(r,t,e)}function pI(r){r.registerCoordinateSystem("geo",cI),r.registerComponentModel(ZH),r.registerComponentView(XH),r.registerImpl("registerMap",$H),r.registerImpl("getMap",function(e){return Ja.getMapForUser(e)});function t(e,a){a.update="geo:updateSelectStatus",r.registerAction(a,function(n,i){var o={},s=[];return i.eachComponent({mainType:"geo",query:n},function(l){l[e](n.name);var u=l.coordinateSystem;A(u.regions,function(v){o[v.name]=l.isSelected(v.name)||!1});var f=[];A(o,function(v,h){o[h]&&f.push(h)}),s.push({geoIndex:l.componentIndex,name:f})}),{selected:o,allSelected:s,name:n.name}})}t("toggleSelected",{type:"geoToggleSelect",event:"geoselectchanged"}),t("select",{type:"geoSelect",event:"geoselected"}),t("unSelect",{type:"geoUnSelect",event:"geounselected"}),r.registerAction({type:"geoRoam",event:"geoRoam",update:"updateTransform"},function(e,a,n){var i=e.componentType;i||(e.geoId!=null?i="geo":e.seriesId!=null&&(i="series")),i||(i="series"),a.eachComponent({mainType:i,query:e},function(o){var s=o.coordinateSystem;if(s.type==="geo"){var l=sc(s,e,o.get("scaleLimit"));o.setCenter&&o.setCenter(l.center),o.setZoom&&o.setZoom(l.zoom),i==="series"&&A(o.seriesGroup,function(u){u.setCenter(l.center),u.setZoom(l.zoom)})}})})}function qH(r){mt(pI),r.registerChartView(zH),r.registerSeriesModel(VH),r.registerLayout(HH),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,FH),jD("map",r.registerAction)}function KH(r){var t=r;t.hierNode={defaultAncestor:null,ancestor:t,prelim:0,modifier:0,change:0,shift:0,i:0,thread:null};for(var e=[t],a,n;a=e.pop();)if(n=a.children,a.isExpand&&n.length)for(var i=n.length,o=i-1;o>=0;o--){var s=n[o];s.hierNode={defaultAncestor:null,ancestor:s,prelim:0,modifier:0,change:0,shift:0,i:o,thread:null},e.push(s)}}function jH(r,t){var e=r.isExpand?r.children:[],a=r.parentNode.children,n=r.hierNode.i?a[r.hierNode.i-1]:null;if(e.length){QH(r);var i=(e[0].hierNode.prelim+e[e.length-1].hierNode.prelim)/2;n?(r.hierNode.prelim=n.hierNode.prelim+t(r,n),r.hierNode.modifier=r.hierNode.prelim-i):r.hierNode.prelim=i}else n&&(r.hierNode.prelim=n.hierNode.prelim+t(r,n));r.parentNode.hierNode.defaultAncestor=t4(r,n,r.parentNode.hierNode.defaultAncestor||a[0],t)}function JH(r){var t=r.hierNode.prelim+r.parentNode.hierNode.modifier;r.setLayout({x:t},!0),r.hierNode.modifier+=r.parentNode.hierNode.modifier}function Eb(r){return arguments.length?r:a4}function xl(r,t){return r-=Math.PI/2,{x:t*Math.cos(r),y:t*Math.sin(r)}}function QH(r){for(var t=r.children,e=t.length,a=0,n=0;--e>=0;){var i=t[e];i.hierNode.prelim+=a,i.hierNode.modifier+=a,n+=i.hierNode.change,a+=i.hierNode.shift+n}}function t4(r,t,e,a){if(t){for(var n=r,i=r,o=i.parentNode.children[0],s=t,l=n.hierNode.modifier,u=i.hierNode.modifier,f=o.hierNode.modifier,v=s.hierNode.modifier;s=zp(s),i=Vp(i),s&&i;){n=zp(n),o=Vp(o),n.hierNode.ancestor=r;var h=s.hierNode.prelim+v-i.hierNode.prelim-u+a(s,i);h>0&&(r4(e4(s,r,e),r,h),u+=h,l+=h),v+=s.hierNode.modifier,u+=i.hierNode.modifier,l+=n.hierNode.modifier,f+=o.hierNode.modifier}s&&!zp(n)&&(n.hierNode.thread=s,n.hierNode.modifier+=v-l),i&&!Vp(o)&&(o.hierNode.thread=i,o.hierNode.modifier+=u-f,e=r)}return e}function zp(r){var t=r.children;return t.length&&r.isExpand?t[t.length-1]:r.hierNode.thread}function Vp(r){var t=r.children;return t.length&&r.isExpand?t[0]:r.hierNode.thread}function e4(r,t,e){return r.hierNode.ancestor.parentNode===t.parentNode?r.hierNode.ancestor:e}function r4(r,t,e){var a=e/(t.hierNode.i-r.hierNode.i);t.hierNode.change-=a,t.hierNode.shift+=e,t.hierNode.modifier+=e,t.hierNode.prelim+=e,r.hierNode.change+=a}function a4(r,t){return r.parentNode===t.parentNode?1:2}var n4=function(){function r(){this.parentPoint=[],this.childPoints=[]}return r}(),i4=function(r){z(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:N.color.neutral99,fill:null}},t.prototype.getDefaultShape=function(){return new n4},t.prototype.buildPath=function(e,a){var n=a.childPoints,i=n.length,o=a.parentPoint,s=n[0],l=n[i-1];if(i===1){e.moveTo(o[0],o[1]),e.lineTo(s[0],s[1]);return}var u=a.orient,f=u==="TB"||u==="BT"?0:1,v=1-f,h=Z(a.forkPosition,1),c=[];c[f]=o[f],c[v]=o[v]+(l[v]-o[v])*h,e.moveTo(o[0],o[1]),e.lineTo(c[0],c[1]),e.moveTo(s[0],s[1]),c[f]=s[f],e.lineTo(c[0],c[1]),c[f]=l[f],e.lineTo(c[0],c[1]),e.lineTo(l[0],l[1]);for(var p=1;p<i-1;p++){var d=n[p];e.moveTo(d[0],d[1]),c[f]=d[f],e.lineTo(c[0],c[1])}},t}(bt),o4=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e._mainGroup=new rt,e}return t.prototype.init=function(e,a){this._controller=new ao(a.getZr()),this._controllerHost={target:this.group},this.group.add(this._mainGroup)},t.prototype.render=function(e,a,n){var i=e.getData(),o=e.layoutInfo,s=this._mainGroup,l=e.get("layout");l==="radial"?(s.x=o.x+o.width/2,s.y=o.y+o.height/2):(s.x=o.x,s.y=o.y),this._updateViewCoordSys(e,n),this._updateController(e,null,a,n);var u=this._data;i.diff(u).add(function(f){Ob(i,f)&&Nb(i,f,null,s,e)}).update(function(f,v){var h=u.getItemGraphicEl(v);if(!Ob(i,f)){h&&zb(u,v,h,s,e);return}Nb(i,f,h,s,e)}).remove(function(f){var v=u.getItemGraphicEl(f);v&&zb(u,f,v,s,e)}).execute(),this._nodeScaleRatio=e.get("nodeScaleRatio"),this._updateNodeAndLinkScale(e),e.get("expandAndCollapse")===!0&&i.eachItemGraphicEl(function(f,v){f.off("click").on("click",function(){n.dispatchAction({type:"treeExpandAndCollapse",seriesId:e.id,dataIndex:v})})}),this._data=i},t.prototype._updateViewCoordSys=function(e,a){var n=e.getData(),i=[];n.each(function(v){var h=n.getItemLayout(v);h&&!isNaN(h.x)&&!isNaN(h.y)&&i.push([+h.x,+h.y])});var o=[],s=[];Uh(i,o,s);var l=this._min,u=this._max;s[0]-o[0]===0&&(o[0]=l?l[0]:o[0]-1,s[0]=u?u[0]:s[0]+1),s[1]-o[1]===0&&(o[1]=l?l[1]:o[1]-1,s[1]=u?u[1]:s[1]+1);var f=e.coordinateSystem=new no(null,{api:a,ecModel:e.ecModel});f.zoomLimit=e.get("scaleLimit"),f.setBoundingRect(o[0],o[1],s[0]-o[0],s[1]-o[1]),f.setCenter(e.get("center")),f.setZoom(e.get("zoom")),this.group.attr({x:f.x,y:f.y,scaleX:f.scaleX,scaleY:f.scaleY}),this._min=o,this._max=s},t.prototype._updateController=function(e,a,n,i){var o=this;iI(e,i,this.group,this._controller,this._controllerHost,a),this._controller.on("zoom",function(s){o._updateNodeAndLinkScale(e)})},t.prototype._updateNodeAndLinkScale=function(e){var a=e.getData(),n=this._getNodeGlobalScale(e);a.eachItemGraphicEl(function(i,o){i.setSymbolScale(n)})},t.prototype._getNodeGlobalScale=function(e){var a=e.coordinateSystem;if(a.type!=="view")return 1;var n=this._nodeScaleRatio,i=a.scaleX||1,o=a.getZoom(),s=(o-1)*n+1;return s/i},t.prototype.dispose=function(){this._controller&&this._controller.dispose(),this._controllerHost=null},t.prototype.remove=function(){this._mainGroup.removeAll(),this._data=null},t.type="tree",t}(Nt);function Ob(r,t){var e=r.getItemLayout(t);return e&&!isNaN(e.x)&&!isNaN(e.y)}function Nb(r,t,e,a,n){var i=!e,o=r.tree.getNodeByDataIndex(t),s=o.getModel(),l=o.getVisual("style").fill,u=o.isExpand===!1&&o.children.length!==0?l:N.color.neutral00,f=r.tree.root,v=o.parentNode===f?o:o.parentNode||o,h=r.getItemGraphicEl(v.dataIndex),c=v.getLayout(),p=h?{x:h.__oldX,y:h.__oldY,rawX:h.__radialOldRawX,rawY:h.__radialOldRawY}:c,d=o.getLayout();i?(e=new ku(r,t,null,{symbolInnerColor:u,useNameLabel:!0}),e.x=p.x,e.y=p.y):e.updateData(r,t,null,{symbolInnerColor:u,useNameLabel:!0}),e.__radialOldRawX=e.__radialRawX,e.__radialOldRawY=e.__radialRawY,e.__radialRawX=d.rawX,e.__radialRawY=d.rawY,a.add(e),r.setItemGraphicEl(t,e),e.__oldX=e.x,e.__oldY=e.y,Lt(e,{x:d.x,y:d.y},n);var g=e.getSymbolPath();if(n.get("layout")==="radial"){var y=f.children[0],m=y.getLayout(),_=y.children.length,S=void 0,x=void 0;if(d.x===m.x&&o.isExpand===!0&&y.children.length){var b={x:(y.children[0].getLayout().x+y.children[_-1].getLayout().x)/2,y:(y.children[0].getLayout().y+y.children[_-1].getLayout().y)/2};S=Math.atan2(b.y-m.y,b.x-m.x),S<0&&(S=Math.PI*2+S),x=b.x<m.x,x&&(S=S-Math.PI)}else S=Math.atan2(d.y-m.y,d.x-m.x),S<0&&(S=Math.PI*2+S),o.children.length===0||o.children.length!==0&&o.isExpand===!1?(x=d.x<m.x,x&&(S=S-Math.PI)):(x=d.x>m.x,x||(S=S-Math.PI));var w=x?"left":"right",T=s.getModel("label"),C=T.get("rotate"),M=C*(Math.PI/180),D=g.getTextContent();D&&(g.setTextConfig({position:T.get("position")||w,rotation:C==null?-S:M,origin:"center"}),D.setStyle("verticalAlign","middle"))}var I=s.get(["emphasis","focus"]),L=I==="relative"?Ko(o.getAncestorsIndices(),o.getDescendantIndices()):I==="ancestor"?o.getAncestorsIndices():I==="descendant"?o.getDescendantIndices():null;L&&(ut(e).focus=L),s4(n,o,f,e,p,c,d,a),e.__edge&&(e.onHoverStateChange=function(P){if(P!=="blur"){var k=o.parentNode&&r.getItemGraphicEl(o.parentNode.dataIndex);k&&k.hoverState===Tu||zv(e.__edge,P)}})}function s4(r,t,e,a,n,i,o,s){var l=t.getModel(),u=r.get("edgeShape"),f=r.get("layout"),v=r.getOrient(),h=r.get(["lineStyle","curveness"]),c=r.get("edgeForkPosition"),p=l.getModel("lineStyle").getLineStyle(),d=a.__edge;if(u==="curve")t.parentNode&&t.parentNode!==e&&(d||(d=a.__edge=new ms({shape:py(f,v,h,n,n)})),Lt(d,{shape:py(f,v,h,i,o)},r));else if(u==="polyline"&&f==="orthogonal"&&t!==e&&t.children&&t.children.length!==0&&t.isExpand===!0){for(var g=t.children,y=[],m=0;m<g.length;m++){var _=g[m].getLayout();y.push([_.x,_.y])}d||(d=a.__edge=new i4({shape:{parentPoint:[o.x,o.y],childPoints:[[o.x,o.y]],orient:v,forkPosition:c}})),Lt(d,{shape:{parentPoint:[o.x,o.y],childPoints:y}},r)}d&&!(u==="polyline"&&!t.isExpand)&&(d.useStyle(nt({strokeNoScale:!0,fill:null},p)),he(d,l,"lineStyle"),Hi(d),s.add(d))}function Bb(r,t,e,a,n){var i=t.tree.root,o=dI(i,r),s=o.source,l=o.sourceLayout,u=t.getItemGraphicEl(r.dataIndex);if(u){var f=t.getItemGraphicEl(s.dataIndex),v=f.__edge,h=u.__edge||(s.isExpand===!1||s.children.length===1?v:void 0),c=a.get("edgeShape"),p=a.get("layout"),d=a.get("orient"),g=a.get(["lineStyle","curveness"]);h&&(c==="curve"?Pn(h,{shape:py(p,d,g,l,l),style:{opacity:0}},a,{cb:function(){e.remove(h)},removeOpt:n}):c==="polyline"&&a.get("layout")==="orthogonal"&&Pn(h,{shape:{parentPoint:[l.x,l.y],childPoints:[[l.x,l.y]]},style:{opacity:0}},a,{cb:function(){e.remove(h)},removeOpt:n}))}}function dI(r,t){for(var e=t.parentNode===r?t:t.parentNode||t,a;a=e.getLayout(),a==null;)e=e.parentNode===r?e:e.parentNode||e;return{source:e,sourceLayout:a}}function zb(r,t,e,a,n){var i=r.tree.getNodeByDataIndex(t),o=r.tree.root,s=dI(o,i).sourceLayout,l={duration:n.get("animationDurationUpdate"),easing:n.get("animationEasingUpdate")};Pn(e,{x:s.x+1,y:s.y+1},n,{cb:function(){a.remove(e),r.setItemGraphicEl(t,null)},removeOpt:l}),e.fadeOut(null,r.hostModel,{fadeLabel:!0,animation:l}),i.children.forEach(function(u){Bb(u,r,a,n,l)}),Bb(i,r,a,n,l)}function py(r,t,e,a,n){var i,o,s,l,u,f,v,h;if(r==="radial"){u=a.rawX,v=a.rawY,f=n.rawX,h=n.rawY;var c=xl(u,v),p=xl(u,v+(h-v)*e),d=xl(f,h+(v-h)*e),g=xl(f,h);return{x1:c.x||0,y1:c.y||0,x2:g.x||0,y2:g.y||0,cpx1:p.x||0,cpy1:p.y||0,cpx2:d.x||0,cpy2:d.y||0}}else u=a.x,v=a.y,f=n.x,h=n.y,(t==="LR"||t==="RL")&&(i=u+(f-u)*e,o=v,s=f+(u-f)*e,l=h),(t==="TB"||t==="BT")&&(i=u,o=v+(h-v)*e,s=f,l=h+(v-h)*e);return{x1:u,y1:v,x2:f,y2:h,cpx1:i,cpy1:o,cpx2:s,cpy2:l}}var Ar=St();function gI(r){var t=r.mainData,e=r.datas;e||(e={main:t},r.datasAttr={main:"data"}),r.datas=r.mainData=null,yI(t,e,r),A(e,function(a){A(t.TRANSFERABLE_METHODS,function(n){a.wrapMethod(n,pt(l4,r))})}),t.wrapMethod("cloneShallow",pt(f4,r)),A(t.CHANGABLE_METHODS,function(a){t.wrapMethod(a,pt(u4,r))}),Re(e[t.dataType]===t)}function l4(r,t){if(c4(this)){var e=G({},Ar(this).datas);e[this.dataType]=t,yI(t,e,r)}else k0(t,this.dataType,Ar(this).mainData,r);return t}function u4(r,t){return r.struct&&r.struct.update(),t}function f4(r,t){return A(Ar(t).datas,function(e,a){e!==t&&k0(e.cloneShallow(),a,t,r)}),t}function v4(r){var t=Ar(this).mainData;return r==null||t==null?t:Ar(t).datas[r]}function h4(){var r=Ar(this).mainData;return r==null?[{data:r}]:U(Ct(Ar(r).datas),function(t){return{type:t,data:Ar(r).datas[t]}})}function c4(r){return Ar(r).mainData===r}function yI(r,t,e){Ar(r).datas={},A(t,function(a,n){k0(a,n,r,e)})}function k0(r,t,e,a){Ar(e).datas[t]=r,Ar(r).mainData=e,r.dataType=t,a.struct&&(r[a.structAttr]=a.struct,a.struct[a.datasAttr[t]]=r),r.getLinkedData=v4,r.getLinkedDataAll=h4}var p4=function(){function r(t,e){this.depth=0,this.height=0,this.dataIndex=-1,this.children=[],this.viewChildren=[],this.isExpand=!1,this.name=t||"",this.hostTree=e}return r.prototype.isRemoved=function(){return this.dataIndex<0},r.prototype.eachNode=function(t,e,a){tt(t)&&(a=e,e=t,t=null),t=t||{},X(t)&&(t={order:t});var n=t.order||"preorder",i=this[t.attr||"children"],o;n==="preorder"&&(o=e.call(a,this));for(var s=0;!o&&s<i.length;s++)i[s].eachNode(t,e,a);n==="postorder"&&e.call(a,this)},r.prototype.updateDepthAndHeight=function(t){var e=0;this.depth=t;for(var a=0;a<this.children.length;a++){var n=this.children[a];n.updateDepthAndHeight(t+1),n.height>e&&(e=n.height)}this.height=e+1},r.prototype.getNodeById=function(t){if(this.getId()===t)return this;for(var e=0,a=this.children,n=a.length;e<n;e++){var i=a[e].getNodeById(t);if(i)return i}},r.prototype.contains=function(t){if(t===this)return!0;for(var e=0,a=this.children,n=a.length;e<n;e++){var i=a[e].contains(t);if(i)return i}},r.prototype.getAncestors=function(t){for(var e=[],a=t?this:this.parentNode;a;)e.push(a),a=a.parentNode;return e.reverse(),e},r.prototype.getAncestorsIndices=function(){for(var t=[],e=this;e;)t.push(e.dataIndex),e=e.parentNode;return t.reverse(),t},r.prototype.getDescendantIndices=function(){var t=[];return this.eachNode(function(e){t.push(e.dataIndex)}),t},r.prototype.getValue=function(t){var e=this.hostTree.data;return e.getStore().get(e.getDimensionIndex(t||"value"),this.dataIndex)},r.prototype.setLayout=function(t,e){this.dataIndex>=0&&this.hostTree.data.setItemLayout(this.dataIndex,t,e)},r.prototype.getLayout=function(){return this.hostTree.data.getItemLayout(this.dataIndex)},r.prototype.getModel=function(t){if(!(this.dataIndex<0)){var e=this.hostTree,a=e.data.getItemModel(this.dataIndex);return a.getModel(t)}},r.prototype.getLevelModel=function(){return(this.hostTree.levelModels||[])[this.depth]},r.prototype.setVisual=function(t,e){this.dataIndex>=0&&this.hostTree.data.setItemVisual(this.dataIndex,t,e)},r.prototype.getVisual=function(t){return this.hostTree.data.getItemVisual(this.dataIndex,t)},r.prototype.getRawIndex=function(){return this.hostTree.data.getRawIndex(this.dataIndex)},r.prototype.getId=function(){return this.hostTree.data.getId(this.dataIndex)},r.prototype.getChildIndex=function(){if(this.parentNode){for(var t=this.parentNode.children,e=0;e<t.length;++e)if(t[e]===this)return e;return-1}return-1},r.prototype.isAncestorOf=function(t){for(var e=t.parentNode;e;){if(e===this)return!0;e=e.parentNode}return!1},r.prototype.isDescendantOf=function(t){return t!==this&&t.isAncestorOf(this)},r}(),E0=function(){function r(t){this.type="tree",this._nodes=[],this.hostModel=t}return r.prototype.eachNode=function(t,e,a){this.root.eachNode(t,e,a)},r.prototype.getNodeByDataIndex=function(t){var e=this.data.getRawIndex(t);return this._nodes[e]},r.prototype.getNodeById=function(t){return this.root.getNodeById(t)},r.prototype.update=function(){for(var t=this.data,e=this._nodes,a=0,n=e.length;a<n;a++)e[a].dataIndex=-1;for(var a=0,n=t.count();a<n;a++)e[t.getRawIndex(a)].dataIndex=a},r.prototype.clearLayouts=function(){this.data.clearItemLayouts()},r.createTree=function(t,e,a){var n=new r(e),i=[],o=1;s(t);function s(f,v){var h=f.value;o=Math.max(o,W(h)?h.length:1),i.push(f);var c=new p4(ve(f.name,""),n);v?d4(c,v):n.root=c,n._nodes.push(c);var p=f.children;if(p)for(var d=0;d<p.length;d++)s(p[d],c)}n.root.updateDepthAndHeight(0);var l=Ds(i,{coordDimensions:["value"],dimensionsCount:o}).dimensions,u=new Ue(l,e);return u.initData(i),a&&a(u),gI({mainData:u,struct:n,structAttr:"tree"}),n.update(),n},r}();function d4(r,t){var e=t.children;r.parentNode!==t&&(e.push(r),r.parentNode=t)}function fu(r,t,e){if(r&&gt(t,r.type)>=0){var a=e.getData().tree.root,n=r.targetNode;if(X(n)&&(n=a.getNodeById(n)),n&&a.contains(n))return{node:n};var i=r.targetNodeId;if(i!=null&&(n=a.getNodeById(i)))return{node:n}}}function mI(r){for(var t=[];r;)r=r.parentNode,r&&t.push(r);return t.reverse()}function O0(r,t){var e=mI(r);return gt(e,t)>=0}function uc(r,t){for(var e=[];r;){var a=r.dataIndex;e.push({name:r.name,dataIndex:a,value:t.getRawValue(a)}),r=r.parentNode}return e.reverse(),e}var g4=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.hasSymbolVisual=!0,e.ignoreStyleOnData=!0,e}return t.prototype.getInitialData=function(e){var a={name:e.name,children:e.data},n=e.leaves||{},i=new wt(n,this,this.ecModel),o=E0.createTree(a,this,s);function s(v){v.wrapMethod("getItemModel",function(h,c){var p=o.getNodeByDataIndex(c);return p&&p.children.length&&p.isExpand||(h.parentModel=i),h})}var l=0;o.eachNode("preorder",function(v){v.depth>l&&(l=v.depth)});var u=e.expandAndCollapse,f=u&&e.initialTreeDepth>=0?e.initialTreeDepth:l;return o.root.eachNode("preorder",function(v){var h=v.hostTree.data.getRawDataItem(v.dataIndex);v.isExpand=h&&h.collapsed!=null?!h.collapsed:v.depth<=f}),o.data},t.prototype.getOrient=function(){var e=this.get("orient");return e==="horizontal"?e="LR":e==="vertical"&&(e="TB"),e},t.prototype.setZoom=function(e){this.option.zoom=e},t.prototype.setCenter=function(e){this.option.center=e},t.prototype.formatTooltip=function(e,a,n){for(var i=this.getData().tree,o=i.root.children[0],s=i.getNodeByDataIndex(e),l=s.getValue(),u=s.name;s&&s!==o;)u=s.parentNode.name+"."+u,s=s.parentNode;return ue("nameValue",{name:u,value:l,noValue:isNaN(l)||l==null})},t.prototype.getDataParams=function(e){var a=r.prototype.getDataParams.apply(this,arguments),n=this.getData().tree.getNodeByDataIndex(e);return a.treeAncestors=uc(n,this),a.collapsed=!n.isExpand,a},t.type="series.tree",t.layoutMode="box",t.defaultOption={z:2,coordinateSystemUsage:"box",left:"12%",top:"12%",right:"12%",bottom:"12%",layout:"orthogonal",edgeShape:"curve",edgeForkPosition:"50%",roam:!1,roamTrigger:"global",nodeScaleRatio:.4,center:null,zoom:1,orient:"LR",symbol:"emptyCircle",symbolSize:7,expandAndCollapse:!0,initialTreeDepth:2,lineStyle:{color:N.color.borderTint,width:1.5,curveness:.5},itemStyle:{color:"lightsteelblue",borderWidth:1.5},label:{show:!0},animationEasing:"linear",animationDuration:700,animationDurationUpdate:500},t}(Bt);function y4(r,t,e){for(var a=[r],n=[],i;i=a.pop();)if(n.push(i),i.isExpand){var o=i.children;if(o.length)for(var s=0;s<o.length;s++)a.push(o[s])}for(;i=n.pop();)t(i,e)}function rl(r,t){for(var e=[r],a;a=e.pop();)if(t(a),a.isExpand){var n=a.children;if(n.length)for(var i=n.length-1;i>=0;i--)e.push(n[i])}}function m4(r,t){r.eachSeriesByType("tree",function(e){_4(e,t)})}function _4(r,t){var e=pe(r,t).refContainer,a=Xt(r.getBoxLayoutParams(),e);r.layoutInfo=a;var n=r.get("layout"),i=0,o=0,s=null;n==="radial"?(i=2*Math.PI,o=Math.min(a.height,a.width)/2,s=Eb(function(S,x){return(S.parentNode===x.parentNode?1:2)/S.depth})):(i=a.width,o=a.height,s=Eb());var l=r.getData().tree.root,u=l.children[0];if(u){KH(l),y4(u,jH,s),l.hierNode.modifier=-u.hierNode.prelim,rl(u,JH);var f=u,v=u,h=u;rl(u,function(S){var x=S.getLayout().x;x<f.getLayout().x&&(f=S),x>v.getLayout().x&&(v=S),S.depth>h.depth&&(h=S)});var c=f===v?1:s(f,v)/2,p=c-f.getLayout().x,d=0,g=0,y=0,m=0;if(n==="radial")d=i/(v.getLayout().x+c+p),g=o/(h.depth-1||1),rl(u,function(S){y=(S.getLayout().x+p)*d,m=(S.depth-1)*g;var x=xl(y,m);S.setLayout({x:x.x,y:x.y,rawX:y,rawY:m},!0)});else{var _=r.getOrient();_==="RL"||_==="LR"?(g=o/(v.getLayout().x+c+p),d=i/(h.depth-1||1),rl(u,function(S){m=(S.getLayout().x+p)*g,y=_==="LR"?(S.depth-1)*d:i-(S.depth-1)*d,S.setLayout({x:y,y:m},!0)})):(_==="TB"||_==="BT")&&(d=i/(v.getLayout().x+c+p),g=o/(h.depth-1||1),rl(u,function(S){y=(S.getLayout().x+p)*d,m=_==="TB"?(S.depth-1)*g:o-(S.depth-1)*g,S.setLayout({x:y,y:m},!0)}))}}}function S4(r){r.eachSeriesByType("tree",function(t){var e=t.getData(),a=e.tree;a.eachNode(function(n){var i=n.getModel(),o=i.getModel("itemStyle").getItemStyle(),s=e.ensureUniqueItemVisual(n.dataIndex,"style");G(s,o)})})}function x4(r){r.registerAction({type:"treeExpandAndCollapse",event:"treeExpandAndCollapse",update:"update"},function(t,e){e.eachComponent({mainType:"series",subType:"tree",query:t},function(a){var n=t.dataIndex,i=a.getData().tree,o=i.getNodeByDataIndex(n);o.isExpand=!o.isExpand})}),r.registerAction({type:"treeRoam",event:"treeRoam",update:"none"},function(t,e,a){e.eachComponent({mainType:"series",subType:"tree",query:t},function(n){var i=n.coordinateSystem,o=sc(i,t,n.get("scaleLimit"));n.setCenter(o.center),n.setZoom(o.zoom)})})}function b4(r){r.registerChartView(o4),r.registerSeriesModel(g4),r.registerLayout(m4),r.registerVisual(S4),x4(r)}var Vb=["treemapZoomToNode","treemapRender","treemapMove"];function w4(r){for(var t=0;t<Vb.length;t++)r.registerAction({type:Vb[t],update:"updateView"},jt);r.registerAction({type:"treemapRootToNode",update:"updateView"},function(e,a){a.eachComponent({mainType:"series",subType:"treemap",query:e},n);function n(i,o){var s=["treemapZoomToNode","treemapRootToNode"],l=fu(e,s,i);if(l){var u=i.getViewRoot();u&&(e.direction=O0(u,l.node)?"rollUp":"drillDown"),i.resetViewRoot(l.node)}}})}function _I(r){var t=r.getData(),e=t.tree,a={};e.eachNode(function(n){for(var i=n;i&&i.depth>1;)i=i.parentNode;var o=Rg(r.ecModel,i.name||i.dataIndex+"",a);n.setVisual("decal",o)})}var T4=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.preventUsingHoverLayer=!0,e}return t.prototype.getInitialData=function(e,a){var n={name:e.name,children:e.data};SI(n);var i=e.levels||[],o=this.designatedVisualItemStyle={},s=new wt({itemStyle:o},this,a);i=e.levels=C4(i,a);var l=U(i||[],function(v){return new wt(v,s,a)},this),u=E0.createTree(n,this,f);function f(v){v.wrapMethod("getItemModel",function(h,c){var p=u.getNodeByDataIndex(c),d=p?l[p.depth]:null;return h.parentModel=d||s,h})}return u.data},t.prototype.optionUpdated=function(){this.resetViewRoot()},t.prototype.formatTooltip=function(e,a,n){var i=this.getData(),o=this.getRawValue(e),s=i.getName(e);return ue("nameValue",{name:s,value:o})},t.prototype.getDataParams=function(e){var a=r.prototype.getDataParams.apply(this,arguments),n=this.getData().tree.getNodeByDataIndex(e);return a.treeAncestors=uc(n,this),a.treePathInfo=a.treeAncestors,a},t.prototype.setLayoutInfo=function(e){this.layoutInfo=this.layoutInfo||{},G(this.layoutInfo,e)},t.prototype.mapIdToIndex=function(e){var a=this._idIndexMap;a||(a=this._idIndexMap=j(),this._idIndexMapCount=0);var n=a.get(e);return n==null&&a.set(e,n=this._idIndexMapCount++),n},t.prototype.getViewRoot=function(){return this._viewRoot},t.prototype.resetViewRoot=function(e){e?this._viewRoot=e:e=this._viewRoot;var a=this.getRawData().tree.root;(!e||e!==a&&!a.contains(e))&&(this._viewRoot=a)},t.prototype.enableAriaDecal=function(){_I(this)},t.type="series.treemap",t.layoutMode="box",t.defaultOption={progressive:0,coordinateSystemUsage:"box",left:N.size.l,top:N.size.xxxl,right:N.size.l,bottom:N.size.xxxl,sort:!0,clipWindow:"origin",squareRatio:.5*(1+Math.sqrt(5)),leafDepth:null,drillDownIcon:"▶",zoomToNodeRatio:.32*.32,scaleLimit:{max:5,min:.2},roam:!0,roamTrigger:"global",nodeClick:"zoomToNode",animation:!0,animationDurationUpdate:900,animationEasing:"quinticInOut",breadcrumb:{show:!0,height:22,left:"center",bottom:N.size.m,emptyItemWidth:25,itemStyle:{color:N.color.backgroundShade,textStyle:{color:N.color.secondary}},emphasis:{itemStyle:{color:N.color.background}}},label:{show:!0,distance:0,padding:5,position:"inside",color:N.color.neutral00,overflow:"truncate"},upperLabel:{show:!1,position:[0,"50%"],height:20,overflow:"truncate",verticalAlign:"middle"},itemStyle:{color:null,colorAlpha:null,colorSaturation:null,borderWidth:0,gapWidth:0,borderColor:N.color.neutral00,borderColorSaturation:null},emphasis:{upperLabel:{show:!0,position:[0,"50%"],overflow:"truncate",verticalAlign:"middle"}},visualDimension:0,visualMin:null,visualMax:null,color:[],colorAlpha:null,colorSaturation:null,colorMappingBy:"index",visibleMin:10,childrenVisibleMin:null,levels:[]},t}(Bt);function SI(r){var t=0;A(r.children,function(a){SI(a);var n=a.value;W(n)&&(n=n[0]),t+=n});var e=r.value;W(e)&&(e=e[0]),(e==null||isNaN(e))&&(e=t),e<0&&(e=0),W(r.value)?r.value[0]=e:r.value=e}function C4(r,t){var e=Ft(t.get("color")),a=Ft(t.get(["aria","decal","decals"]));if(e){r=r||[];var n,i;A(r,function(s){var l=new wt(s),u=l.get("color"),f=l.get("decal");(l.get(["itemStyle","color"])||u&&u!=="none")&&(n=!0),(l.get(["itemStyle","decal"])||f&&f!=="none")&&(i=!0)});var o=r[0]||(r[0]={});return n||(o.color=e.slice()),!i&&a&&(o.decal=a.slice()),r}}var A4=8,Gb=8,Gp=5,M4=function(){function r(t){this.group=new rt,t.add(this.group)}return r.prototype.render=function(t,e,a,n){var i=t.getModel("breadcrumb"),o=this.group;if(o.removeAll(),!(!i.get("show")||!a)){var s=i.getModel("itemStyle"),l=i.getModel("emphasis"),u=s.getModel("textStyle"),f=l.getModel(["itemStyle","textStyle"]),v=pe(t,e).refContainer,h={left:i.get("left"),right:i.get("right"),top:i.get("top"),bottom:i.get("bottom")},c={emptyItemWidth:i.get("emptyItemWidth"),totalWidth:0,renderList:[]},p=Xt(h,v);this._prepare(a,c,u),this._renderContent(t,c,p,s,l,u,f,n),Jh(o,h,v)}},r.prototype._prepare=function(t,e,a){for(var n=t;n;n=n.parentNode){var i=ve(n.getModel().get("name"),""),o=a.getTextRect(i),s=Math.max(o.width+A4*2,e.emptyItemWidth);e.totalWidth+=s+Gb,e.renderList.push({node:n,text:i,width:s})}},r.prototype._renderContent=function(t,e,a,n,i,o,s,l){for(var u=0,f=e.emptyItemWidth,v=t.get(["breadcrumb","height"]),h=e.totalWidth,c=e.renderList,p=i.getModel("itemStyle").getItemStyle(),d=c.length-1;d>=0;d--){var g=c[d],y=g.node,m=g.width,_=g.text;h>a.width&&(h-=m-f,m=f,_=null);var S=new Ee({shape:{points:D4(u,0,m,v,d===c.length-1,d===0)},style:nt(n.getItemStyle(),{lineJoin:"bevel"}),textContent:new At({style:Gt(o,{text:_})}),textConfig:{position:"inside"},z2:gs*1e4,onclick:pt(l,y)});S.disableLabelAnimation=!0,S.getTextContent().ensureState("emphasis").style=Gt(s,{text:_}),S.ensureState("emphasis").style=p,$t(S,i.get("focus"),i.get("blurScope"),i.get("disabled")),this.group.add(S),L4(S,t,y),u+=m+Gb}},r.prototype.remove=function(){this.group.removeAll()},r}();function D4(r,t,e,a,n,i){var o=[[n?r:r-Gp,t],[r+e,t],[r+e,t+a],[n?r:r-Gp,t+a]];return!i&&o.splice(2,0,[r+e+Gp,t+a/2]),!n&&o.push([r,t+a/2]),o}function L4(r,t,e){ut(r).eventData={componentType:"series",componentSubType:"treemap",componentIndex:t.componentIndex,seriesIndex:t.seriesIndex,seriesName:t.name,seriesType:"treemap",selfType:"breadcrumb",nodeData:{dataIndex:e&&e.dataIndex,name:e&&e.name},treePathInfo:e&&uc(e,t)}}var I4=function(){function r(){this._storage=[],this._elExistsMap={}}return r.prototype.add=function(t,e,a,n,i){return this._elExistsMap[t.id]?!1:(this._elExistsMap[t.id]=!0,this._storage.push({el:t,target:e,duration:a,delay:n,easing:i}),!0)},r.prototype.finished=function(t){return this._finishedCallback=t,this},r.prototype.start=function(){for(var t=this,e=this._storage.length,a=function(){e--,e<=0&&(t._storage.length=0,t._elExistsMap={},t._finishedCallback&&t._finishedCallback())},n=0,i=this._storage.length;n<i;n++){var o=this._storage[n];o.el.animateTo(o.target,{duration:o.duration,delay:o.delay,easing:o.easing,setToFinal:!0,done:a,aborted:a})}return this},r}();function P4(){return new I4}var dy=rt,Fb=_t,Hb=3,Wb="label",Ub="upperLabel",R4=gs*10,k4=gs*2,E4=gs*3,gi=Fi([["fill","color"],["stroke","strokeColor"],["lineWidth","strokeWidth"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"]]),Yb=function(r){var t=gi(r);return t.stroke=t.fill=t.lineWidth=null,t},hh=St(),O4=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e._state="ready",e._storage=al(),e}return t.prototype.render=function(e,a,n,i){var o=a.findComponents({mainType:"series",subType:"treemap",query:i});if(!(gt(o,e)<0)){this.seriesModel=e,this.api=n,this.ecModel=a;var s=["treemapZoomToNode","treemapRootToNode"],l=fu(i,s,e),u=i&&i.type,f=e.layoutInfo,v=!this._oldTree,h=this._storage,c=u==="treemapRootToNode"&&l&&h?{rootNodeGroup:h.nodeGroup[l.node.getRawIndex()],direction:i.direction}:null,p=this._giveContainerGroup(f),d=e.get("animation"),g=this._doRender(p,e,c);d&&!v&&(!u||u==="treemapZoomToNode"||u==="treemapRootToNode")?this._doAnimation(p,g,e,c):g.renderFinally(),this._resetController(n),this._renderBreadcrumb(e,n,l)}},t.prototype._giveContainerGroup=function(e){var a=this._containerGroup;return a||(a=this._containerGroup=new dy,this._initEvents(a),this.group.add(a)),a.x=e.x,a.y=e.y,a},t.prototype._doRender=function(e,a,n){var i=a.getData().tree,o=this._oldTree,s=al(),l=al(),u=this._storage,f=[];function v(m,_,S,x){return N4(a,l,u,n,s,f,m,_,S,x)}d(i.root?[i.root]:[],o&&o.root?[o.root]:[],e,i===o||!o,0);var h=g(u);if(this._oldTree=i,this._storage=l,this._controllerHost){var c=this.seriesModel.layoutInfo,p=i.root.getLayout();p.width===c.width&&p.height===c.height&&(this._controllerHost.zoom=1)}return{lastsForAnimation:s,willDeleteEls:h,renderFinally:y};function d(m,_,S,x,b){x?(_=m,A(m,function(C,M){!C.isRemoved()&&T(M,M)})):new qa(_,m,w,w).add(T).update(T).remove(pt(T,null)).execute();function w(C){return C.getId()}function T(C,M){var D=C!=null?m[C]:null,I=M!=null?_[M]:null,L=v(D,I,S,b);L&&d(D&&D.viewChildren||[],I&&I.viewChildren||[],L,x,b+1)}}function g(m){var _=al();return m&&A(m,function(S,x){var b=_[x];A(S,function(w){w&&(b.push(w),hh(w).willDelete=!0)})}),_}function y(){A(h,function(m){A(m,function(_){_.parent&&_.parent.remove(_)})}),A(f,function(m){m.invisible=!0,m.dirty()})}},t.prototype._doAnimation=function(e,a,n,i){var o=n.get("animationDurationUpdate"),s=n.get("animationEasing"),l=(tt(o)?0:o)||0,u=(tt(s)?null:s)||"cubicOut",f=P4();A(a.willDeleteEls,function(v,h){A(v,function(c,p){if(!c.invisible){var d=c.parent,g,y=hh(d);if(i&&i.direction==="drillDown")g=d===i.rootNodeGroup?{shape:{x:0,y:0,width:y.nodeWidth,height:y.nodeHeight},style:{opacity:0}}:{style:{opacity:0}};else{var m=0,_=0;y.willDelete||(m=y.nodeWidth/2,_=y.nodeHeight/2),g=h==="nodeGroup"?{x:m,y:_,style:{opacity:0}}:{shape:{x:m,y:_,width:0,height:0},style:{opacity:0}}}g&&f.add(c,g,l,0,u)}})}),A(this._storage,function(v,h){A(v,function(c,p){var d=a.lastsForAnimation[h][p],g={};d&&(c instanceof rt?d.oldX!=null&&(g.x=c.x,g.y=c.y,c.x=d.oldX,c.y=d.oldY):(d.oldShape&&(g.shape=G({},c.shape),c.setShape(d.oldShape)),d.fadein?(c.setStyle("opacity",0),g.style={opacity:1}):c.style.opacity!==1&&(g.style={opacity:1})),f.add(c,g,l,0,u))})},this),this._state="animating",f.finished($(function(){this._state="ready",a.renderFinally()},this)).start()},t.prototype._resetController=function(e){var a=this,n=this._controller,i=this._controllerHost;i||(this._controllerHost={target:this.group},i=this._controllerHost);var o=this.seriesModel;n||(n=this._controller=new ao(e.getZr()),n.on("pan",$(this._onPan,this)),n.on("zoom",$(this._onZoom,this))),n.enable(o.get("roam"),{api:e,zInfo:{component:o},triggerInfo:{roamTrigger:o.get("roamTrigger"),isInSelf:function(s,l,u){var f=a._containerGroup;return f?f.getBoundingRect().contain(l-f.x,u-f.y):!1}}}),i.zoomLimit=o.get("scaleLimit"),i.zoom=o.get("zoom")},t.prototype._clearController=function(){var e=this._controller;this._controllerHost=null,e&&(e.dispose(),e=null)},t.prototype._onPan=function(e){if(this._state!=="animating"&&(Math.abs(e.dx)>Hb||Math.abs(e.dy)>Hb)){var a=this.seriesModel.getData().tree.root;if(!a)return;var n=a.getLayout();if(!n)return;this.api.dispatchAction({type:"treemapMove",from:this.uid,seriesId:this.seriesModel.id,rootRect:{x:n.x+e.dx,y:n.y+e.dy,width:n.width,height:n.height}})}},t.prototype._onZoom=function(e){var a=e.originX,n=e.originY,i=e.scale;if(this._state!=="animating"){var o=this.seriesModel.getData().tree.root;if(!o)return;var s=o.getLayout();if(!s)return;var l=new lt(s.x,s.y,s.width,s.height),u=null,f=this._controllerHost;u=f.zoomLimit;var v=f.zoom=f.zoom||1;if(v*=i,u){var h=u.min||0,c=u.max||1/0;v=Math.max(Math.min(c,v),h)}var p=v/f.zoom;f.zoom=v;var d=this.seriesModel.layoutInfo;a-=d.x,n-=d.y;var g=me();Ur(g,g,[-a,-n]),Nh(g,g,[p,p]),Ur(g,g,[a,n]),l.applyTransform(g),this.api.dispatchAction({type:"treemapRender",from:this.uid,seriesId:this.seriesModel.id,rootRect:{x:l.x,y:l.y,width:l.width,height:l.height}})}},t.prototype._initEvents=function(e){var a=this;e.on("click",function(n){if(a._state==="ready"){var i=a.seriesModel.get("nodeClick",!0);if(i){var o=a.findTarget(n.offsetX,n.offsetY);if(o){var s=o.node;if(s.getLayout().isLeafRoot)a._rootToNode(o);else if(i==="zoomToNode")a._zoomToNode(o);else if(i==="link"){var l=s.hostTree.data.getItemModel(s.dataIndex),u=l.get("link",!0),f=l.get("target",!0)||"blank";u&&Hv(u,f)}}}}},this)},t.prototype._renderBreadcrumb=function(e,a,n){var i=this;n||(n=e.get("leafDepth",!0)!=null?{node:e.getViewRoot()}:this.findTarget(a.getWidth()/2,a.getHeight()/2),n||(n={node:e.getData().tree.root})),(this._breadcrumb||(this._breadcrumb=new M4(this.group))).render(e,a,n.node,function(o){i._state!=="animating"&&(O0(e.getViewRoot(),o)?i._rootToNode({node:o}):i._zoomToNode({node:o}))})},t.prototype.remove=function(){this._clearController(),this._containerGroup&&this._containerGroup.removeAll(),this._storage=al(),this._state="ready",this._breadcrumb&&this._breadcrumb.remove()},t.prototype.dispose=function(){this._clearController()},t.prototype._zoomToNode=function(e){this.api.dispatchAction({type:"treemapZoomToNode",from:this.uid,seriesId:this.seriesModel.id,targetNode:e.node})},t.prototype._rootToNode=function(e){this.api.dispatchAction({type:"treemapRootToNode",from:this.uid,seriesId:this.seriesModel.id,targetNode:e.node})},t.prototype.findTarget=function(e,a){var n,i=this.seriesModel.getViewRoot();return i.eachNode({attr:"viewChildren",order:"preorder"},function(o){var s=this._storage.background[o.getRawIndex()];if(s){var l=s.transformCoordToLocal(e,a),u=s.shape;if(u.x<=l[0]&&l[0]<=u.x+u.width&&u.y<=l[1]&&l[1]<=u.y+u.height)n={node:o,offsetX:l[0],offsetY:l[1]};else return!1}},this),n},t.type="treemap",t}(Nt);function al(){return{nodeGroup:[],background:[],content:[]}}function N4(r,t,e,a,n,i,o,s,l,u){if(!o)return;var f=o.getLayout(),v=r.getData(),h=o.getModel();if(v.setItemGraphicEl(o.dataIndex,null),!f||!f.isInView)return;var c=f.width,p=f.height,d=f.borderWidth,g=f.invisible,y=o.getRawIndex(),m=s&&s.getRawIndex(),_=o.viewChildren,S=f.upperHeight,x=_&&_.length,b=h.getModel("itemStyle"),w=h.getModel(["emphasis","itemStyle"]),T=h.getModel(["blur","itemStyle"]),C=h.getModel(["select","itemStyle"]),M=b.get("borderRadius")||0,D=ft("nodeGroup",dy);if(!D)return;if(l.add(D),D.x=f.x||0,D.y=f.y||0,D.markRedraw(),hh(D).nodeWidth=c,hh(D).nodeHeight=p,f.isAboveViewRoot)return D;var I=ft("background",Fb,u,k4);I&&V(D,I,x&&f.upperLabelHeight);var L=h.getModel("emphasis"),P=L.get("focus"),k=L.get("blurScope"),R=L.get("disabled"),O=P==="ancestor"?o.getAncestorsIndices():P==="descendant"?o.getDescendantIndices():P;if(x)ql(D)&&Ai(D,!1),I&&(Ai(I,!R),v.setItemGraphicEl(o.dataIndex,I),xg(I,O,k));else{var E=ft("content",Fb,u,E4);E&&F(D,E),I.disableMorphing=!0,I&&ql(I)&&Ai(I,!1),Ai(D,!R),v.setItemGraphicEl(o.dataIndex,D);var B=h.getShallow("cursor");B&&E.attr("cursor",B),xg(D,O,k)}return D;function V(vt,at,dt){var J=ut(at);if(J.dataIndex=o.dataIndex,J.seriesIndex=r.seriesIndex,at.setShape({x:0,y:0,width:c,height:p,r:M}),g)H(at);else{at.invisible=!1;var ht=o.getVisual("style"),zt=ht.stroke,Dt=Yb(b);Dt.fill=zt;var Et=gi(w);Et.fill=w.get("borderColor");var Vt=gi(T);Vt.fill=T.get("borderColor");var de=gi(C);if(de.fill=C.get("borderColor"),dt){var er=c-2*d;Y(at,zt,ht.opacity,{x:d,y:0,width:er,height:S})}else at.removeTextContent();at.setStyle(Dt),at.ensureState("emphasis").style=Et,at.ensureState("blur").style=Vt,at.ensureState("select").style=de,Hi(at)}vt.add(at)}function F(vt,at){var dt=ut(at);dt.dataIndex=o.dataIndex,dt.seriesIndex=r.seriesIndex;var J=Math.max(c-2*d,0),ht=Math.max(p-2*d,0);if(at.culling=!0,at.setShape({x:d,y:d,width:J,height:ht,r:M}),g)H(at);else{at.invisible=!1;var zt=o.getVisual("style"),Dt=zt.fill,Et=Yb(b);Et.fill=Dt,Et.decal=zt.decal;var Vt=gi(w),de=gi(T),er=gi(C);Y(at,Dt,zt.opacity,null),at.setStyle(Et),at.ensureState("emphasis").style=Vt,at.ensureState("blur").style=de,at.ensureState("select").style=er,Hi(at)}vt.add(at)}function H(vt){!vt.invisible&&i.push(vt)}function Y(vt,at,dt,J){var ht=h.getModel(J?Ub:Wb),zt=ve(h.get("name"),null),Dt=ht.getShallow("show");Se(vt,ce(h,J?Ub:Wb),{defaultText:Dt?zt:null,inheritColor:at,defaultOpacity:dt,labelFetcher:r,labelDataIndex:o.dataIndex});var Et=vt.getTextContent();if(Et){var Vt=Et.style,de=_u(Vt.padding||0);J&&(vt.setTextConfig({layoutRect:J}),Et.disableLabelLayout=!0),Et.beforeUpdate=function(){var $e=Math.max((J?J.width:vt.shape.width)-de[1]-de[3],0),Fn=Math.max((J?J.height:vt.shape.height)-de[0]-de[2],0);(Vt.width!==$e||Vt.height!==Fn)&&Et.setStyle({width:$e,height:Fn})},Vt.truncateMinChar=2,Vt.lineOverflow="truncate",K(Vt,J,f);var er=Et.getState("emphasis");K(er?er.style:null,J,f)}}function K(vt,at,dt){var J=vt?vt.text:null;if(!at&&dt.isLeafRoot&&J!=null){var ht=r.get("drillDownIcon",!0);vt.text=ht?ht+" "+J:J}}function ft(vt,at,dt,J){var ht=m!=null&&e[vt][m],zt=n[vt];return ht?(e[vt][m]=null,It(zt,ht)):g||(ht=new at,ht instanceof Lr&&(ht.z2=B4(dt,J)),Ot(zt,ht)),t[vt][y]=ht}function It(vt,at){var dt=vt[y]={};at instanceof dy?(dt.oldX=at.x,dt.oldY=at.y):dt.oldShape=G({},at.shape)}function Ot(vt,at){var dt=vt[y]={},J=o.parentNode,ht=at instanceof rt;if(J&&(!a||a.direction==="drillDown")){var zt=0,Dt=0,Et=n.background[J.getRawIndex()];!a&&Et&&Et.oldShape&&(zt=Et.oldShape.width,Dt=Et.oldShape.height),ht?(dt.oldX=0,dt.oldY=Dt):dt.oldShape={x:zt,y:Dt,width:0,height:0}}dt.fadein=!ht}}function B4(r,t){return r*R4+t}var vu=A,z4=it,ch=-1,_e=function(){function r(t){var e=t.mappingMethod,a=t.type,n=this.option=et(t);this.type=a,this.mappingMethod=e,this._normalizeData=F4[e];var i=r.visualHandlers[a];this.applyVisual=i.applyVisual,this.getColorMapper=i.getColorMapper,this._normalizedToVisual=i._normalizedToVisual[e],e==="piecewise"?(Fp(n),V4(n)):e==="category"?n.categories?G4(n):Fp(n,!0):(Re(e!=="linear"||n.dataExtent),Fp(n))}return r.prototype.mapValueToVisual=function(t){var e=this._normalizeData(t);return this._normalizedToVisual(e,t)},r.prototype.getNormalizer=function(){return $(this._normalizeData,this)},r.listVisualTypes=function(){return Ct(r.visualHandlers)},r.isValidType=function(t){return r.visualHandlers.hasOwnProperty(t)},r.eachVisual=function(t,e,a){it(t)?A(t,e,a):e.call(a,t)},r.mapVisual=function(t,e,a){var n,i=W(t)?[]:it(t)?{}:(n=!0,null);return r.eachVisual(t,function(o,s){var l=e.call(a,o,s);n?i=l:i[s]=l}),i},r.retrieveVisuals=function(t){var e={},a;return t&&vu(r.visualHandlers,function(n,i){t.hasOwnProperty(i)&&(e[i]=t[i],a=!0)}),a?e:null},r.prepareVisualTypes=function(t){if(W(t))t=t.slice();else if(z4(t)){var e=[];vu(t,function(a,n){e.push(n)}),t=e}else return[];return t.sort(function(a,n){return n==="color"&&a!=="color"&&a.indexOf("color")===0?1:-1}),t},r.dependsOn=function(t,e){return e==="color"?!!(t&&t.indexOf(e)===0):t===e},r.findPieceIndex=function(t,e,a){for(var n,i=1/0,o=0,s=e.length;o<s;o++){var l=e[o].value;if(l!=null){if(l===t||X(l)&&l===t+"")return o;a&&h(l,o)}}for(var o=0,s=e.length;o<s;o++){var u=e[o],f=u.interval,v=u.close;if(f){if(f[0]===-1/0){if(Ef(v[1],t,f[1]))return o}else if(f[1]===1/0){if(Ef(v[0],f[0],t))return o}else if(Ef(v[0],f[0],t)&&Ef(v[1],t,f[1]))return o;a&&h(f[0],o),a&&h(f[1],o)}}if(a)return t===1/0?e.length-1:t===-1/0?0:n;function h(c,p){var d=Math.abs(c-t);d<i&&(i=d,n=p)}},r.visualHandlers={color:{applyVisual:nl("color"),getColorMapper:function(){var t=this.option;return $(t.mappingMethod==="category"?function(e,a){return!a&&(e=this._normalizeData(e)),bl.call(this,e)}:function(e,a,n){var i=!!n;return!a&&(e=this._normalizeData(e)),n=Il(e,t.parsedVisual,n),i?n:Cr(n,"rgba")},this)},_normalizedToVisual:{linear:function(t){return Cr(Il(t,this.option.parsedVisual),"rgba")},category:bl,piecewise:function(t,e){var a=yy.call(this,e);return a==null&&(a=Cr(Il(t,this.option.parsedVisual),"rgba")),a},fixed:yi}},colorHue:kf(function(t,e){return Ga(t,e)}),colorSaturation:kf(function(t,e){return Ga(t,null,e)}),colorLightness:kf(function(t,e){return Ga(t,null,null,e)}),colorAlpha:kf(function(t,e){return Ul(t,e)}),decal:{applyVisual:nl("decal"),_normalizedToVisual:{linear:null,category:bl,piecewise:null,fixed:null}},opacity:{applyVisual:nl("opacity"),_normalizedToVisual:gy([0,1])},liftZ:{applyVisual:nl("liftZ"),_normalizedToVisual:{linear:yi,category:yi,piecewise:yi,fixed:yi}},symbol:{applyVisual:function(t,e,a){var n=this.mapValueToVisual(t);a("symbol",n)},_normalizedToVisual:{linear:Zb,category:bl,piecewise:function(t,e){var a=yy.call(this,e);return a==null&&(a=Zb.call(this,t)),a},fixed:yi}},symbolSize:{applyVisual:nl("symbolSize"),_normalizedToVisual:gy([0,1])}},r}();function V4(r){var t=r.pieceList;r.hasSpecialVisual=!1,A(t,function(e,a){e.originIndex=a,e.visual!=null&&(r.hasSpecialVisual=!0)})}function G4(r){var t=r.categories,e=r.categoryMap={},a=r.visual;if(vu(t,function(o,s){e[o]=s}),!W(a)){var n=[];it(a)?vu(a,function(o,s){var l=e[s];n[l??ch]=o}):n[ch]=a,a=xI(r,n)}for(var i=t.length-1;i>=0;i--)a[i]==null&&(delete e[t[i]],t.pop())}function Fp(r,t){var e=r.visual,a=[];it(e)?vu(e,function(i){a.push(i)}):e!=null&&a.push(e);var n={color:1,symbol:1};!t&&a.length===1&&!n.hasOwnProperty(r.type)&&(a[1]=a[0]),xI(r,a)}function kf(r){return{applyVisual:function(t,e,a){var n=this.mapValueToVisual(t);a("color",r(e("color"),n))},_normalizedToVisual:gy([0,1])}}function Zb(r){var t=this.option.visual;return t[Math.round(Rt(r,[0,1],[0,t.length-1],!0))]||{}}function nl(r){return function(t,e,a){a(r,this.mapValueToVisual(t))}}function bl(r){var t=this.option.visual;return t[this.option.loop&&r!==ch?r%t.length:r]}function yi(){return this.option.visual[0]}function gy(r){return{linear:function(t){return Rt(t,r,this.option.visual,!0)},category:bl,piecewise:function(t,e){var a=yy.call(this,e);return a==null&&(a=Rt(t,r,this.option.visual,!0)),a},fixed:yi}}function yy(r){var t=this.option,e=t.pieceList;if(t.hasSpecialVisual){var a=_e.findPieceIndex(r,e),n=e[a];if(n&&n.visual)return n.visual[this.type]}}function xI(r,t){return r.visual=t,r.type==="color"&&(r.parsedVisual=U(t,function(e){var a=Ve(e);return a||[0,0,0,1]})),t}var F4={linear:function(r){return Rt(r,this.option.dataExtent,[0,1],!0)},piecewise:function(r){var t=this.option.pieceList,e=_e.findPieceIndex(r,t,!0);if(e!=null)return Rt(e,[0,t.length-1],[0,1],!0)},category:function(r){var t=this.option.categories?this.option.categoryMap[r]:r;return t??ch},fixed:jt};function Ef(r,t,e){return r?t<=e:t<e}var H4="itemStyle",bI=St();const W4={seriesType:"treemap",reset:function(r){var t=r.getData().tree,e=t.root;e.isRemoved()||wI(e,{},r.getViewRoot().getAncestors(),r)}};function wI(r,t,e,a){var n=r.getModel(),i=r.getLayout(),o=r.hostTree.data;if(!(!i||i.invisible||!i.isInView)){var s=n.getModel(H4),l=U4(s,t,a),u=o.ensureUniqueItemVisual(r.dataIndex,"style"),f=s.get("borderColor"),v=s.get("borderColorSaturation"),h;v!=null&&(h=Xb(l),f=Y4(v,h)),u.stroke=f;var c=r.viewChildren;if(!c||!c.length)h=Xb(l),u.fill=h;else{var p=Z4(r,n,i,s,l,c);A(c,function(d,g){if(d.depth>=e.length||d===e[d.depth]){var y=X4(n,l,d,g,p,a);wI(d,y,e,a)}})}}}function U4(r,t,e){var a=G({},t),n=e.designatedVisualItemStyle;return A(["color","colorAlpha","colorSaturation"],function(i){n[i]=t[i];var o=r.get(i);n[i]=null,o!=null&&(a[i]=o)}),a}function Xb(r){var t=Hp(r,"color");if(t){var e=Hp(r,"colorAlpha"),a=Hp(r,"colorSaturation");return a&&(t=Ga(t,null,null,a)),e&&(t=Ul(t,e)),t}}function Y4(r,t){return t!=null?Ga(t,null,null,r):null}function Hp(r,t){var e=r[t];if(e!=null&&e!=="none")return e}function Z4(r,t,e,a,n,i){if(!(!i||!i.length)){var o=Wp(t,"color")||n.color!=null&&n.color!=="none"&&(Wp(t,"colorAlpha")||Wp(t,"colorSaturation"));if(o){var s=t.get("visualMin"),l=t.get("visualMax"),u=e.dataExtent.slice();s!=null&&s<u[0]&&(u[0]=s),l!=null&&l>u[1]&&(u[1]=l);var f=t.get("colorMappingBy"),v={type:o.name,dataExtent:u,visual:o.range};v.type==="color"&&(f==="index"||f==="id")?(v.mappingMethod="category",v.loop=!0):v.mappingMethod="linear";var h=new _e(v);return bI(h).drColorMappingBy=f,h}}}function Wp(r,t){var e=r.get(t);return W(e)&&e.length?{name:t,range:e}:null}function X4(r,t,e,a,n,i){var o=G({},t);if(n){var s=n.type,l=s==="color"&&bI(n).drColorMappingBy,u=l==="index"?a:l==="id"?i.mapIdToIndex(e.getId()):e.getValue(r.get("visualDimension"));o[s]=n.mapValueToVisual(u)}return o}var hu=Math.max,ph=Math.min,$b=Ce,N0=A,TI=["itemStyle","borderWidth"],$4=["itemStyle","gapWidth"],q4=["upperLabel","show"],K4=["upperLabel","height"];const j4={seriesType:"treemap",reset:function(r,t,e,a){var n=r.option,i=pe(r,e).refContainer,o=Xt(r.getBoxLayoutParams(),i),s=n.size||[],l=Z($b(o.width,s[0]),i.width),u=Z($b(o.height,s[1]),i.height),f=a&&a.type,v=["treemapZoomToNode","treemapRootToNode"],h=fu(a,v,r),c=f==="treemapRender"||f==="treemapMove"?a.rootRect:null,p=r.getViewRoot(),d=mI(p);if(f!=="treemapMove"){var g=f==="treemapZoomToNode"?aW(r,h,p,l,u):c?[c.width,c.height]:[l,u],y=n.sort;y&&y!=="asc"&&y!=="desc"&&(y="desc");var m={squareRatio:n.squareRatio,sort:y,leafDepth:n.leafDepth};p.hostTree.clearLayouts();var _={x:0,y:0,width:g[0],height:g[1],area:g[0]*g[1]};p.setLayout(_),CI(p,m,!1,0),_=p.getLayout(),N0(d,function(x,b){var w=(d[b+1]||p).getValue();x.setLayout(G({dataExtent:[w,w],borderWidth:0,upperHeight:0},_))})}var S=r.getData().tree.root;S.setLayout(nW(o,c,h),!0),r.setLayoutInfo(o),AI(S,new lt(-o.x,-o.y,e.getWidth(),e.getHeight()),d,p,0)}};function CI(r,t,e,a){var n,i;if(!r.isRemoved()){var o=r.getLayout();n=o.width,i=o.height;var s=r.getModel(),l=s.get(TI),u=s.get($4)/2,f=MI(s),v=Math.max(l,f),h=l-u,c=v-u;r.setLayout({borderWidth:l,upperHeight:v,upperLabelHeight:f},!0),n=hu(n-2*h,0),i=hu(i-h-c,0);var p=n*i,d=J4(r,s,p,t,e,a);if(d.length){var g={x:h,y:c,width:n,height:i},y=ph(n,i),m=1/0,_=[];_.area=0;for(var S=0,x=d.length;S<x;){var b=d[S];_.push(b),_.area+=b.getLayout().area;var w=rW(_,y,t.squareRatio);w<=m?(S++,m=w):(_.area-=_.pop().getLayout().area,qb(_,y,g,u,!1),y=ph(g.width,g.height),_.length=_.area=0,m=1/0)}if(_.length&&qb(_,y,g,u,!0),!e){var T=s.get("childrenVisibleMin");T!=null&&p<T&&(e=!0)}for(var S=0,x=d.length;S<x;S++)CI(d[S],t,e,a+1)}}}function J4(r,t,e,a,n,i){var o=r.children||[],s=a.sort;s!=="asc"&&s!=="desc"&&(s=null);var l=a.leafDepth!=null&&a.leafDepth<=i;if(n&&!l)return r.viewChildren=[];o=Pt(o,function(c){return!c.isRemoved()}),tW(o,s);var u=eW(t,o,s);if(u.sum===0)return r.viewChildren=[];if(u.sum=Q4(t,e,u.sum,s,o),u.sum===0)return r.viewChildren=[];for(var f=0,v=o.length;f<v;f++){var h=o[f].getValue()/u.sum*e;o[f].setLayout({area:h})}return l&&(o.length&&r.setLayout({isLeafRoot:!0},!0),o.length=0),r.viewChildren=o,r.setLayout({dataExtent:u.dataExtent},!0),o}function Q4(r,t,e,a,n){if(!a)return e;for(var i=r.get("visibleMin"),o=n.length,s=o,l=o-1;l>=0;l--){var u=n[a==="asc"?o-l-1:l].getValue();u/e*t<i&&(s=l,e-=u)}return a==="asc"?n.splice(0,o-s):n.splice(s,o-s),e}function tW(r,t){return t&&r.sort(function(e,a){var n=t==="asc"?e.getValue()-a.getValue():a.getValue()-e.getValue();return n===0?t==="asc"?e.dataIndex-a.dataIndex:a.dataIndex-e.dataIndex:n}),r}function eW(r,t,e){for(var a=0,n=0,i=t.length;n<i;n++)a+=t[n].getValue();var o=r.get("visualDimension"),s;return!t||!t.length?s=[NaN,NaN]:o==="value"&&e?(s=[t[t.length-1].getValue(),t[0].getValue()],e==="asc"&&s.reverse()):(s=[1/0,-1/0],N0(t,function(l){var u=l.getValue(o);u<s[0]&&(s[0]=u),u>s[1]&&(s[1]=u)})),{sum:a,dataExtent:s}}function rW(r,t,e){for(var a=0,n=1/0,i=0,o=void 0,s=r.length;i<s;i++)o=r[i].getLayout().area,o&&(o<n&&(n=o),o>a&&(a=o));var l=r.area*r.area,u=t*t*e;return l?hu(u*a/l,l/(u*n)):1/0}function qb(r,t,e,a,n){var i=t===e.width?0:1,o=1-i,s=["x","y"],l=["width","height"],u=e[s[i]],f=t?r.area/t:0;(n||f>e[l[o]])&&(f=e[l[o]]);for(var v=0,h=r.length;v<h;v++){var c=r[v],p={},d=f?c.getLayout().area/f:0,g=p[l[o]]=hu(f-2*a,0),y=e[s[i]]+e[l[i]]-u,m=v===h-1||y<d?y:d,_=p[l[i]]=hu(m-2*a,0);p[s[o]]=e[s[o]]+ph(a,g/2),p[s[i]]=u+ph(a,_/2),u+=m,c.setLayout(p,!0)}e[s[o]]+=f,e[l[o]]-=f}function aW(r,t,e,a,n){var i=(t||{}).node,o=[a,n];if(!i||i===e)return o;for(var s,l=a*n,u=l*r.option.zoomToNodeRatio;s=i.parentNode;){for(var f=0,v=s.children,h=0,c=v.length;h<c;h++)f+=v[h].getValue();var p=i.getValue();if(p===0)return o;u*=f/p;var d=s.getModel(),g=d.get(TI),y=Math.max(g,MI(d));u+=4*g*g+(3*g+y)*Math.pow(u,.5),u>fg&&(u=fg),i=s}u<l&&(u=l);var m=Math.pow(u/l,.5);return[a*m,n*m]}function nW(r,t,e){if(t)return{x:t.x,y:t.y};var a={x:0,y:0};if(!e)return a;var n=e.node,i=n.getLayout();if(!i)return a;for(var o=[i.width/2,i.height/2],s=n;s;){var l=s.getLayout();o[0]+=l.x,o[1]+=l.y,s=s.parentNode}return{x:r.width/2-o[0],y:r.height/2-o[1]}}function AI(r,t,e,a,n){var i=r.getLayout(),o=e[n],s=o&&o===r;if(!(o&&!s||n===e.length&&r!==a)){r.setLayout({isInView:!0,invisible:!s&&!t.intersect(i),isAboveViewRoot:s},!0);var l=new lt(t.x-i.x,t.y-i.y,t.width,t.height);N0(r.viewChildren||[],function(u){AI(u,l,e,a,n+1)})}}function MI(r){return r.get(q4)?r.get(K4):0}function iW(r){r.registerSeriesModel(T4),r.registerChartView(O4),r.registerVisual(W4),r.registerLayout(j4),w4(r)}function oW(r){var t=r.findComponents({mainType:"legend"});!t||!t.length||r.eachSeriesByType("graph",function(e){var a=e.getCategoriesData(),n=e.getGraph(),i=n.data,o=a.mapArray(a.getName);i.filterSelf(function(s){var l=i.getItemModel(s),u=l.getShallow("category");if(u!=null){Mt(u)&&(u=o[u]);for(var f=0;f<t.length;f++)if(!t[f].isSelected(u))return!1}return!0})})}function sW(r){var t={};r.eachSeriesByType("graph",function(e){var a=e.getCategoriesData(),n=e.getData(),i={};a.each(function(o){var s=a.getName(o);i["ec-"+s]=o;var l=a.getItemModel(o),u=l.getModel("itemStyle").getItemStyle();u.fill||(u.fill=e.getColorFromPalette(s,t)),a.setItemVisual(o,"style",u);for(var f=["symbol","symbolSize","symbolKeepAspect"],v=0;v<f.length;v++){var h=l.getShallow(f[v],!0);h!=null&&a.setItemVisual(o,f[v],h)}}),a.count()&&n.each(function(o){var s=n.getItemModel(o),l=s.getShallow("category");if(l!=null){X(l)&&(l=i["ec-"+l]);var u=a.getItemVisual(l,"style"),f=n.ensureUniqueItemVisual(o,"style");G(f,u);for(var v=["symbol","symbolSize","symbolKeepAspect"],h=0;h<v.length;h++)n.setItemVisual(o,v[h],a.getItemVisual(l,v[h]))}})})}function Of(r){return r instanceof Array||(r=[r,r]),r}function lW(r){r.eachSeriesByType("graph",function(t){var e=t.getGraph(),a=t.getEdgeData(),n=Of(t.get("edgeSymbol")),i=Of(t.get("edgeSymbolSize"));a.setVisual("fromSymbol",n&&n[0]),a.setVisual("toSymbol",n&&n[1]),a.setVisual("fromSymbolSize",i&&i[0]),a.setVisual("toSymbolSize",i&&i[1]),a.setVisual("style",t.getModel("lineStyle").getLineStyle()),a.each(function(o){var s=a.getItemModel(o),l=e.getEdgeByIndex(o),u=Of(s.getShallow("symbol",!0)),f=Of(s.getShallow("symbolSize",!0)),v=s.getModel("lineStyle").getLineStyle(),h=a.ensureUniqueItemVisual(o,"style");switch(G(h,v),h.stroke){case"source":{var c=l.node1.getVisual("style");h.stroke=c&&c.fill;break}case"target":{var c=l.node2.getVisual("style");h.stroke=c&&c.fill;break}}u[0]&&l.setVisual("fromSymbol",u[0]),u[1]&&l.setVisual("toSymbol",u[1]),f[0]&&l.setVisual("fromSymbolSize",f[0]),f[1]&&l.setVisual("toSymbolSize",f[1])})})}var my="-->",fc=function(r){return r.get("autoCurveness")||null},DI=function(r,t){var e=fc(r),a=20,n=[];if(Mt(e))a=e;else if(W(e)){r.__curvenessList=e;return}t>a&&(a=t);var i=a%2?a+2:a+3;n=[];for(var o=0;o<i;o++)n.push((o%2?o+1:o)/10*(o%2?-1:1));r.__curvenessList=n},cu=function(r,t,e){var a=[r.id,r.dataIndex].join("."),n=[t.id,t.dataIndex].join(".");return[e.uid,a,n].join(my)},LI=function(r){var t=r.split(my);return[t[0],t[2],t[1]].join(my)},uW=function(r,t){var e=cu(r.node1,r.node2,t);return t.__edgeMap[e]},fW=function(r,t){var e=_y(cu(r.node1,r.node2,t),t),a=_y(cu(r.node2,r.node1,t),t);return e+a},_y=function(r,t){var e=t.__edgeMap;return e[r]?e[r].length:0};function vW(r){fc(r)&&(r.__curvenessList=[],r.__edgeMap={},DI(r))}function hW(r,t,e,a){if(fc(e)){var n=cu(r,t,e),i=e.__edgeMap,o=i[LI(n)];i[n]&&!o?i[n].isForward=!0:o&&i[n]&&(o.isForward=!0,i[n].isForward=!1),i[n]=i[n]||[],i[n].push(a)}}function B0(r,t,e,a){var n=fc(t),i=W(n);if(!n)return null;var o=uW(r,t);if(!o)return null;for(var s=-1,l=0;l<o.length;l++)if(o[l]===e){s=l;break}var u=fW(r,t);DI(t,u),r.lineStyle=r.lineStyle||{};var f=cu(r.node1,r.node2,t),v=t.__curvenessList,h=i||u%2?0:1;if(o.isForward)return v[h+s];var c=LI(f),p=_y(c,t),d=v[s+p+h];return a?i?n&&n[0]===0?(p+h)%2?d:-d:((p%2?0:1)+h)%2?d:-d:(p+h)%2?d:-d:v[s+p+h]}function II(r){var t=r.coordinateSystem;if(!(t&&t.type!=="view")){var e=r.getGraph();e.eachNode(function(a){var n=a.getModel();a.setLayout([+n.get("x"),+n.get("y")])}),z0(e,r)}}function z0(r,t){r.eachEdge(function(e,a){var n=Qe(e.getModel().get(["lineStyle","curveness"]),-B0(e,t,a,!0),0),i=ca(e.node1.getLayout()),o=ca(e.node2.getLayout()),s=[i,o];+n&&s.push([(i[0]+o[0])/2-(i[1]-o[1])*n,(i[1]+o[1])/2-(o[0]-i[0])*n]),e.setLayout(s)})}function cW(r,t){r.eachSeriesByType("graph",function(e){var a=e.get("layout"),n=e.coordinateSystem;if(n&&n.type!=="view"){var i=e.getData(),o=[];A(n.dimensions,function(h){o=o.concat(i.mapDimensionsAll(h))});for(var s=0;s<i.count();s++){for(var l=[],u=!1,f=0;f<o.length;f++){var v=i.get(o[f],s);isNaN(v)||(u=!0),l.push(v)}u?i.setItemLayout(s,n.dataToPoint(l)):i.setItemLayout(s,[NaN,NaN])}z0(i.graph,e)}else(!a||a==="none")&&II(e)})}function wl(r){var t=r.coordinateSystem;if(t.type!=="view")return 1;var e=r.option.nodeScaleRatio,a=t.scaleX,n=t.getZoom(),i=(n-1)*e+1;return i/a}function Tl(r){var t=r.getVisual("symbolSize");return t instanceof Array&&(t=(t[0]+t[1])/2),+t}var Kb=Math.PI,Up=[];function V0(r,t,e,a){var n=r.coordinateSystem;if(!(n&&n.type!=="view")){var i=n.getBoundingRect(),o=r.getData(),s=o.graph,l=i.width/2+i.x,u=i.height/2+i.y,f=Math.min(i.width,i.height)/2,v=o.count();if(o.setLayout({cx:l,cy:u}),!!v){if(e){var h=n.pointToData(a),c=h[0],p=h[1],d=[c-l,p-u];qi(d,d),Al(d,d,f),e.setLayout([l+d[0],u+d[1]],!0);var g=r.get(["circular","rotateLabel"]);PI(e,g,l,u)}pW[t](r,s,o,f,l,u,v),s.eachEdge(function(y,m){var _=Qe(y.getModel().get(["lineStyle","curveness"]),B0(y,r,m),0),S=ca(y.node1.getLayout()),x=ca(y.node2.getLayout()),b,w=(S[0]+x[0])/2,T=(S[1]+x[1])/2;+_&&(_*=3,b=[l*_+w*(1-_),u*_+T*(1-_)]),y.setLayout([S,x,b])})}}}var pW={value:function(r,t,e,a,n,i,o){var s=0,l=e.getSum("value"),u=Math.PI*2/(l||o);t.eachNode(function(f){var v=f.getValue("value"),h=u*(l?v:1)/2;s+=h,f.setLayout([a*Math.cos(s)+n,a*Math.sin(s)+i]),s+=h})},symbolSize:function(r,t,e,a,n,i,o){var s=0;Up.length=o;var l=wl(r);t.eachNode(function(v){var h=Tl(v);isNaN(h)&&(h=2),h<0&&(h=0),h*=l;var c=Math.asin(h/2/a);isNaN(c)&&(c=Kb/2),Up[v.dataIndex]=c,s+=c*2});var u=(2*Kb-s)/o/2,f=0;t.eachNode(function(v){var h=u+Up[v.dataIndex];f+=h,(!v.getLayout()||!v.getLayout().fixed)&&v.setLayout([a*Math.cos(f)+n,a*Math.sin(f)+i]),f+=h})}};function PI(r,t,e,a){var n=r.getGraphicEl();if(n){var i=r.getModel(),o=i.get(["label","rotate"])||0,s=n.getSymbolPath();if(t){var l=r.getLayout(),u=Math.atan2(l[1]-a,l[0]-e);u<0&&(u=Math.PI*2+u);var f=l[0]<e;f&&(u=u-Math.PI);var v=f?"left":"right";s.setTextConfig({rotation:-u,position:v,origin:"center"});var h=s.ensureState("emphasis");G(h.textConfig||(h.textConfig={}),{position:v})}else s.setTextConfig({rotation:o*=Math.PI/180})}}function dW(r){r.eachSeriesByType("graph",function(t){t.get("layout")==="circular"&&V0(t,"symbolSize")})}var wo=bv;function gW(r,t,e){for(var a=r,n=t,i=e.rect,o=i.width,s=i.height,l=[i.x+o/2,i.y+s/2],u=e.gravity==null?.1:e.gravity,f=0;f<a.length;f++){var v=a[f];v.p||(v.p=Bn(o*(Math.random()-.5)+l[0],s*(Math.random()-.5)+l[1])),v.pp=ca(v.p),v.edges=null}var h=e.friction==null?.6:e.friction,c=h,p,d;return{warmUp:function(){c=h*.8},setFixed:function(g){a[g].fixed=!0},setUnfixed:function(g){a[g].fixed=!1},beforeStep:function(g){p=g},afterStep:function(g){d=g},step:function(g){p&&p(a,n);for(var y=[],m=a.length,_=0;_<n.length;_++){var S=n[_];if(!S.ignoreForceLayout){var x=S.n1,b=S.n2;dn(y,b.p,x.p);var w=Fl(y)-S.d,T=b.w/(x.w+b.w);isNaN(T)&&(T=0),qi(y,y),!x.fixed&&wo(x.p,x.p,y,T*w*c),!b.fixed&&wo(b.p,b.p,y,-(1-T)*w*c)}}for(var _=0;_<m;_++){var C=a[_];C.fixed||(dn(y,l,C.p),wo(C.p,C.p,y,u*c))}for(var _=0;_<m;_++)for(var x=a[_],M=_+1;M<m;M++){var b=a[M];dn(y,b.p,x.p);var w=Fl(y);w===0&&(Oh(y,Math.random()-.5,Math.random()-.5),w=1);var D=(x.rep+b.rep)/w/w;!x.fixed&&wo(x.pp,x.pp,y,D),!b.fixed&&wo(b.pp,b.pp,y,-D)}for(var I=[],_=0;_<m;_++){var C=a[_];C.fixed||(dn(I,C.p,C.pp),wo(C.p,C.p,I,c),Ne(C.pp,C.p))}c=c*.992;var L=c<.01;d&&d(a,n,L),g&&g(L)}}}function yW(r){r.eachSeriesByType("graph",function(t){var e=t.coordinateSystem;if(!(e&&e.type!=="view"))if(t.get("layout")==="force"){var a=t.preservedPoints||{},n=t.getGraph(),i=n.data,o=n.edgeData,s=t.getModel("force"),l=s.get("initLayout");t.preservedPoints?i.each(function(_){var S=i.getId(_);i.setItemLayout(_,a[S]||[NaN,NaN])}):!l||l==="none"?II(t):l==="circular"&&V0(t,"value");var u=i.getDataExtent("value"),f=o.getDataExtent("value"),v=s.get("repulsion"),h=s.get("edgeLength"),c=W(v)?v:[v,v],p=W(h)?h:[h,h];p=[p[1],p[0]];var d=i.mapArray("value",function(_,S){var x=i.getItemLayout(S),b=Rt(_,u,c);return isNaN(b)&&(b=(c[0]+c[1])/2),{w:b,rep:b,fixed:i.getItemModel(S).get("fixed"),p:!x||isNaN(x[0])||isNaN(x[1])?null:x}}),g=o.mapArray("value",function(_,S){var x=n.getEdgeByIndex(S),b=Rt(_,f,p);isNaN(b)&&(b=(p[0]+p[1])/2);var w=x.getModel(),T=Qe(x.getModel().get(["lineStyle","curveness"]),-B0(x,t,S,!0),0);return{n1:d[x.node1.dataIndex],n2:d[x.node2.dataIndex],d:b,curveness:T,ignoreForceLayout:w.get("ignoreForceLayout")}}),y=e.getBoundingRect(),m=gW(d,g,{rect:y,gravity:s.get("gravity"),friction:s.get("friction")});m.beforeStep(function(_,S){for(var x=0,b=_.length;x<b;x++)_[x].fixed&&Ne(_[x].p,n.getNodeByIndex(x).getLayout())}),m.afterStep(function(_,S,x){for(var b=0,w=_.length;b<w;b++)_[b].fixed||n.getNodeByIndex(b).setLayout(_[b].p),a[i.getId(b)]=_[b].p;for(var b=0,w=S.length;b<w;b++){var T=S[b],C=n.getEdgeByIndex(b),M=T.n1.p,D=T.n2.p,I=C.getLayout();I=I?I.slice():[],I[0]=I[0]||[],I[1]=I[1]||[],Ne(I[0],M),Ne(I[1],D),+T.curveness&&(I[2]=[(M[0]+D[0])/2-(M[1]-D[1])*T.curveness,(M[1]+D[1])/2-(D[0]-M[0])*T.curveness]),C.setLayout(I)}}),t.forceLayout=m,t.preservedPoints=a,m.step()}else t.forceLayout=null})}function mW(r,t,e){var a=pe(r,t),n=G(r.getBoxLayoutParams(),{aspect:e}),i=Xt(n,a.refContainer);return sD(r,i,e)}function _W(r,t){var e=[];return r.eachSeriesByType("graph",function(a){Iu({targetModel:a,coordSysType:"view",coordSysProvider:n,isDefaultDataCoordSys:!0});function n(){var i=a.getData(),o=i.mapArray(function(p){var d=i.getItemModel(p);return[+d.get("x"),+d.get("y")]}),s=[],l=[];Uh(o,s,l),l[0]-s[0]===0&&(l[0]+=1,s[0]-=1),l[1]-s[1]===0&&(l[1]+=1,s[1]-=1);var u=(l[0]-s[0])/(l[1]-s[1]),f=mW(a,t,u);isNaN(u)&&(s=[f.x,f.y],l=[f.x+f.width,f.y+f.height]);var v=l[0]-s[0],h=l[1]-s[1],c=new no(null,{api:t,ecModel:r});return c.zoomLimit=a.get("scaleLimit"),c.setBoundingRect(s[0],s[1],v,h),c.setViewRect(f.x,f.y,f.width,f.height),c.setCenter(a.get("center")),c.setZoom(a.get("zoom")),e.push(c),c}}),e}var jb=ne.prototype,Yp=ms.prototype,RI=function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.percent=1}return r}();(function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t})(RI);function Zp(r){return isNaN(+r.cpx1)||isNaN(+r.cpy1)}var kI=function(r){z(t,r);function t(e){var a=r.call(this,e)||this;return a.type="ec-line",a}return t.prototype.getDefaultStyle=function(){return{stroke:N.color.neutral99,fill:null}},t.prototype.getDefaultShape=function(){return new RI},t.prototype.buildPath=function(e,a){Zp(a)?jb.buildPath.call(this,e,a):Yp.buildPath.call(this,e,a)},t.prototype.pointAt=function(e){return Zp(this.shape)?jb.pointAt.call(this,e):Yp.pointAt.call(this,e)},t.prototype.tangentAt=function(e){var a=this.shape,n=Zp(a)?[a.x2-a.x1,a.y2-a.y1]:Yp.tangentAt.call(this,e);return qi(n,n)},t}(bt),Xp=["fromSymbol","toSymbol"];function Jb(r){return"_"+r+"Type"}function Qb(r,t,e){var a=t.getItemVisual(e,r);if(!a||a==="none")return a;var n=t.getItemVisual(e,r+"Size"),i=t.getItemVisual(e,r+"Rotate"),o=t.getItemVisual(e,r+"Offset"),s=t.getItemVisual(e,r+"KeepAspect"),l=Ms(n),u=to(o||0,l);return a+l+u+(i||"")+(s||"")}function tw(r,t,e){var a=t.getItemVisual(e,r);if(!(!a||a==="none")){var n=t.getItemVisual(e,r+"Size"),i=t.getItemVisual(e,r+"Rotate"),o=t.getItemVisual(e,r+"Offset"),s=t.getItemVisual(e,r+"KeepAspect"),l=Ms(n),u=to(o||0,l),f=ie(a,-l[0]/2+u[0],-l[1]/2+u[1],l[0],l[1],null,s);return f.__specifiedRotation=i==null||isNaN(i)?void 0:+i*Math.PI/180||0,f.name=r,f}}function SW(r){var t=new kI({name:"line",subPixelOptimize:!0});return Sy(t.shape,r),t}function Sy(r,t){r.x1=t[0][0],r.y1=t[0][1],r.x2=t[1][0],r.y2=t[1][1],r.percent=1;var e=t[2];e?(r.cpx1=e[0],r.cpy1=e[1]):(r.cpx1=NaN,r.cpy1=NaN)}var G0=function(r){z(t,r);function t(e,a,n){var i=r.call(this)||this;return i._createLine(e,a,n),i}return t.prototype._createLine=function(e,a,n){var i=e.hostModel,o=e.getItemLayout(a),s=e.getItemVisual(a,"z2"),l=SW(o);l.shape.percent=0,Yt(l,{z2:Q(s,0),shape:{percent:1}},i,a),this.add(l),A(Xp,function(u){var f=tw(u,e,a);this.add(f),this[Jb(u)]=Qb(u,e,a)},this),this._updateCommonStl(e,a,n)},t.prototype.updateData=function(e,a,n){var i=e.hostModel,o=this.childOfName("line"),s=e.getItemLayout(a),l={shape:{}};Sy(l.shape,s),Lt(o,l,i,a),A(Xp,function(u){var f=Qb(u,e,a),v=Jb(u);if(this[v]!==f){this.remove(this.childOfName(u));var h=tw(u,e,a);this.add(h)}this[v]=f},this),this._updateCommonStl(e,a,n)},t.prototype.getLinePath=function(){return this.childAt(0)},t.prototype._updateCommonStl=function(e,a,n){var i=e.hostModel,o=this.childOfName("line"),s=n&&n.emphasisLineStyle,l=n&&n.blurLineStyle,u=n&&n.selectLineStyle,f=n&&n.labelStatesModels,v=n&&n.emphasisDisabled,h=n&&n.focus,c=n&&n.blurScope;if(!n||e.hasItemOption){var p=e.getItemModel(a),d=p.getModel("emphasis");s=d.getModel("lineStyle").getLineStyle(),l=p.getModel(["blur","lineStyle"]).getLineStyle(),u=p.getModel(["select","lineStyle"]).getLineStyle(),v=d.get("disabled"),h=d.get("focus"),c=d.get("blurScope"),f=ce(p)}var g=e.getItemVisual(a,"style"),y=g.stroke;o.useStyle(g),o.style.fill=null,o.style.strokeNoScale=!0,o.ensureState("emphasis").style=s,o.ensureState("blur").style=l,o.ensureState("select").style=u,A(Xp,function(b){var w=this.childOfName(b);if(w){w.setColor(y),w.style.opacity=g.opacity;for(var T=0;T<Xe.length;T++){var C=Xe[T],M=o.getState(C);if(M){var D=M.style||{},I=w.ensureState(C),L=I.style||(I.style={});D.stroke!=null&&(L[w.__isEmptyBrush?"stroke":"fill"]=D.stroke),D.opacity!=null&&(L.opacity=D.opacity)}}w.markRedraw()}},this);var m=i.getRawValue(a);Se(this,f,{labelDataIndex:a,labelFetcher:{getFormattedLabel:function(b,w){return i.getFormattedLabel(b,w,e.dataType)}},inheritColor:y||N.color.neutral99,defaultOpacity:g.opacity,defaultText:(m==null?e.getName(a):isFinite(m)?ae(m):m)+""});var _=this.getTextContent();if(_){var S=f.normal;_.__align=_.style.align,_.__verticalAlign=_.style.verticalAlign,_.__position=S.get("position")||"middle";var x=S.get("distance");W(x)||(x=[x,x]),_.__labelDistance=x}this.setTextConfig({position:null,local:!0,inside:!1}),$t(this,h,c,v)},t.prototype.highlight=function(){Xa(this)},t.prototype.downplay=function(){$a(this)},t.prototype.updateLayout=function(e,a){this.setLinePoints(e.getItemLayout(a))},t.prototype.setLinePoints=function(e){var a=this.childOfName("line");Sy(a.shape,e),a.dirty()},t.prototype.beforeUpdate=function(){var e=this,a=e.childOfName("fromSymbol"),n=e.childOfName("toSymbol"),i=e.getTextContent();if(!a&&!n&&(!i||i.ignore))return;for(var o=1,s=this.parent;s;)s.scaleX&&(o/=s.scaleX),s=s.parent;var l=e.childOfName("line");if(!this.__dirty&&!l.__dirty)return;var u=l.shape.percent,f=l.pointAt(0),v=l.pointAt(u),h=dn([],v,f);qi(h,h);function c(M,D){var I=M.__specifiedRotation;if(I==null){var L=l.tangentAt(D);M.attr("rotation",(D===1?-1:1)*Math.PI/2-Math.atan2(L[1],L[0]))}else M.attr("rotation",I)}if(a&&(a.setPosition(f),c(a,0),a.scaleX=a.scaleY=o*u,a.markRedraw()),n&&(n.setPosition(v),c(n,1),n.scaleX=n.scaleY=o*u,n.markRedraw()),i&&!i.ignore){i.x=i.y=0,i.originX=i.originY=0;var p=void 0,d=void 0,g=i.__labelDistance,y=g[0]*o,m=g[1]*o,_=u/2,S=l.tangentAt(_),x=[S[1],-S[0]],b=l.pointAt(_);x[1]>0&&(x[0]=-x[0],x[1]=-x[1]);var w=S[0]<0?-1:1;if(i.__position!=="start"&&i.__position!=="end"){var T=-Math.atan2(S[1],S[0]);v[0]<f[0]&&(T=Math.PI+T),i.rotation=T}var C=void 0;switch(i.__position){case"insideStartTop":case"insideMiddleTop":case"insideEndTop":case"middle":C=-m,d="bottom";break;case"insideStartBottom":case"insideMiddleBottom":case"insideEndBottom":C=m,d="top";break;default:C=0,d="middle"}switch(i.__position){case"end":i.x=h[0]*y+v[0],i.y=h[1]*m+v[1],p=h[0]>.8?"left":h[0]<-.8?"right":"center",d=h[1]>.8?"top":h[1]<-.8?"bottom":"middle";break;case"start":i.x=-h[0]*y+f[0],i.y=-h[1]*m+f[1],p=h[0]>.8?"right":h[0]<-.8?"left":"center",d=h[1]>.8?"bottom":h[1]<-.8?"top":"middle";break;case"insideStartTop":case"insideStart":case"insideStartBottom":i.x=y*w+f[0],i.y=f[1]+C,p=S[0]<0?"right":"left",i.originX=-y*w,i.originY=-C;break;case"insideMiddleTop":case"insideMiddle":case"insideMiddleBottom":case"middle":i.x=b[0],i.y=b[1]+C,p="center",i.originY=-C;break;case"insideEndTop":case"insideEnd":case"insideEndBottom":i.x=-y*w+v[0],i.y=v[1]+C,p=S[0]>=0?"right":"left",i.originX=y*w,i.originY=-C;break}i.scaleX=i.scaleY=o,i.setStyle({verticalAlign:i.__verticalAlign||d,align:i.__align||p})}},t}(rt),F0=function(){function r(t){this.group=new rt,this._LineCtor=t||G0}return r.prototype.updateData=function(t){var e=this;this._progressiveEls=null;var a=this,n=a.group,i=a._lineData;a._lineData=t,i||n.removeAll();var o=ew(t);t.diff(i).add(function(s){e._doAdd(t,s,o)}).update(function(s,l){e._doUpdate(i,t,l,s,o)}).remove(function(s){n.remove(i.getItemGraphicEl(s))}).execute()},r.prototype.updateLayout=function(){var t=this._lineData;t&&t.eachItemGraphicEl(function(e,a){e.updateLayout(t,a)},this)},r.prototype.incrementalPrepareUpdate=function(t){this._seriesScope=ew(t),this._lineData=null,this.group.removeAll()},r.prototype.incrementalUpdate=function(t,e){this._progressiveEls=[];function a(s){!s.isGroup&&!xW(s)&&(s.incremental=!0,s.ensureState("emphasis").hoverLayer=!0)}for(var n=t.start;n<t.end;n++){var i=e.getItemLayout(n);if($p(i)){var o=new this._LineCtor(e,n,this._seriesScope);o.traverse(a),this.group.add(o),e.setItemGraphicEl(n,o),this._progressiveEls.push(o)}}},r.prototype.remove=function(){this.group.removeAll()},r.prototype.eachRendered=function(t){zn(this._progressiveEls||this.group,t)},r.prototype._doAdd=function(t,e,a){var n=t.getItemLayout(e);if($p(n)){var i=new this._LineCtor(t,e,a);t.setItemGraphicEl(e,i),this.group.add(i)}},r.prototype._doUpdate=function(t,e,a,n,i){var o=t.getItemGraphicEl(a);if(!$p(e.getItemLayout(n))){this.group.remove(o);return}o?o.updateData(e,n,i):o=new this._LineCtor(e,n,i),e.setItemGraphicEl(n,o),this.group.add(o)},r}();function xW(r){return r.animators&&r.animators.length>0}function ew(r){var t=r.hostModel,e=t.getModel("emphasis");return{lineStyle:t.getModel("lineStyle").getLineStyle(),emphasisLineStyle:e.getModel(["lineStyle"]).getLineStyle(),blurLineStyle:t.getModel(["blur","lineStyle"]).getLineStyle(),selectLineStyle:t.getModel(["select","lineStyle"]).getLineStyle(),emphasisDisabled:e.get("disabled"),blurScope:e.get("blurScope"),focus:e.get("focus"),labelStatesModels:ce(t)}}function rw(r){return isNaN(r[0])||isNaN(r[1])}function $p(r){return r&&!rw(r[0])&&!rw(r[1])}var qp=[],Kp=[],jp=[],To=Te,Jp=bn,aw=Math.abs;function nw(r,t,e){for(var a=r[0],n=r[1],i=r[2],o=1/0,s,l=e*e,u=.1,f=.1;f<=.9;f+=.1){qp[0]=To(a[0],n[0],i[0],f),qp[1]=To(a[1],n[1],i[1],f);var v=aw(Jp(qp,t)-l);v<o&&(o=v,s=f)}for(var h=0;h<32;h++){var c=s+u;Kp[0]=To(a[0],n[0],i[0],s),Kp[1]=To(a[1],n[1],i[1],s),jp[0]=To(a[0],n[0],i[0],c),jp[1]=To(a[1],n[1],i[1],c);var v=Jp(Kp,t)-l;if(aw(v)<.01)break;var p=Jp(jp,t)-l;u/=2,v<0?p>=0?s=s+u:s=s-u:p>=0?s=s-u:s=s+u}return s}function Qp(r,t){var e=[],a=Hl,n=[[],[],[]],i=[[],[]],o=[];t/=2,r.eachEdge(function(s,l){var u=s.getLayout(),f=s.getVisual("fromSymbol"),v=s.getVisual("toSymbol");u.__original||(u.__original=[ca(u[0]),ca(u[1])],u[2]&&u.__original.push(ca(u[2])));var h=u.__original;if(u[2]!=null){if(Ne(n[0],h[0]),Ne(n[1],h[2]),Ne(n[2],h[1]),f&&f!=="none"){var c=Tl(s.node1),p=nw(n,h[0],c*t);a(n[0][0],n[1][0],n[2][0],p,e),n[0][0]=e[3],n[1][0]=e[4],a(n[0][1],n[1][1],n[2][1],p,e),n[0][1]=e[3],n[1][1]=e[4]}if(v&&v!=="none"){var c=Tl(s.node2),p=nw(n,h[1],c*t);a(n[0][0],n[1][0],n[2][0],p,e),n[1][0]=e[1],n[2][0]=e[2],a(n[0][1],n[1][1],n[2][1],p,e),n[1][1]=e[1],n[2][1]=e[2]}Ne(u[0],n[0]),Ne(u[1],n[2]),Ne(u[2],n[1])}else{if(Ne(i[0],h[0]),Ne(i[1],h[1]),dn(o,i[1],i[0]),qi(o,o),f&&f!=="none"){var c=Tl(s.node1);bv(i[0],i[0],o,c*t)}if(v&&v!=="none"){var c=Tl(s.node2);bv(i[1],i[1],o,-c*t)}Ne(u[0],i[0]),Ne(u[1],i[1])}})}var EI=St();function bW(r){if(r)return EI(r).bridge}function iw(r,t){r&&(EI(r).bridge=t)}function ow(r){return r.type==="view"}var wW=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(e,a){var n=new Eu,i=new F0,o=this.group,s=new rt;this._controller=new ao(a.getZr()),this._controllerHost={target:s},s.add(n.group),s.add(i.group),o.add(s),this._symbolDraw=n,this._lineDraw=i,this._mainGroup=s,this._firstRender=!0},t.prototype.render=function(e,a,n){var i=this,o=e.coordinateSystem,s=!1;this._model=e,this._api=n,this._active=!0;var l=this._getThumbnailInfo();l&&l.bridge.reset(n);var u=this._symbolDraw,f=this._lineDraw;if(ow(o)){var v={x:o.x,y:o.y,scaleX:o.scaleX,scaleY:o.scaleY};this._firstRender?this._mainGroup.attr(v):Lt(this._mainGroup,v,e)}Qp(e.getGraph(),wl(e));var h=e.getData();u.updateData(h);var c=e.getEdgeData();f.updateData(c),this._updateNodeAndLinkScale(),this._updateController(null,e,n),clearTimeout(this._layoutTimeout);var p=e.forceLayout,d=e.get(["force","layoutAnimation"]);p&&(s=!0,this._startForceLayoutIteration(p,n,d));var g=e.get("layout");h.graph.eachNode(function(S){var x=S.dataIndex,b=S.getGraphicEl(),w=S.getModel();if(b){b.off("drag").off("dragend");var T=w.get("draggable");T&&b.on("drag",function(M){switch(g){case"force":p.warmUp(),!i._layouting&&i._startForceLayoutIteration(p,n,d),p.setFixed(x),h.setItemLayout(x,[b.x,b.y]);break;case"circular":h.setItemLayout(x,[b.x,b.y]),S.setLayout({fixed:!0},!0),V0(e,"symbolSize",S,[M.offsetX,M.offsetY]),i.updateLayout(e);break;case"none":default:h.setItemLayout(x,[b.x,b.y]),z0(e.getGraph(),e),i.updateLayout(e);break}}).on("dragend",function(){p&&p.setUnfixed(x)}),b.setDraggable(T,!!w.get("cursor"));var C=w.get(["emphasis","focus"]);C==="adjacency"&&(ut(b).focus=S.getAdjacentDataIndices())}}),h.graph.eachEdge(function(S){var x=S.getGraphicEl(),b=S.getModel().get(["emphasis","focus"]);x&&b==="adjacency"&&(ut(x).focus={edge:[S.dataIndex],node:[S.node1.dataIndex,S.node2.dataIndex]})});var y=e.get("layout")==="circular"&&e.get(["circular","rotateLabel"]),m=h.getLayout("cx"),_=h.getLayout("cy");h.graph.eachNode(function(S){PI(S,y,m,_)}),this._firstRender=!1,s||this._renderThumbnail(e,n,this._symbolDraw,this._lineDraw)},t.prototype.dispose=function(){this.remove(),this._controller&&this._controller.dispose(),this._controllerHost=null},t.prototype._startForceLayoutIteration=function(e,a,n){var i=this,o=!1;(function s(){e.step(function(l){i.updateLayout(i._model),(l||!o)&&(o=!0,i._renderThumbnail(i._model,a,i._symbolDraw,i._lineDraw)),(i._layouting=!l)&&(n?i._layoutTimeout=setTimeout(s,16):s())})})()},t.prototype._updateController=function(e,a,n){var i=this._controller,o=this._controllerHost,s=a.coordinateSystem;if(!ow(s)){i.disable();return}i.enable(a.get("roam"),{api:n,zInfo:{component:a},triggerInfo:{roamTrigger:a.get("roamTrigger"),isInSelf:function(l,u,f){return s.containPoint([u,f])},isInClip:function(l,u,f){return!e||e.contain(u,f)}}}),o.zoomLimit=a.get("scaleLimit"),o.zoom=s.getZoom(),i.off("pan").off("zoom").on("pan",function(l){n.dispatchAction({seriesId:a.id,type:"graphRoam",dx:l.dx,dy:l.dy})}).on("zoom",function(l){n.dispatchAction({seriesId:a.id,type:"graphRoam",zoom:l.scale,originX:l.originX,originY:l.originY})})},t.prototype.updateViewOnPan=function(e,a,n){this._active&&(L0(this._controllerHost,n.dx,n.dy),this._updateThumbnailWindow())},t.prototype.updateViewOnZoom=function(e,a,n){this._active&&(I0(this._controllerHost,n.zoom,n.originX,n.originY),this._updateNodeAndLinkScale(),Qp(e.getGraph(),wl(e)),this._lineDraw.updateLayout(),a.updateLabelLayout(),this._updateThumbnailWindow())},t.prototype._updateNodeAndLinkScale=function(){var e=this._model,a=e.getData(),n=wl(e);a.eachItemGraphicEl(function(i,o){i&&i.setSymbolScale(n)})},t.prototype.updateLayout=function(e){this._active&&(Qp(e.getGraph(),wl(e)),this._symbolDraw.updateLayout(),this._lineDraw.updateLayout())},t.prototype.remove=function(){this._active=!1,clearTimeout(this._layoutTimeout),this._layouting=!1,this._layoutTimeout=null,this._symbolDraw&&this._symbolDraw.remove(),this._lineDraw&&this._lineDraw.remove(),this._controller&&this._controller.disable()},t.prototype._getThumbnailInfo=function(){var e=this._model,a=e.coordinateSystem;if(a.type==="view"){var n=bW(e);if(n)return{bridge:n,coordSys:a}}},t.prototype._updateThumbnailWindow=function(){var e=this._getThumbnailInfo();e&&e.bridge.updateWindow(e.coordSys.transform,this._api)},t.prototype._renderThumbnail=function(e,a,n,i){var o=this._getThumbnailInfo();if(o){var s=new rt,l=n.group.children(),u=i.group.children(),f=new rt,v=new rt;s.add(v),s.add(f);for(var h=0;h<l.length;h++){var c=l[h],p=c.children()[0],d=c.x,g=c.y,y=et(p.shape),m=G(y,{width:p.scaleX,height:p.scaleY,x:d-p.scaleX/2,y:g-p.scaleY/2}),_=et(p.style),S=new p.constructor({shape:m,style:_,z2:151});v.add(S)}for(var h=0;h<u.length;h++){var c=u[h],x=c.children()[0],_=et(x.style),m=et(x.shape),b=new kI({style:_,shape:m,z2:151});f.add(b)}o.bridge.renderContent({api:a,roamType:e.get("roam"),viewportRect:null,group:s,targetTrans:o.coordSys.transform})}},t.type="graph",t}(Nt);function Co(r){return"_EC_"+r}var TW=function(){function r(t){this.type="graph",this.nodes=[],this.edges=[],this._nodesMap={},this._edgesMap={},this._directed=t||!1}return r.prototype.isDirected=function(){return this._directed},r.prototype.addNode=function(t,e){t=t==null?""+e:""+t;var a=this._nodesMap;if(!a[Co(t)]){var n=new mi(t,e);return n.hostGraph=this,this.nodes.push(n),a[Co(t)]=n,n}},r.prototype.getNodeByIndex=function(t){var e=this.data.getRawIndex(t);return this.nodes[e]},r.prototype.getNodeById=function(t){return this._nodesMap[Co(t)]},r.prototype.addEdge=function(t,e,a){var n=this._nodesMap,i=this._edgesMap;if(Mt(t)&&(t=this.nodes[t]),Mt(e)&&(e=this.nodes[e]),t instanceof mi||(t=n[Co(t)]),e instanceof mi||(e=n[Co(e)]),!(!t||!e)){var o=t.id+"-"+e.id,s=new OI(t,e,a);return s.hostGraph=this,this._directed&&(t.outEdges.push(s),e.inEdges.push(s)),t.edges.push(s),t!==e&&e.edges.push(s),this.edges.push(s),i[o]=s,s}},r.prototype.getEdgeByIndex=function(t){var e=this.edgeData.getRawIndex(t);return this.edges[e]},r.prototype.getEdge=function(t,e){t instanceof mi&&(t=t.id),e instanceof mi&&(e=e.id);var a=this._edgesMap;return this._directed?a[t+"-"+e]:a[t+"-"+e]||a[e+"-"+t]},r.prototype.eachNode=function(t,e){for(var a=this.nodes,n=a.length,i=0;i<n;i++)a[i].dataIndex>=0&&t.call(e,a[i],i)},r.prototype.eachEdge=function(t,e){for(var a=this.edges,n=a.length,i=0;i<n;i++)a[i].dataIndex>=0&&a[i].node1.dataIndex>=0&&a[i].node2.dataIndex>=0&&t.call(e,a[i],i)},r.prototype.breadthFirstTraverse=function(t,e,a,n){if(e instanceof mi||(e=this._nodesMap[Co(e)]),!!e){for(var i=a==="out"?"outEdges":a==="in"?"inEdges":"edges",o=0;o<this.nodes.length;o++)this.nodes[o].__visited=!1;if(!t.call(n,e,null))for(var s=[e];s.length;)for(var l=s.shift(),u=l[i],o=0;o<u.length;o++){var f=u[o],v=f.node1===l?f.node2:f.node1;if(!v.__visited){if(t.call(n,v,l))return;s.push(v),v.__visited=!0}}}},r.prototype.update=function(){for(var t=this.data,e=this.edgeData,a=this.nodes,n=this.edges,i=0,o=a.length;i<o;i++)a[i].dataIndex=-1;for(var i=0,o=t.count();i<o;i++)a[t.getRawIndex(i)].dataIndex=i;e.filterSelf(function(s){var l=n[e.getRawIndex(s)];return l.node1.dataIndex>=0&&l.node2.dataIndex>=0});for(var i=0,o=n.length;i<o;i++)n[i].dataIndex=-1;for(var i=0,o=e.count();i<o;i++)n[e.getRawIndex(i)].dataIndex=i},r.prototype.clone=function(){for(var t=new r(this._directed),e=this.nodes,a=this.edges,n=0;n<e.length;n++)t.addNode(e[n].id,e[n].dataIndex);for(var n=0;n<a.length;n++){var i=a[n];t.addEdge(i.node1.id,i.node2.id,i.dataIndex)}return t},r}(),mi=function(){function r(t,e){this.inEdges=[],this.outEdges=[],this.edges=[],this.dataIndex=-1,this.id=t??"",this.dataIndex=e??-1}return r.prototype.degree=function(){return this.edges.length},r.prototype.inDegree=function(){return this.inEdges.length},r.prototype.outDegree=function(){return this.outEdges.length},r.prototype.getModel=function(t){if(!(this.dataIndex<0)){var e=this.hostGraph,a=e.data.getItemModel(this.dataIndex);return a.getModel(t)}},r.prototype.getAdjacentDataIndices=function(){for(var t={edge:[],node:[]},e=0;e<this.edges.length;e++){var a=this.edges[e];a.dataIndex<0||(t.edge.push(a.dataIndex),t.node.push(a.node1.dataIndex,a.node2.dataIndex))}return t},r.prototype.getTrajectoryDataIndices=function(){for(var t=j(),e=j(),a=0,n=this.edges.length;a<n;a++){var i=this.edges[a];if(!(i.dataIndex<0)){t.set(i.dataIndex,!0);for(var o=[i.node1],s=[i.node2],l=0;l<o.length;){var u=o[l];l++,e.set(u.dataIndex,!0);for(var f=u.inEdges,v=0,h=f.length,c=void 0,p=void 0;v<h;v++)c=f[v],p=c.dataIndex,p>=0&&!t.hasKey(p)&&(t.set(p,!0),o.push(c.node1))}for(l=0;l<s.length;){var d=s[l];l++,e.set(d.dataIndex,!0);for(var g=d.outEdges,v=0,y=g.length,m=void 0,_=void 0;v<y;v++)m=g[v],_=m.dataIndex,_>=0&&!t.hasKey(_)&&(t.set(_,!0),s.push(m.node2))}}}return{edge:t.keys(),node:e.keys()}},r}(),OI=function(){function r(t,e,a){this.dataIndex=-1,this.node1=t,this.node2=e,this.dataIndex=a??-1}return r.prototype.getModel=function(t){if(!(this.dataIndex<0)){var e=this.hostGraph,a=e.edgeData.getItemModel(this.dataIndex);return a.getModel(t)}},r.prototype.getAdjacentDataIndices=function(){return{edge:[this.dataIndex],node:[this.node1.dataIndex,this.node2.dataIndex]}},r.prototype.getTrajectoryDataIndices=function(){var t=j(),e=j();t.set(this.dataIndex,!0);for(var a=[this.node1],n=[this.node2],i=0;i<a.length;){var o=a[i];i++,e.set(o.dataIndex,!0);for(var s=o.inEdges,l=0,u=s.length,f=void 0,v=void 0;l<u;l++)f=o.inEdges[l],v=f.dataIndex,v>=0&&!t.hasKey(v)&&(t.set(v,!0),a.push(f.node1))}for(i=0;i<n.length;){var h=n[i];i++,e.set(h.dataIndex,!0);for(var c=h.outEdges,l=0,u=c.length,p=void 0,d=void 0;l<u;l++)p=h.outEdges[l],d=p.dataIndex,d>=0&&!t.hasKey(d)&&(t.set(d,!0),n.push(p.node2))}return{edge:t.keys(),node:e.keys()}},r}();function NI(r,t){return{getValue:function(e){var a=this[r][t];return a.getStore().get(a.getDimensionIndex(e||"value"),this.dataIndex)},setVisual:function(e,a){this.dataIndex>=0&&this[r][t].setItemVisual(this.dataIndex,e,a)},getVisual:function(e){return this[r][t].getItemVisual(this.dataIndex,e)},setLayout:function(e,a){this.dataIndex>=0&&this[r][t].setItemLayout(this.dataIndex,e,a)},getLayout:function(){return this[r][t].getItemLayout(this.dataIndex)},getGraphicEl:function(){return this[r][t].getItemGraphicEl(this.dataIndex)},getRawIndex:function(){return this[r][t].getRawIndex(this.dataIndex)}}}Qt(mi,NI("hostGraph","data"));Qt(OI,NI("hostGraph","edgeData"));function H0(r,t,e,a,n){for(var i=new TW(a),o=0;o<r.length;o++)i.addNode(Ce(r[o].id,r[o].name,o),o);for(var s=[],l=[],u=0,o=0;o<t.length;o++){var f=t[o],v=f.source,h=f.target;i.addEdge(v,h,u)&&(l.push(f),s.push(Ce(ve(f.id,null),v+" > "+h)),u++)}var c=e.get("coordinateSystem"),p;if(c==="cartesian2d"||c==="polar"||c==="matrix")p=Ca(r,e);else{var d=Ts.get(c),g=d?d.dimensions||[]:[];gt(g,"value")<0&&g.concat(["value"]);var y=Ds(r,{coordDimensions:g,encodeDefine:e.getEncode()}).dimensions;p=new Ue(y,e),p.initData(r)}var m=new Ue(["value"],e);return m.initData(l,s),n&&n(p,m),gI({mainData:p,struct:i,structAttr:"graph",datas:{node:p,edge:m},datasAttr:{node:"data",edge:"edgeData"}}),i.update(),i}var CW=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.hasSymbolVisual=!0,e}return t.prototype.init=function(e){r.prototype.init.apply(this,arguments);var a=this;function n(){return a._categoriesData}this.legendVisualProvider=new ks(n,n),this.fillDataTextStyle(e.edges||e.links),this._updateCategoriesData()},t.prototype.mergeOption=function(e){r.prototype.mergeOption.apply(this,arguments),this.fillDataTextStyle(e.edges||e.links),this._updateCategoriesData()},t.prototype.mergeDefaultAndTheme=function(e){r.prototype.mergeDefaultAndTheme.apply(this,arguments),Vi(e,"edgeLabel",["show"])},t.prototype.getInitialData=function(e,a){var n=e.edges||e.links||[],i=e.data||e.nodes||[],o=this;if(i&&n){vW(this);var s=H0(i,n,this,!0,l);return A(s.edges,function(u){hW(u.node1,u.node2,this,u.dataIndex)},this),s.data}function l(u,f){u.wrapMethod("getItemModel",function(p){var d=o._categoriesModels,g=p.getShallow("category"),y=d[g];return y&&(y.parentModel=p.parentModel,p.parentModel=y),p});var v=wt.prototype.getModel;function h(p,d){var g=v.call(this,p,d);return g.resolveParentPath=c,g}f.wrapMethod("getItemModel",function(p){return p.resolveParentPath=c,p.getModel=h,p});function c(p){if(p&&(p[0]==="label"||p[1]==="label")){var d=p.slice();return p[0]==="label"?d[0]="edgeLabel":p[1]==="label"&&(d[1]="edgeLabel"),d}return p}}},t.prototype.getGraph=function(){return this.getData().graph},t.prototype.getEdgeData=function(){return this.getGraph().edgeData},t.prototype.getCategoriesData=function(){return this._categoriesData},t.prototype.formatTooltip=function(e,a,n){if(n==="edge"){var i=this.getData(),o=this.getDataParams(e,n),s=i.graph.getEdgeByIndex(e),l=i.getName(s.node1.dataIndex),u=i.getName(s.node2.dataIndex),f=[];return l!=null&&f.push(l),u!=null&&f.push(u),ue("nameValue",{name:f.join(" > "),value:o.value,noValue:o.value==null})}var v=FD({series:this,dataIndex:e,multipleSeries:a});return v},t.prototype._updateCategoriesData=function(){var e=U(this.option.categories||[],function(n){return n.value!=null?n:G({value:0},n)}),a=new Ue(["value"],this);a.initData(e),this._categoriesData=a,this._categoriesModels=a.mapArray(function(n){return a.getItemModel(n)})},t.prototype.setZoom=function(e){this.option.zoom=e},t.prototype.setCenter=function(e){this.option.center=e},t.prototype.isAnimationEnabled=function(){return r.prototype.isAnimationEnabled.call(this)&&!(this.get("layout")==="force"&&this.get(["force","layoutAnimation"]))},t.type="series.graph",t.dependencies=["grid","polar","geo","singleAxis","calendar"],t.defaultOption={z:2,coordinateSystem:"view",legendHoverLink:!0,layout:null,circular:{rotateLabel:!1},force:{initLayout:null,repulsion:[0,50],gravity:.1,friction:.6,edgeLength:30,layoutAnimation:!0},left:"center",top:"center",symbol:"circle",symbolSize:10,edgeSymbol:["none","none"],edgeSymbolSize:10,edgeLabel:{position:"middle",distance:5},draggable:!1,roam:!1,center:null,zoom:1,nodeScaleRatio:.6,label:{show:!1,formatter:"{b}"},itemStyle:{},lineStyle:{color:N.color.neutral50,width:1,opacity:.5},emphasis:{scale:!0,label:{show:!0}},select:{itemStyle:{borderColor:N.color.primary}}},t}(Bt);function AW(r){r.registerChartView(wW),r.registerSeriesModel(CW),r.registerProcessor(oW),r.registerVisual(sW),r.registerVisual(lW),r.registerLayout(cW),r.registerLayout(r.PRIORITY.VISUAL.POST_CHART_LAYOUT,dW),r.registerLayout(yW),r.registerCoordinateSystem("graphView",{dimensions:no.dimensions,create:_W}),r.registerAction({type:"focusNodeAdjacency",event:"focusNodeAdjacency",update:"series:focusNodeAdjacency"},jt),r.registerAction({type:"unfocusNodeAdjacency",event:"unfocusNodeAdjacency",update:"series:unfocusNodeAdjacency"},jt),r.registerAction({type:"graphRoam",event:"graphRoam",update:"none"},function(t,e,a){e.eachComponent({mainType:"series",query:t},function(n){var i=a.getViewOfSeriesModel(n);i&&(t.dx!=null&&t.dy!=null&&i.updateViewOnPan(n,a,t),t.zoom!=null&&t.originX!=null&&t.originY!=null&&i.updateViewOnZoom(n,a,t));var o=n.coordinateSystem,s=sc(o,t,n.get("scaleLimit"));n.setCenter&&n.setCenter(s.center),n.setZoom&&n.setZoom(s.zoom)})})}var sw=function(r){z(t,r);function t(e,a,n){var i=r.call(this)||this;ut(i).dataType="node",i.z2=2;var o=new At;return i.setTextContent(o),i.updateData(e,a,n,!0),i}return t.prototype.updateData=function(e,a,n,i){var o=this,s=e.graph.getNodeByIndex(a),l=e.hostModel,u=s.getModel(),f=u.getModel("emphasis"),v=e.getItemLayout(a),h=G(ha(u.getModel("itemStyle"),v,!0),v),c=this;if(isNaN(h.startAngle)){c.setShape(h);return}i?c.setShape(h):Lt(c,{shape:h},l,a);var p=G(ha(u.getModel("itemStyle"),v,!0),v);o.setShape(p),o.useStyle(e.getItemVisual(a,"style")),he(o,u),this._updateLabel(l,u,s),e.setItemGraphicEl(a,c),he(c,u,"itemStyle");var d=f.get("focus");$t(this,d==="adjacency"?s.getAdjacentDataIndices():d,f.get("blurScope"),f.get("disabled"))},t.prototype._updateLabel=function(e,a,n){var i=this.getTextContent(),o=n.getLayout(),s=(o.startAngle+o.endAngle)/2,l=Math.cos(s),u=Math.sin(s),f=a.getModel("label");i.ignore=!f.get("show");var v=ce(a),h=n.getVisual("style");Se(i,v,{labelFetcher:{getFormattedLabel:function(m,_,S,x,b,w){return e.getFormattedLabel(m,_,"node",x,Qe(b,v.normal&&v.normal.get("formatter"),a.get("name")),w)}},labelDataIndex:n.dataIndex,defaultText:n.dataIndex+"",inheritColor:h.fill,defaultOpacity:h.opacity,defaultOutsidePosition:"startArc"});var c=f.get("position")||"outside",p=f.get("distance")||0,d;c==="outside"?d=o.r+p:d=(o.r+o.r0)/2,this.textConfig={inside:c!=="outside"};var g=c!=="outside"?f.get("align")||"center":l>0?"left":"right",y=c!=="outside"?f.get("verticalAlign")||"middle":u>0?"top":"bottom";i.attr({x:l*d+o.cx,y:u*d+o.cy,rotation:0,style:{align:g,verticalAlign:y}})},t}(ke),MW=function(r){z(t,r);function t(e,a,n,i){var o=r.call(this)||this;return ut(o).dataType="edge",o.updateData(e,a,n,i,!0),o}return t.prototype.buildPath=function(e,a){e.moveTo(a.s1[0],a.s1[1]);var n=.7,i=a.clockwise;e.arc(a.cx,a.cy,a.r,a.sStartAngle,a.sEndAngle,!i),e.bezierCurveTo((a.cx-a.s2[0])*n+a.s2[0],(a.cy-a.s2[1])*n+a.s2[1],(a.cx-a.t1[0])*n+a.t1[0],(a.cy-a.t1[1])*n+a.t1[1],a.t1[0],a.t1[1]),e.arc(a.cx,a.cy,a.r,a.tStartAngle,a.tEndAngle,!i),e.bezierCurveTo((a.cx-a.t2[0])*n+a.t2[0],(a.cy-a.t2[1])*n+a.t2[1],(a.cx-a.s1[0])*n+a.s1[0],(a.cy-a.s1[1])*n+a.s1[1],a.s1[0],a.s1[1]),e.closePath()},t.prototype.updateData=function(e,a,n,i,o){var s=e.hostModel,l=a.graph.getEdgeByIndex(n),u=l.getLayout(),f=l.node1.getModel(),v=a.getItemModel(l.dataIndex),h=v.getModel("lineStyle"),c=v.getModel("emphasis"),p=c.get("focus"),d=G(ha(f.getModel("itemStyle"),u,!0),u),g=this;if(isNaN(d.sStartAngle)||isNaN(d.tStartAngle)){g.setShape(d);return}o?(g.setShape(d),lw(g,l,e,h)):(Ir(g),lw(g,l,e,h),Lt(g,{shape:d},s,n)),$t(this,p==="adjacency"?l.getAdjacentDataIndices():p,c.get("blurScope"),c.get("disabled")),he(g,v,"lineStyle"),a.setItemGraphicEl(l.dataIndex,g)},t}(bt);function lw(r,t,e,a){var n=t.node1,i=t.node2,o=r.style;r.setStyle(a.getLineStyle());var s=a.get("color");switch(s){case"source":o.fill=e.getItemVisual(n.dataIndex,"style").fill,o.decal=n.getVisual("style").decal;break;case"target":o.fill=e.getItemVisual(i.dataIndex,"style").fill,o.decal=i.getVisual("style").decal;break;case"gradient":var l=e.getItemVisual(n.dataIndex,"style").fill,u=e.getItemVisual(i.dataIndex,"style").fill;if(X(l)&&X(u)){var f=r.shape,v=(f.s1[0]+f.s2[0])/2,h=(f.s1[1]+f.s2[1])/2,c=(f.t1[0]+f.t2[0])/2,p=(f.t1[1]+f.t2[1])/2;o.fill=new Ki(v,h,c,p,[{offset:0,color:l},{offset:1,color:u}],!0)}break}}var DW=Math.PI/180,LW=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(e,a){},t.prototype.render=function(e,a,n){var i=e.getData(),o=this._data,s=this.group,l=-e.get("startAngle")*DW;if(i.diff(o).add(function(f){var v=i.getItemLayout(f);if(v){var h=new sw(i,f,l);ut(h).dataIndex=f,s.add(h)}}).update(function(f,v){var h=o.getItemGraphicEl(v),c=i.getItemLayout(f);if(!c){h&&Fa(h,e,v);return}h?h.updateData(i,f,l):h=new sw(i,f,l),s.add(h)}).remove(function(f){var v=o.getItemGraphicEl(f);v&&Fa(v,e,f)}).execute(),!o){var u=e.get("center");this.group.scaleX=.01,this.group.scaleY=.01,this.group.originX=Z(u[0],n.getWidth()),this.group.originY=Z(u[1],n.getHeight()),Yt(this.group,{scaleX:1,scaleY:1},e)}this._data=i,this.renderEdges(e,l)},t.prototype.renderEdges=function(e,a){var n=e.getData(),i=e.getEdgeData(),o=this._edgeData,s=this.group;i.diff(o).add(function(l){var u=new MW(n,i,l,a);ut(u).dataIndex=l,s.add(u)}).update(function(l,u){var f=o.getItemGraphicEl(u);f.updateData(n,i,l,a),s.add(f)}).remove(function(l){var u=o.getItemGraphicEl(l);u&&Fa(u,e,l)}).execute(),this._edgeData=i},t.prototype.dispose=function(){},t.type="chord",t}(Nt),IW=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(e){r.prototype.init.apply(this,arguments),this.fillDataTextStyle(e.edges||e.links),this.legendVisualProvider=new ks($(this.getData,this),$(this.getRawData,this))},t.prototype.mergeOption=function(e){r.prototype.mergeOption.apply(this,arguments),this.fillDataTextStyle(e.edges||e.links)},t.prototype.getInitialData=function(e,a){var n=e.edges||e.links||[],i=e.data||e.nodes||[];if(i&&n){var o=H0(i,n,this,!0,s);return o.data}function s(l,u){var f=wt.prototype.getModel;function v(c,p){var d=f.call(this,c,p);return d.resolveParentPath=h,d}u.wrapMethod("getItemModel",function(c){return c.resolveParentPath=h,c.getModel=v,c});function h(c){if(c&&(c[0]==="label"||c[1]==="label")){var p=c.slice();return c[0]==="label"?p[0]="edgeLabel":c[1]==="label"&&(p[1]="edgeLabel"),p}return c}}},t.prototype.getGraph=function(){return this.getData().graph},t.prototype.getEdgeData=function(){return this.getGraph().edgeData},t.prototype.formatTooltip=function(e,a,n){var i=this.getDataParams(e,n);if(n==="edge"){var o=this.getData(),s=o.graph.getEdgeByIndex(e),l=o.getName(s.node1.dataIndex),u=o.getName(s.node2.dataIndex),f=[];return l!=null&&f.push(l),u!=null&&f.push(u),ue("nameValue",{name:f.join(" > "),value:i.value,noValue:i.value==null})}return ue("nameValue",{name:i.name,value:i.value,noValue:i.value==null})},t.prototype.getDataParams=function(e,a){var n=r.prototype.getDataParams.call(this,e,a);if(a==="node"){var i=this.getData(),o=this.getGraph().getNodeByIndex(e);if(n.name==null&&(n.name=i.getName(e)),n.value==null){var s=o.getLayout().value;n.value=s}}return n},t.type="series.chord",t.defaultOption={z:2,coordinateSystem:"none",legendHoverLink:!0,colorBy:"data",left:0,top:0,right:0,bottom:0,width:null,height:null,center:["50%","50%"],radius:["70%","80%"],clockwise:!0,startAngle:90,endAngle:"auto",minAngle:0,padAngle:3,itemStyle:{borderRadius:[0,0,5,5]},lineStyle:{width:0,color:"source",opacity:.2},label:{show:!0,position:"outside",distance:5},emphasis:{focus:"adjacency",lineStyle:{opacity:.5}}},t}(Bt),td=Math.PI/180;function PW(r,t){r.eachSeriesByType("chord",function(e){RW(e,t)})}function RW(r,t){var e=r.getData(),a=e.graph,n=r.getEdgeData(),i=n.count();if(i){var o=oD(r,t),s=o.cx,l=o.cy,u=o.r,f=o.r0,v=Math.max((r.get("padAngle")||0)*td,0),h=Math.max((r.get("minAngle")||0)*td,0),c=-r.get("startAngle")*td,p=c+Math.PI*2,d=r.get("clockwise"),g=d?1:-1,y=[c,p];Yh(y,!d);var m=y[0],_=y[1],S=_-m,x=e.getSum("value")===0&&n.getSum("value")===0,b=[],w=0;a.eachEdge(function(E){var B=x?1:E.getValue("value");x&&(B>0||h)&&(w+=2);var V=E.node1.dataIndex,F=E.node2.dataIndex;b[V]=(b[V]||0)+B,b[F]=(b[F]||0)+B});var T=0;if(a.eachNode(function(E){var B=E.getValue("value");isNaN(B)||(b[E.dataIndex]=Math.max(B,b[E.dataIndex]||0)),!x&&(b[E.dataIndex]>0||h)&&w++,T+=b[E.dataIndex]||0}),!(w===0||T===0)){v*w>=Math.abs(S)&&(v=Math.max(0,(Math.abs(S)-h*w)/w)),(v+h)*w>=Math.abs(S)&&(h=(Math.abs(S)-v*w)/w);var C=(S-v*w*g)/T,M=0,D=0,I=0;a.eachNode(function(E){var B=b[E.dataIndex]||0,V=C*(T?B:1)*g;Math.abs(V)<h?M+=h-Math.abs(V):(D+=Math.abs(V)-h,I+=Math.abs(V)),E.setLayout({angle:V,value:B})});var L=!1;if(M>D){var P=M/D;a.eachNode(function(E){var B=E.getLayout().angle;Math.abs(B)>=h?E.setLayout({angle:B*P,ratio:P},!0):E.setLayout({angle:h,ratio:h===0?1:B/h},!0)})}else a.eachNode(function(E){if(!L){var B=E.getLayout().angle,V=Math.min(B/I,1),F=V*M;B-F<h&&(L=!0)}});var k=M;a.eachNode(function(E){if(!(k<=0)){var B=E.getLayout().angle;if(B>h&&h>0){var V=L?1:Math.min(B/I,1),F=B-h,H=Math.min(F,Math.min(k,M*V));k-=H,E.setLayout({angle:B-H,ratio:(B-H)/B},!0)}else h>0&&E.setLayout({angle:h,ratio:B===0?1:h/B},!0)}});var R=m,O=[];a.eachNode(function(E){var B=Math.max(E.getLayout().angle,h);E.setLayout({cx:s,cy:l,r0:f,r:u,startAngle:R,endAngle:R+B*g,clockwise:d},!0),O[E.dataIndex]=R,R+=(B+v)*g}),a.eachEdge(function(E){var B=x?1:E.getValue("value"),V=C*(T?B:1)*g,F=E.node1.dataIndex,H=O[F]||0,Y=Math.abs((E.node1.getLayout().ratio||1)*V),K=H+Y*g,ft=[s+f*Math.cos(H),l+f*Math.sin(H)],It=[s+f*Math.cos(K),l+f*Math.sin(K)],Ot=E.node2.dataIndex,vt=O[Ot]||0,at=Math.abs((E.node2.getLayout().ratio||1)*V),dt=vt+at*g,J=[s+f*Math.cos(vt),l+f*Math.sin(vt)],ht=[s+f*Math.cos(dt),l+f*Math.sin(dt)];E.setLayout({s1:ft,s2:It,sStartAngle:H,sEndAngle:K,t1:J,t2:ht,tStartAngle:vt,tEndAngle:dt,cx:s,cy:l,r:f,value:B,clockwise:d}),O[F]=K,O[Ot]=dt})}}}function kW(r){r.registerChartView(LW),r.registerSeriesModel(IW),r.registerLayout(r.PRIORITY.VISUAL.POST_CHART_LAYOUT,PW),r.registerProcessor(Ps("chord"))}var EW=function(){function r(){this.angle=0,this.width=10,this.r=10,this.x=0,this.y=0}return r}(),OW=function(r){z(t,r);function t(e){var a=r.call(this,e)||this;return a.type="pointer",a}return t.prototype.getDefaultShape=function(){return new EW},t.prototype.buildPath=function(e,a){var n=Math.cos,i=Math.sin,o=a.r,s=a.width,l=a.angle,u=a.x-n(l)*s*(s>=o/3?1:2),f=a.y-i(l)*s*(s>=o/3?1:2);l=a.angle-Math.PI/2,e.moveTo(u,f),e.lineTo(a.x+n(l)*s,a.y+i(l)*s),e.lineTo(a.x+n(a.angle)*o,a.y+i(a.angle)*o),e.lineTo(a.x-n(l)*s,a.y-i(l)*s),e.lineTo(u,f)},t}(bt);function NW(r,t){var e=r.get("center"),a=t.getWidth(),n=t.getHeight(),i=Math.min(a,n),o=Z(e[0],t.getWidth()),s=Z(e[1],t.getHeight()),l=Z(r.get("radius"),i/2);return{cx:o,cy:s,r:l}}function Nf(r,t){var e=r==null?"":r+"";return t&&(X(t)?e=t.replace("{value}",e):tt(t)&&(e=t(r))),e}var BW=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n){this.group.removeAll();var i=e.get(["axisLine","lineStyle","color"]),o=NW(e,n);this._renderMain(e,a,n,i,o),this._data=e.getData()},t.prototype.dispose=function(){},t.prototype._renderMain=function(e,a,n,i,o){var s=this.group,l=e.get("clockwise"),u=-e.get("startAngle")/180*Math.PI,f=-e.get("endAngle")/180*Math.PI,v=e.getModel("axisLine"),h=v.get("roundCap"),c=h?sh:ke,p=v.get("show"),d=v.getModel("lineStyle"),g=d.get("width"),y=[u,f];Yh(y,!l),u=y[0],f=y[1];for(var m=f-u,_=u,S=[],x=0;p&&x<i.length;x++){var b=Math.min(Math.max(i[x][0],0),1);f=u+m*b;var w=new c({shape:{startAngle:_,endAngle:f,cx:o.cx,cy:o.cy,clockwise:l,r0:o.r-g,r:o.r},silent:!0});w.setStyle({fill:i[x][1]}),w.setStyle(d.getLineStyle(["color","width"])),S.push(w),_=f}S.reverse(),A(S,function(C){return s.add(C)});var T=function(C){if(C<=0)return i[0][1];var M;for(M=0;M<i.length;M++)if(i[M][0]>=C&&(M===0?0:i[M-1][0])<C)return i[M][1];return i[M-1][1]};this._renderTicks(e,a,n,T,o,u,f,l,g),this._renderTitleAndDetail(e,a,n,T,o),this._renderAnchor(e,o),this._renderPointer(e,a,n,T,o,u,f,l,g)},t.prototype._renderTicks=function(e,a,n,i,o,s,l,u,f){for(var v=this.group,h=o.cx,c=o.cy,p=o.r,d=+e.get("min"),g=+e.get("max"),y=e.getModel("splitLine"),m=e.getModel("axisTick"),_=e.getModel("axisLabel"),S=e.get("splitNumber"),x=m.get("splitNumber"),b=Z(y.get("length"),p),w=Z(m.get("length"),p),T=s,C=(l-s)/S,M=C/x,D=y.getModel("lineStyle").getLineStyle(),I=m.getModel("lineStyle").getLineStyle(),L=y.get("distance"),P,k,R=0;R<=S;R++){if(P=Math.cos(T),k=Math.sin(T),y.get("show")){var O=L?L+f:f,E=new ne({shape:{x1:P*(p-O)+h,y1:k*(p-O)+c,x2:P*(p-b-O)+h,y2:k*(p-b-O)+c},style:D,silent:!0});D.stroke==="auto"&&E.setStyle({stroke:i(R/S)}),v.add(E)}if(_.get("show")){var O=_.get("distance")+L,B=Nf(ae(R/S*(g-d)+d),_.get("formatter")),V=i(R/S),F=P*(p-b-O)+h,H=k*(p-b-O)+c,Y=_.get("rotate"),K=0;Y==="radial"?(K=-T+2*Math.PI,K>Math.PI/2&&(K+=Math.PI)):Y==="tangential"?K=-T-Math.PI/2:Mt(Y)&&(K=Y*Math.PI/180),K===0?v.add(new At({style:Gt(_,{text:B,x:F,y:H,verticalAlign:k<-.8?"top":k>.8?"bottom":"middle",align:P<-.4?"left":P>.4?"right":"center"},{inheritColor:V}),silent:!0})):v.add(new At({style:Gt(_,{text:B,x:F,y:H,verticalAlign:"middle",align:"center"},{inheritColor:V}),silent:!0,originX:F,originY:H,rotation:K}))}if(m.get("show")&&R!==S){var O=m.get("distance");O=O?O+f:f;for(var ft=0;ft<=x;ft++){P=Math.cos(T),k=Math.sin(T);var It=new ne({shape:{x1:P*(p-O)+h,y1:k*(p-O)+c,x2:P*(p-w-O)+h,y2:k*(p-w-O)+c},silent:!0,style:I});I.stroke==="auto"&&It.setStyle({stroke:i((R+ft/x)/S)}),v.add(It),T+=M}T-=M}else T+=C}},t.prototype._renderPointer=function(e,a,n,i,o,s,l,u,f){var v=this.group,h=this._data,c=this._progressEls,p=[],d=e.get(["pointer","show"]),g=e.getModel("progress"),y=g.get("show"),m=e.getData(),_=m.mapDimension("value"),S=+e.get("min"),x=+e.get("max"),b=[S,x],w=[s,l];function T(M,D){var I=m.getItemModel(M),L=I.getModel("pointer"),P=Z(L.get("width"),o.r),k=Z(L.get("length"),o.r),R=e.get(["pointer","icon"]),O=L.get("offsetCenter"),E=Z(O[0],o.r),B=Z(O[1],o.r),V=L.get("keepAspect"),F;return R?F=ie(R,E-P/2,B-k,P,k,null,V):F=new OW({shape:{angle:-Math.PI/2,width:P,r:k,x:E,y:B}}),F.rotation=-(D+Math.PI/2),F.x=o.cx,F.y=o.cy,F}function C(M,D){var I=g.get("roundCap"),L=I?sh:ke,P=g.get("overlap"),k=P?g.get("width"):f/m.count(),R=P?o.r-k:o.r-(M+1)*k,O=P?o.r:o.r-M*k,E=new L({shape:{startAngle:s,endAngle:D,cx:o.cx,cy:o.cy,clockwise:u,r0:R,r:O}});return P&&(E.z2=Rt(m.get(_,M),[S,x],[100,0],!0)),E}(y||d)&&(m.diff(h).add(function(M){var D=m.get(_,M);if(d){var I=T(M,s);Yt(I,{rotation:-((isNaN(+D)?w[0]:Rt(D,b,w,!0))+Math.PI/2)},e),v.add(I),m.setItemGraphicEl(M,I)}if(y){var L=C(M,s),P=g.get("clip");Yt(L,{shape:{endAngle:Rt(D,b,w,P)}},e),v.add(L),yg(e.seriesIndex,m.dataType,M,L),p[M]=L}}).update(function(M,D){var I=m.get(_,M);if(d){var L=h.getItemGraphicEl(D),P=L?L.rotation:s,k=T(M,P);k.rotation=P,Lt(k,{rotation:-((isNaN(+I)?w[0]:Rt(I,b,w,!0))+Math.PI/2)},e),v.add(k),m.setItemGraphicEl(M,k)}if(y){var R=c[D],O=R?R.shape.endAngle:s,E=C(M,O),B=g.get("clip");Lt(E,{shape:{endAngle:Rt(I,b,w,B)}},e),v.add(E),yg(e.seriesIndex,m.dataType,M,E),p[M]=E}}).execute(),m.each(function(M){var D=m.getItemModel(M),I=D.getModel("emphasis"),L=I.get("focus"),P=I.get("blurScope"),k=I.get("disabled");if(d){var R=m.getItemGraphicEl(M),O=m.getItemVisual(M,"style"),E=O.fill;if(R instanceof xe){var B=R.style;R.useStyle(G({image:B.image,x:B.x,y:B.y,width:B.width,height:B.height},O))}else R.useStyle(O),R.type!=="pointer"&&R.setColor(E);R.setStyle(D.getModel(["pointer","itemStyle"]).getItemStyle()),R.style.fill==="auto"&&R.setStyle("fill",i(Rt(m.get(_,M),b,[0,1],!0))),R.z2EmphasisLift=0,he(R,D),$t(R,L,P,k)}if(y){var V=p[M];V.useStyle(m.getItemVisual(M,"style")),V.setStyle(D.getModel(["progress","itemStyle"]).getItemStyle()),V.z2EmphasisLift=0,he(V,D),$t(V,L,P,k)}}),this._progressEls=p)},t.prototype._renderAnchor=function(e,a){var n=e.getModel("anchor"),i=n.get("show");if(i){var o=n.get("size"),s=n.get("icon"),l=n.get("offsetCenter"),u=n.get("keepAspect"),f=ie(s,a.cx-o/2+Z(l[0],a.r),a.cy-o/2+Z(l[1],a.r),o,o,null,u);f.z2=n.get("showAbove")?1:0,f.setStyle(n.getModel("itemStyle").getItemStyle()),this.group.add(f)}},t.prototype._renderTitleAndDetail=function(e,a,n,i,o){var s=this,l=e.getData(),u=l.mapDimension("value"),f=+e.get("min"),v=+e.get("max"),h=new rt,c=[],p=[],d=e.isAnimationEnabled(),g=e.get(["pointer","showAbove"]);l.diff(this._data).add(function(y){c[y]=new At({silent:!0}),p[y]=new At({silent:!0})}).update(function(y,m){c[y]=s._titleEls[m],p[y]=s._detailEls[m]}).execute(),l.each(function(y){var m=l.getItemModel(y),_=l.get(u,y),S=new rt,x=i(Rt(_,[f,v],[0,1],!0)),b=m.getModel("title");if(b.get("show")){var w=b.get("offsetCenter"),T=o.cx+Z(w[0],o.r),C=o.cy+Z(w[1],o.r),M=c[y];M.attr({z2:g?0:2,style:Gt(b,{x:T,y:C,text:l.getName(y),align:"center",verticalAlign:"middle"},{inheritColor:x})}),S.add(M)}var D=m.getModel("detail");if(D.get("show")){var I=D.get("offsetCenter"),L=o.cx+Z(I[0],o.r),P=o.cy+Z(I[1],o.r),k=Z(D.get("width"),o.r),R=Z(D.get("height"),o.r),O=e.get(["progress","show"])?l.getItemVisual(y,"style").fill:x,M=p[y],E=D.get("formatter");M.attr({z2:g?0:2,style:Gt(D,{x:L,y:P,text:Nf(_,E),width:isNaN(k)?null:k,height:isNaN(R)?null:R,align:"center",verticalAlign:"middle"},{inheritColor:O})}),FM(M,{normal:D},_,function(V){return Nf(V,E)}),d&&HM(M,y,l,e,{getFormattedLabel:function(V,F,H,Y,K,ft){return Nf(ft?ft.interpolatedValue:_,E)}}),S.add(M)}h.add(S)}),this.group.add(h),this._titleEls=c,this._detailEls=p},t.type="gauge",t}(Nt),zW=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.visualStyleAccessPath="itemStyle",e}return t.prototype.getInitialData=function(e,a){return Rs(this,["value"])},t.type="series.gauge",t.defaultOption={z:2,colorBy:"data",center:["50%","50%"],legendHoverLink:!0,radius:"75%",startAngle:225,endAngle:-45,clockwise:!0,min:0,max:100,splitNumber:10,axisLine:{show:!0,roundCap:!1,lineStyle:{color:[[1,N.color.neutral10]],width:10}},progress:{show:!1,overlap:!0,width:10,roundCap:!1,clip:!0},splitLine:{show:!0,length:10,distance:10,lineStyle:{color:N.color.axisTick,width:3,type:"solid"}},axisTick:{show:!0,splitNumber:5,length:6,distance:10,lineStyle:{color:N.color.axisTickMinor,width:1,type:"solid"}},axisLabel:{show:!0,distance:15,color:N.color.axisLabel,fontSize:12,rotate:0},pointer:{icon:null,offsetCenter:[0,0],show:!0,showAbove:!0,length:"60%",width:6,keepAspect:!1},anchor:{show:!1,showAbove:!1,size:6,icon:"circle",offsetCenter:[0,0],keepAspect:!1,itemStyle:{color:N.color.neutral00,borderWidth:0,borderColor:N.color.theme[0]}},title:{show:!0,offsetCenter:[0,"20%"],color:N.color.secondary,fontSize:16,valueAnimation:!1},detail:{show:!0,backgroundColor:N.color.transparent,borderWidth:0,borderColor:N.color.neutral40,width:100,height:null,padding:[5,10],offsetCenter:[0,"40%"],color:N.color.primary,fontSize:30,fontWeight:"bold",lineHeight:30,valueAnimation:!1}},t}(Bt);function VW(r){r.registerChartView(BW),r.registerSeriesModel(zW)}var GW=["itemStyle","opacity"],FW=function(r){z(t,r);function t(e,a){var n=r.call(this)||this,i=n,o=new Ae,s=new At;return i.setTextContent(s),n.setTextGuideLine(o),n.updateData(e,a,!0),n}return t.prototype.updateData=function(e,a,n){var i=this,o=e.hostModel,s=e.getItemModel(a),l=e.getItemLayout(a),u=s.getModel("emphasis"),f=s.get(GW);f=f??1,n||Ir(i),i.useStyle(e.getItemVisual(a,"style")),i.style.lineJoin="round",n?(i.setShape({points:l.points}),i.style.opacity=0,Yt(i,{style:{opacity:f}},o,a)):Lt(i,{style:{opacity:f},shape:{points:l.points}},o,a),he(i,s),this._updateLabel(e,a),$t(this,u.get("focus"),u.get("blurScope"),u.get("disabled"))},t.prototype._updateLabel=function(e,a){var n=this,i=this.getTextGuideLine(),o=n.getTextContent(),s=e.hostModel,l=e.getItemModel(a),u=e.getItemLayout(a),f=u.label,v=e.getItemVisual(a,"style"),h=v.fill;Se(o,ce(l),{labelFetcher:e.hostModel,labelDataIndex:a,defaultOpacity:v.opacity,defaultText:e.getName(a)},{normal:{align:f.textAlign,verticalAlign:f.verticalAlign}});var c=l.getModel("label"),p=c.get("color"),d=p==="inherit"?h:null;n.setTextConfig({local:!0,inside:!!f.inside,insideStroke:d,outsideFill:d});var g=f.linePoints;i.setShape({points:g}),n.textGuideLineConfig={anchor:g?new st(g[0][0],g[0][1]):null},Lt(o,{style:{x:f.x,y:f.y}},s,a),o.attr({rotation:f.rotation,originX:f.x,originY:f.y,z2:10}),d0(n,g0(l),{stroke:h})},t}(Ee),HW=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.ignoreLabelLineUpdate=!0,e}return t.prototype.render=function(e,a,n){var i=e.getData(),o=this._data,s=this.group;i.diff(o).add(function(l){var u=new FW(i,l);i.setItemGraphicEl(l,u),s.add(u)}).update(function(l,u){var f=o.getItemGraphicEl(u);f.updateData(i,l),s.add(f),i.setItemGraphicEl(l,f)}).remove(function(l){var u=o.getItemGraphicEl(l);Fa(u,e,l)}).execute(),this._data=i},t.prototype.remove=function(){this.group.removeAll(),this._data=null},t.prototype.dispose=function(){},t.type="funnel",t}(Nt),WW=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(e){r.prototype.init.apply(this,arguments),this.legendVisualProvider=new ks($(this.getData,this),$(this.getRawData,this)),this._defaultLabelLine(e)},t.prototype.getInitialData=function(e,a){return Rs(this,{coordDimensions:["value"],encodeDefaulter:pt(Xm,this)})},t.prototype._defaultLabelLine=function(e){Vi(e,"labelLine",["show"]);var a=e.labelLine,n=e.emphasis.labelLine;a.show=a.show&&e.label.show,n.show=n.show&&e.emphasis.label.show},t.prototype.getDataParams=function(e){var a=this.getData(),n=r.prototype.getDataParams.call(this,e),i=a.mapDimension("value"),o=a.getSum(i);return n.percent=o?+(a.get(i,e)/o*100).toFixed(2):0,n.$vars.push("percent"),n},t.type="series.funnel",t.defaultOption={coordinateSystemUsage:"box",z:2,legendHoverLink:!0,colorBy:"data",left:80,top:60,right:80,bottom:65,minSize:"0%",maxSize:"100%",sort:"descending",orient:"vertical",gap:0,funnelAlign:"center",label:{show:!0,position:"outer"},labelLine:{show:!0,length:20,lineStyle:{width:1}},itemStyle:{borderColor:N.color.neutral00,borderWidth:1},emphasis:{label:{show:!0}},select:{itemStyle:{borderColor:N.color.primary}}},t}(Bt);function UW(r,t){for(var e=r.mapDimension("value"),a=r.mapArray(e,function(l){return l}),n=[],i=t==="ascending",o=0,s=r.count();o<s;o++)n[o]=o;return tt(t)?n.sort(t):t!=="none"&&n.sort(function(l,u){return i?a[l]-a[u]:a[u]-a[l]}),n}function YW(r){var t=r.hostModel,e=t.get("orient");r.each(function(a){var n=r.getItemModel(a),i=n.getModel("label"),o=i.get("position"),s=n.getModel("labelLine"),l=r.getItemLayout(a),u=l.points,f=o==="inner"||o==="inside"||o==="center"||o==="insideLeft"||o==="insideRight",v,h,c,p;if(f)o==="insideLeft"?(h=(u[0][0]+u[3][0])/2+5,c=(u[0][1]+u[3][1])/2,v="left"):o==="insideRight"?(h=(u[1][0]+u[2][0])/2-5,c=(u[1][1]+u[2][1])/2,v="right"):(h=(u[0][0]+u[1][0]+u[2][0]+u[3][0])/4,c=(u[0][1]+u[1][1]+u[2][1]+u[3][1])/4,v="center"),p=[[h,c],[h,c]];else{var d=void 0,g=void 0,y=void 0,m=void 0,_=s.get("length");o==="left"?(d=(u[3][0]+u[0][0])/2,g=(u[3][1]+u[0][1])/2,y=d-_,h=y-5,v="right"):o==="right"?(d=(u[1][0]+u[2][0])/2,g=(u[1][1]+u[2][1])/2,y=d+_,h=y+5,v="left"):o==="top"?(d=(u[3][0]+u[0][0])/2,g=(u[3][1]+u[0][1])/2,m=g-_,c=m-5,v="center"):o==="bottom"?(d=(u[1][0]+u[2][0])/2,g=(u[1][1]+u[2][1])/2,m=g+_,c=m+5,v="center"):o==="rightTop"?(d=e==="horizontal"?u[3][0]:u[1][0],g=e==="horizontal"?u[3][1]:u[1][1],e==="horizontal"?(m=g-_,c=m-5,v="center"):(y=d+_,h=y+5,v="top")):o==="rightBottom"?(d=u[2][0],g=u[2][1],e==="horizontal"?(m=g+_,c=m+5,v="center"):(y=d+_,h=y+5,v="bottom")):o==="leftTop"?(d=u[0][0],g=e==="horizontal"?u[0][1]:u[1][1],e==="horizontal"?(m=g-_,c=m-5,v="center"):(y=d-_,h=y-5,v="right")):o==="leftBottom"?(d=e==="horizontal"?u[1][0]:u[3][0],g=e==="horizontal"?u[1][1]:u[2][1],e==="horizontal"?(m=g+_,c=m+5,v="center"):(y=d-_,h=y-5,v="right")):(d=(u[1][0]+u[2][0])/2,g=(u[1][1]+u[2][1])/2,e==="horizontal"?(m=g+_,c=m+5,v="center"):(y=d+_,h=y+5,v="left")),e==="horizontal"?(y=d,h=y):(m=g,c=m),p=[[d,g],[y,m]]}l.label={linePoints:p,x:h,y:c,verticalAlign:"middle",textAlign:v,inside:f}})}function ZW(r,t){r.eachSeriesByType("funnel",function(e){var a=e.getData(),n=a.mapDimension("value"),i=e.get("sort"),o=pe(e,t),s=Xt(e.getBoxLayoutParams(),o.refContainer),l=e.get("orient"),u=s.width,f=s.height,v=UW(a,i),h=s.x,c=s.y,p=l==="horizontal"?[Z(e.get("minSize"),f),Z(e.get("maxSize"),f)]:[Z(e.get("minSize"),u),Z(e.get("maxSize"),u)],d=a.getDataExtent(n),g=e.get("min"),y=e.get("max");g==null&&(g=Math.min(d[0],0)),y==null&&(y=d[1]);var m=e.get("funnelAlign"),_=e.get("gap"),S=l==="horizontal"?u:f,x=(S-_*(a.count()-1))/a.count(),b=function(k,R){if(l==="horizontal"){var O=a.get(n,k)||0,E=Rt(O,[g,y],p,!0),B=void 0;switch(m){case"top":B=c;break;case"center":B=c+(f-E)/2;break;case"bottom":B=c+(f-E);break}return[[R,B],[R,B+E]]}var V=a.get(n,k)||0,F=Rt(V,[g,y],p,!0),H;switch(m){case"left":H=h;break;case"center":H=h+(u-F)/2;break;case"right":H=h+u-F;break}return[[H,R],[H+F,R]]};i==="ascending"&&(x=-x,_=-_,l==="horizontal"?h+=u:c+=f,v=v.reverse());for(var w=0;w<v.length;w++){var T=v[w],C=v[w+1],M=a.getItemModel(T);if(l==="horizontal"){var D=M.get(["itemStyle","width"]);D==null?D=x:(D=Z(D,u),i==="ascending"&&(D=-D));var I=b(T,h),L=b(C,h+D);h+=D+_,a.setItemLayout(T,{points:I.concat(L.slice().reverse())})}else{var P=M.get(["itemStyle","height"]);P==null?P=x:(P=Z(P,f),i==="ascending"&&(P=-P));var I=b(T,c),L=b(C,c+P);c+=P+_,a.setItemLayout(T,{points:I.concat(L.slice().reverse())})}}YW(a)})}function XW(r){r.registerChartView(HW),r.registerSeriesModel(WW),r.registerLayout(ZW),r.registerProcessor(Ps("funnel"))}var $W=.3,qW=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e._dataGroup=new rt,e._initialized=!1,e}return t.prototype.init=function(){this.group.add(this._dataGroup)},t.prototype.render=function(e,a,n,i){this._progressiveEls=null;var o=this._dataGroup,s=e.getData(),l=this._data,u=e.coordinateSystem,f=u.dimensions,v=fw(e);s.diff(l).add(h).update(c).remove(p).execute();function h(g){var y=uw(s,o,g,f,u);ed(y,s,g,v)}function c(g,y){var m=l.getItemGraphicEl(y),_=BI(s,g,f,u);s.setItemGraphicEl(g,m),Lt(m,{shape:{points:_}},e,g),Ir(m),ed(m,s,g,v)}function p(g){var y=l.getItemGraphicEl(g);o.remove(y)}if(!this._initialized){this._initialized=!0;var d=KW(u,e,function(){setTimeout(function(){o.removeClipPath()})});o.setClipPath(d)}this._data=s},t.prototype.incrementalPrepareRender=function(e,a,n){this._initialized=!0,this._data=null,this._dataGroup.removeAll()},t.prototype.incrementalRender=function(e,a,n){for(var i=a.getData(),o=a.coordinateSystem,s=o.dimensions,l=fw(a),u=this._progressiveEls=[],f=e.start;f<e.end;f++){var v=uw(i,this._dataGroup,f,s,o);v.incremental=!0,ed(v,i,f,l),u.push(v)}},t.prototype.remove=function(){this._dataGroup&&this._dataGroup.removeAll(),this._data=null},t.type="parallel",t}(Nt);function KW(r,t,e){var a=r.model,n=r.getRect(),i=new _t({shape:{x:n.x,y:n.y,width:n.width,height:n.height}}),o=a.get("layout")==="horizontal"?"width":"height";return i.setShape(o,0),Yt(i,{shape:{width:n.width,height:n.height}},t,e),i}function BI(r,t,e,a){for(var n=[],i=0;i<e.length;i++){var o=e[i],s=r.get(r.mapDimension(o),t);jW(s,a.getAxis(o).type)||n.push(a.dataToPoint(s,o))}return n}function uw(r,t,e,a,n){var i=BI(r,e,a,n),o=new Ae({shape:{points:i},z2:10});return t.add(o),r.setItemGraphicEl(e,o),o}function fw(r){var t=r.get("smooth",!0);return t===!0&&(t=$W),t=ya(t),Ie(t)&&(t=0),{smooth:t}}function ed(r,t,e,a){r.useStyle(t.getItemVisual(e,"style")),r.style.fill=null,r.setShape("smooth",a.smooth);var n=t.getItemModel(e),i=n.getModel("emphasis");he(r,n,"lineStyle"),$t(r,i.get("focus"),i.get("blurScope"),i.get("disabled"))}function jW(r,t){return t==="category"?r==null:r==null||isNaN(r)}var JW=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.visualStyleAccessPath="lineStyle",e.visualDrawType="stroke",e}return t.prototype.getInitialData=function(e,a){return Ca(null,this,{useEncodeDefaulter:$(QW,null,this)})},t.prototype.getRawIndicesByActiveState=function(e){var a=this.coordinateSystem,n=this.getData(),i=[];return a.eachActiveState(n,function(o,s){e===o&&i.push(n.getRawIndex(s))}),i},t.type="series.parallel",t.dependencies=["parallel"],t.defaultOption={z:2,coordinateSystem:"parallel",parallelIndex:0,label:{show:!1},inactiveOpacity:.05,activeOpacity:1,lineStyle:{width:1,opacity:.45,type:"solid"},emphasis:{label:{show:!1}},progressive:500,smooth:!1,animationEasing:"linear"},t}(Bt);function QW(r){var t=r.ecModel.getComponent("parallel",r.get("parallelIndex"));if(t){var e={};return A(t.dimensions,function(a){var n=tU(a);e[a]=n}),e}}function tU(r){return+r.replace("dim","")}var eU=["lineStyle","opacity"],rU={seriesType:"parallel",reset:function(r,t){var e=r.coordinateSystem,a={normal:r.get(["lineStyle","opacity"]),active:r.get("activeOpacity"),inactive:r.get("inactiveOpacity")};return{progress:function(n,i){e.eachActiveState(i,function(o,s){var l=a[o];if(o==="normal"&&i.hasItemOption){var u=i.getItemModel(s).get(eU,!0);u!=null&&(l=u)}var f=i.ensureUniqueItemVisual(s,"style");f.opacity=l},n.start,n.end)}}}};function aU(r){nU(r),iU(r)}function nU(r){if(!r.parallel){var t=!1;A(r.series,function(e){e&&e.type==="parallel"&&(t=!0)}),t&&(r.parallel=[{}])}}function iU(r){var t=Ft(r.parallelAxis);A(t,function(e){if(it(e)){var a=e.parallelIndex||0,n=Ft(r.parallel)[a];n&&n.parallelAxisDefault&&yt(e,n.parallelAxisDefault,!1)}})}var oU=5,sU=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n){this._model=e,this._api=n,this._handlers||(this._handlers={},A(lU,function(i,o){n.getZr().on(o,this._handlers[o]=$(i,this))},this)),As(this,"_throttledDispatchExpand",e.get("axisExpandRate"),"fixRate")},t.prototype.dispose=function(e,a){tu(this,"_throttledDispatchExpand"),A(this._handlers,function(n,i){a.getZr().off(i,n)}),this._handlers=null},t.prototype._throttledDispatchExpand=function(e){this._dispatchExpand(e)},t.prototype._dispatchExpand=function(e){e&&this._api.dispatchAction(G({type:"parallelAxisExpand"},e))},t.type="parallel",t}(Wt),lU={mousedown:function(r){rd(this,"click")&&(this._mouseDownPoint=[r.offsetX,r.offsetY])},mouseup:function(r){var t=this._mouseDownPoint;if(rd(this,"click")&&t){var e=[r.offsetX,r.offsetY],a=Math.pow(t[0]-e[0],2)+Math.pow(t[1]-e[1],2);if(a>oU)return;var n=this._model.coordinateSystem.getSlidedAxisExpandWindow([r.offsetX,r.offsetY]);n.behavior!=="none"&&this._dispatchExpand({axisExpandWindow:n.axisExpandWindow})}this._mouseDownPoint=null},mousemove:function(r){if(!(this._mouseDownPoint||!rd(this,"mousemove"))){var t=this._model,e=t.coordinateSystem.getSlidedAxisExpandWindow([r.offsetX,r.offsetY]),a=e.behavior;a==="jump"&&this._throttledDispatchExpand.debounceNextCall(t.get("axisExpandDebounce")),this._throttledDispatchExpand(a==="none"?null:{axisExpandWindow:e.axisExpandWindow,animation:a==="jump"?null:{duration:0}})}}};function rd(r,t){var e=r._model;return e.get("axisExpandable")&&e.get("axisExpandTriggerOn")===t}var uU=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(){r.prototype.init.apply(this,arguments),this.mergeOption({})},t.prototype.mergeOption=function(e){var a=this.option;e&&yt(a,e,!0),this._initDimensions()},t.prototype.contains=function(e,a){var n=e.get("parallelIndex");return n!=null&&a.getComponent("parallel",n)===this},t.prototype.setAxisExpand=function(e){A(["axisExpandable","axisExpandCenter","axisExpandCount","axisExpandWidth","axisExpandWindow"],function(a){e.hasOwnProperty(a)&&(this.option[a]=e[a])},this)},t.prototype._initDimensions=function(){var e=this.dimensions=[],a=this.parallelAxisIndex=[],n=Pt(this.ecModel.queryComponents({mainType:"parallelAxis"}),function(i){return(i.get("parallelIndex")||0)===this.componentIndex},this);A(n,function(i){e.push("dim"+i.get("dim")),a.push(i.componentIndex)})},t.type="parallel",t.dependencies=["parallelAxis"],t.layoutMode="box",t.defaultOption={z:0,left:80,top:60,right:80,bottom:60,layout:"horizontal",axisExpandable:!1,axisExpandCenter:null,axisExpandCount:0,axisExpandWidth:50,axisExpandRate:17,axisExpandDebounce:50,axisExpandSlideTriggerArea:[-.15,.05,.4],axisExpandTriggerOn:"click",parallelAxisDefault:null},t}(xt),fU=function(r){z(t,r);function t(e,a,n,i,o){var s=r.call(this,e,a,n)||this;return s.type=i||"value",s.axisIndex=o,s}return t.prototype.isHorizontal=function(){return this.coordinateSystem.getModel().get("layout")!=="horizontal"},t}($r);function kn(r,t,e,a,n,i){r=r||0;var o=e[1]-e[0];if(n!=null&&(n=Ao(n,[0,o])),i!=null&&(i=Math.max(i,n??0)),a==="all"){var s=Math.abs(t[1]-t[0]);s=Ao(s,[0,o]),n=i=Ao(s,[n,i]),a=0}t[0]=Ao(t[0],e),t[1]=Ao(t[1],e);var l=ad(t,a);t[a]+=r;var u=n||0,f=e.slice();l.sign<0?f[0]+=u:f[1]-=u,t[a]=Ao(t[a],f);var v;return v=ad(t,a),n!=null&&(v.sign!==l.sign||v.span<n)&&(t[1-a]=t[a]+l.sign*n),v=ad(t,a),i!=null&&v.span>i&&(t[1-a]=t[a]+v.sign*i),t}function ad(r,t){var e=r[t]-r[1-t];return{span:Math.abs(e),sign:e>0?-1:e<0?1:t?-1:1}}function Ao(r,t){return Math.min(t[1]!=null?t[1]:1/0,Math.max(t[0]!=null?t[0]:-1/0,r))}var nd=A,zI=Math.min,VI=Math.max,vw=Math.floor,vU=Math.ceil,hw=ae,hU=Math.PI,cU=function(){function r(t,e,a){this.type="parallel",this._axesMap=j(),this._axesLayout={},this.dimensions=t.dimensions,this._model=t,this._init(t,e,a)}return r.prototype._init=function(t,e,a){var n=t.dimensions,i=t.parallelAxisIndex;nd(n,function(o,s){var l=i[s],u=e.getComponent("parallelAxis",l),f=this._axesMap.set(o,new fU(o,Ru(u),[0,0],u.get("type"),l)),v=f.type==="category";f.onBand=v&&u.get("boundaryGap"),f.inverse=u.get("inverse"),u.axis=f,f.model=u,f.coordinateSystem=u.coordinateSystem=this},this)},r.prototype.update=function(t,e){this._updateAxesFromSeries(this._model,t)},r.prototype.containPoint=function(t){var e=this._makeLayoutInfo(),a=e.axisBase,n=e.layoutBase,i=e.pixelDimIndex,o=t[1-i],s=t[i];return o>=a&&o<=a+e.axisLength&&s>=n&&s<=n+e.layoutLength},r.prototype.getModel=function(){return this._model},r.prototype._updateAxesFromSeries=function(t,e){e.eachSeries(function(a){if(t.contains(a,e)){var n=a.getData();nd(this.dimensions,function(i){var o=this._axesMap.get(i);o.scale.unionExtentFromData(n,n.mapDimension(i)),Zi(o.scale,o.model)},this)}},this)},r.prototype.resize=function(t,e){var a=pe(t,e).refContainer;this._rect=Xt(t.getBoxLayoutParams(),a),this._layoutAxes()},r.prototype.getRect=function(){return this._rect},r.prototype._makeLayoutInfo=function(){var t=this._model,e=this._rect,a=["x","y"],n=["width","height"],i=t.get("layout"),o=i==="horizontal"?0:1,s=e[n[o]],l=[0,s],u=this.dimensions.length,f=Bf(t.get("axisExpandWidth"),l),v=Bf(t.get("axisExpandCount")||0,[0,u]),h=t.get("axisExpandable")&&u>3&&u>v&&v>1&&f>0&&s>0,c=t.get("axisExpandWindow"),p;if(c)p=Bf(c[1]-c[0],l),c[1]=c[0]+p;else{p=Bf(f*(v-1),l);var d=t.get("axisExpandCenter")||vw(u/2);c=[f*d-p/2],c[1]=c[0]+p}var g=(s-p)/(u-v);g<3&&(g=0);var y=[vw(hw(c[0]/f,1))+1,vU(hw(c[1]/f,1))-1],m=g/f*c[0];return{layout:i,pixelDimIndex:o,layoutBase:e[a[o]],layoutLength:s,axisBase:e[a[1-o]],axisLength:e[n[1-o]],axisExpandable:h,axisExpandWidth:f,axisCollapseWidth:g,axisExpandWindow:c,axisCount:u,winInnerIndices:y,axisExpandWindow0Pos:m}},r.prototype._layoutAxes=function(){var t=this._rect,e=this._axesMap,a=this.dimensions,n=this._makeLayoutInfo(),i=n.layout;e.each(function(o){var s=[0,n.axisLength],l=o.inverse?1:0;o.setExtent(s[l],s[1-l])}),nd(a,function(o,s){var l=(n.axisExpandable?dU:pU)(s,n),u={horizontal:{x:l.position,y:n.axisLength},vertical:{x:0,y:l.position}},f={horizontal:hU/2,vertical:0},v=[u[i].x+t.x,u[i].y+t.y],h=f[i],c=me();Qa(c,c,h),Ur(c,c,v),this._axesLayout[o]={position:v,rotation:h,transform:c,axisNameAvailableWidth:l.axisNameAvailableWidth,axisLabelShow:l.axisLabelShow,nameTruncateMaxWidth:l.nameTruncateMaxWidth,tickDirection:1,labelDirection:1}},this)},r.prototype.getAxis=function(t){return this._axesMap.get(t)},r.prototype.dataToPoint=function(t,e){return this.axisCoordToPoint(this._axesMap.get(e).dataToCoord(t),e)},r.prototype.eachActiveState=function(t,e,a,n){a==null&&(a=0),n==null&&(n=t.count());var i=this._axesMap,o=this.dimensions,s=[],l=[];A(o,function(g){s.push(t.mapDimension(g)),l.push(i.get(g).model)});for(var u=this.hasAxisBrushed(),f=a;f<n;f++){var v=void 0;if(!u)v="normal";else{v="active";for(var h=t.getValues(s,f),c=0,p=o.length;c<p;c++){var d=l[c].getActiveState(h[c]);if(d==="inactive"){v="inactive";break}}}e(v,f)}},r.prototype.hasAxisBrushed=function(){for(var t=this.dimensions,e=this._axesMap,a=!1,n=0,i=t.length;n<i;n++)e.get(t[n]).model.getActiveState()!=="normal"&&(a=!0);return a},r.prototype.axisCoordToPoint=function(t,e){var a=this._axesLayout[e];return Hr([t,0],a.transform)},r.prototype.getAxisLayout=function(t){return et(this._axesLayout[t])},r.prototype.getSlidedAxisExpandWindow=function(t){var e=this._makeLayoutInfo(),a=e.pixelDimIndex,n=e.axisExpandWindow.slice(),i=n[1]-n[0],o=[0,e.axisExpandWidth*(e.axisCount-1)];if(!this.containPoint(t))return{behavior:"none",axisExpandWindow:n};var s=t[a]-e.layoutBase-e.axisExpandWindow0Pos,l,u="slide",f=e.axisCollapseWidth,v=this._model.get("axisExpandSlideTriggerArea"),h=v[0]!=null;if(f)h&&f&&s<i*v[0]?(u="jump",l=s-i*v[2]):h&&f&&s>i*(1-v[0])?(u="jump",l=s-i*(1-v[2])):(l=s-i*v[1])>=0&&(l=s-i*(1-v[1]))<=0&&(l=0),l*=e.axisExpandWidth/f,l?kn(l,n,o,"all"):u="none";else{var c=n[1]-n[0],p=o[1]*s/c;n=[VI(0,p-c/2)],n[1]=zI(o[1],n[0]+c),n[0]=n[1]-c}return{axisExpandWindow:n,behavior:u}},r}();function Bf(r,t){return zI(VI(r,t[0]),t[1])}function pU(r,t){var e=t.layoutLength/(t.axisCount-1);return{position:e*r,axisNameAvailableWidth:e,axisLabelShow:!0}}function dU(r,t){var e=t.layoutLength,a=t.axisExpandWidth,n=t.axisCount,i=t.axisCollapseWidth,o=t.winInnerIndices,s,l=i,u=!1,f;return r<o[0]?(s=r*i,f=i):r<=o[1]?(s=t.axisExpandWindow0Pos+r*a-t.axisExpandWindow[0],l=a,u=!0):(s=e-(n-1-r)*i,f=i),{position:s,axisNameAvailableWidth:l,axisLabelShow:u,nameTruncateMaxWidth:f}}function gU(r,t){var e=[];return r.eachComponent("parallel",function(a,n){var i=new cU(a,r,t);i.name="parallel_"+n,i.resize(a,t),a.coordinateSystem=i,i.model=a,e.push(i)}),r.eachSeries(function(a){if(a.get("coordinateSystem")==="parallel"){var n=a.getReferringComponents("parallel",Kt).models[0];a.coordinateSystem=n.coordinateSystem}}),e}var yU={create:gU},xy=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.activeIntervals=[],e}return t.prototype.getAreaSelectStyle=function(){return Fi([["fill","color"],["lineWidth","borderWidth"],["stroke","borderColor"],["width","width"],["opacity","opacity"]])(this.getModel("areaSelectStyle"))},t.prototype.setActiveIntervals=function(e){var a=this.activeIntervals=et(e);if(a)for(var n=a.length-1;n>=0;n--)lr(a[n])},t.prototype.getActiveState=function(e){var a=this.activeIntervals;if(!a.length)return"normal";if(e==null||isNaN(+e))return"inactive";if(a.length===1){var n=a[0];if(n[0]<=e&&e<=n[1])return"active"}else for(var i=0,o=a.length;i<o;i++)if(a[i][0]<=e&&e<=a[i][1])return"active";return"inactive"},t}(xt);Qt(xy,Is);var Xi=!0,pu=Math.min,fs=Math.max,mU=Math.pow,_U=1e4,SU=6,xU=6,cw="globalPan",bU={w:[0,0],e:[0,1],n:[1,0],s:[1,1]},wU={w:"ew",e:"ew",n:"ns",s:"ns",ne:"nesw",sw:"nesw",nw:"nwse",se:"nwse"},pw={brushStyle:{lineWidth:2,stroke:N.color.backgroundTint,fill:N.color.borderTint},transformable:!0,brushMode:"single",removeOnClick:!1},TU=0,W0=function(r){z(t,r);function t(e){var a=r.call(this)||this;return a._track=[],a._covers=[],a._handlers={},a._zr=e,a.group=new rt,a._uid="brushController_"+TU++,A(PU,function(n,i){this._handlers[i]=$(n,this)},a),a}return t.prototype.enableBrush=function(e){return this._brushType&&this._doDisableBrush(),e.brushType&&this._doEnableBrush(e),this},t.prototype._doEnableBrush=function(e){var a=this._zr;this._enableGlobalPan||sH(a,cw,this._uid),A(this._handlers,function(n,i){a.on(i,n)}),this._brushType=e.brushType,this._brushOption=yt(et(pw),e,!0)},t.prototype._doDisableBrush=function(){var e=this._zr;lH(e,cw,this._uid),A(this._handlers,function(a,n){e.off(n,a)}),this._brushType=this._brushOption=null},t.prototype.setPanels=function(e){if(e&&e.length){var a=this._panels={};A(e,function(n){a[n.panelId]=et(n)})}else this._panels=null;return this},t.prototype.mount=function(e){e=e||{},this._enableGlobalPan=e.enableGlobalPan;var a=this.group;return this._zr.add(a),a.attr({x:e.x||0,y:e.y||0,rotation:e.rotation||0,scaleX:e.scaleX||1,scaleY:e.scaleY||1}),this._transform=a.getLocalTransform(),this},t.prototype.updateCovers=function(e){e=U(e,function(h){return yt(et(pw),h,!0)});var a="\0-brush-index-",n=this._covers,i=this._covers=[],o=this,s=this._creatingCover;return new qa(n,e,u,l).add(f).update(f).remove(v).execute(),this;function l(h,c){return(h.id!=null?h.id:a+c)+"-"+h.brushType}function u(h,c){return l(h.__brushOption,c)}function f(h,c){var p=e[h];if(c!=null&&n[c]===s)i[h]=n[c];else{var d=i[h]=c!=null?(n[c].__brushOption=p,n[c]):FI(o,GI(o,p));U0(o,d)}}function v(h){n[h]!==s&&o.group.remove(n[h])}},t.prototype.unmount=function(){return this.enableBrush(!1),by(this),this._zr.remove(this.group),this},t.prototype.dispose=function(){this.unmount(),this.off()},t}(Pr);function GI(r,t){var e=vc[t.brushType].createCover(r,t);return e.__brushOption=t,WI(e,t),r.group.add(e),e}function FI(r,t){var e=Y0(t);return e.endCreating&&(e.endCreating(r,t),WI(t,t.__brushOption)),t}function HI(r,t){var e=t.__brushOption;Y0(t).updateCoverShape(r,t,e.range,e)}function WI(r,t){var e=t.z;e==null&&(e=_U),r.traverse(function(a){a.z=e,a.z2=e})}function U0(r,t){Y0(t).updateCommon(r,t),HI(r,t)}function Y0(r){return vc[r.__brushOption.brushType]}function Z0(r,t,e){var a=r._panels;if(!a)return Xi;var n,i=r._transform;return A(a,function(o){o.isTargetByCursor(t,e,i)&&(n=o)}),n}function UI(r,t){var e=r._panels;if(!e)return Xi;var a=t.__brushOption.panelId;return a!=null?e[a]:Xi}function by(r){var t=r._covers,e=t.length;return A(t,function(a){r.group.remove(a)},r),t.length=0,!!e}function $i(r,t){var e=U(r._covers,function(a){var n=a.__brushOption,i=et(n.range);return{brushType:n.brushType,panelId:n.panelId,range:i}});r.trigger("brush",{areas:e,isEnd:!!t.isEnd,removeOnClick:!!t.removeOnClick})}function CU(r){var t=r._track;if(!t.length)return!1;var e=t[t.length-1],a=t[0],n=e[0]-a[0],i=e[1]-a[1],o=mU(n*n+i*i,.5);return o>SU}function YI(r){var t=r.length-1;return t<0&&(t=0),[r[0],r[t]]}function ZI(r,t,e,a){var n=new rt;return n.add(new _t({name:"main",style:X0(e),silent:!0,draggable:!0,cursor:"move",drift:pt(dw,r,t,n,["n","s","w","e"]),ondragend:pt($i,t,{isEnd:!0})})),A(a,function(i){n.add(new _t({name:i.join(""),style:{opacity:0},draggable:!0,silent:!0,invisible:!0,drift:pt(dw,r,t,n,i),ondragend:pt($i,t,{isEnd:!0})}))}),n}function XI(r,t,e,a){var n=a.brushStyle.lineWidth||0,i=fs(n,xU),o=e[0][0],s=e[1][0],l=o-n/2,u=s-n/2,f=e[0][1],v=e[1][1],h=f-i+n/2,c=v-i+n/2,p=f-o,d=v-s,g=p+n,y=d+n;Ia(r,t,"main",o,s,p,d),a.transformable&&(Ia(r,t,"w",l,u,i,y),Ia(r,t,"e",h,u,i,y),Ia(r,t,"n",l,u,g,i),Ia(r,t,"s",l,c,g,i),Ia(r,t,"nw",l,u,i,i),Ia(r,t,"ne",h,u,i,i),Ia(r,t,"sw",l,c,i,i),Ia(r,t,"se",h,c,i,i))}function wy(r,t){var e=t.__brushOption,a=e.transformable,n=t.childAt(0);n.useStyle(X0(e)),n.attr({silent:!a,cursor:a?"move":"default"}),A([["w"],["e"],["n"],["s"],["s","e"],["s","w"],["n","e"],["n","w"]],function(i){var o=t.childOfName(i.join("")),s=i.length===1?Ty(r,i[0]):MU(r,i);o&&o.attr({silent:!a,invisible:!a,cursor:a?wU[s]+"-resize":null})})}function Ia(r,t,e,a,n,i,o){var s=t.childOfName(e);s&&s.setShape(LU($0(r,t,[[a,n],[a+i,n+o]])))}function X0(r){return nt({strokeNoScale:!0},r.brushStyle)}function $I(r,t,e,a){var n=[pu(r,e),pu(t,a)],i=[fs(r,e),fs(t,a)];return[[n[0],i[0]],[n[1],i[1]]]}function AU(r){return An(r.group)}function Ty(r,t){var e={w:"left",e:"right",n:"top",s:"bottom"},a={left:"w",right:"e",top:"n",bottom:"s"},n=qh(e[t],AU(r));return a[n]}function MU(r,t){var e=[Ty(r,t[0]),Ty(r,t[1])];return(e[0]==="e"||e[0]==="w")&&e.reverse(),e.join("")}function dw(r,t,e,a,n,i){var o=e.__brushOption,s=r.toRectRange(o.range),l=qI(t,n,i);A(a,function(u){var f=bU[u];s[f[0]][f[1]]+=l[f[0]]}),o.range=r.fromRectRange($I(s[0][0],s[1][0],s[0][1],s[1][1])),U0(t,e),$i(t,{isEnd:!1})}function DU(r,t,e,a){var n=t.__brushOption.range,i=qI(r,e,a);A(n,function(o){o[0]+=i[0],o[1]+=i[1]}),U0(r,t),$i(r,{isEnd:!1})}function qI(r,t,e){var a=r.group,n=a.transformCoordToLocal(t,e),i=a.transformCoordToLocal(0,0);return[n[0]-i[0],n[1]-i[1]]}function $0(r,t,e){var a=UI(r,t);return a&&a!==Xi?a.clipPath(e,r._transform):et(e)}function LU(r){var t=pu(r[0][0],r[1][0]),e=pu(r[0][1],r[1][1]),a=fs(r[0][0],r[1][0]),n=fs(r[0][1],r[1][1]);return{x:t,y:e,width:a-t,height:n-e}}function IU(r,t,e){if(!(!r._brushType||RU(r,t.offsetX,t.offsetY))){var a=r._zr,n=r._covers,i=Z0(r,t,e);if(!r._dragging)for(var o=0;o<n.length;o++){var s=n[o].__brushOption;if(i&&(i===Xi||s.panelId===i.panelId)&&vc[s.brushType].contain(n[o],e[0],e[1]))return}i&&a.setCursorStyle("crosshair")}}function Cy(r){var t=r.event;t.preventDefault&&t.preventDefault()}function Ay(r,t,e){return r.childOfName("main").contain(t,e)}function KI(r,t,e,a){var n=r._creatingCover,i=r._creatingPanel,o=r._brushOption,s;if(r._track.push(e.slice()),CU(r)||n){if(i&&!n){o.brushMode==="single"&&by(r);var l=et(o);l.brushType=gw(l.brushType,i),l.panelId=i===Xi?null:i.panelId,n=r._creatingCover=GI(r,l),r._covers.push(n)}if(n){var u=vc[gw(r._brushType,i)],f=n.__brushOption;f.range=u.getCreatingRange($0(r,n,r._track)),a&&(FI(r,n),u.updateCommon(r,n)),HI(r,n),s={isEnd:a}}}else a&&o.brushMode==="single"&&o.removeOnClick&&Z0(r,t,e)&&by(r)&&(s={isEnd:a,removeOnClick:!0});return s}function gw(r,t){return r==="auto"?t.defaultBrushType:r}var PU={mousedown:function(r){if(this._dragging)yw(this,r);else if(!r.target||!r.target.draggable){Cy(r);var t=this.group.transformCoordToLocal(r.offsetX,r.offsetY);this._creatingCover=null;var e=this._creatingPanel=Z0(this,r,t);e&&(this._dragging=!0,this._track=[t.slice()])}},mousemove:function(r){var t=r.offsetX,e=r.offsetY,a=this.group.transformCoordToLocal(t,e);if(IU(this,r,a),this._dragging){Cy(r);var n=KI(this,r,a,!1);n&&$i(this,n)}},mouseup:function(r){yw(this,r)}};function yw(r,t){if(r._dragging){Cy(t);var e=t.offsetX,a=t.offsetY,n=r.group.transformCoordToLocal(e,a),i=KI(r,t,n,!0);r._dragging=!1,r._track=[],r._creatingCover=null,i&&$i(r,i)}}function RU(r,t,e){var a=r._zr;return t<0||t>a.getWidth()||e<0||e>a.getHeight()}var vc={lineX:mw(0),lineY:mw(1),rect:{createCover:function(r,t){function e(a){return a}return ZI({toRectRange:e,fromRectRange:e},r,t,[["w"],["e"],["n"],["s"],["s","e"],["s","w"],["n","e"],["n","w"]])},getCreatingRange:function(r){var t=YI(r);return $I(t[1][0],t[1][1],t[0][0],t[0][1])},updateCoverShape:function(r,t,e,a){XI(r,t,e,a)},updateCommon:wy,contain:Ay},polygon:{createCover:function(r,t){var e=new rt;return e.add(new Ae({name:"main",style:X0(t),silent:!0})),e},getCreatingRange:function(r){return r},endCreating:function(r,t){t.remove(t.childAt(0)),t.add(new Ee({name:"main",draggable:!0,drift:pt(DU,r,t),ondragend:pt($i,r,{isEnd:!0})}))},updateCoverShape:function(r,t,e,a){t.childAt(0).setShape({points:$0(r,t,e)})},updateCommon:wy,contain:Ay}};function mw(r){return{createCover:function(t,e){return ZI({toRectRange:function(a){var n=[a,[0,100]];return r&&n.reverse(),n},fromRectRange:function(a){return a[r]}},t,e,[[["w"],["e"]],[["n"],["s"]]][r])},getCreatingRange:function(t){var e=YI(t),a=pu(e[0][r],e[1][r]),n=fs(e[0][r],e[1][r]);return[a,n]},updateCoverShape:function(t,e,a,n){var i,o=UI(t,e);if(o!==Xi&&o.getLinearBrushOtherExtent)i=o.getLinearBrushOtherExtent(r);else{var s=t._zr;i=[0,[s.getWidth(),s.getHeight()][1-r]]}var l=[a,i];r&&l.reverse(),XI(t,e,l,n)},updateCommon:wy,contain:Ay}}function jI(r){return r=q0(r),function(t){return Lm(t,r)}}function JI(r,t){return r=q0(r),function(e){var a=t??e,n=a?r.width:r.height,i=a?r.x:r.y;return[i,i+(n||0)]}}function QI(r,t,e){var a=q0(r);return function(n,i){return a.contain(i[0],i[1])&&!nI(n,t,e)}}function q0(r){return lt.create(r)}var kU=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(e,a){r.prototype.init.apply(this,arguments),(this._brushController=new W0(a.getZr())).on("brush",$(this._onBrush,this))},t.prototype.render=function(e,a,n,i){if(!EU(e,a,i)){this.axisModel=e,this.api=n,this.group.removeAll();var o=this._axisGroup;if(this._axisGroup=new rt,this.group.add(this._axisGroup),!!e.get("show")){var s=NU(e,a),l=s.coordinateSystem,u=e.getAreaSelectStyle(),f=u.width,v=e.axis.dim,h=l.getAxisLayout(v),c=G({strokeContainThreshold:f},h),p=new Ye(e,n,c);p.build(),this._axisGroup.add(p.group),this._refreshBrushController(c,u,e,s,f,n),Du(o,this._axisGroup,e)}}},t.prototype._refreshBrushController=function(e,a,n,i,o,s){var l=n.axis.getExtent(),u=l[1]-l[0],f=Math.min(30,Math.abs(u)*.1),v=lt.create({x:l[0],y:-o/2,width:u,height:o});v.x-=f,v.width+=2*f,this._brushController.mount({enableGlobalPan:!0,rotation:e.rotation,x:e.position[0],y:e.position[1]}).setPanels([{panelId:"pl",clipPath:jI(v),isTargetByCursor:QI(v,s,i),getLinearBrushOtherExtent:JI(v,0)}]).enableBrush({brushType:"lineX",brushStyle:a,removeOnClick:!0}).updateCovers(OU(n))},t.prototype._onBrush=function(e){var a=e.areas,n=this.axisModel,i=n.axis,o=U(a,function(s){return[i.coordToData(s.range[0],!0),i.coordToData(s.range[1],!0)]});(!n.option.realtime===e.isEnd||e.removeOnClick)&&this.api.dispatchAction({type:"axisAreaSelect",parallelAxisId:n.id,intervals:o})},t.prototype.dispose=function(){this._brushController.dispose()},t.type="parallelAxis",t}(Wt);function EU(r,t,e){return e&&e.type==="axisAreaSelect"&&t.findComponents({mainType:"parallelAxis",query:e})[0]===r}function OU(r){var t=r.axis;return U(r.activeIntervals,function(e){return{brushType:"lineX",panelId:"pl",range:[t.dataToCoord(e[0],!0),t.dataToCoord(e[1],!0)]}})}function NU(r,t){return t.getComponent("parallel",r.get("parallelIndex"))}var BU={type:"axisAreaSelect",event:"axisAreaSelected"};function zU(r){r.registerAction(BU,function(t,e){e.eachComponent({mainType:"parallelAxis",query:t},function(a){a.axis.model.setActiveIntervals(t.intervals)})}),r.registerAction("parallelAxisExpand",function(t,e){e.eachComponent({mainType:"parallel",query:t},function(a){a.setAxisExpand(t)})})}var VU={type:"value",areaSelectStyle:{width:20,borderWidth:1,borderColor:"rgba(160,197,232)",color:"rgba(160,197,232)",opacity:.3},realtime:!0,z:10};function tP(r){r.registerComponentView(sU),r.registerComponentModel(uU),r.registerCoordinateSystem("parallel",yU),r.registerPreprocessor(aU),r.registerComponentModel(xy),r.registerComponentView(kU),ls(r,"parallel",xy,VU),zU(r)}function GU(r){mt(tP),r.registerChartView(qW),r.registerSeriesModel(JW),r.registerVisual(r.PRIORITY.VISUAL.BRUSH,rU)}var FU=function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.cpx1=0,this.cpy1=0,this.cpx2=0,this.cpy2=0,this.extent=0}return r}(),HU=function(r){z(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new FU},t.prototype.buildPath=function(e,a){var n=a.extent;e.moveTo(a.x1,a.y1),e.bezierCurveTo(a.cpx1,a.cpy1,a.cpx2,a.cpy2,a.x2,a.y2),a.orient==="vertical"?(e.lineTo(a.x2+n,a.y2),e.bezierCurveTo(a.cpx2+n,a.cpy2,a.cpx1+n,a.cpy1,a.x1+n,a.y1)):(e.lineTo(a.x2,a.y2+n),e.bezierCurveTo(a.cpx2,a.cpy2+n,a.cpx1,a.cpy1+n,a.x1,a.y1+n)),e.closePath()},t.prototype.highlight=function(){Xa(this)},t.prototype.downplay=function(){$a(this)},t}(bt),WU=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e._mainGroup=new rt,e._focusAdjacencyDisabled=!1,e}return t.prototype.init=function(e,a){this._controller=new ao(a.getZr()),this._controllerHost={target:this.group},this.group.add(this._mainGroup)},t.prototype.render=function(e,a,n){var i=this,o=e.getGraph(),s=this._mainGroup,l=e.layoutInfo,u=l.width,f=l.height,v=e.getData(),h=e.getData("edge"),c=e.get("orient");this._model=e,s.removeAll(),s.x=l.x,s.y=l.y,this._updateViewCoordSys(e,n),iI(e,n,s,this._controller,this._controllerHost,null),o.eachEdge(function(p){var d=new HU,g=ut(d);g.dataIndex=p.dataIndex,g.seriesIndex=e.seriesIndex,g.dataType="edge";var y=p.getModel(),m=y.getModel("lineStyle"),_=m.get("curveness"),S=p.node1.getLayout(),x=p.node1.getModel(),b=x.get("localX"),w=x.get("localY"),T=p.node2.getLayout(),C=p.node2.getModel(),M=C.get("localX"),D=C.get("localY"),I=p.getLayout(),L,P,k,R,O,E,B,V;d.shape.extent=Math.max(1,I.dy),d.shape.orient=c,c==="vertical"?(L=(b!=null?b*u:S.x)+I.sy,P=(w!=null?w*f:S.y)+S.dy,k=(M!=null?M*u:T.x)+I.ty,R=D!=null?D*f:T.y,O=L,E=P*(1-_)+R*_,B=k,V=P*_+R*(1-_)):(L=(b!=null?b*u:S.x)+S.dx,P=(w!=null?w*f:S.y)+I.sy,k=M!=null?M*u:T.x,R=(D!=null?D*f:T.y)+I.ty,O=L*(1-_)+k*_,E=P,B=L*_+k*(1-_),V=R),d.setShape({x1:L,y1:P,x2:k,y2:R,cpx1:O,cpy1:E,cpx2:B,cpy2:V}),d.useStyle(m.getItemStyle()),_w(d.style,c,p);var F=""+y.get("value"),H=ce(y,"edgeLabel");Se(d,H,{labelFetcher:{getFormattedLabel:function(ft,It,Ot,vt,at,dt){return e.getFormattedLabel(ft,It,"edge",vt,Qe(at,H.normal&&H.normal.get("formatter"),F),dt)}},labelDataIndex:p.dataIndex,defaultText:F}),d.setTextConfig({position:"inside"});var Y=y.getModel("emphasis");he(d,y,"lineStyle",function(ft){var It=ft.getItemStyle();return _w(It,c,p),It}),s.add(d),h.setItemGraphicEl(p.dataIndex,d);var K=Y.get("focus");$t(d,K==="adjacency"?p.getAdjacentDataIndices():K==="trajectory"?p.getTrajectoryDataIndices():K,Y.get("blurScope"),Y.get("disabled"))}),o.eachNode(function(p){var d=p.getLayout(),g=p.getModel(),y=g.get("localX"),m=g.get("localY"),_=g.getModel("emphasis"),S=g.get(["itemStyle","borderRadius"])||0,x=new _t({shape:{x:y!=null?y*u:d.x,y:m!=null?m*f:d.y,width:d.dx,height:d.dy,r:S},style:g.getModel("itemStyle").getItemStyle(),z2:10});Se(x,ce(g),{labelFetcher:{getFormattedLabel:function(w,T){return e.getFormattedLabel(w,T,"node")}},labelDataIndex:p.dataIndex,defaultText:p.id}),x.disableLabelAnimation=!0,x.setStyle("fill",p.getVisual("color")),x.setStyle("decal",p.getVisual("style").decal),he(x,g),s.add(x),v.setItemGraphicEl(p.dataIndex,x),ut(x).dataType="node";var b=_.get("focus");$t(x,b==="adjacency"?p.getAdjacentDataIndices():b==="trajectory"?p.getTrajectoryDataIndices():b,_.get("blurScope"),_.get("disabled"))}),v.eachItemGraphicEl(function(p,d){var g=v.getItemModel(d);g.get("draggable")&&(p.drift=function(y,m){i._focusAdjacencyDisabled=!0,this.shape.x+=y,this.shape.y+=m,this.dirty(),n.dispatchAction({type:"dragNode",seriesId:e.id,dataIndex:v.getRawIndex(d),localX:this.shape.x/u,localY:this.shape.y/f})},p.ondragend=function(){i._focusAdjacencyDisabled=!1},p.draggable=!0,p.cursor="move")}),!this._data&&e.isAnimationEnabled()&&s.setClipPath(UU(s.getBoundingRect(),e,function(){s.removeClipPath()})),this._data=e.getData()},t.prototype.dispose=function(){this._controller&&this._controller.dispose(),this._controllerHost=null},t.prototype._updateViewCoordSys=function(e,a){var n=e.layoutInfo,i=n.width,o=n.height,s=e.coordinateSystem=new no(null,{api:a,ecModel:e.ecModel});s.zoomLimit=e.get("scaleLimit"),s.setBoundingRect(0,0,i,o),s.setCenter(e.get("center")),s.setZoom(e.get("zoom")),this._controllerHost.target.attr({x:s.x,y:s.y,scaleX:s.scaleX,scaleY:s.scaleY})},t.type="sankey",t}(Nt);function _w(r,t,e){switch(r.fill){case"source":r.fill=e.node1.getVisual("color"),r.decal=e.node1.getVisual("style").decal;break;case"target":r.fill=e.node2.getVisual("color"),r.decal=e.node2.getVisual("style").decal;break;case"gradient":var a=e.node1.getVisual("color"),n=e.node2.getVisual("color");X(a)&&X(n)&&(r.fill=new Ki(0,0,+(t==="horizontal"),+(t==="vertical"),[{color:a,offset:0},{color:n,offset:1}]))}}function UU(r,t,e){var a=new _t({shape:{x:r.x-10,y:r.y-10,width:0,height:r.height+20}});return Yt(a,{shape:{width:r.width+20}},t,e),a}var YU=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.getInitialData=function(e,a){var n=e.edges||e.links||[],i=e.data||e.nodes||[],o=e.levels||[];this.levelModels=[];for(var s=this.levelModels,l=0;l<o.length;l++)o[l].depth!=null&&o[l].depth>=0&&(s[o[l].depth]=new wt(o[l],this,a));var u=H0(i,n,this,!0,f);return u.data;function f(v,h){v.wrapMethod("getItemModel",function(c,p){var d=c.parentModel,g=d.getData().getItemLayout(p);if(g){var y=g.depth,m=d.levelModels[y];m&&(c.parentModel=m)}return c}),h.wrapMethod("getItemModel",function(c,p){var d=c.parentModel,g=d.getGraph().getEdgeByIndex(p),y=g.node1.getLayout();if(y){var m=y.depth,_=d.levelModels[m];_&&(c.parentModel=_)}return c})}},t.prototype.setNodePosition=function(e,a){var n=this.option.data||this.option.nodes,i=n[e];i.localX=a[0],i.localY=a[1]},t.prototype.setCenter=function(e){this.option.center=e},t.prototype.setZoom=function(e){this.option.zoom=e},t.prototype.getGraph=function(){return this.getData().graph},t.prototype.getEdgeData=function(){return this.getGraph().edgeData},t.prototype.formatTooltip=function(e,a,n){function i(c){return isNaN(c)||c==null}if(n==="edge"){var o=this.getDataParams(e,n),s=o.data,l=o.value,u=s.source+" -- "+s.target;return ue("nameValue",{name:u,value:l,noValue:i(l)})}else{var f=this.getGraph().getNodeByIndex(e),v=f.getLayout().value,h=this.getDataParams(e,n).data.name;return ue("nameValue",{name:h!=null?h+"":null,value:v,noValue:i(v)})}},t.prototype.optionUpdated=function(){},t.prototype.getDataParams=function(e,a){var n=r.prototype.getDataParams.call(this,e,a);if(n.value==null&&a==="node"){var i=this.getGraph().getNodeByIndex(e),o=i.getLayout().value;n.value=o}return n},t.type="series.sankey",t.layoutMode="box",t.defaultOption={z:2,coordinateSystemUsage:"box",left:"5%",top:"5%",right:"20%",bottom:"5%",orient:"horizontal",nodeWidth:20,nodeGap:8,draggable:!0,layoutIterations:32,roam:!1,roamTrigger:"global",center:null,zoom:1,label:{show:!0,position:"right",fontSize:12},edgeLabel:{show:!1,fontSize:12},levels:[],nodeAlign:"justify",lineStyle:{color:N.color.neutral50,opacity:.2,curveness:.5},emphasis:{label:{show:!0},lineStyle:{opacity:.5}},select:{itemStyle:{borderColor:N.color.primary}},animationEasing:"linear",animationDuration:1e3},t}(Bt);function ZU(r,t){r.eachSeriesByType("sankey",function(e){var a=e.get("nodeWidth"),n=e.get("nodeGap"),i=pe(e,t).refContainer,o=Xt(e.getBoxLayoutParams(),i);e.layoutInfo=o;var s=o.width,l=o.height,u=e.getGraph(),f=u.nodes,v=u.edges;$U(f);var h=Pt(f,function(g){return g.getLayout().value===0}),c=h.length!==0?0:e.get("layoutIterations"),p=e.get("orient"),d=e.get("nodeAlign");XU(f,v,a,n,s,l,c,p,d)})}function XU(r,t,e,a,n,i,o,s,l){qU(r,t,e,n,i,s,l),QU(r,t,i,n,a,o,s),l8(r,s)}function $U(r){A(r,function(t){var e=Ln(t.outEdges,dh),a=Ln(t.inEdges,dh),n=t.getValue()||0,i=Math.max(e,a,n);t.setLayout({value:i},!0)})}function qU(r,t,e,a,n,i,o){for(var s=[],l=[],u=[],f=[],v=0,h=0;h<t.length;h++)s[h]=1;for(var h=0;h<r.length;h++)l[h]=r[h].inEdges.length,l[h]===0&&u.push(r[h]);for(var c=-1;u.length;){for(var p=0;p<u.length;p++){var d=u[p],g=d.hostGraph.data.getRawDataItem(d.dataIndex),y=g.depth!=null&&g.depth>=0;y&&g.depth>c&&(c=g.depth),d.setLayout({depth:y?g.depth:v},!0),i==="vertical"?d.setLayout({dy:e},!0):d.setLayout({dx:e},!0);for(var m=0;m<d.outEdges.length;m++){var _=d.outEdges[m],S=t.indexOf(_);s[S]=0;var x=_.node2,b=r.indexOf(x);--l[b]===0&&f.indexOf(x)<0&&f.push(x)}}++v,u=f,f=[]}for(var h=0;h<s.length;h++)if(s[h]===1)throw new Error("Sankey is a DAG, the original data has cycle!");var w=c>v-1?c:v-1;o&&o!=="left"&&KU(r,o,i,w);var T=i==="vertical"?(n-e)/w:(a-e)/w;JU(r,T,i)}function eP(r){var t=r.hostGraph.data.getRawDataItem(r.dataIndex);return t.depth!=null&&t.depth>=0}function KU(r,t,e,a){if(t==="right"){for(var n=[],i=r,o=0;i.length;){for(var s=0;s<i.length;s++){var l=i[s];l.setLayout({skNodeHeight:o},!0);for(var u=0;u<l.inEdges.length;u++){var f=l.inEdges[u];n.indexOf(f.node1)<0&&n.push(f.node1)}}i=n,n=[],++o}A(r,function(v){eP(v)||v.setLayout({depth:Math.max(0,a-v.getLayout().skNodeHeight)},!0)})}else t==="justify"&&jU(r,a)}function jU(r,t){A(r,function(e){!eP(e)&&!e.outEdges.length&&e.setLayout({depth:t},!0)})}function JU(r,t,e){A(r,function(a){var n=a.getLayout().depth*t;e==="vertical"?a.setLayout({y:n},!0):a.setLayout({x:n},!0)})}function QU(r,t,e,a,n,i,o){var s=t8(r,o);e8(s,t,e,a,n,o),id(s,n,e,a,o);for(var l=1;i>0;i--)l*=.99,r8(s,l,o),id(s,n,e,a,o),s8(s,l,o),id(s,n,e,a,o)}function t8(r,t){var e=[],a=t==="vertical"?"y":"x",n=hg(r,function(i){return i.getLayout()[a]});return n.keys.sort(function(i,o){return i-o}),A(n.keys,function(i){e.push(n.buckets.get(i))}),e}function e8(r,t,e,a,n,i){var o=1/0;A(r,function(s){var l=s.length,u=0;A(s,function(v){u+=v.getLayout().value});var f=i==="vertical"?(a-(l-1)*n)/u:(e-(l-1)*n)/u;f<o&&(o=f)}),A(r,function(s){A(s,function(l,u){var f=l.getLayout().value*o;i==="vertical"?(l.setLayout({x:u},!0),l.setLayout({dx:f},!0)):(l.setLayout({y:u},!0),l.setLayout({dy:f},!0))})}),A(t,function(s){var l=+s.getValue()*o;s.setLayout({dy:l},!0)})}function id(r,t,e,a,n){var i=n==="vertical"?"x":"y";A(r,function(o){o.sort(function(d,g){return d.getLayout()[i]-g.getLayout()[i]});for(var s,l,u,f=0,v=o.length,h=n==="vertical"?"dx":"dy",c=0;c<v;c++)l=o[c],u=f-l.getLayout()[i],u>0&&(s=l.getLayout()[i]+u,n==="vertical"?l.setLayout({x:s},!0):l.setLayout({y:s},!0)),f=l.getLayout()[i]+l.getLayout()[h]+t;var p=n==="vertical"?a:e;if(u=f-t-p,u>0){s=l.getLayout()[i]-u,n==="vertical"?l.setLayout({x:s},!0):l.setLayout({y:s},!0),f=s;for(var c=v-2;c>=0;--c)l=o[c],u=l.getLayout()[i]+l.getLayout()[h]+t-f,u>0&&(s=l.getLayout()[i]-u,n==="vertical"?l.setLayout({x:s},!0):l.setLayout({y:s},!0)),f=l.getLayout()[i]}})}function r8(r,t,e){A(r.slice().reverse(),function(a){A(a,function(n){if(n.outEdges.length){var i=Ln(n.outEdges,a8,e)/Ln(n.outEdges,dh);if(isNaN(i)){var o=n.outEdges.length;i=o?Ln(n.outEdges,n8,e)/o:0}if(e==="vertical"){var s=n.getLayout().x+(i-En(n,e))*t;n.setLayout({x:s},!0)}else{var l=n.getLayout().y+(i-En(n,e))*t;n.setLayout({y:l},!0)}}})})}function a8(r,t){return En(r.node2,t)*r.getValue()}function n8(r,t){return En(r.node2,t)}function i8(r,t){return En(r.node1,t)*r.getValue()}function o8(r,t){return En(r.node1,t)}function En(r,t){return t==="vertical"?r.getLayout().x+r.getLayout().dx/2:r.getLayout().y+r.getLayout().dy/2}function dh(r){return r.getValue()}function Ln(r,t,e){for(var a=0,n=r.length,i=-1;++i<n;){var o=+t(r[i],e);isNaN(o)||(a+=o)}return a}function s8(r,t,e){A(r,function(a){A(a,function(n){if(n.inEdges.length){var i=Ln(n.inEdges,i8,e)/Ln(n.inEdges,dh);if(isNaN(i)){var o=n.inEdges.length;i=o?Ln(n.inEdges,o8,e)/o:0}if(e==="vertical"){var s=n.getLayout().x+(i-En(n,e))*t;n.setLayout({x:s},!0)}else{var l=n.getLayout().y+(i-En(n,e))*t;n.setLayout({y:l},!0)}}})})}function l8(r,t){var e=t==="vertical"?"x":"y";A(r,function(a){a.outEdges.sort(function(n,i){return n.node2.getLayout()[e]-i.node2.getLayout()[e]}),a.inEdges.sort(function(n,i){return n.node1.getLayout()[e]-i.node1.getLayout()[e]})}),A(r,function(a){var n=0,i=0;A(a.outEdges,function(o){o.setLayout({sy:n},!0),n+=o.getLayout().dy}),A(a.inEdges,function(o){o.setLayout({ty:i},!0),i+=o.getLayout().dy})})}function u8(r){r.eachSeriesByType("sankey",function(t){var e=t.getGraph(),a=e.nodes,n=e.edges;if(a.length){var i=1/0,o=-1/0;A(a,function(s){var l=s.getLayout().value;l<i&&(i=l),l>o&&(o=l)}),A(a,function(s){var l=new _e({type:"color",mappingMethod:"linear",dataExtent:[i,o],visual:t.get("color")}),u=l.mapValueToVisual(s.getLayout().value),f=s.getModel().get(["itemStyle","color"]);f!=null?(s.setVisual("color",f),s.setVisual("style",{fill:f})):(s.setVisual("color",u),s.setVisual("style",{fill:u}))})}n.length&&A(n,function(s){var l=s.getModel().get("lineStyle");s.setVisual("style",l)})})}function f8(r){r.registerChartView(WU),r.registerSeriesModel(YU),r.registerLayout(ZU),r.registerVisual(u8),r.registerAction({type:"dragNode",event:"dragnode",update:"update"},function(t,e){e.eachComponent({mainType:"series",subType:"sankey",query:t},function(a){a.setNodePosition(t.dataIndex,[t.localX,t.localY])})}),r.registerAction({type:"sankeyRoam",event:"sankeyRoam",update:"none"},function(t,e,a){e.eachComponent({mainType:"series",subType:"sankey",query:t},function(n){var i=n.coordinateSystem,o=sc(i,t,n.get("scaleLimit"));n.setCenter(o.center),n.setZoom(o.zoom)})})}var rP=function(){function r(){}return r.prototype._hasEncodeRule=function(t){var e=this.getEncode();return e&&e.get(t)!=null},r.prototype.getInitialData=function(t,e){var a,n=e.getComponent("xAxis",this.get("xAxisIndex")),i=e.getComponent("yAxis",this.get("yAxisIndex")),o=n.get("type"),s=i.get("type"),l;o==="category"?(t.layout="horizontal",a=n.getOrdinalMeta(),l=!this._hasEncodeRule("x")):s==="category"?(t.layout="vertical",a=i.getOrdinalMeta(),l=!this._hasEncodeRule("y")):t.layout=t.layout||"horizontal";var u=["x","y"],f=t.layout==="horizontal"?0:1,v=this._baseAxisDim=u[f],h=u[1-f],c=[n,i],p=c[f].get("type"),d=c[1-f].get("type"),g=t.data;if(g&&l){var y=[];A(g,function(S,x){var b;W(S)?(b=S.slice(),S.unshift(x)):W(S.value)?(b=G({},S),b.value=b.value.slice(),S.value.unshift(x)):b=S,y.push(b)}),t.data=y}var m=this.defaultValueDimensions,_=[{name:v,type:Jv(p),ordinalMeta:a,otherDims:{tooltip:!1,itemName:0},dimsDef:["base"]},{name:h,type:Jv(d),dimsDef:m.slice()}];return Rs(this,{coordDimensions:_,dimensionsCount:m.length+1,encodeDefaulter:pt(pD,_,this)})},r.prototype.getBaseAxis=function(){var t=this._baseAxisDim;return this.ecModel.getComponent(t+"Axis",this.get(t+"AxisIndex")).axis},r}(),aP=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.defaultValueDimensions=[{name:"min",defaultTooltip:!0},{name:"Q1",defaultTooltip:!0},{name:"median",defaultTooltip:!0},{name:"Q3",defaultTooltip:!0},{name:"max",defaultTooltip:!0}],e.visualDrawType="stroke",e}return t.type="series.boxplot",t.dependencies=["xAxis","yAxis","grid"],t.defaultOption={z:2,coordinateSystem:"cartesian2d",legendHoverLink:!0,layout:null,boxWidth:[7,50],itemStyle:{color:N.color.neutral00,borderWidth:1},emphasis:{scale:!0,itemStyle:{borderWidth:2,shadowBlur:5,shadowOffsetX:1,shadowOffsetY:1,shadowColor:N.color.shadow}},animationDuration:800},t}(Bt);Qt(aP,rP,!0);var v8=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n){var i=e.getData(),o=this.group,s=this._data;this._data||o.removeAll();var l=e.get("layout")==="horizontal"?1:0;i.diff(s).add(function(u){if(i.hasValue(u)){var f=i.getItemLayout(u),v=Sw(f,i,u,l,!0);i.setItemGraphicEl(u,v),o.add(v)}}).update(function(u,f){var v=s.getItemGraphicEl(f);if(!i.hasValue(u)){o.remove(v);return}var h=i.getItemLayout(u);v?(Ir(v),nP(h,v,i,u)):v=Sw(h,i,u,l),o.add(v),i.setItemGraphicEl(u,v)}).remove(function(u){var f=s.getItemGraphicEl(u);f&&o.remove(f)}).execute(),this._data=i},t.prototype.remove=function(e){var a=this.group,n=this._data;this._data=null,n&&n.eachItemGraphicEl(function(i){i&&a.remove(i)})},t.type="boxplot",t}(Nt),h8=function(){function r(){}return r}(),c8=function(r){z(t,r);function t(e){var a=r.call(this,e)||this;return a.type="boxplotBoxPath",a}return t.prototype.getDefaultShape=function(){return new h8},t.prototype.buildPath=function(e,a){var n=a.points,i=0;for(e.moveTo(n[i][0],n[i][1]),i++;i<4;i++)e.lineTo(n[i][0],n[i][1]);for(e.closePath();i<n.length;i++)e.moveTo(n[i][0],n[i][1]),i++,e.lineTo(n[i][0],n[i][1])},t}(bt);function Sw(r,t,e,a,n){var i=r.ends,o=new c8({shape:{points:n?p8(i,a,r):i}});return nP(r,o,t,e,n),o}function nP(r,t,e,a,n){var i=e.hostModel,o=ji[n?"initProps":"updateProps"];o(t,{shape:{points:r.ends}},i,a),t.useStyle(e.getItemVisual(a,"style")),t.style.strokeNoScale=!0,t.z2=100;var s=e.getItemModel(a),l=s.getModel("emphasis");he(t,s),$t(t,l.get("focus"),l.get("blurScope"),l.get("disabled"))}function p8(r,t,e){return U(r,function(a){return a=a.slice(),a[t]=e.initBaseline,a})}var zl=A;function d8(r){var t=g8(r);zl(t,function(e){var a=e.seriesModels;a.length&&(y8(e),zl(a,function(n,i){m8(n,e.boxOffsetList[i],e.boxWidthList[i])}))})}function g8(r){var t=[],e=[];return r.eachSeriesByType("boxplot",function(a){var n=a.getBaseAxis(),i=gt(e,n);i<0&&(i=e.length,e[i]=n,t[i]={axis:n,seriesModels:[]}),t[i].seriesModels.push(a)}),t}function y8(r){var t=r.axis,e=r.seriesModels,a=e.length,n=r.boxWidthList=[],i=r.boxOffsetList=[],o=[],s;if(t.type==="category")s=t.getBandWidth();else{var l=0;zl(e,function(p){l=Math.max(l,p.getData().count())});var u=t.getExtent();s=Math.abs(u[1]-u[0])/l}zl(e,function(p){var d=p.get("boxWidth");W(d)||(d=[d,d]),o.push([Z(d[0],s)||0,Z(d[1],s)||0])});var f=s*.8-2,v=f/a*.3,h=(f-v*(a-1))/a,c=h/2-f/2;zl(e,function(p,d){i.push(c),c+=v+h,n.push(Math.min(Math.max(h,o[d][0]),o[d][1]))})}function m8(r,t,e){var a=r.coordinateSystem,n=r.getData(),i=e/2,o=r.get("layout")==="horizontal"?0:1,s=1-o,l=["x","y"],u=n.mapDimension(l[o]),f=n.mapDimensionsAll(l[s]);if(u==null||f.length<5)return;for(var v=0;v<n.count();v++){var h=n.get(u,v),c=_(h,f[2],v),p=_(h,f[0],v),d=_(h,f[1],v),g=_(h,f[3],v),y=_(h,f[4],v),m=[];S(m,d,!1),S(m,g,!0),m.push(p,d,y,g),x(m,p),x(m,y),x(m,c),n.setItemLayout(v,{initBaseline:c[s],ends:m})}function _(b,w,T){var C=n.get(w,T),M=[];M[o]=b,M[s]=C;var D;return isNaN(b)||isNaN(C)?D=[NaN,NaN]:(D=a.dataToPoint(M),D[o]+=t),D}function S(b,w,T){var C=w.slice(),M=w.slice();C[o]+=i,M[o]-=i,T?b.push(C,M):b.push(M,C)}function x(b,w){var T=w.slice(),C=w.slice();T[o]-=i,C[o]+=i,b.push(T,C)}}function _8(r,t){t=t||{};for(var e=[],a=[],n=t.boundIQR,i=n==="none"||n===0,o=0;o<r.length;o++){var s=lr(r[o].slice()),l=ov(s,.25),u=ov(s,.5),f=ov(s,.75),v=s[0],h=s[s.length-1],c=(n??1.5)*(f-l),p=i?v:Math.max(v,l-c),d=i?h:Math.min(h,f+c),g=t.itemNameFormatter,y=tt(g)?g({value:o}):X(g)?g.replace("{value}",o+""):o+"";e.push([y,p,l,u,f,d]);for(var m=0;m<s.length;m++){var _=s[m];if(_<p||_>d){var S=[y,_];a.push(S)}}}return{boxData:e,outliers:a}}var S8={type:"echarts:boxplot",transform:function(t){var e=t.upstream;if(e.sourceFormat!==Me){var a="";kt(a)}var n=_8(e.getRawData(),t.config);return[{dimensions:["ItemName","Low","Q1","Q2","Q3","High"],data:n.boxData},{data:n.outliers}]}};function x8(r){r.registerSeriesModel(aP),r.registerChartView(v8),r.registerLayout(d8),r.registerTransform(S8)}var b8=["itemStyle","borderColor"],w8=["itemStyle","borderColor0"],T8=["itemStyle","borderColorDoji"],C8=["itemStyle","color"],A8=["itemStyle","color0"];function K0(r,t){return t.get(r>0?C8:A8)}function j0(r,t){return t.get(r===0?T8:r>0?b8:w8)}var M8={seriesType:"candlestick",plan:Cs(),performRawSeries:!0,reset:function(r,t){if(!t.isSeriesFiltered(r)){var e=r.pipelineContext.large;return!e&&{progress:function(a,n){for(var i;(i=a.next())!=null;){var o=n.getItemModel(i),s=n.getItemLayout(i).sign,l=o.getItemStyle();l.fill=K0(s,o),l.stroke=j0(s,o)||l.fill;var u=n.ensureUniqueItemVisual(i,"style");G(u,l)}}}}}},D8=["color","borderColor"],L8=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n){this.group.removeClipPath(),this._progressiveEls=null,this._updateDrawMode(e),this._isLargeDraw?this._renderLarge(e):this._renderNormal(e)},t.prototype.incrementalPrepareRender=function(e,a,n){this._clear(),this._updateDrawMode(e)},t.prototype.incrementalRender=function(e,a,n,i){this._progressiveEls=[],this._isLargeDraw?this._incrementalRenderLarge(e,a):this._incrementalRenderNormal(e,a)},t.prototype.eachRendered=function(e){zn(this._progressiveEls||this.group,e)},t.prototype._updateDrawMode=function(e){var a=e.pipelineContext.large;(this._isLargeDraw==null||a!==this._isLargeDraw)&&(this._isLargeDraw=a,this._clear())},t.prototype._renderNormal=function(e){var a=e.getData(),n=this._data,i=this.group,o=a.getLayout("isSimpleBox"),s=e.get("clip",!0),l=e.coordinateSystem,u=l.getArea&&l.getArea();this._data||i.removeAll(),a.diff(n).add(function(f){if(a.hasValue(f)){var v=a.getItemLayout(f);if(s&&xw(u,v))return;var h=od(v,f,!0);Yt(h,{shape:{points:v.ends}},e,f),sd(h,a,f,o),i.add(h),a.setItemGraphicEl(f,h)}}).update(function(f,v){var h=n.getItemGraphicEl(v);if(!a.hasValue(f)){i.remove(h);return}var c=a.getItemLayout(f);if(s&&xw(u,c)){i.remove(h);return}h?(Lt(h,{shape:{points:c.ends}},e,f),Ir(h)):h=od(c),sd(h,a,f,o),i.add(h),a.setItemGraphicEl(f,h)}).remove(function(f){var v=n.getItemGraphicEl(f);v&&i.remove(v)}).execute(),this._data=a},t.prototype._renderLarge=function(e){this._clear(),bw(e,this.group);var a=e.get("clip",!0)?Ou(e.coordinateSystem,!1,e):null;a?this.group.setClipPath(a):this.group.removeClipPath()},t.prototype._incrementalRenderNormal=function(e,a){for(var n=a.getData(),i=n.getLayout("isSimpleBox"),o;(o=e.next())!=null;){var s=n.getItemLayout(o),l=od(s);sd(l,n,o,i),l.incremental=!0,this.group.add(l),this._progressiveEls.push(l)}},t.prototype._incrementalRenderLarge=function(e,a){bw(a,this.group,this._progressiveEls,!0)},t.prototype.remove=function(e){this._clear()},t.prototype._clear=function(){this.group.removeAll(),this._data=null},t.type="candlestick",t}(Nt),I8=function(){function r(){}return r}(),P8=function(r){z(t,r);function t(e){var a=r.call(this,e)||this;return a.type="normalCandlestickBox",a}return t.prototype.getDefaultShape=function(){return new I8},t.prototype.buildPath=function(e,a){var n=a.points;this.__simpleBox?(e.moveTo(n[4][0],n[4][1]),e.lineTo(n[6][0],n[6][1])):(e.moveTo(n[0][0],n[0][1]),e.lineTo(n[1][0],n[1][1]),e.lineTo(n[2][0],n[2][1]),e.lineTo(n[3][0],n[3][1]),e.closePath(),e.moveTo(n[4][0],n[4][1]),e.lineTo(n[5][0],n[5][1]),e.moveTo(n[6][0],n[6][1]),e.lineTo(n[7][0],n[7][1]))},t}(bt);function od(r,t,e){var a=r.ends;return new P8({shape:{points:e?R8(a,r):a},z2:100})}function xw(r,t){for(var e=!0,a=0;a<t.ends.length;a++)if(r.contain(t.ends[a][0],t.ends[a][1])){e=!1;break}return e}function sd(r,t,e,a){var n=t.getItemModel(e);r.useStyle(t.getItemVisual(e,"style")),r.style.strokeNoScale=!0,r.__simpleBox=a,he(r,n);var i=t.getItemLayout(e).sign;A(r.states,function(s,l){var u=n.getModel(l),f=K0(i,u),v=j0(i,u)||f,h=s.style||(s.style={});f&&(h.fill=f),v&&(h.stroke=v)});var o=n.getModel("emphasis");$t(r,o.get("focus"),o.get("blurScope"),o.get("disabled"))}function R8(r,t){return U(r,function(e){return e=e.slice(),e[1]=t.initBaseline,e})}var k8=function(){function r(){}return r}(),ld=function(r){z(t,r);function t(e){var a=r.call(this,e)||this;return a.type="largeCandlestickBox",a}return t.prototype.getDefaultShape=function(){return new k8},t.prototype.buildPath=function(e,a){for(var n=a.points,i=0;i<n.length;)if(this.__sign===n[i++]){var o=n[i++];e.moveTo(o,n[i++]),e.lineTo(o,n[i++])}else i+=3},t}(bt);function bw(r,t,e,a){var n=r.getData(),i=n.getLayout("largePoints"),o=new ld({shape:{points:i},__sign:1,ignoreCoarsePointer:!0});t.add(o);var s=new ld({shape:{points:i},__sign:-1,ignoreCoarsePointer:!0});t.add(s);var l=new ld({shape:{points:i},__sign:0,ignoreCoarsePointer:!0});t.add(l),ud(1,o,r),ud(-1,s,r),ud(0,l,r),a&&(o.incremental=!0,s.incremental=!0),e&&e.push(o,s)}function ud(r,t,e,a){var n=j0(r,e)||K0(r,e),i=e.getModel("itemStyle").getItemStyle(D8);t.useStyle(i),t.style.fill=null,t.style.stroke=n}var iP=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.defaultValueDimensions=[{name:"open",defaultTooltip:!0},{name:"close",defaultTooltip:!0},{name:"lowest",defaultTooltip:!0},{name:"highest",defaultTooltip:!0}],e}return t.prototype.getShadowDim=function(){return"open"},t.prototype.brushSelector=function(e,a,n){var i=a.getItemLayout(e);return i&&n.rect(i.brushRect)},t.type="series.candlestick",t.dependencies=["xAxis","yAxis","grid"],t.defaultOption={z:2,coordinateSystem:"cartesian2d",legendHoverLink:!0,layout:null,clip:!0,itemStyle:{color:"#eb5454",color0:"#47b262",borderColor:"#eb5454",borderColor0:"#47b262",borderColorDoji:null,borderWidth:1},emphasis:{itemStyle:{borderWidth:2}},barMaxWidth:null,barMinWidth:null,barWidth:null,large:!0,largeThreshold:600,progressive:3e3,progressiveThreshold:1e4,progressiveChunkMode:"mod",animationEasing:"linear",animationDuration:300},t}(Bt);Qt(iP,rP,!0);function E8(r){!r||!W(r.series)||A(r.series,function(t){it(t)&&t.type==="k"&&(t.type="candlestick")})}var O8={seriesType:"candlestick",plan:Cs(),reset:function(r){var t=r.coordinateSystem,e=r.getData(),a=N8(r,e),n=0,i=1,o=["x","y"],s=e.getDimensionIndex(e.mapDimension(o[n])),l=U(e.mapDimensionsAll(o[i]),e.getDimensionIndex,e),u=l[0],f=l[1],v=l[2],h=l[3];if(e.setLayout({candleWidth:a,isSimpleBox:a<=1.3}),s<0||l.length<4)return;return{progress:r.pipelineContext.large?p:c};function c(d,g){for(var y,m=g.getStore();(y=d.next())!=null;){var _=m.get(s,y),S=m.get(u,y),x=m.get(f,y),b=m.get(v,y),w=m.get(h,y),T=Math.min(S,x),C=Math.max(S,x),M=O(T,_),D=O(C,_),I=O(b,_),L=O(w,_),P=[];E(P,D,0),E(P,M,1),P.push(V(L),V(D),V(I),V(M));var k=g.getItemModel(y),R=!!k.get(["itemStyle","borderColorDoji"]);g.setItemLayout(y,{sign:ww(m,y,S,x,f,R),initBaseline:S>x?D[i]:M[i],ends:P,brushRect:B(b,w,_)})}function O(F,H){var Y=[];return Y[n]=H,Y[i]=F,isNaN(H)||isNaN(F)?[NaN,NaN]:t.dataToPoint(Y)}function E(F,H,Y){var K=H.slice(),ft=H.slice();K[n]=lv(K[n]+a/2,1,!1),ft[n]=lv(ft[n]-a/2,1,!0),Y?F.push(K,ft):F.push(ft,K)}function B(F,H,Y){var K=O(F,Y),ft=O(H,Y);return K[n]-=a/2,ft[n]-=a/2,{x:K[0],y:K[1],width:a,height:ft[1]-K[1]}}function V(F){return F[n]=lv(F[n],1),F}}function p(d,g){for(var y=fa(d.count*4),m=0,_,S=[],x=[],b,w=g.getStore(),T=!!r.get(["itemStyle","borderColorDoji"]);(b=d.next())!=null;){var C=w.get(s,b),M=w.get(u,b),D=w.get(f,b),I=w.get(v,b),L=w.get(h,b);if(isNaN(C)||isNaN(I)||isNaN(L)){y[m++]=NaN,m+=3;continue}y[m++]=ww(w,b,M,D,f,T),S[n]=C,S[i]=I,_=t.dataToPoint(S,null,x),y[m++]=_?_[0]:NaN,y[m++]=_?_[1]:NaN,S[i]=L,_=t.dataToPoint(S,null,x),y[m++]=_?_[1]:NaN}g.setLayout("largePoints",y)}}};function ww(r,t,e,a,n,i){var o;return e>a?o=-1:e<a?o=1:o=i?0:t>0?r.get(n,t-1)<=a?1:-1:1,o}function N8(r,t){var e=r.getBaseAxis(),a,n=e.type==="category"?e.getBandWidth():(a=e.getExtent(),Math.abs(a[1]-a[0])/t.count()),i=Z(Q(r.get("barMaxWidth"),n),n),o=Z(Q(r.get("barMinWidth"),1),n),s=r.get("barWidth");return s!=null?Z(s,n):Math.max(Math.min(n/2,i),o)}function B8(r){r.registerChartView(L8),r.registerSeriesModel(iP),r.registerPreprocessor(E8),r.registerVisual(M8),r.registerLayout(O8)}function Tw(r,t){var e=t.rippleEffectColor||t.color;r.eachChild(function(a){a.attr({z:t.z,zlevel:t.zlevel,style:{stroke:t.brushType==="stroke"?e:null,fill:t.brushType==="fill"?e:null}})})}var z8=function(r){z(t,r);function t(e,a){var n=r.call(this)||this,i=new ku(e,a),o=new rt;return n.add(i),n.add(o),n.updateData(e,a),n}return t.prototype.stopEffectAnimation=function(){this.childAt(1).removeAll()},t.prototype.startEffectAnimation=function(e){for(var a=e.symbolType,n=e.color,i=e.rippleNumber,o=this.childAt(1),s=0;s<i;s++){var l=ie(a,-1,-1,2,2,n);l.attr({style:{strokeNoScale:!0},z2:99,silent:!0,scaleX:.5,scaleY:.5});var u=-s/i*e.period+e.effectOffset;l.animate("",!0).when(e.period,{scaleX:e.rippleScale/2,scaleY:e.rippleScale/2}).delay(u).start(),l.animateStyle(!0).when(e.period,{opacity:0}).delay(u).start(),o.add(l)}Tw(o,e)},t.prototype.updateEffectAnimation=function(e){for(var a=this._effectCfg,n=this.childAt(1),i=["symbolType","period","rippleScale","rippleNumber"],o=0;o<i.length;o++){var s=i[o];if(a[s]!==e[s]){this.stopEffectAnimation(),this.startEffectAnimation(e);return}}Tw(n,e)},t.prototype.highlight=function(){Xa(this)},t.prototype.downplay=function(){$a(this)},t.prototype.getSymbolType=function(){var e=this.childAt(0);return e&&e.getSymbolType()},t.prototype.updateData=function(e,a){var n=this,i=e.hostModel;this.childAt(0).updateData(e,a);var o=this.childAt(1),s=e.getItemModel(a),l=e.getItemVisual(a,"symbol"),u=Ms(e.getItemVisual(a,"symbolSize")),f=e.getItemVisual(a,"style"),v=f&&f.fill,h=s.getModel("emphasis");o.setScale(u),o.traverse(function(g){g.setStyle("fill",v)});var c=to(e.getItemVisual(a,"symbolOffset"),u);c&&(o.x=c[0],o.y=c[1]);var p=e.getItemVisual(a,"symbolRotate");o.rotation=(p||0)*Math.PI/180||0;var d={};d.showEffectOn=i.get("showEffectOn"),d.rippleScale=s.get(["rippleEffect","scale"]),d.brushType=s.get(["rippleEffect","brushType"]),d.period=s.get(["rippleEffect","period"])*1e3,d.effectOffset=a/e.count(),d.z=i.getShallow("z")||0,d.zlevel=i.getShallow("zlevel")||0,d.symbolType=l,d.color=v,d.rippleEffectColor=s.get(["rippleEffect","color"]),d.rippleNumber=s.get(["rippleEffect","number"]),d.showEffectOn==="render"?(this._effectCfg?this.updateEffectAnimation(d):this.startEffectAnimation(d),this._effectCfg=d):(this._effectCfg=null,this.stopEffectAnimation(),this.onHoverStateChange=function(g){g==="emphasis"?d.showEffectOn!=="render"&&n.startEffectAnimation(d):g==="normal"&&d.showEffectOn!=="render"&&n.stopEffectAnimation()}),this._effectCfg=d,$t(this,h.get("focus"),h.get("blurScope"),h.get("disabled"))},t.prototype.fadeOut=function(e){e&&e()},t}(rt),V8=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(){this._symbolDraw=new Eu(z8)},t.prototype.render=function(e,a,n){var i=e.getData(),o=this._symbolDraw;o.updateData(i,{clipShape:this._getClipShape(e)}),this.group.add(o.group)},t.prototype._getClipShape=function(e){var a=e.coordinateSystem,n=a&&a.getArea&&a.getArea();return e.get("clip",!0)?n:null},t.prototype.updateTransform=function(e,a,n){var i=e.getData();this.group.dirty();var o=Nu("").reset(e,a,n);o.progress&&o.progress({start:0,end:i.count(),count:i.count()},i),this._symbolDraw.updateLayout()},t.prototype._updateGroupTransform=function(e){var a=e.coordinateSystem;a&&a.getRoamTransform&&(this.group.transform=pA(a.getRoamTransform()),this.group.decomposeTransform())},t.prototype.remove=function(e,a){this._symbolDraw&&this._symbolDraw.remove(!0)},t.type="effectScatter",t}(Nt),G8=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.hasSymbolVisual=!0,e}return t.prototype.getInitialData=function(e,a){return Ca(null,this,{useEncodeDefaulter:!0})},t.prototype.brushSelector=function(e,a,n){return n.point(a.getItemLayout(e))},t.type="series.effectScatter",t.dependencies=["grid","polar"],t.defaultOption={coordinateSystem:"cartesian2d",z:2,legendHoverLink:!0,effectType:"ripple",progressive:0,showEffectOn:"render",clip:!0,rippleEffect:{period:4,scale:2.5,brushType:"fill",number:3},universalTransition:{divideShape:"clone"},symbolSize:10},t}(Bt);function F8(r){r.registerChartView(V8),r.registerSeriesModel(G8),r.registerLayout(Nu("effectScatter"))}var oP=function(r){z(t,r);function t(e,a,n){var i=r.call(this)||this;return i.add(i.createLine(e,a,n)),i._updateEffectSymbol(e,a),i}return t.prototype.createLine=function(e,a,n){return new G0(e,a,n)},t.prototype._updateEffectSymbol=function(e,a){var n=e.getItemModel(a),i=n.getModel("effect"),o=i.get("symbolSize"),s=i.get("symbol");W(o)||(o=[o,o]);var l=e.getItemVisual(a,"style"),u=i.get("color")||l&&l.stroke,f=this.childAt(1);this._symbolType!==s&&(this.remove(f),f=ie(s,-.5,-.5,1,1,u),f.z2=100,f.culling=!0,this.add(f)),f&&(f.setStyle("shadowColor",u),f.setStyle(i.getItemStyle(["color"])),f.scaleX=o[0],f.scaleY=o[1],f.setColor(u),this._symbolType=s,this._symbolScale=o,this._updateEffectAnimation(e,i,a))},t.prototype._updateEffectAnimation=function(e,a,n){var i=this.childAt(1);if(i){var o=e.getItemLayout(n),s=a.get("period")*1e3,l=a.get("loop"),u=a.get("roundTrip"),f=a.get("constantSpeed"),v=Ce(a.get("delay"),function(c){return c/e.count()*s/3});if(i.ignore=!0,this._updateAnimationPoints(i,o),f>0&&(s=this._getLineLength(i)/f*1e3),s!==this._period||l!==this._loop||u!==this._roundTrip){i.stopAnimation();var h=void 0;tt(v)?h=v(n):h=v,i.__t>0&&(h=-s*i.__t),this._animateSymbol(i,s,h,l,u)}this._period=s,this._loop=l,this._roundTrip=u}},t.prototype._animateSymbol=function(e,a,n,i,o){if(a>0){e.__t=0;var s=this,l=e.animate("",i).when(o?a*2:a,{__t:o?2:1}).delay(n).during(function(){s._updateSymbolPosition(e)});i||l.done(function(){s.remove(e)}),l.start()}},t.prototype._getLineLength=function(e){return Ea(e.__p1,e.__cp1)+Ea(e.__cp1,e.__p2)},t.prototype._updateAnimationPoints=function(e,a){e.__p1=a[0],e.__p2=a[1],e.__cp1=a[2]||[(a[0][0]+a[1][0])/2,(a[0][1]+a[1][1])/2]},t.prototype.updateData=function(e,a,n){this.childAt(0).updateData(e,a,n),this._updateEffectSymbol(e,a)},t.prototype._updateSymbolPosition=function(e){var a=e.__p1,n=e.__p2,i=e.__cp1,o=e.__t<1?e.__t:2-e.__t,s=[e.x,e.y],l=s.slice(),u=Te,f=Kd;s[0]=u(a[0],i[0],n[0],o),s[1]=u(a[1],i[1],n[1],o);var v=e.__t<1?f(a[0],i[0],n[0],o):f(n[0],i[0],a[0],1-o),h=e.__t<1?f(a[1],i[1],n[1],o):f(n[1],i[1],a[1],1-o);e.rotation=-Math.atan2(h,v)-Math.PI/2,(this._symbolType==="line"||this._symbolType==="rect"||this._symbolType==="roundRect")&&(e.__lastT!==void 0&&e.__lastT<e.__t?(e.scaleY=Ea(l,s)*1.05,o===1&&(s[0]=l[0]+(s[0]-l[0])/2,s[1]=l[1]+(s[1]-l[1])/2)):e.__lastT===1?e.scaleY=2*Ea(a,s):e.scaleY=this._symbolScale[1]),e.__lastT=e.__t,e.ignore=!1,e.x=s[0],e.y=s[1]},t.prototype.updateLayout=function(e,a){this.childAt(0).updateLayout(e,a);var n=e.getItemModel(a).getModel("effect");this._updateEffectAnimation(e,n,a)},t}(rt),sP=function(r){z(t,r);function t(e,a,n){var i=r.call(this)||this;return i._createPolyline(e,a,n),i}return t.prototype._createPolyline=function(e,a,n){var i=e.getItemLayout(a),o=new Ae({shape:{points:i}});this.add(o),this._updateCommonStl(e,a,n)},t.prototype.updateData=function(e,a,n){var i=e.hostModel,o=this.childAt(0),s={shape:{points:e.getItemLayout(a)}};Lt(o,s,i,a),this._updateCommonStl(e,a,n)},t.prototype._updateCommonStl=function(e,a,n){var i=this.childAt(0),o=e.getItemModel(a),s=n&&n.emphasisLineStyle,l=n&&n.focus,u=n&&n.blurScope,f=n&&n.emphasisDisabled;if(!n||e.hasItemOption){var v=o.getModel("emphasis");s=v.getModel("lineStyle").getLineStyle(),f=v.get("disabled"),l=v.get("focus"),u=v.get("blurScope")}i.useStyle(e.getItemVisual(a,"style")),i.style.fill=null,i.style.strokeNoScale=!0;var h=i.ensureState("emphasis");h.style=s,$t(this,l,u,f)},t.prototype.updateLayout=function(e,a){var n=this.childAt(0);n.setShape("points",e.getItemLayout(a))},t}(rt),H8=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e._lastFrame=0,e._lastFramePercent=0,e}return t.prototype.createLine=function(e,a,n){return new sP(e,a,n)},t.prototype._updateAnimationPoints=function(e,a){this._points=a;for(var n=[0],i=0,o=1;o<a.length;o++){var s=a[o-1],l=a[o];i+=Ea(s,l),n.push(i)}if(i===0){this._length=0;return}for(var o=0;o<n.length;o++)n[o]/=i;this._offsets=n,this._length=i},t.prototype._getLineLength=function(){return this._length},t.prototype._updateSymbolPosition=function(e){var a=e.__t<1?e.__t:2-e.__t,n=this._points,i=this._offsets,o=n.length;if(i){var s=this._lastFrame,l;if(a<this._lastFramePercent){var u=Math.min(s+1,o-1);for(l=u;l>=0&&!(i[l]<=a);l--);l=Math.min(l,o-2)}else{for(l=s;l<o&&!(i[l]>a);l++);l=Math.min(l-1,o-2)}var f=(a-i[l])/(i[l+1]-i[l]),v=n[l],h=n[l+1];e.x=v[0]*(1-f)+f*h[0],e.y=v[1]*(1-f)+f*h[1];var c=e.__t<1?h[0]-v[0]:v[0]-h[0],p=e.__t<1?h[1]-v[1]:v[1]-h[1];e.rotation=-Math.atan2(p,c)-Math.PI/2,this._lastFrame=l,this._lastFramePercent=a,e.ignore=!1}},t}(oP),W8=function(){function r(){this.polyline=!1,this.curveness=0,this.segs=[]}return r}(),U8=function(r){z(t,r);function t(e){var a=r.call(this,e)||this;return a._off=0,a.hoverDataIdx=-1,a}return t.prototype.reset=function(){this.notClear=!1,this._off=0},t.prototype.getDefaultStyle=function(){return{stroke:N.color.neutral99,fill:null}},t.prototype.getDefaultShape=function(){return new W8},t.prototype.buildPath=function(e,a){var n=a.segs,i=a.curveness,o;if(a.polyline)for(o=this._off;o<n.length;){var s=n[o++];if(s>0){e.moveTo(n[o++],n[o++]);for(var l=1;l<s;l++)e.lineTo(n[o++],n[o++])}}else for(o=this._off;o<n.length;){var u=n[o++],f=n[o++],v=n[o++],h=n[o++];if(e.moveTo(u,f),i>0){var c=(u+v)/2-(f-h)*i,p=(f+h)/2-(v-u)*i;e.quadraticCurveTo(c,p,v,h)}else e.lineTo(v,h)}this.incremental&&(this._off=o,this.notClear=!0)},t.prototype.findDataIndex=function(e,a){var n=this.shape,i=n.segs,o=n.curveness,s=this.style.lineWidth;if(n.polyline)for(var l=0,u=0;u<i.length;){var f=i[u++];if(f>0)for(var v=i[u++],h=i[u++],c=1;c<f;c++){var p=i[u++],d=i[u++];if(cn(v,h,p,d,s,e,a))return l}l++}else for(var l=0,u=0;u<i.length;){var v=i[u++],h=i[u++],p=i[u++],d=i[u++];if(o>0){var g=(v+p)/2-(h-d)*o,y=(h+d)/2-(p-v)*o;if(lM(v,h,g,y,p,d,s,e,a))return l}else if(cn(v,h,p,d,s,e,a))return l;l++}return-1},t.prototype.contain=function(e,a){var n=this.transformCoordToLocal(e,a),i=this.getBoundingRect();if(e=n[0],a=n[1],i.contain(e,a)){var o=this.hoverDataIdx=this.findDataIndex(e,a);return o>=0}return this.hoverDataIdx=-1,!1},t.prototype.getBoundingRect=function(){var e=this._rect;if(!e){for(var a=this.shape,n=a.segs,i=1/0,o=1/0,s=-1/0,l=-1/0,u=0;u<n.length;){var f=n[u++],v=n[u++];i=Math.min(f,i),s=Math.max(f,s),o=Math.min(v,o),l=Math.max(v,l)}e=this._rect=new lt(i,o,s,l)}return e},t}(bt),Y8=function(){function r(){this.group=new rt}return r.prototype.updateData=function(t){this._clear();var e=this._create();e.setShape({segs:t.getLayout("linesPoints")}),this._setCommon(e,t)},r.prototype.incrementalPrepareUpdate=function(t){this.group.removeAll(),this._clear()},r.prototype.incrementalUpdate=function(t,e){var a=this._newAdded[0],n=e.getLayout("linesPoints"),i=a&&a.shape.segs;if(i&&i.length<2e4){var o=i.length,s=new Float32Array(o+n.length);s.set(i),s.set(n,o),a.setShape({segs:s})}else{this._newAdded=[];var l=this._create();l.incremental=!0,l.setShape({segs:n}),this._setCommon(l,e),l.__startIndex=t.start}},r.prototype.remove=function(){this._clear()},r.prototype.eachRendered=function(t){this._newAdded[0]&&t(this._newAdded[0])},r.prototype._create=function(){var t=new U8({cursor:"default",ignoreCoarsePointer:!0});return this._newAdded.push(t),this.group.add(t),t},r.prototype._setCommon=function(t,e,a){var n=e.hostModel;t.setShape({polyline:n.get("polyline"),curveness:n.get(["lineStyle","curveness"])}),t.useStyle(n.getModel("lineStyle").getLineStyle()),t.style.strokeNoScale=!0;var i=e.getVisual("style");i&&i.stroke&&t.setStyle("stroke",i.stroke),t.setStyle("fill",null);var o=ut(t);o.seriesIndex=n.seriesIndex,t.on("mousemove",function(s){o.dataIndex=null;var l=t.hoverDataIdx;l>0&&(o.dataIndex=l+t.__startIndex)})},r.prototype._clear=function(){this._newAdded=[],this.group.removeAll()},r}(),lP={seriesType:"lines",plan:Cs(),reset:function(r){var t=r.coordinateSystem;if(t){var e=r.get("polyline"),a=r.pipelineContext.large;return{progress:function(n,i){var o=[];if(a){var s=void 0,l=n.end-n.start;if(e){for(var u=0,f=n.start;f<n.end;f++)u+=r.getLineCoordsCount(f);s=new Float32Array(l+u*2)}else s=new Float32Array(l*4);for(var v=0,h=[],f=n.start;f<n.end;f++){var c=r.getLineCoords(f,o);e&&(s[v++]=c);for(var p=0;p<c;p++)h=t.dataToPoint(o[p],!1,h),s[v++]=h[0],s[v++]=h[1]}i.setLayout("linesPoints",s)}else for(var f=n.start;f<n.end;f++){var d=i.getItemModel(f),c=r.getLineCoords(f,o),g=[];if(e)for(var y=0;y<c;y++)g.push(t.dataToPoint(o[y]));else{g[0]=t.dataToPoint(o[0]),g[1]=t.dataToPoint(o[1]);var m=d.get(["lineStyle","curveness"]);+m&&(g[2]=[(g[0][0]+g[1][0])/2-(g[0][1]-g[1][1])*m,(g[0][1]+g[1][1])/2-(g[1][0]-g[0][0])*m])}i.setItemLayout(f,g)}}}}}},Z8=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n){var i=e.getData(),o=this._updateLineDraw(i,e),s=e.get("zlevel"),l=e.get(["effect","trailLength"]),u=n.getZr(),f=u.painter.getType()==="svg";f||u.painter.getLayer(s).clear(!0),this._lastZlevel!=null&&!f&&u.configLayer(this._lastZlevel,{motionBlur:!1}),this._showEffect(e)&&l>0&&(f||u.configLayer(s,{motionBlur:!0,lastFrameAlpha:Math.max(Math.min(l/10+.9,1),0)})),o.updateData(i);var v=e.get("clip",!0)&&Ou(e.coordinateSystem,!1,e);v?this.group.setClipPath(v):this.group.removeClipPath(),this._lastZlevel=s,this._finished=!0},t.prototype.incrementalPrepareRender=function(e,a,n){var i=e.getData(),o=this._updateLineDraw(i,e);o.incrementalPrepareUpdate(i),this._clearLayer(n),this._finished=!1},t.prototype.incrementalRender=function(e,a,n){this._lineDraw.incrementalUpdate(e,a.getData()),this._finished=e.end===a.getData().count()},t.prototype.eachRendered=function(e){this._lineDraw&&this._lineDraw.eachRendered(e)},t.prototype.updateTransform=function(e,a,n){var i=e.getData(),o=e.pipelineContext;if(!this._finished||o.large||o.progressiveRender)return{update:!0};var s=lP.reset(e,a,n);s.progress&&s.progress({start:0,end:i.count(),count:i.count()},i),this._lineDraw.updateLayout(),this._clearLayer(n)},t.prototype._updateLineDraw=function(e,a){var n=this._lineDraw,i=this._showEffect(a),o=!!a.get("polyline"),s=a.pipelineContext,l=s.large;return(!n||i!==this._hasEffet||o!==this._isPolyline||l!==this._isLargeDraw)&&(n&&n.remove(),n=this._lineDraw=l?new Y8:new F0(o?i?H8:sP:i?oP:G0),this._hasEffet=i,this._isPolyline=o,this._isLargeDraw=l),this.group.add(n.group),n},t.prototype._showEffect=function(e){return!!e.get(["effect","show"])},t.prototype._clearLayer=function(e){var a=e.getZr(),n=a.painter.getType()==="svg";!n&&this._lastZlevel!=null&&a.painter.getLayer(this._lastZlevel).clear(!0)},t.prototype.remove=function(e,a){this._lineDraw&&this._lineDraw.remove(),this._lineDraw=null,this._clearLayer(a)},t.prototype.dispose=function(e,a){this.remove(e,a)},t.type="lines",t}(Nt),X8=typeof Uint32Array>"u"?Array:Uint32Array,$8=typeof Float64Array>"u"?Array:Float64Array;function Cw(r){var t=r.data;t&&t[0]&&t[0][0]&&t[0][0].coord&&(r.data=U(t,function(e){var a=[e[0].coord,e[1].coord],n={coords:a};return e[0].name&&(n.fromName=e[0].name),e[1].name&&(n.toName=e[1].name),kh([n,e[0],e[1]])}))}var q8=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.visualStyleAccessPath="lineStyle",e.visualDrawType="stroke",e}return t.prototype.init=function(e){e.data=e.data||[],Cw(e);var a=this._processFlatCoordsArray(e.data);this._flatCoords=a.flatCoords,this._flatCoordsOffset=a.flatCoordsOffset,a.flatCoords&&(e.data=new Float32Array(a.count)),r.prototype.init.apply(this,arguments)},t.prototype.mergeOption=function(e){if(Cw(e),e.data){var a=this._processFlatCoordsArray(e.data);this._flatCoords=a.flatCoords,this._flatCoordsOffset=a.flatCoordsOffset,a.flatCoords&&(e.data=new Float32Array(a.count))}r.prototype.mergeOption.apply(this,arguments)},t.prototype.appendData=function(e){var a=this._processFlatCoordsArray(e.data);a.flatCoords&&(this._flatCoords?(this._flatCoords=Ko(this._flatCoords,a.flatCoords),this._flatCoordsOffset=Ko(this._flatCoordsOffset,a.flatCoordsOffset)):(this._flatCoords=a.flatCoords,this._flatCoordsOffset=a.flatCoordsOffset),e.data=new Float32Array(a.count)),this.getRawData().appendData(e.data)},t.prototype._getCoordsFromItemModel=function(e){var a=this.getData().getItemModel(e),n=a.option instanceof Array?a.option:a.getShallow("coords");return n},t.prototype.getLineCoordsCount=function(e){return this._flatCoordsOffset?this._flatCoordsOffset[e*2+1]:this._getCoordsFromItemModel(e).length},t.prototype.getLineCoords=function(e,a){if(this._flatCoordsOffset){for(var n=this._flatCoordsOffset[e*2],i=this._flatCoordsOffset[e*2+1],o=0;o<i;o++)a[o]=a[o]||[],a[o][0]=this._flatCoords[n+o*2],a[o][1]=this._flatCoords[n+o*2+1];return i}else{for(var s=this._getCoordsFromItemModel(e),o=0;o<s.length;o++)a[o]=a[o]||[],a[o][0]=s[o][0],a[o][1]=s[o][1];return s.length}},t.prototype._processFlatCoordsArray=function(e){var a=0;if(this._flatCoords&&(a=this._flatCoords.length),Mt(e[0])){for(var n=e.length,i=new X8(n),o=new $8(n),s=0,l=0,u=0,f=0;f<n;){u++;var v=e[f++];i[l++]=s+a,i[l++]=v;for(var h=0;h<v;h++){var c=e[f++],p=e[f++];o[s++]=c,o[s++]=p}}return{flatCoordsOffset:new Uint32Array(i.buffer,0,l),flatCoords:o,count:u}}return{flatCoordsOffset:null,flatCoords:null,count:e.length}},t.prototype.getInitialData=function(e,a){var n=new Ue(["value"],this);return n.hasItemOption=!1,n.initData(e.data,[],function(i,o,s,l){if(i instanceof Array)return NaN;n.hasItemOption=!0;var u=i.value;if(u!=null)return u instanceof Array?u[l]:u}),n},t.prototype.formatTooltip=function(e,a,n){var i=this.getData(),o=i.getItemModel(e),s=o.get("name");if(s)return s;var l=o.get("fromName"),u=o.get("toName"),f=[];return l!=null&&f.push(l),u!=null&&f.push(u),ue("nameValue",{name:f.join(" > ")})},t.prototype.preventIncremental=function(){return!!this.get(["effect","show"])},t.prototype.getProgressive=function(){var e=this.option.progressive;return e??(this.option.large?1e4:this.get("progressive"))},t.prototype.getProgressiveThreshold=function(){var e=this.option.progressiveThreshold;return e??(this.option.large?2e4:this.get("progressiveThreshold"))},t.prototype.getZLevelKey=function(){var e=this.getModel("effect"),a=e.get("trailLength");return this.getData().count()>this.getProgressiveThreshold()?this.id:e.get("show")&&a>0?a+"":""},t.type="series.lines",t.dependencies=["grid","polar","geo","calendar"],t.defaultOption={coordinateSystem:"geo",z:2,legendHoverLink:!0,xAxisIndex:0,yAxisIndex:0,symbol:["none","none"],symbolSize:[10,10],geoIndex:0,effect:{show:!1,period:4,constantSpeed:0,symbol:"circle",symbolSize:3,loop:!0,trailLength:.2},large:!1,largeThreshold:2e3,polyline:!1,clip:!0,label:{show:!1,position:"end"},lineStyle:{opacity:.5}},t}(Bt);function zf(r){return r instanceof Array||(r=[r,r]),r}var K8={seriesType:"lines",reset:function(r){var t=zf(r.get("symbol")),e=zf(r.get("symbolSize")),a=r.getData();a.setVisual("fromSymbol",t&&t[0]),a.setVisual("toSymbol",t&&t[1]),a.setVisual("fromSymbolSize",e&&e[0]),a.setVisual("toSymbolSize",e&&e[1]);function n(i,o){var s=i.getItemModel(o),l=zf(s.getShallow("symbol",!0)),u=zf(s.getShallow("symbolSize",!0));l[0]&&i.setItemVisual(o,"fromSymbol",l[0]),l[1]&&i.setItemVisual(o,"toSymbol",l[1]),u[0]&&i.setItemVisual(o,"fromSymbolSize",u[0]),u[1]&&i.setItemVisual(o,"toSymbolSize",u[1])}return{dataEach:a.hasItemOption?n:null}}};function j8(r){r.registerChartView(Z8),r.registerSeriesModel(q8),r.registerLayout(lP),r.registerVisual(K8)}var J8=256,Q8=function(){function r(){this.blurSize=30,this.pointSize=20,this.maxOpacity=1,this.minOpacity=0,this._gradientPixels={inRange:null,outOfRange:null};var t=tr.createCanvas();this.canvas=t}return r.prototype.update=function(t,e,a,n,i,o){var s=this._getBrush(),l=this._getGradient(i,"inRange"),u=this._getGradient(i,"outOfRange"),f=this.pointSize+this.blurSize,v=this.canvas,h=v.getContext("2d"),c=t.length;v.width=e,v.height=a;for(var p=0;p<c;++p){var d=t[p],g=d[0],y=d[1],m=d[2],_=n(m);h.globalAlpha=_,h.drawImage(s,g-f,y-f)}if(!v.width||!v.height)return v;for(var S=h.getImageData(0,0,v.width,v.height),x=S.data,b=0,w=x.length,T=this.minOpacity,C=this.maxOpacity,M=C-T;b<w;){var _=x[b+3]/256,D=Math.floor(_*(J8-1))*4;if(_>0){var I=o(_)?l:u;_>0&&(_=_*M+T),x[b++]=I[D],x[b++]=I[D+1],x[b++]=I[D+2],x[b++]=I[D+3]*_*256}else b+=4}return h.putImageData(S,0,0),v},r.prototype._getBrush=function(){var t=this._brushCanvas||(this._brushCanvas=tr.createCanvas()),e=this.pointSize+this.blurSize,a=e*2;t.width=a,t.height=a;var n=t.getContext("2d");return n.clearRect(0,0,a,a),n.shadowOffsetX=a,n.shadowBlur=this.blurSize,n.shadowColor=N.color.neutral99,n.beginPath(),n.arc(-e,e,this.pointSize,0,Math.PI*2,!0),n.closePath(),n.fill(),t},r.prototype._getGradient=function(t,e){for(var a=this._gradientPixels,n=a[e]||(a[e]=new Uint8ClampedArray(256*4)),i=[0,0,0,0],o=0,s=0;s<256;s++)t[e](s/255,!0,i),n[o++]=i[0],n[o++]=i[1],n[o++]=i[2],n[o++]=i[3];return n},r}();function t6(r,t,e){var a=r[1]-r[0];t=U(t,function(o){return{interval:[(o.interval[0]-r[0])/a,(o.interval[1]-r[0])/a]}});var n=t.length,i=0;return function(o){var s;for(s=i;s<n;s++){var l=t[s].interval;if(l[0]<=o&&o<=l[1]){i=s;break}}if(s===n)for(s=i-1;s>=0;s--){var l=t[s].interval;if(l[0]<=o&&o<=l[1]){i=s;break}}return s>=0&&s<n&&e[s]}}function e6(r,t){var e=r[1]-r[0];return t=[(t[0]-r[0])/e,(t[1]-r[0])/e],function(a){return a>=t[0]&&a<=t[1]}}function Aw(r){var t=r.dimensions;return t[0]==="lng"&&t[1]==="lat"}var r6=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n){var i;a.eachComponent("visualMap",function(s){s.eachTargetSeries(function(l){l===e&&(i=s)})}),this._progressiveEls=null,this.group.removeAll();var o=e.coordinateSystem;o.type==="cartesian2d"||o.type==="calendar"||o.type==="matrix"?this._renderOnGridLike(e,n,0,e.getData().count()):Aw(o)&&this._renderOnGeo(o,e,i,n)},t.prototype.incrementalPrepareRender=function(e,a,n){this.group.removeAll()},t.prototype.incrementalRender=function(e,a,n,i){var o=a.coordinateSystem;o&&(Aw(o)?this.render(a,n,i):(this._progressiveEls=[],this._renderOnGridLike(a,i,e.start,e.end,!0)))},t.prototype.eachRendered=function(e){zn(this._progressiveEls||this.group,e)},t.prototype._renderOnGridLike=function(e,a,n,i,o){var s=e.coordinateSystem,l=Rn(s,"cartesian2d"),u=Rn(s,"matrix"),f,v,h,c;if(l){var p=s.getAxis("x"),d=s.getAxis("y");f=p.getBandWidth()+.5,v=d.getBandWidth()+.5,h=p.scale.getExtent(),c=d.scale.getExtent()}for(var g=this.group,y=e.getData(),m=e.getModel(["emphasis","itemStyle"]).getItemStyle(),_=e.getModel(["blur","itemStyle"]).getItemStyle(),S=e.getModel(["select","itemStyle"]).getItemStyle(),x=e.get(["itemStyle","borderRadius"]),b=ce(e),w=e.getModel("emphasis"),T=w.get("focus"),C=w.get("blurScope"),M=w.get("disabled"),D=l||u?[y.mapDimension("x"),y.mapDimension("y"),y.mapDimension("value")]:[y.mapDimension("time"),y.mapDimension("value")],I=n;I<i;I++){var L=void 0,P=y.getItemVisual(I,"style");if(l){var k=y.get(D[0],I),R=y.get(D[1],I);if(isNaN(y.get(D[2],I))||isNaN(k)||isNaN(R)||k<h[0]||k>h[1]||R<c[0]||R>c[1])continue;var O=s.dataToPoint([k,R]);L=new _t({shape:{x:O[0]-f/2,y:O[1]-v/2,width:f,height:v},style:P})}else if(u){var E=s.dataToLayout([y.get(D[0],I),y.get(D[1],I)]).rect;if(Ie(E.x))continue;L=new _t({z2:1,shape:E,style:P})}else{if(isNaN(y.get(D[1],I)))continue;var B=s.dataToLayout([y.get(D[0],I)]),E=B.contentRect||B.rect;if(Ie(E.x)||Ie(E.y))continue;L=new _t({z2:1,shape:E,style:P})}if(y.hasItemOption){var V=y.getItemModel(I),F=V.getModel("emphasis");m=F.getModel("itemStyle").getItemStyle(),_=V.getModel(["blur","itemStyle"]).getItemStyle(),S=V.getModel(["select","itemStyle"]).getItemStyle(),x=V.get(["itemStyle","borderRadius"]),T=F.get("focus"),C=F.get("blurScope"),M=F.get("disabled"),b=ce(V)}L.shape.r=x;var H=e.getRawValue(I),Y="-";H&&H[2]!=null&&(Y=H[2]+""),Se(L,b,{labelFetcher:e,labelDataIndex:I,defaultOpacity:P.opacity,defaultText:Y}),L.ensureState("emphasis").style=m,L.ensureState("blur").style=_,L.ensureState("select").style=S,$t(L,T,C,M),L.incremental=o,o&&(L.states.emphasis.hoverLayer=!0),g.add(L),y.setItemGraphicEl(I,L),this._progressiveEls&&this._progressiveEls.push(L)}},t.prototype._renderOnGeo=function(e,a,n,i){var o=n.targetVisuals.inRange,s=n.targetVisuals.outOfRange,l=a.getData(),u=this._hmLayer||this._hmLayer||new Q8;u.blurSize=a.get("blurSize"),u.pointSize=a.get("pointSize"),u.minOpacity=a.get("minOpacity"),u.maxOpacity=a.get("maxOpacity");var f=e.getViewRect().clone(),v=e.getRoamTransform();f.applyTransform(v);var h=Math.max(f.x,0),c=Math.max(f.y,0),p=Math.min(f.width+f.x,i.getWidth()),d=Math.min(f.height+f.y,i.getHeight()),g=p-h,y=d-c,m=[l.mapDimension("lng"),l.mapDimension("lat"),l.mapDimension("value")],_=l.mapArray(m,function(w,T,C){var M=e.dataToPoint([w,T]);return M[0]-=h,M[1]-=c,M.push(C),M}),S=n.getExtent(),x=n.type==="visualMap.continuous"?e6(S,n.option.range):t6(S,n.getPieceList(),n.option.selected);u.update(_,g,y,o.color.getNormalizer(),{inRange:o.color.getColorMapper(),outOfRange:s.color.getColorMapper()},x);var b=new xe({style:{width:g,height:y,x:h,y:c,image:u.canvas},silent:!0});this.group.add(b)},t.type="heatmap",t}(Nt),a6=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.getInitialData=function(e,a){return Ca(null,this,{generateCoord:"value"})},t.prototype.preventIncremental=function(){var e=Ts.get(this.get("coordinateSystem"));if(e&&e.dimensions)return e.dimensions[0]==="lng"&&e.dimensions[1]==="lat"},t.type="series.heatmap",t.dependencies=["grid","geo","calendar","matrix"],t.defaultOption={coordinateSystem:"cartesian2d",z:2,geoIndex:0,blurSize:30,pointSize:20,maxOpacity:1,minOpacity:0,select:{itemStyle:{borderColor:N.color.primary}}},t}(Bt);function n6(r){r.registerChartView(r6),r.registerSeriesModel(a6)}var i6=["itemStyle","borderWidth"],Mw=[{xy:"x",wh:"width",index:0,posDesc:["left","right"]},{xy:"y",wh:"height",index:1,posDesc:["top","bottom"]}],fd=new wa,o6=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n){var i=this.group,o=e.getData(),s=this._data,l=e.coordinateSystem,u=l.getBaseAxis(),f=u.isHorizontal(),v=l.master.getRect(),h={ecSize:{width:n.getWidth(),height:n.getHeight()},seriesModel:e,coordSys:l,coordSysExtent:[[v.x,v.x+v.width],[v.y,v.y+v.height]],isHorizontal:f,valueDim:Mw[+f],categoryDim:Mw[1-+f]};o.diff(s).add(function(p){if(o.hasValue(p)){var d=Lw(o,p),g=Dw(o,p,d,h),y=Iw(o,h,g);o.setItemGraphicEl(p,y),i.add(y),Rw(y,h,g)}}).update(function(p,d){var g=s.getItemGraphicEl(d);if(!o.hasValue(p)){i.remove(g);return}var y=Lw(o,p),m=Dw(o,p,y,h),_=pP(o,m);g&&_!==g.__pictorialShapeStr&&(i.remove(g),o.setItemGraphicEl(p,null),g=null),g?c6(g,h,m):g=Iw(o,h,m,!0),o.setItemGraphicEl(p,g),g.__pictorialSymbolMeta=m,i.add(g),Rw(g,h,m)}).remove(function(p){var d=s.getItemGraphicEl(p);d&&Pw(s,p,d.__pictorialSymbolMeta.animationModel,d)}).execute();var c=e.get("clip",!0)?Ou(e.coordinateSystem,!1,e):null;return c?i.setClipPath(c):i.removeClipPath(),this._data=o,this.group},t.prototype.remove=function(e,a){var n=this.group,i=this._data;e.get("animation")?i&&i.eachItemGraphicEl(function(o){Pw(i,ut(o).dataIndex,e,o)}):n.removeAll()},t.type="pictorialBar",t}(Nt);function Dw(r,t,e,a){var n=r.getItemLayout(t),i=e.get("symbolRepeat"),o=e.get("symbolClip"),s=e.get("symbolPosition")||"start",l=e.get("symbolRotate"),u=(l||0)*Math.PI/180||0,f=e.get("symbolPatternSize")||2,v=e.isAnimationEnabled(),h={dataIndex:t,layout:n,itemModel:e,symbolType:r.getItemVisual(t,"symbol")||"circle",style:r.getItemVisual(t,"style"),symbolClip:o,symbolRepeat:i,symbolRepeatDirection:e.get("symbolRepeatDirection"),symbolPatternSize:f,rotation:u,animationModel:v?e:null,hoverScale:v&&e.get(["emphasis","scale"]),z2:e.getShallow("z",!0)||0};s6(e,i,n,a,h),l6(r,t,n,i,o,h.boundingLength,h.pxSign,f,a,h),u6(e,h.symbolScale,u,a,h);var c=h.symbolSize,p=to(e.get("symbolOffset"),c);return f6(e,c,n,i,o,p,s,h.valueLineWidth,h.boundingLength,h.repeatCutLength,a,h),h}function s6(r,t,e,a,n){var i=a.valueDim,o=r.get("symbolBoundingData"),s=a.coordSys.getOtherAxis(a.coordSys.getBaseAxis()),l=s.toGlobalCoord(s.dataToCoord(0)),u=1-+(e[i.wh]<=0),f;if(W(o)){var v=[vd(s,o[0])-l,vd(s,o[1])-l];v[1]<v[0]&&v.reverse(),f=v[u]}else o!=null?f=vd(s,o)-l:t?f=a.coordSysExtent[i.index][u]-l:f=e[i.wh];n.boundingLength=f,t&&(n.repeatCutLength=e[i.wh]);var h=i.xy==="x",c=s.inverse;n.pxSign=h&&!c||!h&&c?f>=0?1:-1:f>0?1:-1}function vd(r,t){return r.toGlobalCoord(r.dataToCoord(r.scale.parse(t)))}function l6(r,t,e,a,n,i,o,s,l,u){var f=l.valueDim,v=l.categoryDim,h=Math.abs(e[v.wh]),c=r.getItemVisual(t,"symbolSize"),p;W(c)?p=c.slice():c==null?p=["100%","100%"]:p=[c,c],p[v.index]=Z(p[v.index],h),p[f.index]=Z(p[f.index],a?h:Math.abs(i)),u.symbolSize=p;var d=u.symbolScale=[p[0]/s,p[1]/s];d[f.index]*=(l.isHorizontal?-1:1)*o}function u6(r,t,e,a,n){var i=r.get(i6)||0;i&&(fd.attr({scaleX:t[0],scaleY:t[1],rotation:e}),fd.updateTransform(),i/=fd.getLineScale(),i*=t[a.valueDim.index]),n.valueLineWidth=i||0}function f6(r,t,e,a,n,i,o,s,l,u,f,v){var h=f.categoryDim,c=f.valueDim,p=v.pxSign,d=Math.max(t[c.index]+s,0),g=d;if(a){var y=Math.abs(l),m=Ce(r.get("symbolMargin"),"15%")+"",_=!1;m.lastIndexOf("!")===m.length-1&&(_=!0,m=m.slice(0,m.length-1));var S=Z(m,t[c.index]),x=Math.max(d+S*2,0),b=_?0:S*2,w=hm(a),T=w?a:kw((y+b)/x),C=y-T*d;S=C/2/(_?T:Math.max(T-1,1)),x=d+S*2,b=_?0:S*2,!w&&a!=="fixed"&&(T=u?kw((Math.abs(u)+b)/x):0),g=T*x-b,v.repeatTimes=T,v.symbolMargin=S}var M=p*(g/2),D=v.pathPosition=[];D[h.index]=e[h.wh]/2,D[c.index]=o==="start"?M:o==="end"?l-M:l/2,i&&(D[0]+=i[0],D[1]+=i[1]);var I=v.bundlePosition=[];I[h.index]=e[h.xy],I[c.index]=e[c.xy];var L=v.barRectShape=G({},e);L[c.wh]=p*Math.max(Math.abs(e[c.wh]),Math.abs(D[c.index]+M)),L[h.wh]=e[h.wh];var P=v.clipShape={};P[h.xy]=-e[h.xy],P[h.wh]=f.ecSize[h.wh],P[c.xy]=0,P[c.wh]=e[c.wh]}function uP(r){var t=r.symbolPatternSize,e=ie(r.symbolType,-t/2,-t/2,t,t);return e.attr({culling:!0}),e.type!=="image"&&e.setStyle({strokeNoScale:!0}),e}function fP(r,t,e,a){var n=r.__pictorialBundle,i=e.symbolSize,o=e.valueLineWidth,s=e.pathPosition,l=t.valueDim,u=e.repeatTimes||0,f=0,v=i[t.valueDim.index]+o+e.symbolMargin*2;for(J0(r,function(d){d.__pictorialAnimationIndex=f,d.__pictorialRepeatTimes=u,f<u?qo(d,null,p(f),e,a):qo(d,null,{scaleX:0,scaleY:0},e,a,function(){n.remove(d)}),f++});f<u;f++){var h=uP(e);h.__pictorialAnimationIndex=f,h.__pictorialRepeatTimes=u,n.add(h);var c=p(f);qo(h,{x:c.x,y:c.y,scaleX:0,scaleY:0},{scaleX:c.scaleX,scaleY:c.scaleY,rotation:c.rotation},e,a)}function p(d){var g=s.slice(),y=e.pxSign,m=d;return(e.symbolRepeatDirection==="start"?y>0:y<0)&&(m=u-1-d),g[l.index]=v*(m-u/2+.5)+s[l.index],{x:g[0],y:g[1],scaleX:e.symbolScale[0],scaleY:e.symbolScale[1],rotation:e.rotation}}}function vP(r,t,e,a){var n=r.__pictorialBundle,i=r.__pictorialMainPath;i?qo(i,null,{x:e.pathPosition[0],y:e.pathPosition[1],scaleX:e.symbolScale[0],scaleY:e.symbolScale[1],rotation:e.rotation},e,a):(i=r.__pictorialMainPath=uP(e),n.add(i),qo(i,{x:e.pathPosition[0],y:e.pathPosition[1],scaleX:0,scaleY:0,rotation:e.rotation},{scaleX:e.symbolScale[0],scaleY:e.symbolScale[1]},e,a))}function hP(r,t,e){var a=G({},t.barRectShape),n=r.__pictorialBarRect;n?qo(n,null,{shape:a},t,e):(n=r.__pictorialBarRect=new _t({z2:2,shape:a,silent:!0,style:{stroke:"transparent",fill:"transparent",lineWidth:0}}),n.disableMorphing=!0,r.add(n))}function cP(r,t,e,a){if(e.symbolClip){var n=r.__pictorialClipPath,i=G({},e.clipShape),o=t.valueDim,s=e.animationModel,l=e.dataIndex;if(n)Lt(n,{shape:i},s,l);else{i[o.wh]=0,n=new _t({shape:i}),r.__pictorialBundle.setClipPath(n),r.__pictorialClipPath=n;var u={};u[o.wh]=e.clipShape[o.wh],ji[a?"updateProps":"initProps"](n,{shape:u},s,l)}}}function Lw(r,t){var e=r.getItemModel(t);return e.getAnimationDelayParams=v6,e.isAnimationEnabled=h6,e}function v6(r){return{index:r.__pictorialAnimationIndex,count:r.__pictorialRepeatTimes}}function h6(){return this.parentModel.isAnimationEnabled()&&!!this.getShallow("animation")}function Iw(r,t,e,a){var n=new rt,i=new rt;return n.add(i),n.__pictorialBundle=i,i.x=e.bundlePosition[0],i.y=e.bundlePosition[1],e.symbolRepeat?fP(n,t,e):vP(n,t,e),hP(n,e,a),cP(n,t,e,a),n.__pictorialShapeStr=pP(r,e),n.__pictorialSymbolMeta=e,n}function c6(r,t,e){var a=e.animationModel,n=e.dataIndex,i=r.__pictorialBundle;Lt(i,{x:e.bundlePosition[0],y:e.bundlePosition[1]},a,n),e.symbolRepeat?fP(r,t,e,!0):vP(r,t,e,!0),hP(r,e,!0),cP(r,t,e,!0)}function Pw(r,t,e,a){var n=a.__pictorialBarRect;n&&n.removeTextContent();var i=[];J0(a,function(o){i.push(o)}),a.__pictorialMainPath&&i.push(a.__pictorialMainPath),a.__pictorialClipPath&&(e=null),A(i,function(o){Pn(o,{scaleX:0,scaleY:0},e,t,function(){a.parent&&a.parent.remove(a)})}),r.setItemGraphicEl(t,null)}function pP(r,t){return[r.getItemVisual(t.dataIndex,"symbol")||"none",!!t.symbolRepeat,!!t.symbolClip].join(":")}function J0(r,t,e){A(r.__pictorialBundle.children(),function(a){a!==r.__pictorialBarRect&&t.call(e,a)})}function qo(r,t,e,a,n,i){t&&r.attr(t),a.symbolClip&&!n?e&&r.attr(e):e&&ji[n?"updateProps":"initProps"](r,e,a.animationModel,a.dataIndex,i)}function Rw(r,t,e){var a=e.dataIndex,n=e.itemModel,i=n.getModel("emphasis"),o=i.getModel("itemStyle").getItemStyle(),s=n.getModel(["blur","itemStyle"]).getItemStyle(),l=n.getModel(["select","itemStyle"]).getItemStyle(),u=n.getShallow("cursor"),f=i.get("focus"),v=i.get("blurScope"),h=i.get("scale");J0(r,function(d){if(d instanceof xe){var g=d.style;d.useStyle(G({image:g.image,x:g.x,y:g.y,width:g.width,height:g.height},e.style))}else d.useStyle(e.style);var y=d.ensureState("emphasis");y.style=o,h&&(y.scaleX=d.scaleX*1.1,y.scaleY=d.scaleY*1.1),d.ensureState("blur").style=s,d.ensureState("select").style=l,u&&(d.cursor=u),d.z2=e.z2});var c=t.valueDim.posDesc[+(e.boundingLength>0)],p=r.__pictorialBarRect;p.ignoreClip=!0,Se(p,ce(n),{labelFetcher:t.seriesModel,labelDataIndex:a,defaultText:ss(t.seriesModel.getData(),a),inheritColor:e.style.fill,defaultOpacity:e.style.opacity,defaultOutsidePosition:c}),$t(r,f,v,i.get("disabled"))}function kw(r){var t=Math.round(r);return Math.abs(r-t)<1e-4?t:Math.ceil(r)}var p6=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.hasSymbolVisual=!0,e.defaultSymbol="roundRect",e}return t.prototype.getInitialData=function(e){return e.stack=null,r.prototype.getInitialData.apply(this,arguments)},t.type="series.pictorialBar",t.dependencies=["grid"],t.defaultOption=Vn(lu.defaultOption,{symbol:"circle",symbolSize:null,symbolRotate:null,symbolPosition:null,symbolOffset:null,symbolMargin:null,symbolRepeat:!1,symbolRepeatDirection:"end",symbolClip:!1,symbolBoundingData:null,symbolPatternSize:400,barGap:"-100%",clip:!1,progressive:0,emphasis:{scale:!1},select:{itemStyle:{borderColor:N.color.primary}}}),t}(lu);function d6(r){r.registerChartView(o6),r.registerSeriesModel(p6),r.registerLayout(r.PRIORITY.VISUAL.LAYOUT,pt(EL,"pictorialBar")),r.registerLayout(r.PRIORITY.VISUAL.PROGRESSIVE_LAYOUT,OL("pictorialBar"))}var g6=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e._layers=[],e}return t.prototype.render=function(e,a,n){var i=e.getData(),o=this,s=this.group,l=e.getLayerSeries(),u=i.getLayout("layoutInfo"),f=u.rect,v=u.boundaryGap;s.x=0,s.y=f.y+v[0];function h(g){return g.name}var c=new qa(this._layersSeries||[],l,h,h),p=[];c.add($(d,this,"add")).update($(d,this,"update")).remove($(d,this,"remove")).execute();function d(g,y,m){var _=o._layers;if(g==="remove"){s.remove(_[y]);return}for(var S=[],x=[],b,w=l[y].indices,T=0;T<w.length;T++){var C=i.getItemLayout(w[T]),M=C.x,D=C.y0,I=C.y;S.push(M,D),x.push(M,D+I),b=i.getItemVisual(w[T],"style")}var L,P=i.getItemLayout(w[0]),k=e.getModel("label"),R=k.get("margin"),O=e.getModel("emphasis");if(g==="add"){var E=p[y]=new rt;L=new C2({shape:{points:S,stackedOnPoints:x,smooth:.4,stackedOnSmooth:.4,smoothConstraint:!1},z2:0}),E.add(L),s.add(E),e.isAnimationEnabled()&&L.setClipPath(y6(L.getBoundingRect(),e,function(){L.removeClipPath()}))}else{var E=_[m];L=E.childAt(0),s.add(E),p[y]=E,Lt(L,{shape:{points:S,stackedOnPoints:x}},e),Ir(L)}Se(L,ce(e),{labelDataIndex:w[T-1],defaultText:i.getName(w[T-1]),inheritColor:b.fill},{normal:{verticalAlign:"middle"}}),L.setTextConfig({position:null,local:!0});var B=L.getTextContent();B&&(B.x=P.x-R,B.y=P.y0+P.y/2),L.useStyle(b),i.setItemGraphicEl(y,L),he(L,e),$t(L,O.get("focus"),O.get("blurScope"),O.get("disabled"))}this._layersSeries=l,this._layers=p},t.type="themeRiver",t}(Nt);function y6(r,t,e){var a=new _t({shape:{x:r.x-10,y:r.y-10,width:0,height:r.height+20}});return Yt(a,{shape:{x:r.x-50,width:r.width+100,height:r.height+20}},t,e),a}var hd=2,m6=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(e){r.prototype.init.apply(this,arguments),this.legendVisualProvider=new ks($(this.getData,this),$(this.getRawData,this))},t.prototype.fixData=function(e){var a=e.length,n={},i=hg(e,function(h){return n.hasOwnProperty(h[0]+"")||(n[h[0]+""]=-1),h[2]}),o=[];i.buckets.each(function(h,c){o.push({name:c,dataList:h})});for(var s=o.length,l=0;l<s;++l){for(var u=o[l].name,f=0;f<o[l].dataList.length;++f){var v=o[l].dataList[f][0]+"";n[v]=l}for(var v in n)n.hasOwnProperty(v)&&n[v]!==l&&(n[v]=l,e[a]=[v,0,u],a++)}return e},t.prototype.getInitialData=function(e,a){for(var n=this.getReferringComponents("singleAxis",Kt).models[0],i=n.get("type"),o=Pt(e.data,function(p){return p[2]!==void 0}),s=this.fixData(o||[]),l=[],u=this.nameMap=j(),f=0,v=0;v<s.length;++v)l.push(s[v][hd]),u.get(s[v][hd])||(u.set(s[v][hd],f),f++);var h=Ds(s,{coordDimensions:["single"],dimensionsDefine:[{name:"time",type:Jv(i)},{name:"value",type:"float"},{name:"name",type:"ordinal"}],encodeDefine:{single:0,value:1,itemName:2}}).dimensions,c=new Ue(h,this);return c.initData(s),c},t.prototype.getLayerSeries=function(){for(var e=this.getData(),a=e.count(),n=[],i=0;i<a;++i)n[i]=i;var o=e.mapDimension("single"),s=hg(n,function(u){return e.get("name",u)}),l=[];return s.buckets.each(function(u,f){u.sort(function(v,h){return e.get(o,v)-e.get(o,h)}),l.push({name:f,indices:u})}),l},t.prototype.getAxisTooltipData=function(e,a,n){W(e)||(e=e?[e]:[]);for(var i=this.getData(),o=this.getLayerSeries(),s=[],l=o.length,u,f=0;f<l;++f){for(var v=Number.MAX_VALUE,h=-1,c=o[f].indices.length,p=0;p<c;++p){var d=i.get(e[0],o[f].indices[p]),g=Math.abs(d-a);g<=v&&(u=d,v=g,h=o[f].indices[p])}s.push(h)}return{dataIndices:s,nestestValue:u}},t.prototype.formatTooltip=function(e,a,n){var i=this.getData(),o=i.getName(e),s=i.get(i.mapDimension("value"),e);return ue("nameValue",{name:o,value:s})},t.type="series.themeRiver",t.dependencies=["singleAxis"],t.defaultOption={z:2,colorBy:"data",coordinateSystem:"singleAxis",boundaryGap:["10%","10%"],singleAxisIndex:0,animationEasing:"linear",label:{margin:4,show:!0,position:"left",fontSize:11},emphasis:{label:{show:!0}}},t}(Bt);function _6(r,t){r.eachSeriesByType("themeRiver",function(e){var a=e.getData(),n=e.coordinateSystem,i={},o=n.getRect();i.rect=o;var s=e.get("boundaryGap"),l=n.getAxis();if(i.boundaryGap=s,l.orient==="horizontal"){s[0]=Z(s[0],o.height),s[1]=Z(s[1],o.height);var u=o.height-s[0]-s[1];Ew(a,e,u)}else{s[0]=Z(s[0],o.width),s[1]=Z(s[1],o.width);var f=o.width-s[0]-s[1];Ew(a,e,f)}a.setLayout("layoutInfo",i)})}function Ew(r,t,e){if(r.count())for(var a=t.coordinateSystem,n=t.getLayerSeries(),i=r.mapDimension("single"),o=r.mapDimension("value"),s=U(n,function(g){return U(g.indices,function(y){var m=a.dataToPoint(r.get(i,y));return m[1]=r.get(o,y),m})}),l=S6(s),u=l.y0,f=e/l.max,v=n.length,h=n[0].indices.length,c,p=0;p<h;++p){c=u[p]*f,r.setItemLayout(n[0].indices[p],{layerIndex:0,x:s[0][p][0],y0:c,y:s[0][p][1]*f});for(var d=1;d<v;++d)c+=s[d-1][p][1]*f,r.setItemLayout(n[d].indices[p],{layerIndex:d,x:s[d][p][0],y0:c,y:s[d][p][1]*f})}}function S6(r){for(var t=r.length,e=r[0].length,a=[],n=[],i=0,o=0;o<e;++o){for(var s=0,l=0;l<t;++l)s+=r[l][o][1];s>i&&(i=s),a.push(s)}for(var u=0;u<e;++u)n[u]=(i-a[u])/2;i=0;for(var f=0;f<e;++f){var v=a[f]+n[f];v>i&&(i=v)}return{y0:n,max:i}}function x6(r){r.registerChartView(g6),r.registerSeriesModel(m6),r.registerLayout(_6),r.registerProcessor(Ps("themeRiver"))}var b6=2,w6=4,Ow=function(r){z(t,r);function t(e,a,n,i){var o=r.call(this)||this;o.z2=b6,o.textConfig={inside:!0},ut(o).seriesIndex=a.seriesIndex;var s=new At({z2:w6,silent:e.getModel().get(["label","silent"])});return o.setTextContent(s),o.updateData(!0,e,a,n,i),o}return t.prototype.updateData=function(e,a,n,i,o){this.node=a,a.piece=this,n=n||this._seriesModel,i=i||this._ecModel;var s=this;ut(s).dataIndex=a.dataIndex;var l=a.getModel(),u=l.getModel("emphasis"),f=a.getLayout(),v=G({},f);v.label=null;var h=a.getVisual("style");h.lineJoin="bevel";var c=a.getVisual("decal");c&&(h.decal=ns(c,o));var p=ha(l.getModel("itemStyle"),v,!0);G(v,p),A(Xe,function(m){var _=s.ensureState(m),S=l.getModel([m,"itemStyle"]);_.style=S.getItemStyle();var x=ha(S,v);x&&(_.shape=x)}),e?(s.setShape(v),s.shape.r=f.r0,Yt(s,{shape:{r:f.r}},n,a.dataIndex)):(Lt(s,{shape:v},n),Ir(s)),s.useStyle(h),this._updateLabel(n);var d=l.getShallow("cursor");d&&s.attr("cursor",d),this._seriesModel=n||this._seriesModel,this._ecModel=i||this._ecModel;var g=u.get("focus"),y=g==="relative"?Ko(a.getAncestorsIndices(),a.getDescendantIndices()):g==="ancestor"?a.getAncestorsIndices():g==="descendant"?a.getDescendantIndices():g;$t(this,y,u.get("blurScope"),u.get("disabled"))},t.prototype._updateLabel=function(e){var a=this,n=this.node.getModel(),i=n.getModel("label"),o=this.node.getLayout(),s=o.endAngle-o.startAngle,l=(o.startAngle+o.endAngle)/2,u=Math.cos(l),f=Math.sin(l),v=this,h=v.getTextContent(),c=this.node.dataIndex,p=i.get("minAngle")/180*Math.PI,d=i.get("show")&&!(p!=null&&Math.abs(s)<p);h.ignore=!d,A($l,function(y){var m=y==="normal"?n.getModel("label"):n.getModel([y,"label"]),_=y==="normal",S=_?h:h.ensureState(y),x=e.getFormattedLabel(c,y);_&&(x=x||a.node.name),S.style=Gt(m,{},null,y!=="normal",!0),x&&(S.style.text=x);var b=m.get("show");b!=null&&!_&&(S.ignore=!b);var w=g(m,"position"),T=_?v:v.states[y],C=T.style.fill;T.textConfig={outsideFill:m.get("color")==="inherit"?C:null,inside:w!=="outside"};var M,D=g(m,"distance")||0,I=g(m,"align"),L=g(m,"rotate"),P=Math.PI*.5,k=Math.PI*1.5,R=ur(L==="tangential"?Math.PI/2-l:l),O=R>P&&!Qo(R-P)&&R<k;w==="outside"?(M=o.r+D,I=O?"right":"left"):!I||I==="center"?(s===2*Math.PI&&o.r0===0?M=0:M=(o.r+o.r0)/2,I="center"):I==="left"?(M=o.r0+D,I=O?"right":"left"):I==="right"&&(M=o.r-D,I=O?"left":"right"),S.style.align=I,S.style.verticalAlign=g(m,"verticalAlign")||"middle",S.x=M*u+o.cx,S.y=M*f+o.cy;var E=0;L==="radial"?E=ur(-l)+(O?Math.PI:0):L==="tangential"?E=ur(Math.PI/2-l)+(O?Math.PI:0):Mt(L)&&(E=L*Math.PI/180),S.rotation=ur(E)});function g(y,m){var _=y.get(m);return _??i.get(m)}h.dirtyStyle()},t}(ke),My="sunburstRootToNode",Nw="sunburstHighlight",T6="sunburstUnhighlight";function C6(r){r.registerAction({type:My,update:"updateView"},function(t,e){e.eachComponent({mainType:"series",subType:"sunburst",query:t},a);function a(n,i){var o=fu(t,[My],n);if(o){var s=n.getViewRoot();s&&(t.direction=O0(s,o.node)?"rollUp":"drillDown"),n.resetViewRoot(o.node)}}}),r.registerAction({type:Nw,update:"none"},function(t,e,a){t=G({},t),e.eachComponent({mainType:"series",subType:"sunburst",query:t},n);function n(i){var o=fu(t,[Nw],i);o&&(t.dataIndex=o.node.dataIndex)}a.dispatchAction(G(t,{type:"highlight"}))}),r.registerAction({type:T6,update:"updateView"},function(t,e,a){t=G({},t),a.dispatchAction(G(t,{type:"downplay"}))})}var A6=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n,i){var o=this;this.seriesModel=e,this.api=n,this.ecModel=a;var s=e.getData(),l=s.tree.root,u=e.getViewRoot(),f=this.group,v=e.get("renderLabelForZeroData"),h=[];u.eachNode(function(m){h.push(m)});var c=this._oldChildren||[];p(h,c),y(l,u),this._initEvents(),this._oldChildren=h;function p(m,_){if(m.length===0&&_.length===0)return;new qa(_,m,S,S).add(x).update(x).remove(pt(x,null)).execute();function S(b){return b.getId()}function x(b,w){var T=b==null?null:m[b],C=w==null?null:_[w];d(T,C)}}function d(m,_){if(!v&&m&&!m.getValue()&&(m=null),m!==l&&_!==l){if(_&&_.piece)m?(_.piece.updateData(!1,m,e,a,n),s.setItemGraphicEl(m.dataIndex,_.piece)):g(_);else if(m){var S=new Ow(m,e,a,n);f.add(S),s.setItemGraphicEl(m.dataIndex,S)}}}function g(m){m&&m.piece&&(f.remove(m.piece),m.piece=null)}function y(m,_){_.depth>0?(o.virtualPiece?o.virtualPiece.updateData(!1,m,e,a,n):(o.virtualPiece=new Ow(m,e,a,n),f.add(o.virtualPiece)),_.piece.off("click"),o.virtualPiece.on("click",function(S){o._rootToNode(_.parentNode)})):o.virtualPiece&&(f.remove(o.virtualPiece),o.virtualPiece=null)}},t.prototype._initEvents=function(){var e=this;this.group.off("click"),this.group.on("click",function(a){var n=!1,i=e.seriesModel.getViewRoot();i.eachNode(function(o){if(!n&&o.piece&&o.piece===a.target){var s=o.getModel().get("nodeClick");if(s==="rootToNode")e._rootToNode(o);else if(s==="link"){var l=o.getModel(),u=l.get("link");if(u){var f=l.get("target",!0)||"_blank";Hv(u,f)}}n=!0}})})},t.prototype._rootToNode=function(e){e!==this.seriesModel.getViewRoot()&&this.api.dispatchAction({type:My,from:this.uid,seriesId:this.seriesModel.id,targetNode:e})},t.prototype.containPoint=function(e,a){var n=a.getData(),i=n.getItemLayout(0);if(i){var o=e[0]-i.cx,s=e[1]-i.cy,l=Math.sqrt(o*o+s*s);return l<=i.r&&l>=i.r0}},t.type="sunburst",t}(Nt),M6=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.ignoreStyleOnData=!0,e}return t.prototype.getInitialData=function(e,a){var n={name:e.name,children:e.data};dP(n);var i=this._levelModels=U(e.levels||[],function(l){return new wt(l,this,a)},this),o=E0.createTree(n,this,s);function s(l){l.wrapMethod("getItemModel",function(u,f){var v=o.getNodeByDataIndex(f),h=i[v.depth];return h&&(u.parentModel=h),u})}return o.data},t.prototype.optionUpdated=function(){this.resetViewRoot()},t.prototype.getDataParams=function(e){var a=r.prototype.getDataParams.apply(this,arguments),n=this.getData().tree.getNodeByDataIndex(e);return a.treePathInfo=uc(n,this),a},t.prototype.getLevelModel=function(e){return this._levelModels&&this._levelModels[e.depth]},t.prototype.getViewRoot=function(){return this._viewRoot},t.prototype.resetViewRoot=function(e){e?this._viewRoot=e:e=this._viewRoot;var a=this.getRawData().tree.root;(!e||e!==a&&!a.contains(e))&&(this._viewRoot=a)},t.prototype.enableAriaDecal=function(){_I(this)},t.type="series.sunburst",t.defaultOption={z:2,center:["50%","50%"],radius:[0,"75%"],clockwise:!0,startAngle:90,minAngle:0,stillShowZeroSum:!0,nodeClick:"rootToNode",renderLabelForZeroData:!1,label:{rotate:"radial",show:!0,opacity:1,align:"center",position:"inside",distance:5,silent:!0},itemStyle:{borderWidth:1,borderColor:"white",borderType:"solid",shadowBlur:0,shadowColor:"rgba(0, 0, 0, 0.2)",shadowOffsetX:0,shadowOffsetY:0,opacity:1},emphasis:{focus:"descendant"},blur:{itemStyle:{opacity:.2},label:{opacity:.1}},animationType:"expansion",animationDuration:1e3,animationDurationUpdate:500,data:[],sort:"desc"},t}(Bt);function dP(r){var t=0;A(r.children,function(a){dP(a);var n=a.value;W(n)&&(n=n[0]),t+=n});var e=r.value;W(e)&&(e=e[0]),(e==null||isNaN(e))&&(e=t),e<0&&(e=0),W(r.value)?r.value[0]=e:r.value=e}var Bw=Math.PI/180;function D6(r,t,e){t.eachSeriesByType(r,function(a){var n=a.get("center"),i=a.get("radius");W(i)||(i=[0,i]),W(n)||(n=[n,n]);var o=e.getWidth(),s=e.getHeight(),l=Math.min(o,s),u=Z(n[0],o),f=Z(n[1],s),v=Z(i[0],l/2),h=Z(i[1],l/2),c=-a.get("startAngle")*Bw,p=a.get("minAngle")*Bw,d=a.getData().tree.root,g=a.getViewRoot(),y=g.depth,m=a.get("sort");m!=null&&gP(g,m);var _=0;A(g.children,function(R){!isNaN(R.getValue())&&_++});var S=g.getValue(),x=Math.PI/(S||_)*2,b=g.depth>0,w=g.height-(b?-1:1),T=(h-v)/(w||1),C=a.get("clockwise"),M=a.get("stillShowZeroSum"),D=C?1:-1,I=function(R,O){if(R){var E=O;if(R!==d){var B=R.getValue(),V=S===0&&M?x:B*x;V<p&&(V=p),E=O+D*V;var F=R.depth-y-(b?-1:1),H=v+T*F,Y=v+T*(F+1),K=a.getLevelModel(R);if(K){var ft=K.get("r0",!0),It=K.get("r",!0),Ot=K.get("radius",!0);Ot!=null&&(ft=Ot[0],It=Ot[1]),ft!=null&&(H=Z(ft,l/2)),It!=null&&(Y=Z(It,l/2))}R.setLayout({angle:V,startAngle:O,endAngle:E,clockwise:C,cx:u,cy:f,r0:H,r:Y})}if(R.children&&R.children.length){var vt=0;A(R.children,function(at){vt+=I(at,O+vt)})}return E-O}};if(b){var L=v,P=v+T,k=Math.PI*2;d.setLayout({angle:k,startAngle:c,endAngle:c+k,clockwise:C,cx:u,cy:f,r0:L,r:P})}I(g,c)})}function gP(r,t){var e=r.children||[];r.children=L6(e,t),e.length&&A(r.children,function(a){gP(a,t)})}function L6(r,t){if(tt(t)){var e=U(r,function(n,i){var o=n.getValue();return{params:{depth:n.depth,height:n.height,dataIndex:n.dataIndex,getValue:function(){return o}},index:i}});return e.sort(function(n,i){return t(n.params,i.params)}),U(e,function(n){return r[n.index]})}else{var a=t==="asc";return r.sort(function(n,i){var o=(n.getValue()-i.getValue())*(a?1:-1);return o===0?(n.dataIndex-i.dataIndex)*(a?-1:1):o})}}function I6(r){var t={};function e(a,n,i){if(a.depth===0)return N.color.neutral50;for(var o=a;o&&o.depth>1;)o=o.parentNode;var s=n.getColorFromPalette(o.name||o.dataIndex+"",t);return a.depth>1&&X(s)&&(s=Dv(s,(a.depth-1)/(i-1)*.5)),s}r.eachSeriesByType("sunburst",function(a){var n=a.getData(),i=n.tree;i.eachNode(function(o){var s=o.getModel(),l=s.getModel("itemStyle").getItemStyle();l.fill||(l.fill=e(o,a,i.root.height));var u=n.ensureUniqueItemVisual(o.dataIndex,"style");G(u,l)})})}function P6(r){r.registerChartView(A6),r.registerSeriesModel(M6),r.registerLayout(pt(D6,"sunburst")),r.registerProcessor(pt(Ps,"sunburst")),r.registerVisual(I6),C6(r)}var zw={color:"fill",borderColor:"stroke"},R6={symbol:1,symbolSize:1,symbolKeepAspect:1,legendIcon:1,visualMeta:1,liftZ:1,decal:1},Ha=St(),k6=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.optionUpdated=function(){this.currentZLevel=this.get("zlevel",!0),this.currentZ=this.get("z",!0)},t.prototype.getInitialData=function(e,a){return Ca(null,this)},t.prototype.getDataParams=function(e,a,n){var i=r.prototype.getDataParams.call(this,e,a);return n&&(i.info=Ha(n).info),i},t.type="series.custom",t.dependencies=["grid","polar","geo","singleAxis","calendar","matrix"],t.defaultOption={coordinateSystem:"cartesian2d",z:2,legendHoverLink:!0,clip:!1},t}(Bt);function E6(r,t){return t=t||[0,0],U(["x","y"],function(e,a){var n=this.getAxis(e),i=t[a],o=r[a]/2;return n.type==="category"?n.getBandWidth():Math.abs(n.dataToCoord(i-o)-n.dataToCoord(i+o))},this)}function O6(r){var t=r.master.getRect();return{coordSys:{type:"cartesian2d",x:t.x,y:t.y,width:t.width,height:t.height},api:{coord:function(e){return r.dataToPoint(e)},size:$(E6,r)}}}function N6(r,t){return t=t||[0,0],U([0,1],function(e){var a=t[e],n=r[e]/2,i=[],o=[];return i[e]=a-n,o[e]=a+n,i[1-e]=o[1-e]=t[1-e],Math.abs(this.dataToPoint(i)[e]-this.dataToPoint(o)[e])},this)}function B6(r){var t=r.getBoundingRect();return{coordSys:{type:"geo",x:t.x,y:t.y,width:t.width,height:t.height,zoom:r.getZoom()},api:{coord:function(e){return r.dataToPoint(e)},size:$(N6,r)}}}function z6(r,t){var e=this.getAxis(),a=t instanceof Array?t[0]:t,n=(r instanceof Array?r[0]:r)/2;return e.type==="category"?e.getBandWidth():Math.abs(e.dataToCoord(a-n)-e.dataToCoord(a+n))}function V6(r){var t=r.getRect();return{coordSys:{type:"singleAxis",x:t.x,y:t.y,width:t.width,height:t.height},api:{coord:function(e){return r.dataToPoint(e)},size:$(z6,r)}}}function G6(r,t){return t=t||[0,0],U(["Radius","Angle"],function(e,a){var n="get"+e+"Axis",i=this[n](),o=t[a],s=r[a]/2,l=i.type==="category"?i.getBandWidth():Math.abs(i.dataToCoord(o-s)-i.dataToCoord(o+s));return e==="Angle"&&(l=l*Math.PI/180),l},this)}function F6(r){var t=r.getRadiusAxis(),e=r.getAngleAxis(),a=t.getExtent();return a[0]>a[1]&&a.reverse(),{coordSys:{type:"polar",cx:r.cx,cy:r.cy,r:a[1],r0:a[0]},api:{coord:function(n){var i=t.dataToRadius(n[0]),o=e.dataToAngle(n[1]),s=r.coordToPoint([i,o]);return s.push(i,o*Math.PI/180),s},size:$(G6,r)}}}function H6(r){var t=r.getRect(),e=r.getRangeInfo();return{coordSys:{type:"calendar",x:t.x,y:t.y,width:t.width,height:t.height,cellWidth:r.getCellWidth(),cellHeight:r.getCellHeight(),rangeInfo:{start:e.start,end:e.end,weeks:e.weeks,dayCount:e.allDay}},api:{coord:function(a,n){return r.dataToPoint(a,n)},layout:function(a,n){return r.dataToLayout(a,n)}}}}function W6(r){var t=r.getRect();return{coordSys:{type:"matrix",x:t.x,y:t.y,width:t.width,height:t.height},api:{coord:function(e,a){return r.dataToPoint(e,a)},layout:function(e,a){return r.dataToLayout(e,a)}}}}function yP(r,t,e,a){return r&&(r.legacy||r.legacy!==!1&&!e&&!a&&t!=="tspan"&&(t==="text"||q(r,"text")))}function mP(r,t,e){var a=r,n,i,o;if(t==="text")o=a;else{o={},q(a,"text")&&(o.text=a.text),q(a,"rich")&&(o.rich=a.rich),q(a,"textFill")&&(o.fill=a.textFill),q(a,"textStroke")&&(o.stroke=a.textStroke),q(a,"fontFamily")&&(o.fontFamily=a.fontFamily),q(a,"fontSize")&&(o.fontSize=a.fontSize),q(a,"fontStyle")&&(o.fontStyle=a.fontStyle),q(a,"fontWeight")&&(o.fontWeight=a.fontWeight),i={type:"text",style:o,silent:!0},n={};var s=q(a,"textPosition");e?n.position=s?a.textPosition:"inside":s&&(n.position=a.textPosition),q(a,"textPosition")&&(n.position=a.textPosition),q(a,"textOffset")&&(n.offset=a.textOffset),q(a,"textRotation")&&(n.rotation=a.textRotation),q(a,"textDistance")&&(n.distance=a.textDistance)}return Vw(o,r),A(o.rich,function(l){Vw(l,l)}),{textConfig:n,textContent:i}}function Vw(r,t){t&&(t.font=t.textFont||t.font,q(t,"textStrokeWidth")&&(r.lineWidth=t.textStrokeWidth),q(t,"textAlign")&&(r.align=t.textAlign),q(t,"textVerticalAlign")&&(r.verticalAlign=t.textVerticalAlign),q(t,"textLineHeight")&&(r.lineHeight=t.textLineHeight),q(t,"textWidth")&&(r.width=t.textWidth),q(t,"textHeight")&&(r.height=t.textHeight),q(t,"textBackgroundColor")&&(r.backgroundColor=t.textBackgroundColor),q(t,"textPadding")&&(r.padding=t.textPadding),q(t,"textBorderColor")&&(r.borderColor=t.textBorderColor),q(t,"textBorderWidth")&&(r.borderWidth=t.textBorderWidth),q(t,"textBorderRadius")&&(r.borderRadius=t.textBorderRadius),q(t,"textBoxShadowColor")&&(r.shadowColor=t.textBoxShadowColor),q(t,"textBoxShadowBlur")&&(r.shadowBlur=t.textBoxShadowBlur),q(t,"textBoxShadowOffsetX")&&(r.shadowOffsetX=t.textBoxShadowOffsetX),q(t,"textBoxShadowOffsetY")&&(r.shadowOffsetY=t.textBoxShadowOffsetY))}function Gw(r,t,e){var a=r;a.textPosition=a.textPosition||e.position||"inside",e.offset!=null&&(a.textOffset=e.offset),e.rotation!=null&&(a.textRotation=e.rotation),e.distance!=null&&(a.textDistance=e.distance);var n=a.textPosition.indexOf("inside")>=0,i=r.fill||N.color.neutral99;Fw(a,t);var o=a.textFill==null;return n?o&&(a.textFill=e.insideFill||N.color.neutral00,!a.textStroke&&e.insideStroke&&(a.textStroke=e.insideStroke),!a.textStroke&&(a.textStroke=i),a.textStrokeWidth==null&&(a.textStrokeWidth=2)):(o&&(a.textFill=r.fill||e.outsideFill||N.color.neutral00),!a.textStroke&&e.outsideStroke&&(a.textStroke=e.outsideStroke)),a.text=t.text,a.rich=t.rich,A(t.rich,function(s){Fw(s,s)}),a}function Fw(r,t){t&&(q(t,"fill")&&(r.textFill=t.fill),q(t,"stroke")&&(r.textStroke=t.fill),q(t,"lineWidth")&&(r.textStrokeWidth=t.lineWidth),q(t,"font")&&(r.font=t.font),q(t,"fontStyle")&&(r.fontStyle=t.fontStyle),q(t,"fontWeight")&&(r.fontWeight=t.fontWeight),q(t,"fontSize")&&(r.fontSize=t.fontSize),q(t,"fontFamily")&&(r.fontFamily=t.fontFamily),q(t,"align")&&(r.textAlign=t.align),q(t,"verticalAlign")&&(r.textVerticalAlign=t.verticalAlign),q(t,"lineHeight")&&(r.textLineHeight=t.lineHeight),q(t,"width")&&(r.textWidth=t.width),q(t,"height")&&(r.textHeight=t.height),q(t,"backgroundColor")&&(r.textBackgroundColor=t.backgroundColor),q(t,"padding")&&(r.textPadding=t.padding),q(t,"borderColor")&&(r.textBorderColor=t.borderColor),q(t,"borderWidth")&&(r.textBorderWidth=t.borderWidth),q(t,"borderRadius")&&(r.textBorderRadius=t.borderRadius),q(t,"shadowColor")&&(r.textBoxShadowColor=t.shadowColor),q(t,"shadowBlur")&&(r.textBoxShadowBlur=t.shadowBlur),q(t,"shadowOffsetX")&&(r.textBoxShadowOffsetX=t.shadowOffsetX),q(t,"shadowOffsetY")&&(r.textBoxShadowOffsetY=t.shadowOffsetY),q(t,"textShadowColor")&&(r.textShadowColor=t.textShadowColor),q(t,"textShadowBlur")&&(r.textShadowBlur=t.textShadowBlur),q(t,"textShadowOffsetX")&&(r.textShadowOffsetX=t.textShadowOffsetX),q(t,"textShadowOffsetY")&&(r.textShadowOffsetY=t.textShadowOffsetY))}var _P={position:["x","y"],scale:["scaleX","scaleY"],origin:["originX","originY"]},Hw=Ct(_P);Mr(ga,function(r,t){return r[t]=1,r},{});ga.join(", ");var gh=["","style","shape","extra"],vs=St();function Q0(r,t,e,a,n){var i=r+"Animation",o=_s(r,a,n)||{},s=vs(t).userDuring;return o.duration>0&&(o.during=s?$($6,{el:t,userDuring:s}):null,o.setToFinal=!0,o.scope=r),G(o,e[i]),o}function gv(r,t,e,a){a=a||{};var n=a.dataIndex,i=a.isInit,o=a.clearStyle,s=e.isAnimationEnabled(),l=vs(r),u=t.style;l.userDuring=t.during;var f={},v={};if(K6(r,t,v),r.type==="compound")for(var h=r.shape.paths,c=t.shape.paths,p=0;p<c.length;p++){var d=c[p];cd("shape",d,h[p])}else cd("shape",t,v),cd("extra",t,v);if(!i&&s&&(q6(r,t,f),Ww("shape",r,t,f),Ww("extra",r,t,f),j6(r,t,u,f)),v.style=u,U6(r,v,o),Z6(r,t),s)if(i){var g={};A(gh,function(m){var _=m?t[m]:t;_&&_.enterFrom&&(m&&(g[m]=g[m]||{}),G(m?g[m]:g,_.enterFrom))});var y=Q0("enter",r,t,e,n);y.duration>0&&r.animateFrom(g,y)}else Y6(r,t,n||0,e,f);SP(r,t),u?r.dirty():r.markRedraw()}function SP(r,t){for(var e=vs(r).leaveToProps,a=0;a<gh.length;a++){var n=gh[a],i=n?t[n]:t;i&&i.leaveTo&&(e||(e=vs(r).leaveToProps={}),n&&(e[n]=e[n]||{}),G(n?e[n]:e,i.leaveTo))}}function hc(r,t,e,a){if(r){var n=r.parent,i=vs(r).leaveToProps;if(i){var o=Q0("update",r,t,e,0);o.done=function(){n&&n.remove(r)},r.animateTo(i,o)}else n&&n.remove(r)}}function Bi(r){return r==="all"}function U6(r,t,e){var a=t.style;if(!r.isGroup&&a){if(e){r.useStyle({});for(var n=r.animators,i=0;i<n.length;i++){var o=n[i];o.targetName==="style"&&o.changeTarget(r.style)}}r.setStyle(a)}t&&(t.style=null,t&&r.attr(t),t.style=a)}function Y6(r,t,e,a,n){if(n){var i=Q0("update",r,t,a,e);i.duration>0&&r.animateFrom(n,i)}}function Z6(r,t){q(t,"silent")&&(r.silent=t.silent),q(t,"ignore")&&(r.ignore=t.ignore),r instanceof Lr&&q(t,"invisible")&&(r.invisible=t.invisible),r instanceof bt&&q(t,"autoBatch")&&(r.autoBatch=t.autoBatch)}var ra={},X6={setTransform:function(r,t){return ra.el[r]=t,this},getTransform:function(r){return ra.el[r]},setShape:function(r,t){var e=ra.el,a=e.shape||(e.shape={});return a[r]=t,e.dirtyShape&&e.dirtyShape(),this},getShape:function(r){var t=ra.el.shape;if(t)return t[r]},setStyle:function(r,t){var e=ra.el,a=e.style;return a&&(a[r]=t,e.dirtyStyle&&e.dirtyStyle()),this},getStyle:function(r){var t=ra.el.style;if(t)return t[r]},setExtra:function(r,t){var e=ra.el.extra||(ra.el.extra={});return e[r]=t,this},getExtra:function(r){var t=ra.el.extra;if(t)return t[r]}};function $6(){var r=this,t=r.el;if(t){var e=vs(t).userDuring,a=r.userDuring;if(e!==a){r.el=r.userDuring=null;return}ra.el=t,a(X6)}}function Ww(r,t,e,a){var n=e[r];if(n){var i=t[r],o;if(i){var s=e.transition,l=n.transition;if(l)if(!o&&(o=a[r]={}),Bi(l))G(o,i);else for(var u=Ft(l),f=0;f<u.length;f++){var v=u[f],h=i[v];o[v]=h}else if(Bi(s)||gt(s,r)>=0){!o&&(o=a[r]={});for(var c=Ct(i),f=0;f<c.length;f++){var v=c[f],h=i[v];J6(n[v],h)&&(o[v]=h)}}}}}function cd(r,t,e){var a=t[r];if(a)for(var n=e[r]={},i=Ct(a),o=0;o<i.length;o++){var s=i[o];n[s]=Pl(a[s])}}function q6(r,t,e){for(var a=t.transition,n=Bi(a)?ga:Ft(a||[]),i=0;i<n.length;i++){var o=n[i];if(!(o==="style"||o==="shape"||o==="extra")){var s=r[o];e[o]=s}}}function K6(r,t,e){for(var a=0;a<Hw.length;a++){var n=Hw[a],i=_P[n],o=t[n];o&&(e[i[0]]=o[0],e[i[1]]=o[1])}for(var a=0;a<ga.length;a++){var s=ga[a];t[s]!=null&&(e[s]=t[s])}}function j6(r,t,e,a){if(e){var n=r.style,i;if(n){var o=e.transition,s=t.transition;if(o&&!Bi(o)){var l=Ft(o);!i&&(i=a.style={});for(var u=0;u<l.length;u++){var f=l[u],v=n[f];i[f]=v}}else if(r.getAnimationStyleProps&&(Bi(s)||Bi(o)||gt(s,"style")>=0)){var h=r.getAnimationStyleProps(),c=h?h.style:null;if(c){!i&&(i=a.style={});for(var p=Ct(e),u=0;u<p.length;u++){var f=p[u];if(c[f]){var v=n[f];i[f]=v}}}}}}}function J6(r,t){return Pe(r)?r!==t:r!=null&&isFinite(r)}var xP=St(),Q6=["percent","easing","shape","style","extra"];function bP(r){r.stopAnimation("keyframe"),r.attr(xP(r))}function yh(r,t,e){if(!(!e.isAnimationEnabled()||!t)){if(W(t)){A(t,function(s){yh(r,s,e)});return}var a=t.keyframes,n=t.duration;if(e&&n==null){var i=_s("enter",e,0);n=i&&i.duration}if(!(!a||!n)){var o=xP(r);A(gh,function(s){if(!(s&&!r[s])){var l;a.sort(function(u,f){return u.percent-f.percent}),A(a,function(u){var f=r.animators,v=s?u[s]:u;if(v){var h=Ct(v);if(s||(h=Pt(h,function(d){return gt(Q6,d)<0})),!!h.length){l||(l=r.animate(s,t.loop,!0),l.scope="keyframe");for(var c=0;c<f.length;c++)f[c]!==l&&f[c].targetName===l.targetName&&f[c].stopTracks(h);s&&(o[s]=o[s]||{});var p=s?o[s]:o;A(h,function(d){p[d]=((s?r[s]:r)||{})[d]}),l.whenWithKeys(n*u.percent,v,h,u.easing)}}}),l&&l.delay(t.delay||0).duration(n).start(t.easing)}})}}}var Wa="emphasis",Sn="normal",t_="blur",e_="select",On=[Sn,Wa,t_,e_],pd={normal:["itemStyle"],emphasis:[Wa,"itemStyle"],blur:[t_,"itemStyle"],select:[e_,"itemStyle"]},dd={normal:["label"],emphasis:[Wa,"label"],blur:[t_,"label"],select:[e_,"label"]},tY=["x","y"],eY="e\0\0",gr={normal:{},emphasis:{},blur:{},select:{}},rY={cartesian2d:O6,geo:B6,single:V6,polar:F6,calendar:H6,matrix:W6};function Dy(r){return r instanceof bt}function Ly(r){return r instanceof Lr}function aY(r,t){t.copyTransform(r),Ly(t)&&Ly(r)&&(t.setStyle(r.style),t.z=r.z,t.z2=r.z2,t.zlevel=r.zlevel,t.invisible=r.invisible,t.ignore=r.ignore,Dy(t)&&Dy(r)&&t.setShape(r.shape))}var nY=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n,i){this._progressiveEls=null;var o=this._data,s=e.getData(),l=this.group,u=Uw(e,s,a,n);o||l.removeAll(),s.diff(o).add(function(v){gd(n,null,v,u(v,i),e,l,s)}).remove(function(v){var h=o.getItemGraphicEl(v);h&&hc(h,Ha(h).option,e)}).update(function(v,h){var c=o.getItemGraphicEl(h);gd(n,c,v,u(v,i),e,l,s)}).execute();var f=e.get("clip",!0)?Ou(e.coordinateSystem,!1,e):null;f?l.setClipPath(f):l.removeClipPath(),this._data=s},t.prototype.incrementalPrepareRender=function(e,a,n){this.group.removeAll(),this._data=null},t.prototype.incrementalRender=function(e,a,n,i,o){var s=a.getData(),l=Uw(a,s,n,i),u=this._progressiveEls=[];function f(c){c.isGroup||(c.incremental=!0,c.ensureState("emphasis").hoverLayer=!0)}for(var v=e.start;v<e.end;v++){var h=gd(null,null,v,l(v,o),a,this.group,s);h&&(h.traverse(f),u.push(h))}},t.prototype.eachRendered=function(e){zn(this._progressiveEls||this.group,e)},t.prototype.filterForExposedEvent=function(e,a,n,i){var o=a.element;if(o==null||n.name===o)return!0;for(;(n=n.__hostTarget||n.parent)&&n!==this.group;)if(n.name===o)return!0;return!1},t.type="custom",t}(Nt);function r_(r){var t=r.type,e;if(t==="path"){var a=r.shape,n=a.width!=null&&a.height!=null?{x:a.x||0,y:a.y||0,width:a.width,height:a.height}:null,i=CP(a);e=es(i,null,n,a.layout||"center"),Ha(e).customPathData=i}else if(t==="image")e=new xe({}),Ha(e).customImagePath=r.style.image;else if(t==="text")e=new At({});else if(t==="group")e=new rt;else if(t==="compoundPath"){var a=r.shape;if(!a||!a.paths){var o="";kt(o)}var s=U(a.paths,function(f){if(f.type==="path")return es(f.shape.pathData,f,null);var v=Kl(f.type);if(!v){var h="";kt(h)}return new v});e=new Mu({shape:{paths:s}})}else{var l=Kl(t);if(!l){var o="";kt(o)}e=new l}return Ha(e).customGraphicType=t,e.name=r.name,e.z2EmphasisLift=1,e.z2SelectLift=1,e}function a_(r,t,e,a,n,i,o){bP(t);var s=n&&n.normal.cfg;s&&t.setTextConfig(s),a&&a.transition==null&&(a.transition=tY);var l=a&&a.style;if(l){if(t.type==="text"){var u=l;q(u,"textFill")&&(u.fill=u.textFill),q(u,"textStroke")&&(u.stroke=u.textStroke)}var f=void 0,v=Dy(t)?l.decal:null;r&&v&&(v.dirty=!0,f=ns(v,r)),l.__decalPattern=f}if(Ly(t)&&l){var f=l.__decalPattern;f&&(l.decal=f)}gv(t,a,i,{dataIndex:e,isInit:o,clearStyle:!0}),yh(t,a.keyframeAnimation,i)}function wP(r,t,e,a,n){var i=t.isGroup?null:t,o=n&&n[r].cfg;if(i){var s=i.ensureState(r);if(a===!1){var l=i.getState(r);l&&(l.style=null)}else s.style=a||null;o&&(s.textConfig=o),Hi(i)}}function iY(r,t,e){if(!r.isGroup){var a=r,n=e.currentZ,i=e.currentZLevel;a.z=n,a.zlevel=i;var o=t.z2;o!=null&&(a.z2=o||0);for(var s=0;s<On.length;s++)oY(a,t,On[s])}}function oY(r,t,e){var a=e===Sn,n=a?t:mh(t,e),i=n?n.z2:null,o;i!=null&&(o=a?r:r.ensureState(e),o.z2=i||0)}function Uw(r,t,e,a){var n=r.get("renderItem");if(typeof n=="string"){var i=hV(n);i&&(n=i)}var o=r.coordinateSystem,s={};o&&(s=o.prepareCustoms?o.prepareCustoms(o):rY[o.type](o));for(var l=nt({getWidth:a.getWidth,getHeight:a.getHeight,getZr:a.getZr,getDevicePixelRatio:a.getDevicePixelRatio,value:x,style:w,ordinalRawValue:b,styleEmphasis:T,visual:D,barLayout:I,currentSeriesIndices:L,font:P},s.api||{}),u={context:{},seriesId:r.id,seriesName:r.name,seriesIndex:r.seriesIndex,coordSys:s.coordSys,dataInsideLength:t.count(),encode:sY(r.getData()),itemPayload:r.get("itemPayload")||{}},f,v,h={},c={},p={},d={},g=0;g<On.length;g++){var y=On[g];p[y]=r.getModel(pd[y]),d[y]=r.getModel(dd[y])}function m(k){return k===f?v||(v=t.getItemModel(k)):t.getItemModel(k)}function _(k,R){return t.hasItemOption?k===f?h[R]||(h[R]=m(k).getModel(pd[R])):m(k).getModel(pd[R]):p[R]}function S(k,R){return t.hasItemOption?k===f?c[R]||(c[R]=m(k).getModel(dd[R])):m(k).getModel(dd[R]):d[R]}return function(k,R){return f=k,v=null,h={},c={},n&&n(nt({dataIndexInside:k,dataIndex:t.getRawIndex(k),actionType:R?R.type:null},u),l)};function x(k,R){return R==null&&(R=f),t.getStore().get(t.getDimensionIndex(k||0),R)}function b(k,R){R==null&&(R=f),k=k||0;var O=t.getDimensionInfo(k);if(!O){var E=t.getDimensionIndex(k);return E>=0?t.getStore().get(E,R):void 0}var B=t.get(O.name,R),V=O&&O.ordinalMeta;return V?V.categories[B]:B}function w(k,R){R==null&&(R=f);var O=t.getItemVisual(R,"style"),E=O&&O.fill,B=O&&O.opacity,V=_(R,Sn).getItemStyle();E!=null&&(V.fill=E),B!=null&&(V.opacity=B);var F={inheritColor:X(E)?E:N.color.neutral99},H=S(R,Sn),Y=Gt(H,null,F,!1,!0);Y.text=H.getShallow("show")?Q(r.getFormattedLabel(R,Sn),ss(t,R)):null;var K=Vv(H,F,!1);return M(k,V),V=Gw(V,Y,K),k&&C(V,k),V.legacy=!0,V}function T(k,R){R==null&&(R=f);var O=_(R,Wa).getItemStyle(),E=S(R,Wa),B=Gt(E,null,null,!0,!0);B.text=E.getShallow("show")?Qe(r.getFormattedLabel(R,Wa),r.getFormattedLabel(R,Sn),ss(t,R)):null;var V=Vv(E,null,!0);return M(k,O),O=Gw(O,B,V),k&&C(O,k),O.legacy=!0,O}function C(k,R){for(var O in R)q(R,O)&&(k[O]=R[O])}function M(k,R){k&&(k.textFill&&(R.textFill=k.textFill),k.textPosition&&(R.textPosition=k.textPosition))}function D(k,R){if(R==null&&(R=f),q(zw,k)){var O=t.getItemVisual(R,"style");return O?O[zw[k]]:null}if(q(R6,k))return t.getItemVisual(R,k)}function I(k){if(o.type==="cartesian2d"){var R=o.getBaseAxis();return v5(nt({axis:R},k))}}function L(){return e.getCurrentSeriesIndices()}function P(k){return Rm(k,e)}}function sY(r){var t={};return A(r.dimensions,function(e){var a=r.getDimensionInfo(e);if(!a.isExtraCoord){var n=a.coordDim,i=t[n]=t[n]||[];i[a.coordDimIndex]=r.getDimensionIndex(e)}}),t}function gd(r,t,e,a,n,i,o){if(!a){i.remove(t);return}var s=n_(r,t,e,a,n,i);return s&&o.setItemGraphicEl(e,s),s&&$t(s,a.focus,a.blurScope,a.emphasisDisabled),s}function n_(r,t,e,a,n,i){var o=-1,s=t;t&&TP(t,a,n)&&(o=gt(i.childrenRef(),t),t=null);var l=!t,u=t;u?u.clearStates():(u=r_(a),s&&aY(s,u)),a.morph===!1?u.disableMorphing=!0:u.disableMorphing&&(u.disableMorphing=!1),a.tooltipDisabled&&(u.tooltipDisabled=!0),gr.normal.cfg=gr.normal.conOpt=gr.emphasis.cfg=gr.emphasis.conOpt=gr.blur.cfg=gr.blur.conOpt=gr.select.cfg=gr.select.conOpt=null,gr.isLegacy=!1,uY(u,e,a,n,l,gr),lY(u,e,a,n,l),a_(r,u,e,a,gr,n,l),q(a,"info")&&(Ha(u).info=a.info);for(var f=0;f<On.length;f++){var v=On[f];if(v!==Sn){var h=mh(a,v),c=i_(a,h,v);wP(v,u,h,c,gr)}}return iY(u,a,n),a.type==="group"&&fY(r,u,e,a,n),o>=0?i.replaceAt(u,o):i.add(u),u}function TP(r,t,e){var a=Ha(r),n=t.type,i=t.shape,o=t.style;return e.isUniversalTransitionEnabled()||n!=null&&n!==a.customGraphicType||n==="path"&&pY(i)&&CP(i)!==a.customPathData||n==="image"&&q(o,"image")&&o.image!==a.customImagePath}function lY(r,t,e,a,n){var i=e.clipPath;if(i===!1)r&&r.getClipPath()&&r.removeClipPath();else if(i){var o=r.getClipPath();o&&TP(o,i,a)&&(o=null),o||(o=r_(i),r.setClipPath(o)),a_(null,o,t,i,null,a,n)}}function uY(r,t,e,a,n,i){if(!(r.isGroup||r.type==="compoundPath")){Yw(e,null,i),Yw(e,Wa,i);var o=i.normal.conOpt,s=i.emphasis.conOpt,l=i.blur.conOpt,u=i.select.conOpt;if(o!=null||s!=null||u!=null||l!=null){var f=r.getTextContent();if(o===!1)f&&r.removeTextContent();else{o=i.normal.conOpt=o||{type:"text"},f?f.clearStates():(f=r_(o),r.setTextContent(f)),a_(null,f,t,o,null,a,n);for(var v=o&&o.style,h=0;h<On.length;h++){var c=On[h];if(c!==Sn){var p=i[c].conOpt;wP(c,f,p,i_(o,p,c),null)}}v?f.dirty():f.markRedraw()}}}}function Yw(r,t,e){var a=t?mh(r,t):r,n=t?i_(r,a,Wa):r.style,i=r.type,o=a?a.textConfig:null,s=r.textContent,l=s?t?mh(s,t):s:null;if(n&&(e.isLegacy||yP(n,i,!!o,!!l))){e.isLegacy=!0;var u=mP(n,i,!t);!o&&u.textConfig&&(o=u.textConfig),!l&&u.textContent&&(l=u.textContent)}if(!t&&l){var f=l;!f.type&&(f.type="text")}var v=t?e[t]:e.normal;v.cfg=o,v.conOpt=l}function mh(r,t){return t?r?r[t]:null:r}function i_(r,t,e){var a=t&&t.style;return a==null&&e===Wa&&r&&(a=r.styleEmphasis),a}function fY(r,t,e,a,n){var i=a.children,o=i?i.length:0,s=a.$mergeChildren,l=s==="byName"||a.diffChildrenByName,u=s===!1;if(!(!o&&!l&&!u)){if(l){hY({api:r,oldChildren:t.children()||[],newChildren:i||[],dataIndex:e,seriesModel:n,group:t});return}u&&t.removeAll();for(var f=0;f<o;f++){var v=i[f],h=t.childAt(f);v?(v.ignore==null&&(v.ignore=!1),n_(r,h,e,v,n,t)):h.ignore=!0}for(var c=t.childCount()-1;c>=f;c--){var p=t.childAt(c);vY(t,p,n)}}}function vY(r,t,e){t&&hc(t,Ha(r).option,e)}function hY(r){new qa(r.oldChildren,r.newChildren,Zw,Zw,r).add(Xw).update(Xw).remove(cY).execute()}function Zw(r,t){var e=r&&r.name;return e??eY+t}function Xw(r,t){var e=this.context,a=r!=null?e.newChildren[r]:null,n=t!=null?e.oldChildren[t]:null;n_(e.api,n,e.dataIndex,a,e.seriesModel,e.group)}function cY(r){var t=this.context,e=t.oldChildren[r];e&&hc(e,Ha(e).option,t.seriesModel)}function CP(r){return r&&(r.pathData||r.d)}function pY(r){return r&&(q(r,"pathData")||q(r,"d"))}function dY(r){r.registerChartView(nY),r.registerSeriesModel(k6)}var bi=St(),$w=et,yd=$,o_=function(){function r(){this._dragging=!1,this.animationThreshold=15}return r.prototype.render=function(t,e,a,n){var i=e.get("value"),o=e.get("status");if(this._axisModel=t,this._axisPointerModel=e,this._api=a,!(!n&&this._lastValue===i&&this._lastStatus===o)){this._lastValue=i,this._lastStatus=o;var s=this._group,l=this._handle;if(!o||o==="hide"){s&&s.hide(),l&&l.hide();return}s&&s.show(),l&&l.show();var u={};this.makeElOption(u,i,t,e,a);var f=u.graphicKey;f!==this._lastGraphicKey&&this.clear(a),this._lastGraphicKey=f;var v=this._moveAnimation=this.determineAnimation(t,e);if(!s)s=this._group=new rt,this.createPointerEl(s,u,t,e),this.createLabelEl(s,u,t,e),a.getZr().add(s);else{var h=pt(qw,e,v);this.updatePointerEl(s,u,h),this.updateLabelEl(s,u,h,e)}jw(s,e,!0),this._renderHandle(i)}},r.prototype.remove=function(t){this.clear(t)},r.prototype.dispose=function(t){this.clear(t)},r.prototype.determineAnimation=function(t,e){var a=e.get("animation"),n=t.axis,i=n.type==="category",o=e.get("snap");if(!o&&!i)return!1;if(a==="auto"||a==null){var s=this.animationThreshold;if(i&&n.getBandWidth()>s)return!0;if(o){var l=M0(t).seriesDataCount,u=n.getExtent();return Math.abs(u[0]-u[1])/l>s}return!1}return a===!0},r.prototype.makeElOption=function(t,e,a,n,i){},r.prototype.createPointerEl=function(t,e,a,n){var i=e.pointer;if(i){var o=bi(t).pointerEl=new ji[i.type]($w(e.pointer));t.add(o)}},r.prototype.createLabelEl=function(t,e,a,n){if(e.label){var i=bi(t).labelEl=new At($w(e.label));t.add(i),Kw(i,n)}},r.prototype.updatePointerEl=function(t,e,a){var n=bi(t).pointerEl;n&&e.pointer&&(n.setStyle(e.pointer.style),a(n,{shape:e.pointer.shape}))},r.prototype.updateLabelEl=function(t,e,a,n){var i=bi(t).labelEl;i&&(i.setStyle(e.label.style),a(i,{x:e.label.x,y:e.label.y}),Kw(i,n))},r.prototype._renderHandle=function(t){if(!(this._dragging||!this.updateHandleTransform)){var e=this._axisPointerModel,a=this._api.getZr(),n=this._handle,i=e.getModel("handle"),o=e.get("status");if(!i.get("show")||!o||o==="hide"){n&&a.remove(n),this._handle=null;return}var s;this._handle||(s=!0,n=this._handle=Ss(i.get("icon"),{cursor:"move",draggable:!0,onmousemove:function(u){Za(u.event)},onmousedown:yd(this._onHandleDragMove,this,0,0),drift:yd(this._onHandleDragMove,this),ondragend:yd(this._onHandleDragEnd,this)}),a.add(n)),jw(n,e,!1),n.setStyle(i.getItemStyle(null,["color","borderColor","borderWidth","opacity","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"]));var l=i.get("size");W(l)||(l=[l,l]),n.scaleX=l[0]/2,n.scaleY=l[1]/2,As(this,"_doDispatchAxisPointer",i.get("throttle")||0,"fixRate"),this._moveHandleToValue(t,s)}},r.prototype._moveHandleToValue=function(t,e){qw(this._axisPointerModel,!e&&this._moveAnimation,this._handle,md(this.getHandleTransform(t,this._axisModel,this._axisPointerModel)))},r.prototype._onHandleDragMove=function(t,e){var a=this._handle;if(a){this._dragging=!0;var n=this.updateHandleTransform(md(a),[t,e],this._axisModel,this._axisPointerModel);this._payloadInfo=n,a.stopAnimation(),a.attr(md(n)),bi(a).lastProp=null,this._doDispatchAxisPointer()}},r.prototype._doDispatchAxisPointer=function(){var t=this._handle;if(t){var e=this._payloadInfo,a=this._axisModel;this._api.dispatchAction({type:"updateAxisPointer",x:e.cursorPoint[0],y:e.cursorPoint[1],tooltipOption:e.tooltipOption,axesInfo:[{axisDim:a.axis.dim,axisIndex:a.componentIndex}]})}},r.prototype._onHandleDragEnd=function(){this._dragging=!1;var t=this._handle;if(t){var e=this._axisPointerModel.get("value");this._moveHandleToValue(e),this._api.dispatchAction({type:"hideTip"})}},r.prototype.clear=function(t){this._lastValue=null,this._lastStatus=null;var e=t.getZr(),a=this._group,n=this._handle;e&&a&&(this._lastGraphicKey=null,a&&e.remove(a),n&&e.remove(n),this._group=null,this._handle=null,this._payloadInfo=null),tu(this,"_doDispatchAxisPointer")},r.prototype.doClear=function(){},r.prototype.buildLabel=function(t,e,a){return a=a||0,{x:t[a],y:t[1-a],width:e[a],height:e[1-a]}},r}();function qw(r,t,e,a){AP(bi(e).lastProp,a)||(bi(e).lastProp=a,t?Lt(e,a,r):(e.stopAnimation(),e.attr(a)))}function AP(r,t){if(it(r)&&it(t)){var e=!0;return A(t,function(a,n){e=e&&AP(r[n],a)}),!!e}else return r===t}function Kw(r,t){r[t.get(["label","show"])?"show":"hide"]()}function md(r){return{x:r.x||0,y:r.y||0,rotation:r.rotation||0}}function jw(r,t,e){var a=t.get("z"),n=t.get("zlevel");r&&r.traverse(function(i){i.type!=="group"&&(a!=null&&(i.z=a),n!=null&&(i.zlevel=n),i.silent=e)})}function s_(r){var t=r.get("type"),e=r.getModel(t+"Style"),a;return t==="line"?(a=e.getLineStyle(),a.fill=null):t==="shadow"&&(a=e.getAreaStyle(),a.stroke=null),a}function MP(r,t,e,a,n){var i=e.get("value"),o=DP(i,t.axis,t.ecModel,e.get("seriesDataIndices"),{precision:e.get(["label","precision"]),formatter:e.get(["label","formatter"])}),s=e.getModel("label"),l=ws(s.get("padding")||0),u=s.getFont(),f=zh(o,u),v=n.position,h=f.width+l[1]+l[3],c=f.height+l[0]+l[2],p=n.align;p==="right"&&(v[0]-=h),p==="center"&&(v[0]-=h/2);var d=n.verticalAlign;d==="bottom"&&(v[1]-=c),d==="middle"&&(v[1]-=c/2),gY(v,h,c,a);var g=s.get("backgroundColor");(!g||g==="auto")&&(g=t.get(["axisLine","lineStyle","color"])),r.label={x:v[0],y:v[1],style:Gt(s,{text:o,font:u,fill:s.getTextColor(),padding:l,backgroundColor:g}),z2:10}}function gY(r,t,e,a){var n=a.getWidth(),i=a.getHeight();r[0]=Math.min(r[0]+t,n)-t,r[1]=Math.min(r[1]+e,i)-e,r[0]=Math.max(r[0],0),r[1]=Math.max(r[1],0)}function DP(r,t,e,a,n){r=t.scale.parse(r);var i=t.scale.getLabel({value:r},{precision:n.precision}),o=n.formatter;if(o){var s={value:Qv(t,{value:r}),axisDimension:t.dim,axisIndex:t.index,seriesData:[]};A(a,function(l){var u=e.getSeriesByIndex(l.seriesIndex),f=l.dataIndexInside,v=u&&u.getDataParams(f);v&&s.seriesData.push(v)}),X(o)?i=o.replace("{value}",i):tt(o)&&(i=o(s))}return i}function l_(r,t,e){var a=me();return Qa(a,a,e.rotation),Ur(a,a,e.position),Hr([r.dataToCoord(t),(e.labelOffset||0)+(e.labelDirection||1)*(e.labelMargin||0)],a)}function LP(r,t,e,a,n,i){var o=Ye.innerTextLayout(e.rotation,0,e.labelDirection);e.labelMargin=n.get(["label","margin"]),MP(t,a,n,i,{position:l_(a.axis,r,e),align:o.textAlign,verticalAlign:o.textVerticalAlign})}function u_(r,t,e){return e=e||0,{x1:r[e],y1:r[1-e],x2:t[e],y2:t[1-e]}}function IP(r,t,e){return e=e||0,{x:r[e],y:r[1-e],width:t[e],height:t[1-e]}}function Jw(r,t,e,a,n,i){return{cx:r,cy:t,r0:e,r:a,startAngle:n,endAngle:i,clockwise:!0}}var yY=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.makeElOption=function(e,a,n,i,o){var s=n.axis,l=s.grid,u=i.get("type"),f=Qw(l,s).getOtherAxis(s).getGlobalExtent(),v=s.toGlobalCoord(s.dataToCoord(a,!0));if(u&&u!=="none"){var h=s_(i),c=mY[u](s,v,f);c.style=h,e.graphicKey=c.type,e.pointer=c}var p=uh(l.getRect(),n);LP(a,e,p,n,i,o)},t.prototype.getHandleTransform=function(e,a,n){var i=uh(a.axis.grid.getRect(),a,{labelInside:!1});i.labelMargin=n.get(["handle","margin"]);var o=l_(a.axis,e,i);return{x:o[0],y:o[1],rotation:i.rotation+(i.labelDirection<0?Math.PI:0)}},t.prototype.updateHandleTransform=function(e,a,n,i){var o=n.axis,s=o.grid,l=o.getGlobalExtent(!0),u=Qw(s,o).getOtherAxis(o).getGlobalExtent(),f=o.dim==="x"?0:1,v=[e.x,e.y];v[f]+=a[f],v[f]=Math.min(l[1],v[f]),v[f]=Math.max(l[0],v[f]);var h=(u[1]+u[0])/2,c=[h,h];c[f]=v[f];var p=[{verticalAlign:"middle"},{align:"center"}];return{x:v[0],y:v[1],rotation:e.rotation,cursorPoint:c,tooltipOption:p[f]}},t}(o_);function Qw(r,t){var e={};return e[t.dim+"AxisIndex"]=t.index,r.getCartesian(e)}var mY={line:function(r,t,e){var a=u_([t,e[0]],[t,e[1]],tT(r));return{type:"Line",subPixelOptimize:!0,shape:a}},shadow:function(r,t,e){var a=Math.max(1,r.getBandWidth()),n=e[1]-e[0];return{type:"Rect",shape:IP([t-a/2,e[0]],[a,n],tT(r))}}};function tT(r){return r.dim==="x"?0:1}var _Y=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="axisPointer",t.defaultOption={show:"auto",z:50,type:"line",snap:!1,triggerTooltip:!0,triggerEmphasis:!0,value:null,status:null,link:[],animation:null,animationDurationUpdate:200,lineStyle:{color:N.color.border,width:1,type:"dashed"},shadowStyle:{color:N.color.shadowTint},label:{show:!0,formatter:null,precision:"auto",margin:3,color:N.color.neutral00,padding:[5,7,5,7],backgroundColor:N.color.accent60,borderColor:null,borderWidth:0,borderRadius:3},handle:{show:!1,icon:"M10.7,11.9v-1.3H9.3v1.3c-4.9,0.3-8.8,4.4-8.8,9.4c0,5,3.9,9.1,8.8,9.4h1.3c4.9-0.3,8.8-4.4,8.8-9.4C19.5,16.3,15.6,12.2,10.7,11.9z M13.3,24.4H6.7v-1.2h6.6z M13.3,22H6.7v-1.2h6.6z M13.3,19.6H6.7v-1.2h6.6z",size:45,margin:50,color:N.color.accent40,throttle:40}},t}(xt),za=St(),SY=A;function PP(r,t,e){if(!Tt.node){var a=t.getZr();za(a).records||(za(a).records={}),xY(a,t);var n=za(a).records[r]||(za(a).records[r]={});n.handler=e}}function xY(r,t){if(za(r).initialized)return;za(r).initialized=!0,e("click",pt(eT,"click")),e("mousemove",pt(eT,"mousemove")),e("globalout",wY);function e(a,n){r.on(a,function(i){var o=TY(t);SY(za(r).records,function(s){s&&n(s,i,o.dispatchAction)}),bY(o.pendings,t)})}}function bY(r,t){var e=r.showTip.length,a=r.hideTip.length,n;e?n=r.showTip[e-1]:a&&(n=r.hideTip[a-1]),n&&(n.dispatchAction=null,t.dispatchAction(n))}function wY(r,t,e){r.handler("leave",null,e)}function eT(r,t,e,a){t.handler(r,e,a)}function TY(r){var t={showTip:[],hideTip:[]},e=function(a){var n=t[a.type];n?n.push(a):(a.dispatchAction=e,r.dispatchAction(a))};return{dispatchAction:e,pendings:t}}function Iy(r,t){if(!Tt.node){var e=t.getZr(),a=(za(e).records||{})[r];a&&(za(e).records[r]=null)}}var CY=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n){var i=a.getComponent("tooltip"),o=e.get("triggerOn")||i&&i.get("triggerOn")||"mousemove|click";PP("axisPointer",n,function(s,l,u){o!=="none"&&(s==="leave"||o.indexOf(s)>=0)&&u({type:"updateAxisPointer",currTrigger:s,x:l&&l.offsetX,y:l&&l.offsetY})})},t.prototype.remove=function(e,a){Iy("axisPointer",a)},t.prototype.dispose=function(e,a){Iy("axisPointer",a)},t.type="axisPointer",t}(Wt);function RP(r,t){var e=[],a=r.seriesIndex,n;if(a==null||!(n=t.getSeriesByIndex(a)))return{point:[]};var i=n.getData(),o=Gi(i,r);if(o==null||o<0||W(o))return{point:[]};var s=i.getItemGraphicEl(o),l=n.coordinateSystem;if(n.getTooltipPosition)e=n.getTooltipPosition(o)||[];else if(l&&l.dataToPoint)if(r.isStacked){var u=l.getBaseAxis(),f=l.getOtherAxis(u),v=f.dim,h=u.dim,c=v==="x"||v==="radius"?1:0,p=i.mapDimension(h),d=[];d[c]=i.get(p,o),d[1-c]=i.get(i.getCalculationInfo("stackResultDimension"),o),e=l.dataToPoint(d)||[]}else e=l.dataToPoint(i.getValues(U(l.dimensions,function(y){return i.mapDimension(y)}),o))||[];else if(s){var g=s.getBoundingRect().clone();g.applyTransform(s.transform),e=[g.x+g.width/2,g.y+g.height/2]}return{point:e,el:s}}var rT=St();function AY(r,t,e){var a=r.currTrigger,n=[r.x,r.y],i=r,o=r.dispatchAction||$(e.dispatchAction,e),s=t.getComponent("axisPointer").coordSysAxesInfo;if(s){yv(n)&&(n=RP({seriesIndex:i.seriesIndex,dataIndex:i.dataIndex},t).point);var l=yv(n),u=i.axesInfo,f=s.axesInfo,v=a==="leave"||yv(n),h={},c={},p={list:[],map:{}},d={showPointer:pt(DY,c),showTooltip:pt(LY,p)};A(s.coordSysMap,function(y,m){var _=l||y.containPoint(n);A(s.coordSysAxesInfo[m],function(S,x){var b=S.axis,w=kY(u,S);if(!v&&_&&(!u||w)){var T=w&&w.value;T==null&&!l&&(T=b.pointToData(n)),T!=null&&aT(S,T,d,!1,h)}})});var g={};return A(f,function(y,m){var _=y.linkGroup;_&&!c[m]&&A(_.axesInfo,function(S,x){var b=c[x];if(S!==y&&b){var w=b.value;_.mapper&&(w=y.axis.scale.parse(_.mapper(w,nT(S),nT(y)))),g[y.key]=w}})}),A(g,function(y,m){aT(f[m],y,d,!0,h)}),IY(c,f,h),PY(p,n,r,o),RY(f,o,e),h}}function aT(r,t,e,a,n){var i=r.axis;if(!(i.scale.isBlank()||!i.containData(t))){if(!r.involveSeries){e.showPointer(r,t);return}var o=MY(t,r),s=o.payloadBatch,l=o.snapToValue;s[0]&&n.seriesIndex==null&&G(n,s[0]),!a&&r.snap&&i.containData(l)&&l!=null&&(t=l),e.showPointer(r,t,s),e.showTooltip(r,o,l)}}function MY(r,t){var e=t.axis,a=e.dim,n=r,i=[],o=Number.MAX_VALUE,s=-1;return A(t.seriesModels,function(l,u){var f=l.getData().mapDimensionsAll(a),v,h;if(l.getAxisTooltipData){var c=l.getAxisTooltipData(f,r,e);h=c.dataIndices,v=c.nestestValue}else{if(h=l.indicesOfNearest(a,f[0],r,e.type==="category"?.5:null),!h.length)return;v=l.getData().get(f[0],h[0])}if(!(v==null||!isFinite(v))){var p=r-v,d=Math.abs(p);d<=o&&((d<o||p>=0&&s<0)&&(o=d,s=p,n=v,i.length=0),A(h,function(g){i.push({seriesIndex:l.seriesIndex,dataIndexInside:g,dataIndex:l.getData().getRawIndex(g)})}))}}),{payloadBatch:i,snapToValue:n}}function DY(r,t,e,a){r[t.key]={value:e,payloadBatch:a}}function LY(r,t,e,a){var n=e.payloadBatch,i=t.axis,o=i.model,s=t.axisPointerModel;if(!(!t.triggerTooltip||!n.length)){var l=t.coordSys.model,u=uu(l),f=r.map[u];f||(f=r.map[u]={coordSysId:l.id,coordSysIndex:l.componentIndex,coordSysType:l.type,coordSysMainType:l.mainType,dataByAxis:[]},r.list.push(f)),f.dataByAxis.push({axisDim:i.dim,axisIndex:o.componentIndex,axisType:o.type,axisId:o.id,value:a,valueLabelOpt:{precision:s.get(["label","precision"]),formatter:s.get(["label","formatter"])},seriesDataIndices:n.slice()})}}function IY(r,t,e){var a=e.axesInfo=[];A(t,function(n,i){var o=n.axisPointerModel.option,s=r[i];s?(!n.useHandle&&(o.status="show"),o.value=s.value,o.seriesDataIndices=(s.payloadBatch||[]).slice()):!n.useHandle&&(o.status="hide"),o.status==="show"&&a.push({axisDim:n.axis.dim,axisIndex:n.axis.model.componentIndex,value:o.value})})}function PY(r,t,e,a){if(yv(t)||!r.list.length){a({type:"hideTip"});return}var n=((r.list[0].dataByAxis[0]||{}).seriesDataIndices||[])[0]||{};a({type:"showTip",escapeConnect:!0,x:t[0],y:t[1],tooltipOption:e.tooltipOption,position:e.position,dataIndexInside:n.dataIndexInside,dataIndex:n.dataIndex,seriesIndex:n.seriesIndex,dataByCoordSys:r.list})}function RY(r,t,e){var a=e.getZr(),n="axisPointerLastHighlights",i=rT(a)[n]||{},o=rT(a)[n]={};A(r,function(u,f){var v=u.axisPointerModel.option;v.status==="show"&&u.triggerEmphasis&&A(v.seriesDataIndices,function(h){var c=h.seriesIndex+" | "+h.dataIndex;o[c]=h})});var s=[],l=[];A(i,function(u,f){!o[f]&&l.push(u)}),A(o,function(u,f){!i[f]&&s.push(u)}),l.length&&e.dispatchAction({type:"downplay",escapeConnect:!0,notBlur:!0,batch:l}),s.length&&e.dispatchAction({type:"highlight",escapeConnect:!0,notBlur:!0,batch:s})}function kY(r,t){for(var e=0;e<(r||[]).length;e++){var a=r[e];if(t.axis.dim===a.axisDim&&t.axis.model.componentIndex===a.axisIndex)return a}}function nT(r){var t=r.axis.model,e={},a=e.axisDim=r.axis.dim;return e.axisIndex=e[a+"AxisIndex"]=t.componentIndex,e.axisName=e[a+"AxisName"]=t.name,e.axisId=e[a+"AxisId"]=t.id,e}function yv(r){return!r||r[0]==null||isNaN(r[0])||r[1]==null||isNaN(r[1])}function zu(r){ro.registerAxisPointerClass("CartesianAxisPointer",yY),r.registerComponentModel(_Y),r.registerComponentView(CY),r.registerPreprocessor(function(t){if(t){(!t.axisPointer||t.axisPointer.length===0)&&(t.axisPointer={});var e=t.axisPointer.link;e&&!W(e)&&(t.axisPointer.link=[e])}}),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,function(t,e){t.getComponent("axisPointer").coordSysAxesInfo=EF(t,e)}),r.registerAction({type:"updateAxisPointer",event:"updateAxisPointer",update:":updateAxisPointer"},AY)}function EY(r){mt(rI),mt(zu)}var OY=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.makeElOption=function(e,a,n,i,o){var s=n.axis;s.dim==="angle"&&(this.animationThreshold=Math.PI/18);var l=s.polar,u=l.getOtherAxis(s),f=u.getExtent(),v=s.dataToCoord(a),h=i.get("type");if(h&&h!=="none"){var c=s_(i),p=BY[h](s,l,v,f);p.style=c,e.graphicKey=p.type,e.pointer=p}var d=i.get(["label","margin"]),g=NY(a,n,i,l,d);MP(e,n,i,o,g)},t}(o_);function NY(r,t,e,a,n){var i=t.axis,o=i.dataToCoord(r),s=a.getAngleAxis().getExtent()[0];s=s/180*Math.PI;var l=a.getRadiusAxis().getExtent(),u,f,v;if(i.dim==="radius"){var h=me();Qa(h,h,s),Ur(h,h,[a.cx,a.cy]),u=Hr([o,-n],h);var c=t.getModel("axisLabel").get("rotate")||0,p=Ye.innerTextLayout(s,c*Math.PI/180,-1);f=p.textAlign,v=p.textVerticalAlign}else{var d=l[1];u=a.coordToPoint([d+n,o]);var g=a.cx,y=a.cy;f=Math.abs(u[0]-g)/d<.3?"center":u[0]>g?"left":"right",v=Math.abs(u[1]-y)/d<.3?"middle":u[1]>y?"top":"bottom"}return{position:u,align:f,verticalAlign:v}}var BY={line:function(r,t,e,a){return r.dim==="angle"?{type:"Line",shape:u_(t.coordToPoint([a[0],e]),t.coordToPoint([a[1],e]))}:{type:"Circle",shape:{cx:t.cx,cy:t.cy,r:e}}},shadow:function(r,t,e,a){var n=Math.max(1,r.getBandWidth()),i=Math.PI/180;return r.dim==="angle"?{type:"Sector",shape:Jw(t.cx,t.cy,a[0],a[1],(-e-n/2)*i,(-e+n/2)*i)}:{type:"Sector",shape:Jw(t.cx,t.cy,e-n/2,e+n/2,0,Math.PI*2)}}},zY=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.findAxisModel=function(e){var a,n=this.ecModel;return n.eachComponent(e,function(i){i.getCoordSysModel()===this&&(a=i)},this),a},t.type="polar",t.dependencies=["radiusAxis","angleAxis"],t.defaultOption={z:0,center:["50%","50%"],radius:"80%"},t}(xt),f_=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.getCoordSysModel=function(){return this.getReferringComponents("polar",Kt).models[0]},t.type="polarAxis",t}(xt);Qt(f_,Is);var VY=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="angleAxis",t}(f_),GY=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="radiusAxis",t}(f_),v_=function(r){z(t,r);function t(e,a){return r.call(this,"radius",e,a)||this}return t.prototype.pointToData=function(e,a){return this.polar.pointToData(e,a)[this.dim==="radius"?0:1]},t}($r);v_.prototype.dataToRadius=$r.prototype.dataToCoord;v_.prototype.radiusToData=$r.prototype.coordToData;var FY=St(),h_=function(r){z(t,r);function t(e,a){return r.call(this,"angle",e,a||[0,360])||this}return t.prototype.pointToData=function(e,a){return this.polar.pointToData(e,a)[this.dim==="radius"?0:1]},t.prototype.calculateCategoryInterval=function(){var e=this,a=e.getLabelModel(),n=e.scale,i=n.getExtent(),o=n.count();if(i[1]-i[0]<1)return 0;var s=i[0],l=e.dataToCoord(s+1)-e.dataToCoord(s),u=Math.abs(l),f=zh(s==null?"":s+"",a.getFont(),"center","top"),v=Math.max(f.height,7),h=v/u;isNaN(h)&&(h=1/0);var c=Math.max(0,Math.floor(h)),p=FY(e.model),d=p.lastAutoInterval,g=p.lastTickCount;return d!=null&&g!=null&&Math.abs(d-c)<=1&&Math.abs(g-o)<=1&&d>c?c=d:(p.lastTickCount=o,p.lastAutoInterval=c),c},t}($r);h_.prototype.dataToAngle=$r.prototype.dataToCoord;h_.prototype.angleToData=$r.prototype.coordToData;var kP=["radius","angle"],HY=function(){function r(t){this.dimensions=kP,this.type="polar",this.cx=0,this.cy=0,this._radiusAxis=new v_,this._angleAxis=new h_,this.axisPointerEnabled=!0,this.name=t||"",this._radiusAxis.polar=this._angleAxis.polar=this}return r.prototype.containPoint=function(t){var e=this.pointToCoord(t);return this._radiusAxis.contain(e[0])&&this._angleAxis.contain(e[1])},r.prototype.containData=function(t){return this._radiusAxis.containData(t[0])&&this._angleAxis.containData(t[1])},r.prototype.getAxis=function(t){var e="_"+t+"Axis";return this[e]},r.prototype.getAxes=function(){return[this._radiusAxis,this._angleAxis]},r.prototype.getAxesByScale=function(t){var e=[],a=this._angleAxis,n=this._radiusAxis;return a.scale.type===t&&e.push(a),n.scale.type===t&&e.push(n),e},r.prototype.getAngleAxis=function(){return this._angleAxis},r.prototype.getRadiusAxis=function(){return this._radiusAxis},r.prototype.getOtherAxis=function(t){var e=this._angleAxis;return t===e?this._radiusAxis:e},r.prototype.getBaseAxis=function(){return this.getAxesByScale("ordinal")[0]||this.getAxesByScale("time")[0]||this.getAngleAxis()},r.prototype.getTooltipAxes=function(t){var e=t!=null&&t!=="auto"?this.getAxis(t):this.getBaseAxis();return{baseAxes:[e],otherAxes:[this.getOtherAxis(e)]}},r.prototype.dataToPoint=function(t,e,a){return this.coordToPoint([this._radiusAxis.dataToRadius(t[0],e),this._angleAxis.dataToAngle(t[1],e)],a)},r.prototype.pointToData=function(t,e,a){a=a||[];var n=this.pointToCoord(t);return a[0]=this._radiusAxis.radiusToData(n[0],e),a[1]=this._angleAxis.angleToData(n[1],e),a},r.prototype.pointToCoord=function(t){var e=t[0]-this.cx,a=t[1]-this.cy,n=this.getAngleAxis(),i=n.getExtent(),o=Math.min(i[0],i[1]),s=Math.max(i[0],i[1]);n.inverse?o=s-360:s=o+360;var l=Math.sqrt(e*e+a*a);e/=l,a/=l;for(var u=Math.atan2(-a,e)/Math.PI*180,f=u<o?1:-1;u<o||u>s;)u+=f*360;return[l,u]},r.prototype.coordToPoint=function(t,e){e=e||[];var a=t[0],n=t[1]/180*Math.PI;return e[0]=Math.cos(n)*a+this.cx,e[1]=-Math.sin(n)*a+this.cy,e},r.prototype.getArea=function(){var t=this.getAngleAxis(),e=this.getRadiusAxis(),a=e.getExtent().slice();a[0]>a[1]&&a.reverse();var n=t.getExtent(),i=Math.PI/180,o=1e-4;return{cx:this.cx,cy:this.cy,r0:a[0],r:a[1],startAngle:-n[0]*i,endAngle:-n[1]*i,clockwise:t.inverse,contain:function(s,l){var u=s-this.cx,f=l-this.cy,v=u*u+f*f,h=this.r,c=this.r0;return h!==c&&v-o<=h*h&&v+o>=c*c},x:this.cx-a[1],y:this.cy-a[1],width:a[1]*2,height:a[1]*2}},r.prototype.convertToPixel=function(t,e,a){var n=iT(e);return n===this?this.dataToPoint(a):null},r.prototype.convertFromPixel=function(t,e,a){var n=iT(e);return n===this?this.pointToData(a):null},r}();function iT(r){var t=r.seriesModel,e=r.polarModel;return e&&e.coordinateSystem||t&&t.coordinateSystem}function WY(r,t,e){var a=t.get("center"),n=pe(t,e).refContainer;r.cx=Z(a[0],n.width)+n.x,r.cy=Z(a[1],n.height)+n.y;var i=r.getRadiusAxis(),o=Math.min(n.width,n.height)/2,s=t.get("radius");s==null?s=[0,"100%"]:W(s)||(s=[0,s]);var l=[Z(s[0],o),Z(s[1],o)];i.inverse?i.setExtent(l[1],l[0]):i.setExtent(l[0],l[1])}function UY(r,t){var e=this,a=e.getAngleAxis(),n=e.getRadiusAxis();if(a.scale.setExtent(1/0,-1/0),n.scale.setExtent(1/0,-1/0),r.eachSeries(function(s){if(s.coordinateSystem===e){var l=s.getData();A(th(l,"radius"),function(u){n.scale.unionExtentFromData(l,u)}),A(th(l,"angle"),function(u){a.scale.unionExtentFromData(l,u)})}}),Zi(a.scale,a.model),Zi(n.scale,n.model),a.type==="category"&&!a.onBand){var i=a.getExtent(),o=360/a.scale.count();a.inverse?i[1]+=o:i[1]-=o,a.setExtent(i[0],i[1])}}function YY(r){return r.mainType==="angleAxis"}function oT(r,t){var e;if(r.type=t.get("type"),r.scale=Ru(t),r.onBand=t.get("boundaryGap")&&r.type==="category",r.inverse=t.get("inverse"),YY(t)){r.inverse=r.inverse!==t.get("clockwise");var a=t.get("startAngle"),n=(e=t.get("endAngle"))!==null&&e!==void 0?e:a+(r.inverse?-360:360);r.setExtent(a,n)}t.axis=r,r.model=t}var ZY={dimensions:kP,create:function(r,t){var e=[];return r.eachComponent("polar",function(a,n){var i=new HY(n+"");i.update=UY;var o=i.getRadiusAxis(),s=i.getAngleAxis(),l=a.findAxisModel("radiusAxis"),u=a.findAxisModel("angleAxis");oT(o,l),oT(s,u),WY(i,a,t),e.push(i),a.coordinateSystem=i,i.model=a}),r.eachSeries(function(a){if(a.get("coordinateSystem")==="polar"){var n=a.getReferringComponents("polar",Kt).models[0];a.coordinateSystem=n.coordinateSystem}}),e}},XY=["axisLine","axisLabel","axisTick","minorTick","splitLine","minorSplitLine","splitArea"];function Vf(r,t,e){t[1]>t[0]&&(t=t.slice().reverse());var a=r.coordToPoint([t[0],e]),n=r.coordToPoint([t[1],e]);return{x1:a[0],y1:a[1],x2:n[0],y2:n[1]}}function Gf(r){var t=r.getRadiusAxis();return t.inverse?0:1}function sT(r){var t=r[0],e=r[r.length-1];t&&e&&Math.abs(Math.abs(t.coord-e.coord)-360)<1e-4&&r.pop()}var $Y=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.axisPointerClass="PolarAxisPointer",e}return t.prototype.render=function(e,a){if(this.group.removeAll(),!!e.get("show")){var n=e.axis,i=n.polar,o=i.getRadiusAxis().getExtent(),s=n.getTicksCoords({breakTicks:"none"}),l=n.getMinorTicksCoords(),u=U(n.getViewLabels(),function(f){f=et(f);var v=n.scale,h=v.type==="ordinal"?v.getRawOrdinalNumber(f.tickValue):f.tickValue;return f.coord=n.dataToCoord(h),f});sT(u),sT(s),A(XY,function(f){e.get([f,"show"])&&(!n.scale.isBlank()||f==="axisLine")&&qY[f](this.group,e,i,s,l,o,u)},this)}},t.type="angleAxis",t}(ro),qY={axisLine:function(r,t,e,a,n,i){var o=t.getModel(["axisLine","lineStyle"]),s=e.getAngleAxis(),l=Math.PI/180,u=s.getExtent(),f=Gf(e),v=f?0:1,h,c=Math.abs(u[1]-u[0])===360?"Circle":"Arc";i[v]===0?h=new ji[c]({shape:{cx:e.cx,cy:e.cy,r:i[f],startAngle:-u[0]*l,endAngle:-u[1]*l,clockwise:s.inverse},style:o.getLineStyle(),z2:1,silent:!0}):h=new ys({shape:{cx:e.cx,cy:e.cy,r:i[f],r0:i[v]},style:o.getLineStyle(),z2:1,silent:!0}),h.style.fill=null,r.add(h)},axisTick:function(r,t,e,a,n,i){var o=t.getModel("axisTick"),s=(o.get("inside")?-1:1)*o.get("length"),l=i[Gf(e)],u=U(a,function(f){return new ne({shape:Vf(e,[l,l+s],f.coord)})});r.add(or(u,{style:nt(o.getModel("lineStyle").getLineStyle(),{stroke:t.get(["axisLine","lineStyle","color"])})}))},minorTick:function(r,t,e,a,n,i){if(n.length){for(var o=t.getModel("axisTick"),s=t.getModel("minorTick"),l=(o.get("inside")?-1:1)*s.get("length"),u=i[Gf(e)],f=[],v=0;v<n.length;v++)for(var h=0;h<n[v].length;h++)f.push(new ne({shape:Vf(e,[u,u+l],n[v][h].coord)}));r.add(or(f,{style:nt(s.getModel("lineStyle").getLineStyle(),nt(o.getLineStyle(),{stroke:t.get(["axisLine","lineStyle","color"])}))}))}},axisLabel:function(r,t,e,a,n,i,o){var s=t.getCategories(!0),l=t.getModel("axisLabel"),u=l.get("margin"),f=t.get("triggerEvent");A(o,function(v,h){var c=l,p=v.tickValue,d=i[Gf(e)],g=e.coordToPoint([d+u,v.coord]),y=e.cx,m=e.cy,_=Math.abs(g[0]-y)/d<.3?"center":g[0]>y?"left":"right",S=Math.abs(g[1]-m)/d<.3?"middle":g[1]>m?"top":"bottom";if(s&&s[p]){var x=s[p];it(x)&&x.textStyle&&(c=new wt(x.textStyle,l,l.ecModel))}var b=new At({silent:Ye.isLabelSilent(t),style:Gt(c,{x:g[0],y:g[1],fill:c.getTextColor()||t.get(["axisLine","lineStyle","color"]),text:v.formattedLabel,align:_,verticalAlign:S})});if(r.add(b),en({el:b,componentModel:t,itemName:v.formattedLabel,formatterParamsExtra:{isTruncated:function(){return b.isTruncated},value:v.rawLabel,tickIndex:h}}),f){var w=Ye.makeAxisEventDataBase(t);w.targetType="axisLabel",w.value=v.rawLabel,ut(b).eventData=w}},this)},splitLine:function(r,t,e,a,n,i){var o=t.getModel("splitLine"),s=o.getModel("lineStyle"),l=s.get("color"),u=0;l=l instanceof Array?l:[l];for(var f=[],v=0;v<a.length;v++){var h=u++%l.length;f[h]=f[h]||[],f[h].push(new ne({shape:Vf(e,i,a[v].coord)}))}for(var v=0;v<f.length;v++)r.add(or(f[v],{style:nt({stroke:l[v%l.length]},s.getLineStyle()),silent:!0,z:t.get("z")}))},minorSplitLine:function(r,t,e,a,n,i){if(n.length){for(var o=t.getModel("minorSplitLine"),s=o.getModel("lineStyle"),l=[],u=0;u<n.length;u++)for(var f=0;f<n[u].length;f++)l.push(new ne({shape:Vf(e,i,n[u][f].coord)}));r.add(or(l,{style:s.getLineStyle(),silent:!0,z:t.get("z")}))}},splitArea:function(r,t,e,a,n,i){if(a.length){var o=t.getModel("splitArea"),s=o.getModel("areaStyle"),l=s.get("color"),u=0;l=l instanceof Array?l:[l];for(var f=[],v=Math.PI/180,h=-a[0].coord*v,c=Math.min(i[0],i[1]),p=Math.max(i[0],i[1]),d=t.get("clockwise"),g=1,y=a.length;g<=y;g++){var m=g===y?a[0].coord:a[g].coord,_=u++%l.length;f[_]=f[_]||[],f[_].push(new ke({shape:{cx:e.cx,cy:e.cy,r0:c,r:p,startAngle:h,endAngle:-m*v,clockwise:d},silent:!0})),h=-m*v}for(var g=0;g<f.length;g++)r.add(or(f[g],{style:nt({fill:l[g%l.length]},s.getAreaStyle()),silent:!0}))}}},KY=["splitLine","splitArea","minorSplitLine"],jY=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.axisPointerClass="PolarAxisPointer",e}return t.prototype.render=function(e,a,n){if(this.group.removeAll(),!!e.get("show")){var i=this._axisGroup,o=this._axisGroup=new rt;this.group.add(o);var s=e.axis,l=s.polar,u=l.getAngleAxis(),f=s.getTicksCoords(),v=s.getMinorTicksCoords(),h=u.getExtent()[0],c=s.getExtent(),p=QY(l,e,h),d=new Ye(e,n,p);d.build(),o.add(d.group),Du(i,o,e),A(KY,function(g){e.get([g,"show"])&&!s.scale.isBlank()&&JY[g](this.group,e,l,h,c,f,v)},this)}},t.type="radiusAxis",t}(ro),JY={splitLine:function(r,t,e,a,n,i){var o=t.getModel("splitLine"),s=o.getModel("lineStyle"),l=s.get("color"),u=0,f=e.getAngleAxis(),v=Math.PI/180,h=f.getExtent(),c=Math.abs(h[1]-h[0])===360?"Circle":"Arc";l=l instanceof Array?l:[l];for(var p=[],d=0;d<i.length;d++){var g=u++%l.length;p[g]=p[g]||[],p[g].push(new ji[c]({shape:{cx:e.cx,cy:e.cy,r:Math.max(i[d].coord,0),startAngle:-h[0]*v,endAngle:-h[1]*v,clockwise:f.inverse}}))}for(var d=0;d<p.length;d++)r.add(or(p[d],{style:nt({stroke:l[d%l.length],fill:null},s.getLineStyle()),silent:!0}))},minorSplitLine:function(r,t,e,a,n,i,o){if(o.length){for(var s=t.getModel("minorSplitLine"),l=s.getModel("lineStyle"),u=[],f=0;f<o.length;f++)for(var v=0;v<o[f].length;v++)u.push(new wa({shape:{cx:e.cx,cy:e.cy,r:o[f][v].coord}}));r.add(or(u,{style:nt({fill:null},l.getLineStyle()),silent:!0}))}},splitArea:function(r,t,e,a,n,i){if(i.length){var o=t.getModel("splitArea"),s=o.getModel("areaStyle"),l=s.get("color"),u=0;l=l instanceof Array?l:[l];for(var f=[],v=i[0].coord,h=1;h<i.length;h++){var c=u++%l.length;f[c]=f[c]||[],f[c].push(new ke({shape:{cx:e.cx,cy:e.cy,r0:v,r:i[h].coord,startAngle:0,endAngle:Math.PI*2},silent:!0})),v=i[h].coord}for(var h=0;h<f.length;h++)r.add(or(f[h],{style:nt({fill:l[h%l.length]},s.getAreaStyle()),silent:!0}))}}};function QY(r,t,e){return{position:[r.cx,r.cy],rotation:e/180*Math.PI,labelDirection:-1,tickDirection:-1,nameDirection:1,labelRotate:t.getModel("axisLabel").get("rotate"),z2:1}}function EP(r){return r.get("stack")||"__ec_stack_"+r.seriesIndex}function OP(r,t){return t.dim+r.model.componentIndex}function t7(r,t,e){var a={},n=e7(Pt(t.getSeriesByType(r),function(i){return!t.isSeriesFiltered(i)&&i.coordinateSystem&&i.coordinateSystem.type==="polar"}));t.eachSeriesByType(r,function(i){if(i.coordinateSystem.type==="polar"){var o=i.getData(),s=i.coordinateSystem,l=s.getBaseAxis(),u=OP(s,l),f=EP(i),v=n[u][f],h=v.offset,c=v.width,p=s.getOtherAxis(l),d=i.coordinateSystem.cx,g=i.coordinateSystem.cy,y=i.get("barMinHeight")||0,m=i.get("barMinAngle")||0;a[f]=a[f]||[];for(var _=o.mapDimension(p.dim),S=o.mapDimension(l.dim),x=Ka(o,_),b=l.dim!=="radius"||!i.get("roundCap",!0),w=p.model,T=w.get("startValue"),C=p.dataToCoord(T||0),M=0,D=o.count();M<D;M++){var I=o.get(_,M),L=o.get(S,M),P=I>=0?"p":"n",k=C;x&&(a[f][L]||(a[f][L]={p:C,n:C}),k=a[f][L][P]);var R=void 0,O=void 0,E=void 0,B=void 0;if(p.dim==="radius"){var V=p.dataToCoord(I)-C,F=l.dataToCoord(L);Math.abs(V)<y&&(V=(V<0?-1:1)*y),R=k,O=k+V,E=F-h,B=E-c,x&&(a[f][L][P]=O)}else{var H=p.dataToCoord(I,b)-C,Y=l.dataToCoord(L);Math.abs(H)<m&&(H=(H<0?-1:1)*m),R=Y+h,O=R+c,E=k,B=k+H,x&&(a[f][L][P]=B)}o.setItemLayout(M,{cx:d,cy:g,r0:R,r:O,startAngle:-E*Math.PI/180,endAngle:-B*Math.PI/180,clockwise:E>=B})}}})}function e7(r){var t={};A(r,function(a,n){var i=a.getData(),o=a.coordinateSystem,s=o.getBaseAxis(),l=OP(o,s),u=s.getExtent(),f=s.type==="category"?s.getBandWidth():Math.abs(u[1]-u[0])/i.count(),v=t[l]||{bandWidth:f,remainedWidth:f,autoWidthCount:0,categoryGap:"20%",gap:"30%",stacks:{}},h=v.stacks;t[l]=v;var c=EP(a);h[c]||v.autoWidthCount++,h[c]=h[c]||{width:0,maxWidth:0};var p=Z(a.get("barWidth"),f),d=Z(a.get("barMaxWidth"),f),g=a.get("barGap"),y=a.get("barCategoryGap");p&&!h[c].width&&(p=Math.min(v.remainedWidth,p),h[c].width=p,v.remainedWidth-=p),d&&(h[c].maxWidth=d),g!=null&&(v.gap=g),y!=null&&(v.categoryGap=y)});var e={};return A(t,function(a,n){e[n]={};var i=a.stacks,o=a.bandWidth,s=Z(a.categoryGap,o),l=Z(a.gap,1),u=a.remainedWidth,f=a.autoWidthCount,v=(u-s)/(f+(f-1)*l);v=Math.max(v,0),A(i,function(d,g){var y=d.maxWidth;y&&y<v&&(y=Math.min(y,u),d.width&&(y=Math.min(y,d.width)),u-=y,d.width=y,f--)}),v=(u-s)/(f+(f-1)*l),v=Math.max(v,0);var h=0,c;A(i,function(d,g){d.width||(d.width=v),c=d,h+=d.width*(1+l)}),c&&(h-=c.width*l);var p=-h/2;A(i,function(d,g){e[n][g]=e[n][g]||{offset:p,width:d.width},p+=d.width*(1+l)})}),e}var r7={startAngle:90,clockwise:!0,splitNumber:12,axisLabel:{rotate:0}},a7={splitNumber:5},n7=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="polar",t}(Wt);function i7(r){mt(zu),ro.registerAxisPointerClass("PolarAxisPointer",OY),r.registerCoordinateSystem("polar",ZY),r.registerComponentModel(zY),r.registerComponentView(n7),ls(r,"angle",VY,r7),ls(r,"radius",GY,a7),r.registerComponentView($Y),r.registerComponentView(jY),r.registerLayout(pt(t7,"bar"))}function Py(r,t){t=t||{};var e=r.coordinateSystem,a=r.axis,n={},i=a.position,o=a.orient,s=e.getRect(),l=[s.x,s.x+s.width,s.y,s.y+s.height],u={horizontal:{top:l[2],bottom:l[3]},vertical:{left:l[0],right:l[1]}};n.position=[o==="vertical"?u.vertical[i]:l[0],o==="horizontal"?u.horizontal[i]:l[3]];var f={horizontal:0,vertical:1};n.rotation=Math.PI/2*f[o];var v={top:-1,bottom:1,right:1,left:-1};n.labelDirection=n.tickDirection=n.nameDirection=v[i],r.get(["axisTick","inside"])&&(n.tickDirection=-n.tickDirection),Ce(t.labelInside,r.get(["axisLabel","inside"]))&&(n.labelDirection=-n.labelDirection);var h=r.get(["axisLabel","rotate"]);return n.labelRotate=i==="top"?-h:h,n.z2=1,n}var o7=["splitArea","splitLine","breakArea"],s7=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.axisPointerClass="SingleAxisPointer",e}return t.prototype.render=function(e,a,n,i){var o=this.group;o.removeAll();var s=this._axisGroup;this._axisGroup=new rt;var l=Py(e),u=new Ye(e,n,l);u.build(),o.add(this._axisGroup),o.add(u.group),A(o7,function(f){e.get([f,"show"])&&l7[f](this,this.group,this._axisGroup,e,n)},this),Du(s,this._axisGroup,e),r.prototype.render.call(this,e,a,n,i)},t.prototype.remove=function(){Q2(this)},t.type="singleAxis",t}(ro),l7={splitLine:function(r,t,e,a,n){var i=a.axis;if(!i.scale.isBlank()){var o=a.getModel("splitLine"),s=o.getModel("lineStyle"),l=s.get("color");l=l instanceof Array?l:[l];for(var u=s.get("width"),f=a.coordinateSystem.getRect(),v=i.isHorizontal(),h=[],c=0,p=i.getTicksCoords({tickModel:o,breakTicks:"none",pruneByBreak:"preserve_extent_bound"}),d=[],g=[],y=0;y<p.length;++y){var m=i.toGlobalCoord(p[y].coord);v?(d[0]=m,d[1]=f.y,g[0]=m,g[1]=f.y+f.height):(d[0]=f.x,d[1]=m,g[0]=f.x+f.width,g[1]=m);var _=new ne({shape:{x1:d[0],y1:d[1],x2:g[0],y2:g[1]},silent:!0});rs(_.shape,u);var S=c++%l.length;h[S]=h[S]||[],h[S].push(_)}for(var x=s.getLineStyle(["color"]),y=0;y<h.length;++y)t.add(or(h[y],{style:nt({stroke:l[y%l.length]},x),silent:!0}))}},splitArea:function(r,t,e,a,n){J2(r,e,a,a)},breakArea:function(r,t,e,a,n){var i=Bu(),o=a.axis.scale;i&&o.type!=="ordinal"&&i.rectCoordBuildBreakAxis(t,r,a,a.coordinateSystem.getRect(),n)}},mv=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.getCoordSysModel=function(){return this},t.type="singleAxis",t.layoutMode="box",t.defaultOption={left:"5%",top:"5%",right:"5%",bottom:"5%",type:"value",position:"bottom",orient:"horizontal",axisLine:{show:!0,lineStyle:{width:1,type:"solid"}},tooltip:{show:!0},axisTick:{show:!0,length:6,lineStyle:{width:1}},axisLabel:{show:!0,interval:"auto"},splitLine:{show:!0,lineStyle:{type:"dashed",opacity:.2}},jitter:0,jitterOverlap:!0,jitterMargin:2},t}(xt);Qt(mv,Is.prototype);var u7=function(r){z(t,r);function t(e,a,n,i,o){var s=r.call(this,e,a,n)||this;return s.type=i||"value",s.position=o||"bottom",s}return t.prototype.isHorizontal=function(){var e=this.position;return e==="top"||e==="bottom"},t.prototype.pointToData=function(e,a){return this.coordinateSystem.pointToData(e)[0]},t}($r),NP=["single"],f7=function(){function r(t,e,a){this.type="single",this.dimension="single",this.dimensions=NP,this.axisPointerEnabled=!0,this.model=t,this._init(t,e,a)}return r.prototype._init=function(t,e,a){var n=this.dimension,i=new u7(n,Ru(t),[0,0],t.get("type"),t.get("position")),o=i.type==="category";i.onBand=o&&t.get("boundaryGap"),i.inverse=t.get("inverse"),i.orient=t.get("orient"),t.axis=i,i.model=t,i.coordinateSystem=this,this._axis=i},r.prototype.update=function(t,e){t.eachSeries(function(a){if(a.coordinateSystem===this){var n=a.getData();A(n.mapDimensionsAll(this.dimension),function(i){this._axis.scale.unionExtentFromData(n,i)},this),Zi(this._axis.scale,this._axis.model)}},this)},r.prototype.resize=function(t,e){var a=pe(t,e).refContainer;this._rect=Xt(t.getBoxLayoutParams(),a),this._adjustAxis()},r.prototype.getRect=function(){return this._rect},r.prototype._adjustAxis=function(){var t=this._rect,e=this._axis,a=e.isHorizontal(),n=a?[0,t.width]:[0,t.height],i=e.inverse?1:0;e.setExtent(n[i],n[1-i]),this._updateAxisTransform(e,a?t.x:t.y)},r.prototype._updateAxisTransform=function(t,e){var a=t.getExtent(),n=a[0]+a[1],i=t.isHorizontal();t.toGlobalCoord=i?function(o){return o+e}:function(o){return n-o+e},t.toLocalCoord=i?function(o){return o-e}:function(o){return n-o+e}},r.prototype.getAxis=function(){return this._axis},r.prototype.getBaseAxis=function(){return this._axis},r.prototype.getAxes=function(){return[this._axis]},r.prototype.getTooltipAxes=function(){return{baseAxes:[this.getAxis()],otherAxes:[]}},r.prototype.containPoint=function(t){var e=this.getRect(),a=this.getAxis(),n=a.orient;return n==="horizontal"?a.contain(a.toLocalCoord(t[0]))&&t[1]>=e.y&&t[1]<=e.y+e.height:a.contain(a.toLocalCoord(t[1]))&&t[0]>=e.y&&t[0]<=e.y+e.height},r.prototype.pointToData=function(t,e,a){a=a||[];var n=this.getAxis();return a[0]=n.coordToData(n.toLocalCoord(t[n.orient==="horizontal"?0:1])),a},r.prototype.dataToPoint=function(t,e,a){var n=this.getAxis(),i=this.getRect();a=a||[];var o=n.orient==="horizontal"?0:1;return t instanceof Array&&(t=t[0]),a[o]=n.toGlobalCoord(n.dataToCoord(+t)),a[1-o]=o===0?i.y+i.height/2:i.x+i.width/2,a},r.prototype.convertToPixel=function(t,e,a){var n=lT(e);return n===this?this.dataToPoint(a):null},r.prototype.convertFromPixel=function(t,e,a){var n=lT(e);return n===this?this.pointToData(a):null},r}();function lT(r){var t=r.seriesModel,e=r.singleAxisModel;return e&&e.coordinateSystem||t&&t.coordinateSystem}function v7(r,t){var e=[];return r.eachComponent("singleAxis",function(a,n){var i=new f7(a,r,t);i.name="single_"+n,i.resize(a,t),a.coordinateSystem=i,e.push(i)}),r.eachSeries(function(a){if(a.get("coordinateSystem")==="singleAxis"){var n=a.getReferringComponents("singleAxis",Kt).models[0];a.coordinateSystem=n&&n.coordinateSystem}}),e}var h7={create:v7,dimensions:NP},uT=["x","y"],c7=["width","height"],p7=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.makeElOption=function(e,a,n,i,o){var s=n.axis,l=s.coordinateSystem,u=_d(l,1-_h(s)),f=l.dataToPoint(a)[0],v=i.get("type");if(v&&v!=="none"){var h=s_(i),c=d7[v](s,f,u);c.style=h,e.graphicKey=c.type,e.pointer=c}var p=Py(n);LP(a,e,p,n,i,o)},t.prototype.getHandleTransform=function(e,a,n){var i=Py(a,{labelInside:!1});i.labelMargin=n.get(["handle","margin"]);var o=l_(a.axis,e,i);return{x:o[0],y:o[1],rotation:i.rotation+(i.labelDirection<0?Math.PI:0)}},t.prototype.updateHandleTransform=function(e,a,n,i){var o=n.axis,s=o.coordinateSystem,l=_h(o),u=_d(s,l),f=[e.x,e.y];f[l]+=a[l],f[l]=Math.min(u[1],f[l]),f[l]=Math.max(u[0],f[l]);var v=_d(s,1-l),h=(v[1]+v[0])/2,c=[h,h];return c[l]=f[l],{x:f[0],y:f[1],rotation:e.rotation,cursorPoint:c,tooltipOption:{verticalAlign:"middle"}}},t}(o_),d7={line:function(r,t,e){var a=u_([t,e[0]],[t,e[1]],_h(r));return{type:"Line",subPixelOptimize:!0,shape:a}},shadow:function(r,t,e){var a=r.getBandWidth(),n=e[1]-e[0];return{type:"Rect",shape:IP([t-a/2,e[0]],[a,n],_h(r))}}};function _h(r){return r.isHorizontal()?0:1}function _d(r,t){var e=r.getRect();return[e[uT[t]],e[uT[t]]+e[c7[t]]]}var g7=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="single",t}(Wt);function y7(r){mt(zu),ro.registerAxisPointerClass("SingleAxisPointer",p7),r.registerComponentView(g7),r.registerComponentView(s7),r.registerComponentModel(mv),ls(r,"single",mv,mv.defaultOption),r.registerCoordinateSystem("single",h7)}var m7=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(e,a,n){var i=Ji(e);r.prototype.init.apply(this,arguments),fT(e,i)},t.prototype.mergeOption=function(e){r.prototype.mergeOption.apply(this,arguments),fT(this.option,e)},t.prototype.getCellSize=function(){return this.option.cellSize},t.type="calendar",t.layoutMode="box",t.defaultOption={z:2,left:80,top:60,cellSize:20,orient:"horizontal",splitLine:{show:!0,lineStyle:{color:N.color.axisLine,width:1,type:"solid"}},itemStyle:{color:N.color.neutral00,borderWidth:1,borderColor:N.color.neutral10},dayLabel:{show:!0,firstDay:0,position:"start",margin:N.size.s,color:N.color.secondary},monthLabel:{show:!0,position:"start",margin:N.size.s,align:"center",formatter:null,color:N.color.secondary},yearLabel:{show:!0,position:null,margin:N.size.xl,formatter:null,color:N.color.quaternary,fontFamily:"sans-serif",fontWeight:"bolder",fontSize:20}},t}(xt);function fT(r,t){var e=r.cellSize,a;W(e)?a=e:a=r.cellSize=[e,e],a.length===1&&(a[1]=a[0]);var n=U([0,1],function(i){return QN(t,i)&&(a[i]="auto"),a[i]!=null&&a[i]!=="auto"});_a(r,t,{type:"box",ignoreSize:n})}var _7=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n){var i=this.group;i.removeAll();var o=e.coordinateSystem,s=o.getRangeInfo(),l=o.getOrient(),u=a.getLocaleModel();this._renderDayRect(e,s,i),this._renderLines(e,s,l,i),this._renderYearText(e,s,l,i),this._renderMonthText(e,u,l,i),this._renderWeekText(e,u,s,l,i)},t.prototype._renderDayRect=function(e,a,n){for(var i=e.coordinateSystem,o=e.getModel("itemStyle").getItemStyle(),s=i.getCellWidth(),l=i.getCellHeight(),u=a.start.time;u<=a.end.time;u=i.getNextNDay(u,1).time){var f=i.dataToCalendarLayout([u],!1).tl,v=new _t({shape:{x:f[0],y:f[1],width:s,height:l},cursor:"default",style:o});n.add(v)}},t.prototype._renderLines=function(e,a,n,i){var o=this,s=e.coordinateSystem,l=e.getModel(["splitLine","lineStyle"]).getLineStyle(),u=e.get(["splitLine","show"]),f=l.lineWidth;this._tlpoints=[],this._blpoints=[],this._firstDayOfMonth=[],this._firstDayPoints=[];for(var v=a.start,h=0;v.time<=a.end.time;h++){p(v.formatedDate),h===0&&(v=s.getDateInfo(a.start.y+"-"+a.start.m));var c=v.date;c.setMonth(c.getMonth()+1),v=s.getDateInfo(c)}p(s.getNextNDay(a.end.time,1).formatedDate);function p(d){o._firstDayOfMonth.push(s.getDateInfo(d)),o._firstDayPoints.push(s.dataToCalendarLayout([d],!1).tl);var g=o._getLinePointsOfOneWeek(e,d,n);o._tlpoints.push(g[0]),o._blpoints.push(g[g.length-1]),u&&o._drawSplitline(g,l,i)}u&&this._drawSplitline(o._getEdgesPoints(o._tlpoints,f,n),l,i),u&&this._drawSplitline(o._getEdgesPoints(o._blpoints,f,n),l,i)},t.prototype._getEdgesPoints=function(e,a,n){var i=[e[0].slice(),e[e.length-1].slice()],o=n==="horizontal"?0:1;return i[0][o]=i[0][o]-a/2,i[1][o]=i[1][o]+a/2,i},t.prototype._drawSplitline=function(e,a,n){var i=new Ae({z2:20,shape:{points:e},style:a});n.add(i)},t.prototype._getLinePointsOfOneWeek=function(e,a,n){for(var i=e.coordinateSystem,o=i.getDateInfo(a),s=[],l=0;l<7;l++){var u=i.getNextNDay(o.time,l),f=i.dataToCalendarLayout([u.time],!1);s[2*u.day]=f.tl,s[2*u.day+1]=f[n==="horizontal"?"bl":"tr"]}return s},t.prototype._formatterLabel=function(e,a){return X(e)&&e?ZN(e,a):tt(e)?e(a):a.nameMap},t.prototype._yearTextPositionControl=function(e,a,n,i,o){var s=a[0],l=a[1],u=["center","bottom"];i==="bottom"?(l+=o,u=["center","top"]):i==="left"?s-=o:i==="right"?(s+=o,u=["center","top"]):l-=o;var f=0;return(i==="left"||i==="right")&&(f=Math.PI/2),{rotation:f,x:s,y:l,style:{align:u[0],verticalAlign:u[1]}}},t.prototype._renderYearText=function(e,a,n,i){var o=e.getModel("yearLabel");if(o.get("show")){var s=o.get("margin"),l=o.get("position");l||(l=n!=="horizontal"?"top":"left");var u=[this._tlpoints[this._tlpoints.length-1],this._blpoints[0]],f=(u[0][0]+u[1][0])/2,v=(u[0][1]+u[1][1])/2,h=n==="horizontal"?0:1,c={top:[f,u[h][1]],bottom:[f,u[1-h][1]],left:[u[1-h][0],v],right:[u[h][0],v]},p=a.start.y;+a.end.y>+a.start.y&&(p=p+"-"+a.end.y);var d=o.get("formatter"),g={start:a.start.y,end:a.end.y,nameMap:p},y=this._formatterLabel(d,g),m=new At({z2:30,style:Gt(o,{text:y}),silent:o.get("silent")});m.attr(this._yearTextPositionControl(m,c[l],n,l,s)),i.add(m)}},t.prototype._monthTextPositionControl=function(e,a,n,i,o){var s="left",l="top",u=e[0],f=e[1];return n==="horizontal"?(f=f+o,a&&(s="center"),i==="start"&&(l="bottom")):(u=u+o,a&&(l="middle"),i==="start"&&(s="right")),{x:u,y:f,align:s,verticalAlign:l}},t.prototype._renderMonthText=function(e,a,n,i){var o=e.getModel("monthLabel");if(o.get("show")){var s=o.get("nameMap"),l=o.get("margin"),u=o.get("position"),f=o.get("align"),v=[this._tlpoints,this._blpoints];(!s||X(s))&&(s&&(a=Mg(s)||a),s=a.get(["time","monthAbbr"])||[]);var h=u==="start"?0:1,c=n==="horizontal"?0:1;l=u==="start"?-l:l;for(var p=f==="center",d=o.get("silent"),g=0;g<v[h].length-1;g++){var y=v[h][g].slice(),m=this._firstDayOfMonth[g];if(p){var _=this._firstDayPoints[g];y[c]=(_[c]+v[0][g+1][c])/2}var S=o.get("formatter"),x=s[+m.m-1],b={yyyy:m.y,yy:(m.y+"").slice(2),MM:m.m,M:+m.m,nameMap:x},w=this._formatterLabel(S,b),T=new At({z2:30,style:G(Gt(o,{text:w}),this._monthTextPositionControl(y,p,n,u,l)),silent:d});i.add(T)}}},t.prototype._weekTextPositionControl=function(e,a,n,i,o){var s="center",l="middle",u=e[0],f=e[1],v=n==="start";return a==="horizontal"?(u=u+i+(v?1:-1)*o[0]/2,s=v?"right":"left"):(f=f+i+(v?1:-1)*o[1]/2,l=v?"bottom":"top"),{x:u,y:f,align:s,verticalAlign:l}},t.prototype._renderWeekText=function(e,a,n,i,o){var s=e.getModel("dayLabel");if(s.get("show")){var l=e.coordinateSystem,u=s.get("position"),f=s.get("nameMap"),v=s.get("margin"),h=l.getFirstDayOfWeek();if(!f||X(f)){f&&(a=Mg(f)||a);var c=a.get(["time","dayOfWeekShort"]);f=c||U(a.get(["time","dayOfWeekAbbr"]),function(b){return b[0]})}var p=l.getNextNDay(n.end.time,7-n.lweek).time,d=[l.getCellWidth(),l.getCellHeight()];v=Z(v,Math.min(d[1],d[0])),u==="start"&&(p=l.getNextNDay(n.start.time,-(7+n.fweek)).time,v=-v);for(var g=s.get("silent"),y=0;y<7;y++){var m=l.getNextNDay(p,y),_=l.dataToCalendarLayout([m.time],!1).center,S=y;S=Math.abs((y+h)%7);var x=new At({z2:30,style:G(Gt(s,{text:f[S]}),this._weekTextPositionControl(_,i,u,v,d)),silent:g});o.add(x)}}},t.type="calendar",t}(Wt),Sd=864e5,S7=function(){function r(t,e,a){this.type="calendar",this.dimensions=r.dimensions,this.getDimensionsInfo=r.getDimensionsInfo,this._model=t,this._update(e,a)}return r.getDimensionsInfo=function(){return[{name:"time",type:"time"},"value"]},r.prototype.getRangeInfo=function(){return this._rangeInfo},r.prototype.getModel=function(){return this._model},r.prototype.getRect=function(){return this._rect},r.prototype.getCellWidth=function(){return this._sw},r.prototype.getCellHeight=function(){return this._sh},r.prototype.getOrient=function(){return this._orient},r.prototype.getFirstDayOfWeek=function(){return this._firstDayOfWeek},r.prototype.getDateInfo=function(t){t=ba(t);var e=t.getFullYear(),a=t.getMonth()+1,n=a<10?"0"+a:""+a,i=t.getDate(),o=i<10?"0"+i:""+i,s=t.getDay();return s=Math.abs((s+7-this.getFirstDayOfWeek())%7),{y:e+"",m:n,d:o,day:s,time:t.getTime(),formatedDate:e+"-"+n+"-"+o,date:t}},r.prototype.getNextNDay=function(t,e){return e=e||0,e===0?this.getDateInfo(t):(t=new Date(this.getDateInfo(t).time),t.setDate(t.getDate()+e),this.getDateInfo(t))},r.prototype._update=function(t,e){this._firstDayOfWeek=+this._model.getModel("dayLabel").get("firstDay"),this._orient=this._model.get("orient"),this._lineWidth=this._model.getModel("itemStyle").getItemStyle().lineWidth||0,this._rangeInfo=this._getRangeInfo(this._initRangeOption());var a=this._rangeInfo.weeks||1,n=["width","height"],i=this._model.getCellSize().slice(),o=this._model.getBoxLayoutParams(),s=this._orient==="horizontal"?[a,7]:[7,a];A([0,1],function(v){f(i,v)&&(o[n[v]]=i[v]*s[v])});var l={width:e.getWidth(),height:e.getHeight()},u=this._rect=Xt(o,l);A([0,1],function(v){f(i,v)||(i[v]=u[n[v]]/s[v])});function f(v,h){return v[h]!=null&&v[h]!=="auto"}this._sw=i[0],this._sh=i[1]},r.prototype.dataToPoint=function(t,e,a){a=a||[],W(t)&&(t=t[0]),e==null&&(e=!0);var n=this.getDateInfo(t),i=this._rangeInfo,o=n.formatedDate;if(e&&!(n.time>=i.start.time&&n.time<i.end.time+Sd))return a[0]=a[1]=NaN,a;var s=n.day,l=this._getRangeInfo([i.start.time,o]).nthWeek;return this._orient==="vertical"?(a[0]=this._rect.x+s*this._sw+this._sw/2,a[1]=this._rect.y+l*this._sh+this._sh/2):(a[0]=this._rect.x+l*this._sw+this._sw/2,a[1]=this._rect.y+s*this._sh+this._sh/2),a},r.prototype.pointToData=function(t){var e=this.pointToDate(t);return e&&e.time},r.prototype.dataToLayout=function(t,e,a){a=a||{};var n=a.rect=a.rect||{},i=a.contentRect=a.contentRect||{},o=this.dataToPoint(t,e);return n.x=o[0]-this._sw/2,n.y=o[1]-this._sh/2,n.width=this._sw,n.height=this._sh,lt.copy(i,n),Wi(i,this._lineWidth/2,!0,!0),a},r.prototype.dataToCalendarLayout=function(t,e){var a=this.dataToPoint(t,e);return{center:a,tl:[a[0]-this._sw/2,a[1]-this._sh/2],tr:[a[0]+this._sw/2,a[1]-this._sh/2],br:[a[0]+this._sw/2,a[1]+this._sh/2],bl:[a[0]-this._sw/2,a[1]+this._sh/2]}},r.prototype.pointToDate=function(t){var e=Math.floor((t[0]-this._rect.x)/this._sw)+1,a=Math.floor((t[1]-this._rect.y)/this._sh)+1,n=this._rangeInfo.range;return this._orient==="vertical"?this._getDateByWeeksAndDay(a,e-1,n):this._getDateByWeeksAndDay(e,a-1,n)},r.prototype.convertToPixel=function(t,e,a){var n=xd(e);return n===this?n.dataToPoint(a):null},r.prototype.convertToLayout=function(t,e,a){var n=xd(e);return n===this?n.dataToLayout(a):null},r.prototype.convertFromPixel=function(t,e,a){var n=xd(e);return n===this?n.pointToData(a):null},r.prototype.containPoint=function(t){return console.warn("Not implemented."),!1},r.prototype._initRangeOption=function(){var t=this._model.get("range"),e;if(W(t)&&t.length===1&&(t=t[0]),W(t))e=t;else{var a=t.toString();if(/^\d{4}$/.test(a)&&(e=[a+"-01-01",a+"-12-31"]),/^\d{4}[\/|-]\d{1,2}$/.test(a)){var n=this.getDateInfo(a),i=n.date;i.setMonth(i.getMonth()+1);var o=this.getNextNDay(i,-1);e=[n.formatedDate,o.formatedDate]}/^\d{4}[\/|-]\d{1,2}[\/|-]\d{1,2}$/.test(a)&&(e=[a,a])}if(!e)return t;var s=this._getRangeInfo(e);return s.start.time>s.end.time&&e.reverse(),e},r.prototype._getRangeInfo=function(t){var e=[this.getDateInfo(t[0]),this.getDateInfo(t[1])],a;e[0].time>e[1].time&&(a=!0,e.reverse());var n=Math.floor(e[1].time/Sd)-Math.floor(e[0].time/Sd)+1,i=new Date(e[0].time),o=i.getDate(),s=e[1].date.getDate();i.setDate(o+n-1);var l=i.getDate();if(l!==s)for(var u=i.getTime()-e[1].time>0?1:-1;(l=i.getDate())!==s&&(i.getTime()-e[1].time)*u>0;)n-=u,i.setDate(l-u);var f=Math.floor((n+e[0].day+6)/7),v=a?-f+1:f-1;return a&&e.reverse(),{range:[e[0].formatedDate,e[1].formatedDate],start:e[0],end:e[1],allDay:n,weeks:f,nthWeek:v,fweek:e[0].day,lweek:e[1].day}},r.prototype._getDateByWeeksAndDay=function(t,e,a){var n=this._getRangeInfo(a);if(t>n.weeks||t===0&&e<n.fweek||t===n.weeks&&e>n.lweek)return null;var i=(t-1)*7-n.fweek+e,o=new Date(n.start.time);return o.setDate(+n.start.d+i),this.getDateInfo(o)},r.create=function(t,e){var a=[];return t.eachComponent("calendar",function(n){var i=new r(n,t,e);a.push(i),n.coordinateSystem=i}),t.eachComponent(function(n,i){Iu({targetModel:i,coordSysType:"calendar",coordSysProvider:aD})}),a},r.dimensions=["time","value"],r}();function xd(r){var t=r.calendarModel,e=r.seriesModel,a=t?t.coordinateSystem:e?e.coordinateSystem:null;return a}function x7(r){r.registerComponentModel(m7),r.registerComponentView(_7),r.registerCoordinateSystem("calendar",S7)}var ka={level:1,leaf:2,nonLeaf:3},Ua={none:0,all:1,body:2,corner:3};function Ry(r,t,e){var a=t[ct[e]].getCell(r);return!a&&Mt(r)&&r<0&&(a=t[ct[1-e]].getUnitLayoutInfo(e,Math.round(r))),a}function BP(r){var t=r||[];return t[0]=t[0]||[],t[1]=t[1]||[],t[0][0]=t[0][1]=t[1][0]=t[1][1]=NaN,t}function zP(r,t,e,a,n){vT(r[0],t,n,e,a,0),vT(r[1],t,n,e,a,1)}function vT(r,t,e,a,n,i){r[0]=1/0,r[1]=-1/0;var o=a[i],s=W(o)?o:[o],l=s.length,u=!!e;if(l>=1?(hT(r,t,s,u,n,i,0),l>1&&hT(r,t,s,u,n,i,l-1)):r[0]=r[1]=NaN,u){var f=-n[ct[1-i]].getLocatorCount(i),v=n[ct[i]].getLocatorCount(i)-1;e===Ua.body?f=re(0,f):e===Ua.corner&&(v=vr(-1,v)),v<f&&(f=v=NaN),Ie(r[0])&&(r[0]=f),Ie(r[1])&&(r[1]=v),r[0]=re(vr(r[0],v),f),r[1]=re(vr(r[1],v),f)}}function hT(r,t,e,a,n,i,o){var s=Ry(e[o],n,i);if(!s){r[0]=r[1]=NaN;return}var l=s.id[ct[i]],u=l,f=C7(s);f&&(u+=f.span[ct[i]]-1),r[0]=vr(r[0],l,u),r[1]=re(r[1],l,u)}function Ff(r,t){return Ie(r[t][0])||Ie(r[t][1])}function cT(r,t,e,a){t=t||b7;for(var n=0;n<a;n++)t[n]=!1;for(;;){for(var i=!1,n=0;n<a;n++){var o=e[n];!t[n]&&o.cellMergeOwner&&w7(r,o.locatorRange)&&(t[n]=!0,i=!0)}if(!i)break}}var b7=[];function w7(r,t){return!pT(r[0],t[0])||!pT(r[1],t[1])?!1:(r[0][0]=vr(r[0][0],t[0][0]),r[0][1]=re(r[0][1],t[0][1]),r[1][0]=vr(r[1][0],t[1][0]),r[1][1]=re(r[1][1],t[1][1]),!0)}function pT(r,t){return r[1]>=t[0]&&r[0]<=t[1]}function dT(r,t){r.id.set(t[0][0],t[1][0]),r.span.set(t[0][1]-r.id.x+1,t[1][1]-r.id.y+1)}function T7(r,t){r[0][0]=t[0][0],r[0][1]=t[0][1],r[1][0]=t[1][0],r[1][1]=t[1][1]}function gT(r,t,e,a){var n=Ry(t[a][0],e,a),i=Ry(t[a][1],e,a);r[ct[a]]=r[le[a]]=NaN,n&&i&&(r[ct[a]]=n.xy,r[le[a]]=i.xy+i.wh-n.xy)}function il(r,t,e,a){return r[ct[t]]=e,r[ct[1-t]]=a,r}function C7(r){return r&&(r.type===ka.leaf||r.type===ka.nonLeaf)?r:null}function Sh(){return{x:NaN,y:NaN,width:NaN,height:NaN}}var yT=function(){function r(t,e){this._cells=[],this._levels=[],this.dim=t,this.dimIdx=t==="x"?0:1,this._model=e,this._uniqueValueGen=A7(t);var a=e.get("data",!0);a!=null&&!W(a)&&(a=[]),a?this._initByDimModelData(a):this._initBySeriesData()}return r.prototype._initByDimModelData=function(t){var e=this,a=e._cells,n=e._levels,i=[],o=0;e._leavesCount=s(t,0,0),l();return;function s(u,f,v){var h=0;return u&&A(u,function(c,p){var d;X(c)?d={value:c}:it(c)?(d=c,c.value!=null&&!X(c.value)&&(d={value:null})):d={value:null};var g={type:ka.nonLeaf,ordinal:NaN,level:v,firstLeafLocator:f,id:new st,span:il(new st,e.dimIdx,1,1),option:d,xy:NaN,wh:NaN,dim:e,rect:Sh()};o++,(i[f]||(i[f]=[])).push(g),n[v]||(n[v]={type:ka.level,xy:NaN,wh:NaN,option:null,id:new st,dim:e});var y=s(d.children,f,v+1),m=Math.max(1,y);g.span[ct[e.dimIdx]]=m,h+=m,f+=m}),h}function l(){for(var u=[];a.length<o;)for(var f=0;f<i.length;f++){var v=i[f].pop();if(v){v.ordinal=u.length;var h=v.option.value;u.push(h),a.push(v),e._uniqueValueGen.calcDupBase(h)}}e._uniqueValueGen.ensureValueUnique(u,a);var c=e._ordinalMeta=new nu({categories:u,needCollect:!1,deduplication:!1});e._scale=new is({ordinalMeta:c});for(var p=0;p<e._leavesCount;p++){var d=e._cells[p];d.type=ka.leaf,d.span[ct[1-e.dimIdx]]=e._levels.length-d.level}e._initCellsId(),e._initLevelIdOptions()}},r.prototype._initBySeriesData=function(){var t=this;t._leavesCount=0,t._levels=[{type:ka.level,xy:NaN,wh:NaN,option:null,id:new st,dim:t}],t._initLevelIdOptions();var e=t._ordinalMeta=new nu({needCollect:!0,deduplication:!0,onCollect:function(a,n){var i=t._cells[n]={type:ka.leaf,ordinal:n,level:0,firstLeafLocator:n,id:new st,span:il(new st,t.dimIdx,1,1),option:{value:a+""},xy:NaN,wh:NaN,dim:t,rect:Sh()};t._leavesCount++,t._setCellId(i)}});t._scale=new is({ordinalMeta:e})},r.prototype._setCellId=function(t){var e=this._levels.length,a=this.dimIdx;il(t.id,a,t.firstLeafLocator,t.level-e)},r.prototype._initCellsId=function(){var t=this._levels.length,e=this.dimIdx;A(this._cells,function(a){il(a.id,e,a.firstLeafLocator,a.level-t)})},r.prototype._initLevelIdOptions=function(){var t=this._levels.length,e=this.dimIdx,a=this._model.get("levels",!0);a=W(a)?a:[],A(this._levels,function(n,i){il(n.id,e,0,i-t),n.option=a[i]})},r.prototype.shouldShow=function(){return!!this._model.getShallow("show",!0)},r.prototype.resetLayoutIterator=function(t,e,a,n){if(t=t||new Tn,e===this.dimIdx){var i=this._leavesCount,o=a!=null?Math.max(0,a):0;n=n!=null?Math.min(n,i):i,t.reset(this._cells,o,o+n)}else{var i=this._levels.length,o=a!=null?Math.max(0,a+i):0;n=n!=null?Math.min(n,i):i,t.reset(this._levels,o,o+n)}return t},r.prototype.resetCellIterator=function(t){return(t||new Tn).reset(this._cells,0)},r.prototype.resetLevelIterator=function(t){return(t||new Tn).reset(this._levels,0)},r.prototype.getLayout=function(t,e,a){var n=this.getUnitLayoutInfo(e,a);t[ct[e]]=n?n.xy:NaN,t[le[e]]=n?n.wh:NaN},r.prototype.getUnitLayoutInfo=function(t,e){return t===this.dimIdx?e<this._leavesCount?this._cells[e]:void 0:this._levels[e+this._levels.length]},r.prototype.getCell=function(t){var e=this._scale.parse(t);return Ie(e)?void 0:this._cells[e]},r.prototype.getLocatorCount=function(t){return t===this.dimIdx?this._leavesCount:this._levels.length},r.prototype.getOrdinalMeta=function(){return this._ordinalMeta},r}();function A7(r){var t=r.toUpperCase(),e=new RegExp("^"+t+"([0-9]+)$"),a=0;function n(s){var l;s!=null&&(l=s.match(e))&&(a=re(a,+l[1]+1))}function i(){return""+t+a++}function o(s,l){for(var u=j(),f=0;f<s.length;f++){var v=s[f];(v==null||u.get(v)!=null)&&(s[f]=v=i(),l[f].option=nt({value:v},l[f].option)),u.set(v,!0)}}return{calcDupBase:n,ensureValueUnique:o}}var mT=function(){function r(t,e,a){this._model=e,this._dims=a,this._kind=t,this._cellMergeOwnerList=[]}return r.prototype._ensureCellMap=function(){var t=this,e=t._cellMap;return e||(e=t._cellMap=j(),a()),e;function a(){var i=[],o=t._model.getShallow("data");o&&!W(o)&&(o=null),A(o,function(p,d){if(!(!it(p)||!W(p.coord))){var g=BP([]),y=null;if(zP(g,y,p.coord,t._dims,p.coordClamp?Ua[t._kind]:Ua.none),!(Ff(g,0)||Ff(g,1))){var m=p&&p.mergeCells,_={id:new st,span:new st,locatorRange:g,option:p,cellMergeOwner:m};dT(_,g),i.push(_)}}});for(var s=[],l=0;l<i.length;l++){var u=i[l];if(u.cellMergeOwner){var f=u.locatorRange;cT(f,s,i,l);for(var v=0;v<l;v++)s[v]&&(i[v].cellMergeOwner=!1);if(f[0][0]!==u.id.x||f[1][0]!==u.id.y){u.cellMergeOwner=!1;var h=G({},u.option);h.coord=null;var c={id:new st,span:new st,locatorRange:f,option:h,cellMergeOwner:!0};dT(c,f),i.push(c)}}}A(i,function(p){var d=n(p.id.x,p.id.y);if(p.cellMergeOwner&&(d.cellMergeOwner=!0,d.span=p.span,d.locatorRange=p.locatorRange,d.spanRect=Sh(),t._cellMergeOwnerList.push(d)),!(!p.cellMergeOwner&&!p.option))for(var g=0;g<p.span.y;g++)for(var y=0;y<p.span.x;y++){var m=n(p.id.x+y,p.id.y+g);m.option=p.option,p.cellMergeOwner&&(m.inSpanOf=d)}})}function n(i,o){var s=_T(i,o),l=e.get(s);return l||(l=e.set(s,{id:new st(i,o),option:null,inSpanOf:null,span:null,spanRect:null,locatorRange:null,cellMergeOwner:!1})),l}},r.prototype.getCell=function(t){return this._ensureCellMap().get(_T(t[0],t[1]))},r.prototype.travelExistingCells=function(t){this._ensureCellMap().each(t)},r.prototype.expandRangeByCellMerge=function(t){if(!Ff(t,0)&&!Ff(t,1)&&t[0][0]===t[0][1]&&t[1][0]===t[1][1]){bd[0]=t[0][0],bd[1]=t[1][0];var e=this.getCell(bd),a=e&&e.inSpanOf;if(a){T7(t,a.locatorRange);return}}var n=this._cellMergeOwnerList;cT(t,null,n,n.length)},r}(),bd=[];function _T(r,t){return r+"|"+t}var c_={show:!0,color:N.color.secondary,overflow:"break",lineOverflow:"truncate",padding:[2,3,2,3],distance:0};function p_(r){return{color:"none",borderWidth:1,borderColor:r?"none":N.color.borderTint}}var ST={show:!0,label:c_,itemStyle:p_(!1),silent:void 0,dividerLineStyle:{width:1,color:N.color.border}},M7={label:c_,itemStyle:p_(!1),silent:void 0},D7={label:c_,itemStyle:p_(!0),silent:void 0},L7={z:-50,left:"10%",top:"10%",right:"10%",bottom:"10%",x:ST,y:ST,body:M7,corner:D7,backgroundStyle:{color:"none",borderColor:N.color.axisLine,borderWidth:1}},I7=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.optionUpdated=function(){var e=this._dimModels={x:new xT(this.get("x",!0)||{}),y:new xT(this.get("y",!0)||{})};e.x.option.type=e.y.option.type="category";var a=e.x.dim=new yT("x",e.x),n=e.y.dim=new yT("y",e.y),i={x:a,y:n};this._body=new mT("body",new wt(this.getShallow("body")),i),this._corner=new mT("corner",new wt(this.getShallow("corner")),i)},t.prototype.getDimensionModel=function(e){return this._dimModels[e]},t.prototype.getBody=function(){return this._body},t.prototype.getCorner=function(){return this._corner},t.type="matrix",t.layoutMode="box",t.defaultOption=L7,t}(xt),xT=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.getOrdinalMeta=function(){return this.dim.getOrdinalMeta()},t}(wt),Hf=Math.round,P7=0,R7=99,k7={normal:25,special:100},E7={normal:50,special:125},O7=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a){this.group.removeAll();var n=this.group,i=e.coordinateSystem,o=i.getRect(),s=e.getDimensionModel("x"),l=e.getDimensionModel("y"),u=s.dim,f=l.dim;N7(n,e,a),B7(n,e,u,f,a);var v=e.getShallow("borderZ2",!0),h=Q(v,R7),c=h-1,p=e.getModel("backgroundStyle").getItemStyle(["borderWidth"]);p.lineWidth=0;var d=e.getModel("backgroundStyle").getItemStyle(["color","decal","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"]);d.fill="none";var g=ky(o.clone(),p,P7),y=ky(o.clone(),d,h);g.silent=!0,y.silent=!0,n.add(g),n.add(y);var m=u.getUnitLayoutInfo(0,0),_=f.getUnitLayoutInfo(1,0);m&&_&&(u.shouldShow()&&n.add(bT({x1:o.x,y1:_.xy,x2:o.x+o.width,y2:_.xy},s.getModel("dividerLineStyle").getLineStyle(),c)),f.shouldShow()&&n.add(bT({x1:m.xy,y1:o.y,x2:m.xy,y2:o.y+o.height},l.getModel("dividerLineStyle").getLineStyle(),c)))},t.type="matrix",t}(Wt);function N7(r,t,e){a(0),a(1);function a(n){var i=t.getDimensionModel(ct[n]),o=i.dim;if(o.shouldShow())for(var s=i.getModel("itemStyle"),l=i.getModel("label"),u=t.getShallow("tooltip",!0),f=[],v=o.resetCellIterator();v.next();){var h=v.item,c={};lt.copy(c,h.rect),Oh(f,h.id.x,h.id.y),VP(f,t,r,e,h.option,s,l,i,c,h.option.value,E7,u)}}}function B7(r,t,e,a,n){i("body",t.getBody(),e,a),e.shouldShow()&&a.shouldShow()&&i("corner",t.getCorner(),a,e);function i(o,s,l,u){var f=new wt(t.getShallow(o,!0)),v=f.getModel("itemStyle"),h=f.getModel("label"),c=new Tn,p=new Tn,d=[],g=t.getShallow("tooltip",!0);for(u.resetLayoutIterator(p,1);p.next();)for(l.resetLayoutIterator(c,0);c.next();){var y=c.item,m=p.item;Oh(d,y.id.x,m.id.y);var _=s.getCell(d);if(!(_&&_.inSpanOf&&_.inSpanOf!==_)){var S={};_&&_.span?lt.copy(S,_.spanRect):(y.dim.getLayout(S,0,d[0]),m.dim.getLayout(S,1,d[1]));var x=_?_.option:null;VP(d,t,r,n,x,v,h,f,S,x?x.value:null,k7,g)}}}}function VP(r,t,e,a,n,i,o,s,l,u,f,v){var h;Wf.option=n?n.itemStyle:null,Wf.parentModel=i,Mo.option=n,Mo.parentModel=s;var c=Q(Mo.getShallow("z2"),n&&n.itemStyle?f.special:f.normal),p=v&&v.show,d=ky(l,Wf.getItemStyle(),c);e.add(d);var g=Mo.get("cursor");g!=null&&d.attr("cursor",g);var y;if(u!=null){var m=u+"";if(Do.option=n?n.label:null,Do.parentModel=o,Do.ecModel=a,Se(d,{normal:Do},{defaultText:m,autoOverflowArea:!0,layoutRect:et(d.shape)}),y=d.getTextContent(),y){y.z2=c+1;var _=y.style;if(_&&_.overflow&&_.overflow!=="none"&&_.lineOverflow){var S={};lt.copy(S,l),Wi(S,(((h=d.style)===null||h===void 0?void 0:h.lineWidth)||0)/2,!0,!0),d.updateInnerText(),y.getLocalTransform(Uf),Dr(Uf,Uf),lt.applyTransform(S,S,Uf),y.setClipPath(new _t({shape:S}))}}en({el:d,componentModel:t,itemName:m,itemTooltipOption:v,formatterParamsExtra:{xyLocator:r.slice()}})}if(y){var x=Do.get("silent");x==null&&(x=!p),y.silent=x,y.ignoreHostSilent=!0}var b=Mo.get("silent");b==null&&(b=!d.style||d.style.fill==="none"||!d.style.fill),d.silent=b,Oc(Mo),Oc(Wf),Oc(Do)}var Mo=new wt,Wf=new wt,Do=new wt,Uf=[];function ky(r,t,e){var a=t.lineWidth;if(a){var n=r.x+r.width,i=r.y+r.height;r.x=fr(r.x,a,!0),r.y=fr(r.y,a,!0),r.width=fr(n,a,!0)-r.x,r.height=fr(i,a,!0)-r.y}return new _t({shape:r,style:t,z2:e})}function bT(r,t,e){var a=t.lineWidth;return a&&(Hf(r.x1*2)===Hf(r.x2*2)&&(r.x1=r.x2=fr(r.x1,a,!0)),Hf(r.y1*2)===Hf(r.y2*2)&&(r.y1=r.y2=fr(r.y1,a,!0))),new ne({shape:r,style:t,silent:!0,z2:e})}var z7=function(){function r(t,e,a){this.dimensions=r.dimensions,this.type="matrix",this._model=t;var n=this._dimModels={x:t.getDimensionModel("x"),y:t.getDimensionModel("y")};this._dims={x:n.x.dim,y:n.y.dim},this._resize(t,a)}return r.getDimensionsInfo=function(){return[{name:"x",type:"ordinal"},{name:"y",type:"ordinal"},{name:"value"}]},r.create=function(t,e){var a=[];return t.eachComponent("matrix",function(n){var i=new r(n,t,e);a.push(i),n.coordinateSystem=i}),t.eachComponent(function(n,i){Iu({targetModel:i,coordSysType:"matrix",coordSysProvider:aD})}),a},r.prototype.getRect=function(){return this._rect},r.prototype._resize=function(t,e){var a=this._dims,n=this._dimModels,i=this._rect=Xt(t.getBoxLayoutParams(),{width:e.getWidth(),height:e.getHeight()});wT(n,a,i,0),wT(n,a,i,1),TT(0,a),TT(1,a),CT(this._model.getBody(),a),CT(this._model.getCorner(),a)},r.prototype.dataToPoint=function(t,e,a){return a=a||[],this.dataToLayout(t,e,ol),a[0]=ol.rect.x+ol.rect.width/2,a[1]=ol.rect.y+ol.rect.height/2,a},r.prototype.dataToLayout=function(t,e,a){var n=this._dims;a=a||{};var i=a.rect=a.rect||{};i.x=i.y=i.width=i.height=NaN;var o=a.matrixXYLocatorRange=BP(a.matrixXYLocatorRange);return W(t)&&(zP(o,null,t,n,Q(e&&e.clamp,Ua.none)),(!e||!e.ignoreMergeCells)&&((!e||e.clamp!==Ua.corner)&&this._model.getBody().expandRangeByCellMerge(o),(!e||e.clamp!==Ua.body)&&this._model.getCorner().expandRangeByCellMerge(o)),gT(i,o,n,0),gT(i,o,n,1)),a},r.prototype.pointToData=function(t,e,a){var n=this._dims;return AT(ta,0,n,t,e&&e.clamp),AT(ta,1,n,t,e&&e.clamp),a=a||[],a[0]=a[1]=NaN,ta.y===Le.inCorner&&ta.x===Le.inBody?MT(ta,a,0,n):ta.x===Le.inCorner&&ta.y===Le.inBody?MT(ta,a,1,n):(DT(ta,a,0,n),DT(ta,a,1,n)),a},r.prototype.convertToPixel=function(t,e,a,n){var i=Td(e);return i===this?i.dataToPoint(a,n):void 0},r.prototype.convertToLayout=function(t,e,a,n){var i=Td(e);return i===this?i.dataToLayout(a,n):void 0},r.prototype.convertFromPixel=function(t,e,a,n){var i=Td(e);return i===this?i.pointToData(a,n):void 0},r.prototype.containPoint=function(t){return this._rect.contain(t[0],t[1])},r.dimensions=["x","y","value"],r}(),ol={rect:Sh()},Yf=new Tn,wd=new Tn;function wT(r,t,e,a){for(var n=1-a,i=t[ct[a]],o=t[ct[n]],s=o.shouldShow(),l=i.resetCellIterator();l.next();)l.item.wh=l.item.xy=NaN;for(var u=o.resetLayoutIterator(null,a);u.next();)u.item.wh=u.item.xy=NaN;for(var f=e[le[a]],v=i.getLocatorCount(a)+o.getLocatorCount(a),h=new wt,c=o.resetLevelIterator();c.next();)h.option=c.item.option,h.parentModel=r[ct[n]],g(c.item,s?h.get("levelSize"):0);for(var p=new wt,d=i.resetCellIterator();d.next();)d.item.type===ka.leaf&&(p.option=d.item.option,p.parentModel=void 0,g(d.item,p.get("size")));function g(w,T){var C=V7(T,a,e);Ie(C)||(w.wh=Ey(C,f),f=Ey(f-w.wh),v--)}var y=v?f/v:0,m=!v&&f>=1,_=e[ct[a]],S=i.getLocatorCount(a)-1,x=new Tn;for(o.resetLayoutIterator(x,a);x.next();)b(x.item);for(i.resetLayoutIterator(x,a);x.next();)b(x.item);function b(w){Ie(w.wh)&&(w.wh=y),w.xy=_,w.id[ct[a]]===S&&!m&&(w.wh=e[ct[a]]+e[le[a]]-w.xy),_+=w.wh}}function TT(r,t){for(var e=t[ct[r]].resetCellIterator();e.next();){var a=e.item;xh(a.rect,r,a.id,a.span,t),xh(a.rect,1-r,a.id,a.span,t),a.type===ka.nonLeaf&&(a.xy=a.rect[ct[r]],a.wh=a.rect[le[r]])}}function CT(r,t){r.travelExistingCells(function(e){var a=e.span;if(a){var n=e.spanRect,i=e.id;xh(n,0,i,a,t),xh(n,1,i,a,t)}})}function xh(r,t,e,a,n){r[le[t]]=0;var i=e[ct[t]],o=i<0?n[ct[1-t]]:n[ct[t]],s=o.getUnitLayoutInfo(t,e[ct[t]]);if(r[ct[t]]=s.xy,r[le[t]]=s.wh,a[ct[t]]>1){var l=o.getUnitLayoutInfo(t,e[ct[t]]+a[ct[t]]-1);r[le[t]]=l.xy+l.wh-s.xy}}function V7(r,t,e){var a=Ev(r,e[le[t]]);return Ey(a,e[le[t]])}function Ey(r,t){return Math.max(Math.min(r,Q(t,1/0)),0)}function Td(r){var t=r.matrixModel,e=r.seriesModel,a=t?t.coordinateSystem:e?e.coordinateSystem:null;return a}var Le={inBody:1,inCorner:2,outside:3},ta={x:null,y:null,point:[]};function AT(r,t,e,a,n){var i=e[ct[t]],o=e[ct[1-t]],s=i.getUnitLayoutInfo(t,i.getLocatorCount(t)-1),l=i.getUnitLayoutInfo(t,0),u=o.getUnitLayoutInfo(t,-o.getLocatorCount(t)),f=o.shouldShow()?o.getUnitLayoutInfo(t,-1):null,v=r.point[t]=a[t];if(!l&&!f){r[ct[t]]=Le.outside;return}if(n===Ua.body){l?(r[ct[t]]=Le.inBody,v=vr(s.xy+s.wh,re(l.xy,v)),r.point[t]=v):r[ct[t]]=Le.outside;return}else if(n===Ua.corner){f?(r[ct[t]]=Le.inCorner,v=vr(f.xy+f.wh,re(u.xy,v)),r.point[t]=v):r[ct[t]]=Le.outside;return}var h=l?l.xy:f?f.xy+f.wh:NaN,c=u?u.xy:h,p=s?s.xy+s.wh:h;if(v<c){if(!n){r[ct[t]]=Le.outside;return}v=c}else if(v>p){if(!n){r[ct[t]]=Le.outside;return}v=p}r.point[t]=v,r[ct[t]]=h<=v&&v<=p?Le.inBody:c<=v&&v<=h?Le.inCorner:Le.outside}function MT(r,t,e,a){var n=1-e;if(r[ct[e]]!==Le.outside)for(a[ct[e]].resetCellIterator(wd);wd.next();){var i=wd.item;if(LT(r.point[e],i.rect,e)&&LT(r.point[n],i.rect,n)){t[e]=i.ordinal,t[n]=i.id[ct[n]];return}}}function DT(r,t,e,a){if(r[ct[e]]!==Le.outside){var n=r[ct[e]]===Le.inCorner?a[ct[1-e]]:a[ct[e]];for(n.resetLayoutIterator(Yf,e);Yf.next();)if(G7(r.point[e],Yf.item)){t[e]=Yf.item.id[ct[e]];return}}}function G7(r,t){return t.xy<=r&&r<=t.xy+t.wh}function LT(r,t,e){return t[ct[e]]<=r&&r<=t[ct[e]]+t[le[e]]}function F7(r){r.registerComponentModel(I7),r.registerComponentView(O7),r.registerCoordinateSystem("matrix",z7)}function H7(r,t){var e=r.existing;if(t.id=r.keyInfo.id,!t.type&&e&&(t.type=e.type),t.parentId==null){var a=t.parentOption;a?t.parentId=a.id:e&&(t.parentId=e.parentId)}t.parentOption=null}function IT(r,t){var e;return A(t,function(a){r[a]!=null&&r[a]!=="auto"&&(e=!0)}),e}function W7(r,t,e){var a=G({},e),n=r[t],i=e.$action||"merge";i==="merge"?n?(yt(n,a,!0),_a(n,a,{ignoreSize:!0}),lD(e,n),Zf(e,n),Zf(e,n,"shape"),Zf(e,n,"style"),Zf(e,n,"extra"),e.clipPath=n.clipPath):r[t]=a:i==="replace"?r[t]=a:i==="remove"&&n&&(r[t]=null)}var GP=["transition","enterFrom","leaveTo"],U7=GP.concat(["enterAnimation","updateAnimation","leaveAnimation"]);function Zf(r,t,e){if(e&&(!r[e]&&t[e]&&(r[e]={}),r=r[e],t=t[e]),!(!r||!t))for(var a=e?GP:U7,n=0;n<a.length;n++){var i=a[n];r[i]==null&&t[i]!=null&&(r[i]=t[i])}}function Y7(r,t){if(r&&(r.hv=t.hv=[IT(t,["left","right"]),IT(t,["top","bottom"])],r.type==="group")){var e=r,a=t;e.width==null&&(e.width=a.width=0),e.height==null&&(e.height=a.height=0)}}var Z7=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.preventAutoZ=!0,e}return t.prototype.mergeOption=function(e,a){var n=this.option.elements;this.option.elements=null,r.prototype.mergeOption.call(this,e,a),this.option.elements=n},t.prototype.optionUpdated=function(e,a){var n=this.option,i=(a?n:e).elements,o=n.elements=a?[]:n.elements,s=[];this._flatten(i,s,null);var l=jA(o,s,"normalMerge"),u=this._elOptionsToUpdate=[];A(l,function(f,v){var h=f.newOption;h&&(u.push(h),H7(f,h),W7(o,v,h),Y7(o[v],h))},this),n.elements=Pt(o,function(f){return f&&delete f.$action,f!=null})},t.prototype._flatten=function(e,a,n){A(e,function(i){if(i){n&&(i.parentOption=n),a.push(i);var o=i.children;o&&o.length&&this._flatten(o,a,i),delete i.children}},this)},t.prototype.useElOptionsToUpdate=function(){var e=this._elOptionsToUpdate;return this._elOptionsToUpdate=null,e},t.type="graphic",t.defaultOption={elements:[]},t}(xt),PT={path:null,compoundPath:null,group:rt,image:xe,text:At},xr=St(),X7=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(){this._elMap=j()},t.prototype.render=function(e,a,n){e!==this._lastGraphicModel&&this._clear(),this._lastGraphicModel=e,this._updateElements(e),this._relocate(e,n)},t.prototype._updateElements=function(e){var a=e.useElOptionsToUpdate();if(a){var n=this._elMap,i=this.group,o=e.get("z"),s=e.get("zlevel");A(a,function(l){var u=ve(l.id,null),f=u!=null?n.get(u):null,v=ve(l.parentId,null),h=v!=null?n.get(v):i,c=l.type,p=l.style;c==="text"&&p&&l.hv&&l.hv[1]&&(p.textVerticalAlign=p.textBaseline=p.verticalAlign=p.align=null);var d=l.textContent,g=l.textConfig;if(p&&yP(p,c,!!g,!!d)){var y=mP(p,c,!0);!g&&y.textConfig&&(g=l.textConfig=y.textConfig),!d&&y.textContent&&(d=y.textContent)}var m=$7(l),_=l.$action||"merge",S=_==="merge",x=_==="replace";if(S){var b=!f,w=f;b?w=RT(u,h,l.type,n):(w&&(xr(w).isNew=!1),bP(w)),w&&(gv(w,m,e,{isInit:b}),kT(w,l,o,s))}else if(x){_v(f,l,n,e);var T=RT(u,h,l.type,n);T&&(gv(T,m,e,{isInit:!0}),kT(T,l,o,s))}else _==="remove"&&(SP(f,l),_v(f,l,n,e));var C=n.get(u);if(C&&d)if(S){var M=C.getTextContent();M?M.attr(d):C.setTextContent(new At(d))}else x&&C.setTextContent(new At(d));if(C){var D=l.clipPath;if(D){var I=D.type,L=void 0,b=!1;if(S){var P=C.getClipPath();b=!P||xr(P).type!==I,L=b?Oy(I):P}else x&&(b=!0,L=Oy(I));C.setClipPath(L),gv(L,D,e,{isInit:b}),yh(L,D.keyframeAnimation,e)}var k=xr(C);C.setTextConfig(g),k.option=l,q7(C,e,l),en({el:C,componentModel:e,itemName:C.name,itemTooltipOption:l.tooltip}),yh(C,l.keyframeAnimation,e)}})}},t.prototype._relocate=function(e,a){for(var n=e.option.elements,i=this.group,o=this._elMap,s=a.getWidth(),l=a.getHeight(),u=["x","y"],f=0;f<n.length;f++){var v=n[f],h=ve(v.id,null),c=h!=null?o.get(h):null;if(!(!c||!c.isGroup)){var p=c.parent,d=p===i,g=xr(c),y=xr(p);g.width=Z(g.option.width,d?s:y.width)||0,g.height=Z(g.option.height,d?l:y.height)||0}}for(var f=n.length-1;f>=0;f--){var v=n[f],h=ve(v.id,null),c=h!=null?o.get(h):null;if(c){var p=c.parent,y=xr(p),m=p===i?{width:s,height:l}:{width:y.width,height:y.height},_={},S=Jh(c,v,m,null,{hv:v.hv,boundingMode:v.bounding},_);if(!xr(c).isNew&&S){for(var x=v.transition,b={},w=0;w<u.length;w++){var T=u[w],C=_[T];x&&(Bi(x)||gt(x,T)>=0)?b[T]=C:c[T]=C}Lt(c,b,e,0)}else c.attr(_)}}},t.prototype._clear=function(){var e=this,a=this._elMap;a.each(function(n){_v(n,xr(n).option,a,e._lastGraphicModel)}),this._elMap=j()},t.prototype.dispose=function(){this._clear()},t.type="graphic",t}(Wt);function Oy(r){var t=q(PT,r)?PT[r]:Kl(r),e=new t({});return xr(e).type=r,e}function RT(r,t,e,a){var n=Oy(e);return t.add(n),a.set(r,n),xr(n).id=r,xr(n).isNew=!0,n}function _v(r,t,e,a){var n=r&&r.parent;n&&(r.type==="group"&&r.traverse(function(i){_v(i,t,e,a)}),hc(r,t,a),e.removeKey(xr(r).id))}function kT(r,t,e,a){r.isGroup||A([["cursor",Lr.prototype.cursor],["zlevel",a||0],["z",e||0],["z2",0]],function(n){var i=n[0];q(t,i)?r[i]=Q(t[i],n[1]):r[i]==null&&(r[i]=n[1])}),A(Ct(t),function(n){if(n.indexOf("on")===0){var i=t[n];r[n]=tt(i)?i:null}}),q(t,"draggable")&&(r.draggable=t.draggable),t.name!=null&&(r.name=t.name),t.id!=null&&(r.id=t.id)}function $7(r){return r=G({},r),A(["id","parentId","$action","hv","bounding","textContent","clipPath"].concat(nD),function(t){delete r[t]}),r}function q7(r,t,e){var a=ut(r).eventData;!r.silent&&!r.ignore&&!a&&(a=ut(r).eventData={componentType:"graphic",componentIndex:t.componentIndex,name:r.name}),a&&(a.info=e.info)}function K7(r){r.registerComponentModel(Z7),r.registerComponentView(X7),r.registerPreprocessor(function(t){var e=t.graphic;W(e)?!e[0]||!e[0].elements?t.graphic=[{elements:e}]:t.graphic=[t.graphic[0]]:e&&!e.elements&&(t.graphic=[{elements:[e]}])})}var ET=["x","y","radius","angle","single"],j7=["cartesian2d","polar","singleAxis"];function J7(r){var t=r.get("coordinateSystem");return gt(j7,t)>=0}function xn(r){return r+"Axis"}function Q7(r,t){var e=j(),a=[],n=j();r.eachComponent({mainType:"dataZoom",query:t},function(f){n.get(f.uid)||s(f)});var i;do i=!1,r.eachComponent("dataZoom",o);while(i);function o(f){!n.get(f.uid)&&l(f)&&(s(f),i=!0)}function s(f){n.set(f.uid,!0),a.push(f),u(f)}function l(f){var v=!1;return f.eachTargetAxis(function(h,c){var p=e.get(h);p&&p[c]&&(v=!0)}),v}function u(f){f.eachTargetAxis(function(v,h){(e.get(v)||e.set(v,[]))[h]=!0})}return a}function FP(r){var t=r.ecModel,e={infoList:[],infoMap:j()};return r.eachTargetAxis(function(a,n){var i=t.getComponent(xn(a),n);if(i){var o=i.getCoordSysModel();if(o){var s=o.uid,l=e.infoMap.get(s);l||(l={model:o,axisModels:[]},e.infoList.push(l),e.infoMap.set(s,l)),l.axisModels.push(i)}}}),e}var Cd=function(){function r(){this.indexList=[],this.indexMap=[]}return r.prototype.add=function(t){this.indexMap[t]||(this.indexList.push(t),this.indexMap[t]=!0)},r}(),du=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e._autoThrottle=!0,e._noTarget=!0,e._rangePropMode=["percent","percent"],e}return t.prototype.init=function(e,a,n){var i=OT(e);this.settledOption=i,this.mergeDefaultAndTheme(e,n),this._doInit(i)},t.prototype.mergeOption=function(e){var a=OT(e);yt(this.option,e,!0),yt(this.settledOption,a,!0),this._doInit(a)},t.prototype._doInit=function(e){var a=this.option;this._setDefaultThrottle(e),this._updateRangeUse(e);var n=this.settledOption;A([["start","startValue"],["end","endValue"]],function(i,o){this._rangePropMode[o]==="value"&&(a[i[0]]=n[i[0]]=null)},this),this._resetTarget()},t.prototype._resetTarget=function(){var e=this.get("orient",!0),a=this._targetAxisInfoMap=j(),n=this._fillSpecifiedTargetAxis(a);n?this._orient=e||this._makeAutoOrientByTargetAxis():(this._orient=e||"horizontal",this._fillAutoTargetAxisByOrient(a,this._orient)),this._noTarget=!0,a.each(function(i){i.indexList.length&&(this._noTarget=!1)},this)},t.prototype._fillSpecifiedTargetAxis=function(e){var a=!1;return A(ET,function(n){var i=this.getReferringComponents(xn(n),IE);if(i.specified){a=!0;var o=new Cd;A(i.models,function(s){o.add(s.componentIndex)}),e.set(n,o)}},this),a},t.prototype._fillAutoTargetAxisByOrient=function(e,a){var n=this.ecModel,i=!0;if(i){var o=a==="vertical"?"y":"x",s=n.findComponents({mainType:o+"Axis"});l(s,o)}if(i){var s=n.findComponents({mainType:"singleAxis",filter:function(f){return f.get("orient",!0)===a}});l(s,"single")}function l(u,f){var v=u[0];if(v){var h=new Cd;if(h.add(v.componentIndex),e.set(f,h),i=!1,f==="x"||f==="y"){var c=v.getReferringComponents("grid",Kt).models[0];c&&A(u,function(p){v.componentIndex!==p.componentIndex&&c===p.getReferringComponents("grid",Kt).models[0]&&h.add(p.componentIndex)})}}}i&&A(ET,function(u){if(i){var f=n.findComponents({mainType:xn(u),filter:function(h){return h.get("type",!0)==="category"}});if(f[0]){var v=new Cd;v.add(f[0].componentIndex),e.set(u,v),i=!1}}},this)},t.prototype._makeAutoOrientByTargetAxis=function(){var e;return this.eachTargetAxis(function(a){!e&&(e=a)},this),e==="y"?"vertical":"horizontal"},t.prototype._setDefaultThrottle=function(e){if(e.hasOwnProperty("throttle")&&(this._autoThrottle=!1),this._autoThrottle){var a=this.ecModel.option;this.option.throttle=a.animation&&a.animationDurationUpdate>0?100:20}},t.prototype._updateRangeUse=function(e){var a=this._rangePropMode,n=this.get("rangeMode");A([["start","startValue"],["end","endValue"]],function(i,o){var s=e[i[0]]!=null,l=e[i[1]]!=null;s&&!l?a[o]="percent":!s&&l?a[o]="value":n?a[o]=n[o]:s&&(a[o]="percent")})},t.prototype.noTarget=function(){return this._noTarget},t.prototype.getFirstTargetAxisModel=function(){var e;return this.eachTargetAxis(function(a,n){e==null&&(e=this.ecModel.getComponent(xn(a),n))},this),e},t.prototype.eachTargetAxis=function(e,a){this._targetAxisInfoMap.each(function(n,i){A(n.indexList,function(o){e.call(a,i,o)})})},t.prototype.getAxisProxy=function(e,a){var n=this.getAxisModel(e,a);if(n)return n.__dzAxisProxy},t.prototype.getAxisModel=function(e,a){var n=this._targetAxisInfoMap.get(e);if(n&&n.indexMap[a])return this.ecModel.getComponent(xn(e),a)},t.prototype.setRawRange=function(e){var a=this.option,n=this.settledOption;A([["start","startValue"],["end","endValue"]],function(i){(e[i[0]]!=null||e[i[1]]!=null)&&(a[i[0]]=n[i[0]]=e[i[0]],a[i[1]]=n[i[1]]=e[i[1]])},this),this._updateRangeUse(e)},t.prototype.setCalculatedRange=function(e){var a=this.option;A(["start","startValue","end","endValue"],function(n){a[n]=e[n]})},t.prototype.getPercentRange=function(){var e=this.findRepresentativeAxisProxy();if(e)return e.getDataPercentWindow()},t.prototype.getValueRange=function(e,a){if(e==null&&a==null){var n=this.findRepresentativeAxisProxy();if(n)return n.getDataValueWindow()}else return this.getAxisProxy(e,a).getDataValueWindow()},t.prototype.findRepresentativeAxisProxy=function(e){if(e)return e.__dzAxisProxy;for(var a,n=this._targetAxisInfoMap.keys(),i=0;i<n.length;i++)for(var o=n[i],s=this._targetAxisInfoMap.get(o),l=0;l<s.indexList.length;l++){var u=this.getAxisProxy(o,s.indexList[l]);if(u.hostedBy(this))return u;a||(a=u)}return a},t.prototype.getRangePropMode=function(){return this._rangePropMode.slice()},t.prototype.getOrient=function(){return this._orient},t.type="dataZoom",t.dependencies=["xAxis","yAxis","radiusAxis","angleAxis","singleAxis","series","toolbox"],t.defaultOption={z:4,filterMode:"filter",start:0,end:100},t}(xt);function OT(r){var t={};return A(["start","end","startValue","endValue","throttle"],function(e){r.hasOwnProperty(e)&&(t[e]=r[e])}),t}var tZ=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="dataZoom.select",t}(du),d_=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n,i){this.dataZoomModel=e,this.ecModel=a,this.api=n},t.type="dataZoom",t}(Wt),eZ=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="dataZoom.select",t}(d_),Oo=A,NT=lr,rZ=function(){function r(t,e,a,n){this._dimName=t,this._axisIndex=e,this.ecModel=n,this._dataZoomModel=a}return r.prototype.hostedBy=function(t){return this._dataZoomModel===t},r.prototype.getDataValueWindow=function(){return this._valueWindow.slice()},r.prototype.getDataPercentWindow=function(){return this._percentWindow.slice()},r.prototype.getTargetSeriesModels=function(){var t=[];return this.ecModel.eachSeries(function(e){if(J7(e)){var a=xn(this._dimName),n=e.getReferringComponents(a,Kt).models[0];n&&this._axisIndex===n.componentIndex&&t.push(e)}},this),t},r.prototype.getAxisModel=function(){return this.ecModel.getComponent(this._dimName+"Axis",this._axisIndex)},r.prototype.getMinMaxSpan=function(){return et(this._minMaxSpan)},r.prototype.calculateDataWindow=function(t){var e=this._dataExtent,a=this.getAxisModel(),n=a.axis.scale,i=this._dataZoomModel.getRangePropMode(),o=[0,100],s=[],l=[],u;Oo(["start","end"],function(h,c){var p=t[h],d=t[h+"Value"];i[c]==="percent"?(p==null&&(p=o[c]),d=n.parse(Rt(p,o,e))):(u=!0,d=d==null?e[c]:n.parse(d),p=Rt(d,e,o)),l[c]=d==null||isNaN(d)?e[c]:d,s[c]=p==null||isNaN(p)?o[c]:p}),NT(l),NT(s);var f=this._minMaxSpan;u?v(l,s,e,o,!1):v(s,l,o,e,!0);function v(h,c,p,d,g){var y=g?"Span":"ValueSpan";kn(0,h,p,"all",f["min"+y],f["max"+y]);for(var m=0;m<2;m++)c[m]=Rt(h[m],p,d,!0),g&&(c[m]=n.parse(c[m]))}return{valueWindow:l,percentWindow:s}},r.prototype.reset=function(t){if(t===this._dataZoomModel){var e=this.getTargetSeriesModels();this._dataExtent=aZ(this,this._dimName,e),this._updateMinMaxSpan();var a=this.calculateDataWindow(t.settledOption);this._valueWindow=a.valueWindow,this._percentWindow=a.percentWindow,this._setAxisModel()}},r.prototype.filterData=function(t,e){if(t!==this._dataZoomModel)return;var a=this._dimName,n=this.getTargetSeriesModels(),i=t.get("filterMode"),o=this._valueWindow;if(i==="none")return;Oo(n,function(l){var u=l.getData(),f=u.mapDimensionsAll(a);if(f.length){if(i==="weakFilter"){var v=u.getStore(),h=U(f,function(c){return u.getDimensionIndex(c)},u);u.filterSelf(function(c){for(var p,d,g,y=0;y<f.length;y++){var m=v.get(h[y],c),_=!isNaN(m),S=m<o[0],x=m>o[1];if(_&&!S&&!x)return!0;_&&(g=!0),S&&(p=!0),x&&(d=!0)}return g&&p&&d})}else Oo(f,function(c){if(i==="empty")l.setData(u=u.map(c,function(d){return s(d)?d:NaN}));else{var p={};p[c]=o,u.selectRange(p)}});Oo(f,function(c){u.setApproximateExtent(o,c)})}});function s(l){return l>=o[0]&&l<=o[1]}},r.prototype._updateMinMaxSpan=function(){var t=this._minMaxSpan={},e=this._dataZoomModel,a=this._dataExtent;Oo(["min","max"],function(n){var i=e.get(n+"Span"),o=e.get(n+"ValueSpan");o!=null&&(o=this.getAxisModel().axis.scale.parse(o)),o!=null?i=Rt(a[0]+o,a,[0,100],!0):i!=null&&(o=Rt(i,[0,100],a,!0)-a[0]),t[n+"Span"]=i,t[n+"ValueSpan"]=o},this)},r.prototype._setAxisModel=function(){var t=this.getAxisModel(),e=this._percentWindow,a=this._valueWindow;if(e){var n=um(a,[0,500]);n=Math.min(n,20);var i=t.axis.scale.rawExtentInfo;e[0]!==0&&i.setDeterminedMinMax("min",+a[0].toFixed(n)),e[1]!==100&&i.setDeterminedMinMax("max",+a[1].toFixed(n)),i.freeze()}},r}();function aZ(r,t,e){var a=[1/0,-1/0];Oo(e,function(o){I5(a,o.getData(),t)});var n=r.getAxisModel(),i=GL(n.axis.scale,n,a).calculate();return[i.min,i.max]}var nZ={getTargetSeries:function(r){function t(n){r.eachComponent("dataZoom",function(i){i.eachTargetAxis(function(o,s){var l=r.getComponent(xn(o),s);n(o,s,l,i)})})}t(function(n,i,o,s){o.__dzAxisProxy=null});var e=[];t(function(n,i,o,s){o.__dzAxisProxy||(o.__dzAxisProxy=new rZ(n,i,s,r),e.push(o.__dzAxisProxy))});var a=j();return A(e,function(n){A(n.getTargetSeriesModels(),function(i){a.set(i.uid,i)})}),a},overallReset:function(r,t){r.eachComponent("dataZoom",function(e){e.eachTargetAxis(function(a,n){e.getAxisProxy(a,n).reset(e)}),e.eachTargetAxis(function(a,n){e.getAxisProxy(a,n).filterData(e,t)})}),r.eachComponent("dataZoom",function(e){var a=e.findRepresentativeAxisProxy();if(a){var n=a.getDataPercentWindow(),i=a.getDataValueWindow();e.setCalculatedRange({start:n[0],end:n[1],startValue:i[0],endValue:i[1]})}})}};function iZ(r){r.registerAction("dataZoom",function(t,e){var a=Q7(e,t);A(a,function(n){n.setRawRange({start:t.start,end:t.end,startValue:t.startValue,endValue:t.endValue})})})}var BT=!1;function g_(r){BT||(BT=!0,r.registerProcessor(r.PRIORITY.PROCESSOR.FILTER,nZ),iZ(r),r.registerSubTypeDefaulter("dataZoom",function(){return"slider"}))}function oZ(r){r.registerComponentModel(tZ),r.registerComponentView(eZ),g_(r)}var wr=function(){function r(){}return r}(),HP={};function No(r,t){HP[r]=t}function WP(r){return HP[r]}var sZ=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.optionUpdated=function(){r.prototype.optionUpdated.apply(this,arguments);var e=this.ecModel;A(this.option.feature,function(a,n){var i=WP(n);i&&(i.getDefaultOption&&(i.defaultOption=i.getDefaultOption(e)),yt(a,i.defaultOption))})},t.type="toolbox",t.layoutMode={type:"box",ignoreSize:!0},t.defaultOption={show:!0,z:6,orient:"horizontal",left:"right",top:"top",backgroundColor:"transparent",borderColor:N.color.border,borderRadius:0,borderWidth:0,padding:N.size.m,itemSize:15,itemGap:N.size.s,showTitle:!0,iconStyle:{borderColor:N.color.accent50,color:"none"},emphasis:{iconStyle:{borderColor:N.color.accent50}},tooltip:{show:!1,position:"bottom"}},t}(xt);function UP(r,t){var e=ws(t.get("padding")),a=t.getItemStyle(["color","opacity"]);a.fill=t.get("backgroundColor");var n=new _t({shape:{x:r.x-e[3],y:r.y-e[0],width:r.width+e[1]+e[3],height:r.height+e[0]+e[2],r:t.get("borderRadius")},style:a,silent:!0,z2:-1});return n}var lZ=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.render=function(e,a,n,i){var o=this.group;if(o.removeAll(),!e.get("show"))return;var s=+e.get("itemSize"),l=e.get("orient")==="vertical",u=e.get("feature")||{},f=this._features||(this._features={}),v=[];A(u,function(m,_){v.push(_)}),new qa(this._featureNames||[],v).add(h).update(h).remove(pt(h,null)).execute(),this._featureNames=v;function h(m,_){var S=v[m],x=v[_],b=u[S],w=new wt(b,e,e.ecModel),T;if(i&&i.newTitle!=null&&i.featureName===S&&(b.title=i.newTitle),S&&!x){if(uZ(S))T={onclick:w.option.onclick,featureName:S};else{var C=WP(S);if(!C)return;T=new C}f[S]=T}else if(T=f[x],!T)return;T.uid=bs("toolbox-feature"),T.model=w,T.ecModel=a,T.api=n;var M=T instanceof wr;if(!S&&x){M&&T.dispose&&T.dispose(a,n);return}if(!w.get("show")||M&&T.unusable){M&&T.remove&&T.remove(a,n);return}c(w,T,S),w.setIconStatus=function(D,I){var L=this.option,P=this.iconPaths;L.iconStatus=L.iconStatus||{},L.iconStatus[D]=I,P[D]&&(I==="emphasis"?Xa:$a)(P[D])},T instanceof wr&&T.render&&T.render(w,a,n,i)}function c(m,_,S){var x=m.getModel("iconStyle"),b=m.getModel(["emphasis","iconStyle"]),w=_ instanceof wr&&_.getIcons?_.getIcons():m.get("icon"),T=m.get("title")||{},C,M;X(w)?(C={},C[S]=w):C=w,X(T)?(M={},M[S]=T):M=T;var D=m.iconPaths={};A(C,function(I,L){var P=Ss(I,{},{x:-s/2,y:-s/2,width:s,height:s});P.setStyle(x.getItemStyle());var k=P.ensureState("emphasis");k.style=b.getItemStyle();var R=new At({style:{text:M[L],align:b.get("textAlign"),borderRadius:b.get("textBorderRadius"),padding:b.get("textPadding"),fill:null,font:Rm({fontStyle:b.get("textFontStyle"),fontFamily:b.get("textFontFamily"),fontSize:b.get("textFontSize"),fontWeight:b.get("textFontWeight")},a)},ignore:!0});P.setTextContent(R),en({el:P,componentModel:e,itemName:L,formatterParamsExtra:{title:M[L]}}),P.__title=M[L],P.on("mouseover",function(){var O=b.getItemStyle(),E=l?e.get("right")==null&&e.get("left")!=="right"?"right":"left":e.get("bottom")==null&&e.get("top")!=="bottom"?"bottom":"top";R.setStyle({fill:b.get("textFill")||O.fill||O.stroke||N.color.neutral99,backgroundColor:b.get("textBackgroundColor")}),P.setTextConfig({position:b.get("textPosition")||E}),R.ignore=!e.get("showTitle"),n.enterEmphasis(this)}).on("mouseout",function(){m.get(["iconStatus",L])!=="emphasis"&&n.leaveEmphasis(this),R.hide()}),(m.get(["iconStatus",L])==="emphasis"?Xa:$a)(P),o.add(P),P.on("click",$(_.onclick,_,a,n,L)),D[L]=P})}var p=pe(e,n).refContainer,d=e.getBoxLayoutParams(),g=e.get("padding"),y=Xt(d,p,g);Ei(e.get("orient"),o,e.get("itemGap"),y.width,y.height),Jh(o,d,p,g),o.add(UP(o.getBoundingRect(),e)),l||o.eachChild(function(m){var _=m.__title,S=m.ensureState("emphasis"),x=S.textConfig||(S.textConfig={}),b=m.getTextContent(),w=b&&b.ensureState("emphasis");if(w&&!tt(w)&&_){var T=w.style||(w.style={}),C=zh(_,At.makeFont(T)),M=m.x+o.x,D=m.y+o.y+s,I=!1;D+C.height>n.getHeight()&&(x.position="top",I=!0);var L=I?-5-C.height:s+10;M+C.width/2>n.getWidth()?(x.position=["100%",L],T.align="right"):M-C.width/2<0&&(x.position=[0,L],T.align="left")}})},t.prototype.updateView=function(e,a,n,i){A(this._features,function(o){o instanceof wr&&o.updateView&&o.updateView(o.model,a,n,i)})},t.prototype.remove=function(e,a){A(this._features,function(n){n instanceof wr&&n.remove&&n.remove(e,a)}),this.group.removeAll()},t.prototype.dispose=function(e,a){A(this._features,function(n){n instanceof wr&&n.dispose&&n.dispose(e,a)})},t.type="toolbox",t}(Wt);function uZ(r){return r.indexOf("my")===0}var fZ=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.onclick=function(e,a){var n=this.model,i=n.get("name")||e.get("title.0.text")||"echarts",o=a.getZr().painter.getType()==="svg",s=o?"svg":n.get("type",!0)||"png",l=a.getConnectedDataURL({type:s,backgroundColor:n.get("backgroundColor",!0)||e.get("backgroundColor")||N.color.neutral00,connectedBackgroundColor:n.get("connectedBackgroundColor"),excludeComponents:n.get("excludeComponents"),pixelRatio:n.get("pixelRatio")}),u=Tt.browser;if(typeof MouseEvent=="function"&&(u.newEdge||!u.ie&&!u.edge)){var f=document.createElement("a");f.download=i+"."+s,f.target="_blank",f.href=l;var v=new MouseEvent("click",{view:document.defaultView,bubbles:!0,cancelable:!1});f.dispatchEvent(v)}else if(window.navigator.msSaveOrOpenBlob||o){var h=l.split(","),c=h[0].indexOf("base64")>-1,p=o?decodeURIComponent(h[1]):h[1];c&&(p=window.atob(p));var d=i+"."+s;if(window.navigator.msSaveOrOpenBlob){for(var g=p.length,y=new Uint8Array(g);g--;)y[g]=p.charCodeAt(g);var m=new Blob([y]);window.navigator.msSaveOrOpenBlob(m,d)}else{var _=document.createElement("iframe");document.body.appendChild(_);var S=_.contentWindow,x=S.document;x.open("image/svg+xml","replace"),x.write(p),x.close(),S.focus(),x.execCommand("SaveAs",!0,d),document.body.removeChild(_)}}else{var b=n.get("lang"),w='<body style="margin:0;"><img src="'+l+'" style="max-width:100%;" title="'+(b&&b[0]||"")+'" /></body>',T=window.open();T.document.write(w),T.document.title=i}},t.getDefaultOption=function(e){var a={show:!0,icon:"M4.7,22.9L29.3,45.5L54.7,23.4M4.6,43.6L4.6,58L53.8,58L53.8,43.6M29.2,45.1L29.2,0",title:e.getLocaleModel().get(["toolbox","saveAsImage","title"]),type:"png",connectedBackgroundColor:N.color.neutral00,name:"",excludeComponents:["toolbox"],lang:e.getLocaleModel().get(["toolbox","saveAsImage","lang"])};return a},t}(wr),zT="__ec_magicType_stack__",vZ=[["line","bar"],["stack"]],hZ=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.getIcons=function(){var e=this.model,a=e.get("icon"),n={};return A(e.get("type"),function(i){a[i]&&(n[i]=a[i])}),n},t.getDefaultOption=function(e){var a={show:!0,type:[],icon:{line:"M4.1,28.9h7.1l9.3-22l7.4,38l9.7-19.7l3,12.8h14.9M4.1,58h51.4",bar:"M6.7,22.9h10V48h-10V22.9zM24.9,13h10v35h-10V13zM43.2,2h10v46h-10V2zM3.1,58h53.7",stack:"M8.2,38.4l-8.4,4.1l30.6,15.3L60,42.5l-8.1-4.1l-21.5,11L8.2,38.4z M51.9,30l-8.1,4.2l-13.4,6.9l-13.9-6.9L8.2,30l-8.4,4.2l8.4,4.2l22.2,11l21.5-11l8.1-4.2L51.9,30z M51.9,21.7l-8.1,4.2L35.7,30l-5.3,2.8L24.9,30l-8.4-4.1l-8.3-4.2l-8.4,4.2L8.2,30l8.3,4.2l13.9,6.9l13.4-6.9l8.1-4.2l8.1-4.1L51.9,21.7zM30.4,2.2L-0.2,17.5l8.4,4.1l8.3,4.2l8.4,4.2l5.5,2.7l5.3-2.7l8.1-4.2l8.1-4.2l8.1-4.1L30.4,2.2z"},title:e.getLocaleModel().get(["toolbox","magicType","title"]),option:{},seriesIndex:{}};return a},t.prototype.onclick=function(e,a,n){var i=this.model,o=i.get(["seriesIndex",n]);if(VT[n]){var s={series:[]},l=function(v){var h=v.subType,c=v.id,p=VT[n](h,c,v,i);p&&(nt(p,v.option),s.series.push(p));var d=v.coordinateSystem;if(d&&d.type==="cartesian2d"&&(n==="line"||n==="bar")){var g=d.getAxesByScale("ordinal")[0];if(g){var y=g.dim,m=y+"Axis",_=v.getReferringComponents(m,Kt).models[0],S=_.componentIndex;s[m]=s[m]||[];for(var x=0;x<=S;x++)s[m][S]=s[m][S]||{};s[m][S].boundaryGap=n==="bar"}}};A(vZ,function(v){gt(v,n)>=0&&A(v,function(h){i.setIconStatus(h,"normal")})}),i.setIconStatus(n,"emphasis"),e.eachComponent({mainType:"series",query:o==null?null:{seriesIndex:o}},l);var u,f=n;n==="stack"&&(u=yt({stack:i.option.title.tiled,tiled:i.option.title.stack},i.option.title),i.get(["iconStatus",n])!=="emphasis"&&(f="tiled")),a.dispatchAction({type:"changeMagicType",currentType:f,newOption:s,newTitle:u,featureName:"magicType"})}},t}(wr),VT={line:function(r,t,e,a){if(r==="bar")return yt({id:t,type:"line",data:e.get("data"),stack:e.get("stack"),markPoint:e.get("markPoint"),markLine:e.get("markLine")},a.get(["option","line"])||{},!0)},bar:function(r,t,e,a){if(r==="line")return yt({id:t,type:"bar",data:e.get("data"),stack:e.get("stack"),markPoint:e.get("markPoint"),markLine:e.get("markLine")},a.get(["option","bar"])||{},!0)},stack:function(r,t,e,a){var n=e.get("stack")===zT;if(r==="line"||r==="bar")return a.setIconStatus("stack",n?"normal":"emphasis"),yt({id:t,stack:n?"":zT},a.get(["option","stack"])||{},!0)}};Ta({type:"changeMagicType",event:"magicTypeChanged",update:"prepareAndUpdate"},function(r,t){t.mergeOption(r.newOption)});var cc=new Array(60).join("-"),hs="	";function cZ(r){var t={},e=[],a=[];return r.eachRawSeries(function(n){var i=n.coordinateSystem;if(i&&(i.type==="cartesian2d"||i.type==="polar")){var o=i.getBaseAxis();if(o.type==="category"){var s=o.dim+"_"+o.index;t[s]||(t[s]={categoryAxis:o,valueAxis:i.getOtherAxis(o),series:[]},a.push({axisDim:o.dim,axisIndex:o.index})),t[s].series.push(n)}else e.push(n)}else e.push(n)}),{seriesGroupByCategoryAxis:t,other:e,meta:a}}function pZ(r){var t=[];return A(r,function(e,a){var n=e.categoryAxis,i=e.valueAxis,o=i.dim,s=[" "].concat(U(e.series,function(c){return c.name})),l=[n.model.getCategories()];A(e.series,function(c){var p=c.getRawData();l.push(c.getRawData().mapArray(p.mapDimension(o),function(d){return d}))});for(var u=[s.join(hs)],f=0;f<l[0].length;f++){for(var v=[],h=0;h<l.length;h++)v.push(l[h][f]);u.push(v.join(hs))}t.push(u.join(`
`))}),t.join(`

`+cc+`

`)}function dZ(r){return U(r,function(t){var e=t.getRawData(),a=[t.name],n=[];return e.each(e.dimensions,function(){for(var i=arguments.length,o=arguments[i-1],s=e.getName(o),l=0;l<i-1;l++)n[l]=arguments[l];a.push((s?s+hs:"")+n.join(hs))}),a.join(`
`)}).join(`

`+cc+`

`)}function gZ(r){var t=cZ(r);return{value:Pt([pZ(t.seriesGroupByCategoryAxis),dZ(t.other)],function(e){return!!e.replace(/[\n\t\s]/g,"")}).join(`

`+cc+`

`),meta:t.meta}}function bh(r){return r.replace(/^\s\s*/,"").replace(/\s\s*$/,"")}function yZ(r){var t=r.slice(0,r.indexOf(`
`));if(t.indexOf(hs)>=0)return!0}var Ny=new RegExp("["+hs+"]+","g");function mZ(r){for(var t=r.split(/\n+/g),e=bh(t.shift()).split(Ny),a=[],n=U(e,function(l){return{name:l,data:[]}}),i=0;i<t.length;i++){var o=bh(t[i]).split(Ny);a.push(o.shift());for(var s=0;s<o.length;s++)n[s]&&(n[s].data[i]=o[s])}return{series:n,categories:a}}function _Z(r){for(var t=r.split(/\n+/g),e=bh(t.shift()),a=[],n=0;n<t.length;n++){var i=bh(t[n]);if(i){var o=i.split(Ny),s="",l=void 0,u=!1;isNaN(o[0])?(u=!0,s=o[0],o=o.slice(1),a[n]={name:s,value:[]},l=a[n].value):l=a[n]=[];for(var f=0;f<o.length;f++)l.push(+o[f]);l.length===1&&(u?a[n].value=l[0]:a[n]=l[0])}}return{name:e,data:a}}function SZ(r,t){var e=r.split(new RegExp(`
*`+cc+`
*`,"g")),a={series:[]};return A(e,function(n,i){if(yZ(n)){var o=mZ(n),s=t[i],l=s.axisDim+"Axis";s&&(a[l]=a[l]||[],a[l][s.axisIndex]={data:o.categories},a.series=a.series.concat(o.series))}else{var o=_Z(n);a.series.push(o)}}),a}var xZ=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.onclick=function(e,a){setTimeout(function(){a.dispatchAction({type:"hideTip"})});var n=a.getDom(),i=this.model;this._dom&&n.removeChild(this._dom);var o=document.createElement("div");o.style.cssText="position:absolute;top:0;bottom:0;left:0;right:0;padding:5px",o.style.backgroundColor=i.get("backgroundColor")||N.color.neutral00;var s=document.createElement("h4"),l=i.get("lang")||[];s.innerHTML=l[0]||i.get("title"),s.style.cssText="margin:10px 20px",s.style.color=i.get("textColor");var u=document.createElement("div"),f=document.createElement("textarea");u.style.cssText="overflow:auto";var v=i.get("optionToContent"),h=i.get("contentToOption"),c=gZ(e);if(tt(v)){var p=v(a.getOption());X(p)?u.innerHTML=p:zi(p)&&u.appendChild(p)}else{f.readOnly=i.get("readOnly");var d=f.style;d.cssText="display:block;width:100%;height:100%;font-family:monospace;font-size:14px;line-height:1.6rem;resize:none;box-sizing:border-box;outline:none",d.color=i.get("textColor"),d.borderColor=i.get("textareaBorderColor"),d.backgroundColor=i.get("textareaColor"),f.value=c.value,u.appendChild(f)}var g=c.meta,y=document.createElement("div");y.style.cssText="position:absolute;bottom:5px;left:0;right:0";var m="float:right;margin-right:20px;border:none;cursor:pointer;padding:2px 5px;font-size:12px;border-radius:3px",_=document.createElement("div"),S=document.createElement("div");m+=";background-color:"+i.get("buttonColor"),m+=";color:"+i.get("buttonTextColor");var x=this;function b(){n.removeChild(o),x._dom=null}Xd(_,"click",b),Xd(S,"click",function(){if(h==null&&v!=null||h!=null&&v==null){b();return}var w;try{tt(h)?w=h(u,a.getOption()):w=SZ(f.value,g)}catch(T){throw b(),new Error("Data view format error "+T)}w&&a.dispatchAction({type:"changeDataView",newOption:w}),b()}),_.innerHTML=l[1],S.innerHTML=l[2],S.style.cssText=_.style.cssText=m,!i.get("readOnly")&&y.appendChild(S),y.appendChild(_),o.appendChild(s),o.appendChild(u),o.appendChild(y),u.style.height=n.clientHeight-80+"px",n.appendChild(o),this._dom=o},t.prototype.remove=function(e,a){this._dom&&a.getDom().removeChild(this._dom)},t.prototype.dispose=function(e,a){this.remove(e,a)},t.getDefaultOption=function(e){var a={show:!0,readOnly:!1,optionToContent:null,contentToOption:null,icon:"M17.5,17.3H33 M17.5,17.3H33 M45.4,29.5h-28 M11.5,2v56H51V14.8L38.4,2H11.5z M38.4,2.2v12.7H51 M45.4,41.7h-28",title:e.getLocaleModel().get(["toolbox","dataView","title"]),lang:e.getLocaleModel().get(["toolbox","dataView","lang"]),backgroundColor:N.color.background,textColor:N.color.primary,textareaColor:N.color.background,textareaBorderColor:N.color.border,buttonColor:N.color.accent50,buttonTextColor:N.color.neutral00};return a},t}(wr);function bZ(r,t){return U(r,function(e,a){var n=t&&t[a];if(it(n)&&!W(n)){var i=it(e)&&!W(e);i||(e={value:e});var o=n.name!=null&&e.name==null;return e=nt(e,n),o&&delete e.name,e}else return e})}Ta({type:"changeDataView",event:"dataViewChanged",update:"prepareAndUpdate"},function(r,t){var e=[];A(r.newOption.series,function(a){var n=t.getSeriesByName(a.name)[0];if(!n)e.push(G({type:"scatter"},a));else{var i=n.get("data");e.push({name:a.name,data:bZ(a.data,i)})}}),t.mergeOption(nt({series:e},r.newOption))});var YP=A,ZP=St();function wZ(r,t){var e=y_(r);YP(t,function(a,n){for(var i=e.length-1;i>=0;i--){var o=e[i];if(o[n])break}if(i<0){var s=r.queryComponents({mainType:"dataZoom",subType:"select",id:n})[0];if(s){var l=s.getPercentRange();e[0][n]={dataZoomId:n,start:l[0],end:l[1]}}}}),e.push(t)}function TZ(r){var t=y_(r),e=t[t.length-1];t.length>1&&t.pop();var a={};return YP(e,function(n,i){for(var o=t.length-1;o>=0;o--)if(n=t[o][i],n){a[i]=n;break}}),a}function CZ(r){ZP(r).snapshots=null}function AZ(r){return y_(r).length}function y_(r){var t=ZP(r);return t.snapshots||(t.snapshots=[{}]),t.snapshots}var MZ=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.onclick=function(e,a){CZ(e),a.dispatchAction({type:"restore",from:this.uid})},t.getDefaultOption=function(e){var a={show:!0,icon:"M3.8,33.4 M47,18.9h9.8V8.7 M56.3,20.1 C52.1,9,40.5,0.6,26.8,2.1C12.6,3.7,1.6,16.2,2.1,30.6 M13,41.1H3.1v10.2 M3.7,39.9c4.2,11.1,15.8,19.5,29.5,18 c14.2-1.6,25.2-14.1,24.7-28.5",title:e.getLocaleModel().get(["toolbox","restore","title"])};return a},t}(wr);Ta({type:"restore",event:"restore",update:"prepareAndUpdate"},function(r,t){t.resetOption("recreate")});var DZ=["grid","xAxis","yAxis","geo","graph","polar","radiusAxis","angleAxis","bmap"],m_=function(){function r(t,e,a){var n=this;this._targetInfoList=[];var i=GT(e,t);A(LZ,function(o,s){(!a||!a.include||gt(a.include,s)>=0)&&o(i,n._targetInfoList)})}return r.prototype.setOutputRanges=function(t,e){return this.matchOutputRanges(t,e,function(a,n,i){if((a.coordRanges||(a.coordRanges=[])).push(n),!a.coordRange){a.coordRange=n;var o=Ad[a.brushType](0,i,n);a.__rangeOffset={offset:UT[a.brushType](o.values,a.range,[1,1]),xyMinMax:o.xyMinMax}}}),t},r.prototype.matchOutputRanges=function(t,e,a){A(t,function(n){var i=this.findTargetInfo(n,e);i&&i!==!0&&A(i.coordSyses,function(o){var s=Ad[n.brushType](1,o,n.range,!0);a(n,s.values,o,e)})},this)},r.prototype.setInputRanges=function(t,e){A(t,function(a){var n=this.findTargetInfo(a,e);if(a.range=a.range||[],n&&n!==!0){a.panelId=n.panelId;var i=Ad[a.brushType](0,n.coordSys,a.coordRange),o=a.__rangeOffset;a.range=o?UT[a.brushType](i.values,o.offset,IZ(i.xyMinMax,o.xyMinMax)):i.values}},this)},r.prototype.makePanelOpts=function(t,e){return U(this._targetInfoList,function(a){var n=a.getPanelRect();return{panelId:a.panelId,defaultBrushType:e?e(a):null,clipPath:jI(n),isTargetByCursor:QI(n,t,a.coordSysModel),getLinearBrushOtherExtent:JI(n)}})},r.prototype.controlSeries=function(t,e,a){var n=this.findTargetInfo(t,a);return n===!0||n&&gt(n.coordSyses,e.coordinateSystem)>=0},r.prototype.findTargetInfo=function(t,e){for(var a=this._targetInfoList,n=GT(e,t),i=0;i<a.length;i++){var o=a[i],s=t.panelId;if(s){if(o.panelId===s)return o}else for(var l=0;l<FT.length;l++)if(FT[l](n,o))return o}return!0},r}();function By(r){return r[0]>r[1]&&r.reverse(),r}function GT(r,t){return Zo(r,t,{includeMainTypes:DZ})}var LZ={grid:function(r,t){var e=r.xAxisModels,a=r.yAxisModels,n=r.gridModels,i=j(),o={},s={};!e&&!a&&!n||(A(e,function(l){var u=l.axis.grid.model;i.set(u.id,u),o[u.id]=!0}),A(a,function(l){var u=l.axis.grid.model;i.set(u.id,u),s[u.id]=!0}),A(n,function(l){i.set(l.id,l),o[l.id]=!0,s[l.id]=!0}),i.each(function(l){var u=l.coordinateSystem,f=[];A(u.getCartesians(),function(v,h){(gt(e,v.getAxis("x").model)>=0||gt(a,v.getAxis("y").model)>=0)&&f.push(v)}),t.push({panelId:"grid--"+l.id,gridModel:l,coordSysModel:l,coordSys:f[0],coordSyses:f,getPanelRect:HT.grid,xAxisDeclared:o[l.id],yAxisDeclared:s[l.id]})}))},geo:function(r,t){A(r.geoModels,function(e){var a=e.coordinateSystem;t.push({panelId:"geo--"+e.id,geoModel:e,coordSysModel:e,coordSys:a,coordSyses:[a],getPanelRect:HT.geo})})}},FT=[function(r,t){var e=r.xAxisModel,a=r.yAxisModel,n=r.gridModel;return!n&&e&&(n=e.axis.grid.model),!n&&a&&(n=a.axis.grid.model),n&&n===t.gridModel},function(r,t){var e=r.geoModel;return e&&e===t.geoModel}],HT={grid:function(){return this.coordSys.master.getRect().clone()},geo:function(){var r=this.coordSys,t=r.getBoundingRect().clone();return t.applyTransform(An(r)),t}},Ad={lineX:pt(WT,0),lineY:pt(WT,1),rect:function(r,t,e,a){var n=r?t.pointToData([e[0][0],e[1][0]],a):t.dataToPoint([e[0][0],e[1][0]],a),i=r?t.pointToData([e[0][1],e[1][1]],a):t.dataToPoint([e[0][1],e[1][1]],a),o=[By([n[0],i[0]]),By([n[1],i[1]])];return{values:o,xyMinMax:o}},polygon:function(r,t,e,a){var n=[[1/0,-1/0],[1/0,-1/0]],i=U(e,function(o){var s=r?t.pointToData(o,a):t.dataToPoint(o,a);return n[0][0]=Math.min(n[0][0],s[0]),n[1][0]=Math.min(n[1][0],s[1]),n[0][1]=Math.max(n[0][1],s[0]),n[1][1]=Math.max(n[1][1],s[1]),s});return{values:i,xyMinMax:n}}};function WT(r,t,e,a){var n=e.getAxis(["x","y"][r]),i=By(U([0,1],function(s){return t?n.coordToData(n.toLocalCoord(a[s]),!0):n.toGlobalCoord(n.dataToCoord(a[s]))})),o=[];return o[r]=i,o[1-r]=[NaN,NaN],{values:i,xyMinMax:o}}var UT={lineX:pt(YT,0),lineY:pt(YT,1),rect:function(r,t,e){return[[r[0][0]-e[0]*t[0][0],r[0][1]-e[0]*t[0][1]],[r[1][0]-e[1]*t[1][0],r[1][1]-e[1]*t[1][1]]]},polygon:function(r,t,e){return U(r,function(a,n){return[a[0]-e[0]*t[n][0],a[1]-e[1]*t[n][1]]})}};function YT(r,t,e,a){return[t[0]-a[r]*e[0],t[1]-a[r]*e[1]]}function IZ(r,t){var e=ZT(r),a=ZT(t),n=[e[0]/a[0],e[1]/a[1]];return isNaN(n[0])&&(n[0]=1),isNaN(n[1])&&(n[1]=1),n}function ZT(r){return r?[r[0][1]-r[0][0],r[1][1]-r[1][0]]:[NaN,NaN]}var zy=A,PZ=CE("toolbox-dataZoom_"),RZ=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.render=function(e,a,n,i){this._brushController||(this._brushController=new W0(n.getZr()),this._brushController.on("brush",$(this._onBrush,this)).mount()),OZ(e,a,this,i,n),EZ(e,a)},t.prototype.onclick=function(e,a,n){kZ[n].call(this)},t.prototype.remove=function(e,a){this._brushController&&this._brushController.unmount()},t.prototype.dispose=function(e,a){this._brushController&&this._brushController.dispose()},t.prototype._onBrush=function(e){var a=e.areas;if(!e.isEnd||!a.length)return;var n={},i=this.ecModel;this._brushController.updateCovers([]);var o=new m_(__(this.model),i,{include:["grid"]});o.matchOutputRanges(a,i,function(u,f,v){if(v.type==="cartesian2d"){var h=u.brushType;h==="rect"?(s("x",v,f[0]),s("y",v,f[1])):s({lineX:"x",lineY:"y"}[h],v,f)}}),wZ(i,n),this._dispatchZoomAction(n);function s(u,f,v){var h=f.getAxis(u),c=h.model,p=l(u,c,i),d=p.findRepresentativeAxisProxy(c).getMinMaxSpan();(d.minValueSpan!=null||d.maxValueSpan!=null)&&(v=kn(0,v.slice(),h.scale.getExtent(),0,d.minValueSpan,d.maxValueSpan)),p&&(n[p.id]={dataZoomId:p.id,startValue:v[0],endValue:v[1]})}function l(u,f,v){var h;return v.eachComponent({mainType:"dataZoom",subType:"select"},function(c){var p=c.getAxisModel(u,f.componentIndex);p&&(h=c)}),h}},t.prototype._dispatchZoomAction=function(e){var a=[];zy(e,function(n,i){a.push(et(n))}),a.length&&this.api.dispatchAction({type:"dataZoom",from:this.uid,batch:a})},t.getDefaultOption=function(e){var a={show:!0,filterMode:"filter",icon:{zoom:"M0,13.5h26.9 M13.5,26.9V0 M32.1,13.5H58V58H13.5 V32.1",back:"M22,1.4L9.9,13.5l12.3,12.3 M10.3,13.5H54.9v44.6 H10.3v-26"},title:e.getLocaleModel().get(["toolbox","dataZoom","title"]),brushStyle:{borderWidth:0,color:N.color.backgroundTint}};return a},t}(wr),kZ={zoom:function(){var r=!this._isZoomActive;this.api.dispatchAction({type:"takeGlobalCursor",key:"dataZoomSelect",dataZoomSelectActive:r})},back:function(){this._dispatchZoomAction(TZ(this.ecModel))}};function __(r){var t={xAxisIndex:r.get("xAxisIndex",!0),yAxisIndex:r.get("yAxisIndex",!0),xAxisId:r.get("xAxisId",!0),yAxisId:r.get("yAxisId",!0)};return t.xAxisIndex==null&&t.xAxisId==null&&(t.xAxisIndex="all"),t.yAxisIndex==null&&t.yAxisId==null&&(t.yAxisIndex="all"),t}function EZ(r,t){r.setIconStatus("back",AZ(t)>1?"emphasis":"normal")}function OZ(r,t,e,a,n){var i=e._isZoomActive;a&&a.type==="takeGlobalCursor"&&(i=a.key==="dataZoomSelect"?a.dataZoomSelectActive:!1),e._isZoomActive=i,r.setIconStatus("zoom",i?"emphasis":"normal");var o=new m_(__(r),t,{include:["grid"]}),s=o.makePanelOpts(n,function(l){return l.xAxisDeclared&&!l.yAxisDeclared?"lineX":!l.xAxisDeclared&&l.yAxisDeclared?"lineY":"rect"});e._brushController.setPanels(s).enableBrush(i&&s.length?{brushType:"auto",brushStyle:r.getModel("brushStyle").getItemStyle()}:!1)}oB("dataZoom",function(r){var t=r.getComponent("toolbox",0),e=["feature","dataZoom"];if(!t||t.get(e)==null)return;var a=t.getModel(e),n=[],i=__(a),o=Zo(r,i);zy(o.xAxisModels,function(l){return s(l,"xAxis","xAxisIndex")}),zy(o.yAxisModels,function(l){return s(l,"yAxis","yAxisIndex")});function s(l,u,f){var v=l.componentIndex,h={type:"select",$fromToolbox:!0,filterMode:a.get("filterMode",!0)||"filter",id:PZ+u+v};h[f]=v,n.push(h)}return n});function NZ(r){r.registerComponentModel(sZ),r.registerComponentView(lZ),No("saveAsImage",fZ),No("magicType",hZ),No("dataView",xZ),No("dataZoom",RZ),No("restore",MZ),mt(oZ)}var BZ=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="tooltip",t.dependencies=["axisPointer"],t.defaultOption={z:60,show:!0,showContent:!0,trigger:"item",triggerOn:"mousemove|click",alwaysShowContent:!1,renderMode:"auto",confine:null,showDelay:0,hideDelay:100,transitionDuration:.4,displayTransition:!0,enterable:!1,backgroundColor:N.color.neutral00,shadowBlur:10,shadowColor:"rgba(0, 0, 0, .2)",shadowOffsetX:1,shadowOffsetY:2,borderRadius:4,borderWidth:1,defaultBorderColor:N.color.border,padding:null,extraCssText:"",axisPointer:{type:"line",axis:"auto",animation:"auto",animationDurationUpdate:200,animationEasingUpdate:"exponentialOut",crossStyle:{color:N.color.borderShade,width:1,type:"dashed",textStyle:{}}},textStyle:{color:N.color.tertiary,fontSize:14}},t}(xt);function XP(r){var t=r.get("confine");return t!=null?!!t:r.get("renderMode")==="richText"}function $P(r){if(Tt.domSupported){for(var t=document.documentElement.style,e=0,a=r.length;e<a;e++)if(r[e]in t)return r[e]}}var qP=$P(["transform","webkitTransform","OTransform","MozTransform","msTransform"]),zZ=$P(["webkitTransition","transition","OTransition","MozTransition","msTransition"]);function KP(r,t){if(!r)return t;t=Um(t,!0);var e=r.indexOf(t);return r=e===-1?t:"-"+r.slice(0,e)+"-"+t,r.toLowerCase()}function VZ(r,t){var e=r.currentStyle||document.defaultView&&document.defaultView.getComputedStyle(r);return e?e[t]:null}var GZ=KP(zZ,"transition"),S_=KP(qP,"transform"),FZ="position:absolute;display:block;border-style:solid;white-space:nowrap;z-index:9999999;"+(Tt.transform3dSupported?"will-change:transform;":"");function HZ(r){return r=r==="left"?"right":r==="right"?"left":r==="top"?"bottom":"top",r}function WZ(r,t,e){if(!X(e)||e==="inside")return"";var a=r.get("backgroundColor"),n=r.get("borderWidth");t=Yi(t);var i=HZ(e),o=Math.max(Math.round(n)*1.5,6),s="",l=S_+":",u;gt(["left","right"],i)>-1?(s+="top:50%",l+="translateY(-50%) rotate("+(u=i==="left"?-225:-45)+"deg)"):(s+="left:50%",l+="translateX(-50%) rotate("+(u=i==="top"?225:45)+"deg)");var f=u*Math.PI/180,v=o+n,h=v*Math.abs(Math.cos(f))+v*Math.abs(Math.sin(f)),c=Math.round(((h-Math.SQRT2*n)/2+Math.SQRT2*n-(h-v)/2)*100)/100;s+=";"+i+":-"+c+"px";var p=t+" solid "+n+"px;",d=["position:absolute;width:"+o+"px;height:"+o+"px;z-index:-1;",s+";"+l+";","border-bottom:"+p,"border-right:"+p,"background-color:"+a+";"];return'<div style="'+d.join("")+'"></div>'}function UZ(r,t,e){var a="cubic-bezier(0.23,1,0.32,1)",n="",i="";return e&&(n=" "+r/2+"s "+a,i="opacity"+n+",visibility"+n),t||(n=" "+r+"s "+a,i+=(i.length?",":"")+(Tt.transformSupported?""+S_+n:",left"+n+",top"+n)),GZ+":"+i}function XT(r,t,e){var a=r.toFixed(0)+"px",n=t.toFixed(0)+"px";if(!Tt.transformSupported)return e?"top:"+n+";left:"+a+";":[["top",n],["left",a]];var i=Tt.transform3dSupported,o="translate"+(i?"3d":"")+"("+a+","+n+(i?",0":"")+")";return e?"top:0;left:0;"+S_+":"+o+";":[["top",0],["left",0],[qP,o]]}function YZ(r){var t=[],e=r.get("fontSize"),a=r.getTextColor();a&&t.push("color:"+a),t.push("font:"+r.getFont());var n=Q(r.get("lineHeight"),Math.round(e*3/2));e&&t.push("line-height:"+n+"px");var i=r.get("textShadowColor"),o=r.get("textShadowBlur")||0,s=r.get("textShadowOffsetX")||0,l=r.get("textShadowOffsetY")||0;return i&&o&&t.push("text-shadow:"+s+"px "+l+"px "+o+"px "+i),A(["decoration","align"],function(u){var f=r.get(u);f&&t.push("text-"+u+":"+f)}),t.join(";")}function ZZ(r,t,e,a){var n=[],i=r.get("transitionDuration"),o=r.get("backgroundColor"),s=r.get("shadowBlur"),l=r.get("shadowColor"),u=r.get("shadowOffsetX"),f=r.get("shadowOffsetY"),v=r.getModel("textStyle"),h=GD(r,"html"),c=u+"px "+f+"px "+s+"px "+l;return n.push("box-shadow:"+c),t&&i>0&&n.push(UZ(i,e,a)),o&&n.push("background-color:"+o),A(["width","color","radius"],function(p){var d="border-"+p,g=Um(d),y=r.get(g);y!=null&&n.push(d+":"+y+(p==="color"?"":"px"))}),n.push(YZ(v)),h!=null&&n.push("padding:"+ws(h).join("px ")+"px"),n.join(";")+";"}function $T(r,t,e,a,n){var i=t&&t.painter;if(e){var o=i&&i.getViewportRoot();o&&XR(r,o,e,a,n)}else{r[0]=a,r[1]=n;var s=i&&i.getViewportRootOffset();s&&(r[0]+=s.offsetLeft,r[1]+=s.offsetTop)}r[2]=r[0]/t.getWidth(),r[3]=r[1]/t.getHeight()}var XZ=function(){function r(t,e){if(this._show=!1,this._styleCoord=[0,0,0,0],this._enterable=!0,this._alwaysShowContent=!1,this._firstShow=!0,this._longHide=!0,Tt.wxa)return null;var a=document.createElement("div");a.domBelongToZr=!0,this.el=a;var n=this._zr=t.getZr(),i=e.appendTo,o=i&&(X(i)?document.querySelector(i):zi(i)?i:tt(i)&&i(t.getDom()));$T(this._styleCoord,n,o,t.getWidth()/2,t.getHeight()/2),(o||t.getDom()).appendChild(a),this._api=t,this._container=o;var s=this;a.onmouseenter=function(){s._enterable&&(clearTimeout(s._hideTimeout),s._show=!0),s._inContent=!0},a.onmousemove=function(l){if(l=l||window.event,!s._enterable){var u=n.handler,f=n.painter.getViewportRoot();mr(f,l,!0),u.dispatch("mousemove",l)}},a.onmouseleave=function(){s._inContent=!1,s._enterable&&s._show&&s.hideLater(s._hideDelay)}}return r.prototype.update=function(t){if(!this._container){var e=this._api.getDom(),a=VZ(e,"position"),n=e.style;n.position!=="absolute"&&a!=="absolute"&&(n.position="relative")}var i=t.get("alwaysShowContent");i&&this._moveIfResized(),this._alwaysShowContent=i,this._enableDisplayTransition=t.get("displayTransition")&&t.get("transitionDuration")>0,this.el.className=t.get("className")||""},r.prototype.show=function(t,e){clearTimeout(this._hideTimeout),clearTimeout(this._longHideTimeout);var a=this.el,n=a.style,i=this._styleCoord;a.innerHTML?n.cssText=FZ+ZZ(t,!this._firstShow,this._longHide,this._enableDisplayTransition)+XT(i[0],i[1],!0)+("border-color:"+Yi(e)+";")+(t.get("extraCssText")||"")+(";pointer-events:"+(this._enterable?"auto":"none")):n.display="none",this._show=!0,this._firstShow=!1,this._longHide=!1},r.prototype.setContent=function(t,e,a,n,i){var o=this.el;if(t==null){o.innerHTML="";return}var s="";if(X(i)&&a.get("trigger")==="item"&&!XP(a)&&(s=WZ(a,n,i)),X(t))o.innerHTML=t+s;else if(t){o.innerHTML="",W(t)||(t=[t]);for(var l=0;l<t.length;l++)zi(t[l])&&t[l].parentNode!==o&&o.appendChild(t[l]);if(s&&o.childNodes.length){var u=document.createElement("div");u.innerHTML=s,o.appendChild(u)}}},r.prototype.setEnterable=function(t){this._enterable=t},r.prototype.getSize=function(){var t=this.el;return t?[t.offsetWidth,t.offsetHeight]:[0,0]},r.prototype.moveTo=function(t,e){if(this.el){var a=this._styleCoord;if($T(a,this._zr,this._container,t,e),a[0]!=null&&a[1]!=null){var n=this.el.style,i=XT(a[0],a[1]);A(i,function(o){n[o[0]]=o[1]})}}},r.prototype._moveIfResized=function(){var t=this._styleCoord[2],e=this._styleCoord[3];this.moveTo(t*this._zr.getWidth(),e*this._zr.getHeight())},r.prototype.hide=function(){var t=this,e=this.el.style;this._enableDisplayTransition?(e.visibility="hidden",e.opacity="0"):e.display="none",Tt.transform3dSupported&&(e.willChange=""),this._show=!1,this._longHideTimeout=setTimeout(function(){return t._longHide=!0},500)},r.prototype.hideLater=function(t){this._show&&!(this._inContent&&this._enterable)&&!this._alwaysShowContent&&(t?(this._hideDelay=t,this._show=!1,this._hideTimeout=setTimeout($(this.hide,this),t)):this.hide())},r.prototype.isShow=function(){return this._show},r.prototype.dispose=function(){clearTimeout(this._hideTimeout),clearTimeout(this._longHideTimeout);var t=this._zr;$R(t&&t.painter&&t.painter.getViewportRoot(),this._container);var e=this.el;if(e){e.onmouseenter=e.onmousemove=e.onmouseleave=null;var a=e.parentNode;a&&a.removeChild(e)}this.el=this._container=null},r}(),$Z=function(){function r(t){this._show=!1,this._styleCoord=[0,0,0,0],this._alwaysShowContent=!1,this._enterable=!0,this._zr=t.getZr(),KT(this._styleCoord,this._zr,t.getWidth()/2,t.getHeight()/2)}return r.prototype.update=function(t){var e=t.get("alwaysShowContent");e&&this._moveIfResized(),this._alwaysShowContent=e},r.prototype.show=function(){this._hideTimeout&&clearTimeout(this._hideTimeout),this.el.show(),this._show=!0},r.prototype.setContent=function(t,e,a,n,i){var o=this;it(t)&&kt(""),this.el&&this._zr.remove(this.el);var s=a.getModel("textStyle");this.el=new At({style:{rich:e.richTextStyles,text:t,lineHeight:22,borderWidth:1,borderColor:n,textShadowColor:s.get("textShadowColor"),fill:a.get(["textStyle","color"]),padding:GD(a,"richText"),verticalAlign:"top",align:"left"},z:a.get("z")}),A(["backgroundColor","borderRadius","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"],function(u){o.el.style[u]=a.get(u)}),A(["textShadowBlur","textShadowOffsetX","textShadowOffsetY"],function(u){o.el.style[u]=s.get(u)||0}),this._zr.add(this.el);var l=this;this.el.on("mouseover",function(){l._enterable&&(clearTimeout(l._hideTimeout),l._show=!0),l._inContent=!0}),this.el.on("mouseout",function(){l._enterable&&l._show&&l.hideLater(l._hideDelay),l._inContent=!1})},r.prototype.setEnterable=function(t){this._enterable=t},r.prototype.getSize=function(){var t=this.el,e=this.el.getBoundingRect(),a=qT(t.style);return[e.width+a.left+a.right,e.height+a.top+a.bottom]},r.prototype.moveTo=function(t,e){var a=this.el;if(a){var n=this._styleCoord;KT(n,this._zr,t,e),t=n[0],e=n[1];var i=a.style,o=hn(i.borderWidth||0),s=qT(i);a.x=t+o+s.left,a.y=e+o+s.top,a.markRedraw()}},r.prototype._moveIfResized=function(){var t=this._styleCoord[2],e=this._styleCoord[3];this.moveTo(t*this._zr.getWidth(),e*this._zr.getHeight())},r.prototype.hide=function(){this.el&&this.el.hide(),this._show=!1},r.prototype.hideLater=function(t){this._show&&!(this._inContent&&this._enterable)&&!this._alwaysShowContent&&(t?(this._hideDelay=t,this._show=!1,this._hideTimeout=setTimeout($(this.hide,this),t)):this.hide())},r.prototype.isShow=function(){return this._show},r.prototype.dispose=function(){this._zr.remove(this.el)},r}();function hn(r){return Math.max(0,r)}function qT(r){var t=hn(r.shadowBlur||0),e=hn(r.shadowOffsetX||0),a=hn(r.shadowOffsetY||0);return{left:hn(t-e),right:hn(t+e),top:hn(t-a),bottom:hn(t+a)}}function KT(r,t,e,a){r[0]=e,r[1]=a,r[2]=r[0]/t.getWidth(),r[3]=r[1]/t.getHeight()}var qZ=new _t({shape:{x:-1,y:-1,width:2,height:2}}),KZ=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(e,a){if(!(Tt.node||!a.getDom())){var n=e.getComponent("tooltip"),i=this._renderMode=RE(n.get("renderMode"));this._tooltipContent=i==="richText"?new $Z(a):new XZ(a,{appendTo:n.get("appendToBody",!0)?"body":n.get("appendTo",!0)})}},t.prototype.render=function(e,a,n){if(!(Tt.node||!n.getDom())){this.group.removeAll(),this._tooltipModel=e,this._ecModel=a,this._api=n;var i=this._tooltipContent;i.update(e),i.setEnterable(e.get("enterable")),this._initGlobalListener(),this._keepShow(),this._renderMode!=="richText"&&e.get("transitionDuration")?As(this,"_updatePosition",50,"fixRate"):tu(this,"_updatePosition")}},t.prototype._initGlobalListener=function(){var e=this._tooltipModel,a=e.get("triggerOn");PP("itemTooltip",this._api,$(function(n,i,o){a!=="none"&&(a.indexOf(n)>=0?this._tryShow(i,o):n==="leave"&&this._hide(o))},this))},t.prototype._keepShow=function(){var e=this._tooltipModel,a=this._ecModel,n=this._api,i=e.get("triggerOn");if(this._lastX!=null&&this._lastY!=null&&i!=="none"&&i!=="click"){var o=this;clearTimeout(this._refreshUpdateTimeout),this._refreshUpdateTimeout=setTimeout(function(){!n.isDisposed()&&o.manuallyShowTip(e,a,n,{x:o._lastX,y:o._lastY,dataByCoordSys:o._lastDataByCoordSys})})}},t.prototype.manuallyShowTip=function(e,a,n,i){if(!(i.from===this.uid||Tt.node||!n.getDom())){var o=jT(i,n);this._ticket="";var s=i.dataByCoordSys,l=t9(i,a,n);if(l){var u=l.el.getBoundingRect().clone();u.applyTransform(l.el.transform),this._tryShow({offsetX:u.x+u.width/2,offsetY:u.y+u.height/2,target:l.el,position:i.position,positionDefault:"bottom"},o)}else if(i.tooltip&&i.x!=null&&i.y!=null){var f=qZ;f.x=i.x,f.y=i.y,f.update(),ut(f).tooltipConfig={name:null,option:i.tooltip},this._tryShow({offsetX:i.x,offsetY:i.y,target:f},o)}else if(s)this._tryShow({offsetX:i.x,offsetY:i.y,position:i.position,dataByCoordSys:s,tooltipOption:i.tooltipOption},o);else if(i.seriesIndex!=null){if(this._manuallyAxisShowTip(e,a,n,i))return;var v=RP(i,a),h=v.point[0],c=v.point[1];h!=null&&c!=null&&this._tryShow({offsetX:h,offsetY:c,target:v.el,position:i.position,positionDefault:"bottom"},o)}else i.x!=null&&i.y!=null&&(n.dispatchAction({type:"updateAxisPointer",x:i.x,y:i.y}),this._tryShow({offsetX:i.x,offsetY:i.y,position:i.position,target:n.getZr().findHover(i.x,i.y).target},o))}},t.prototype.manuallyHideTip=function(e,a,n,i){var o=this._tooltipContent;this._tooltipModel&&o.hideLater(this._tooltipModel.get("hideDelay")),this._lastX=this._lastY=this._lastDataByCoordSys=null,i.from!==this.uid&&this._hide(jT(i,n))},t.prototype._manuallyAxisShowTip=function(e,a,n,i){var o=i.seriesIndex,s=i.dataIndex,l=a.getComponent("axisPointer").coordSysAxesInfo;if(!(o==null||s==null||l==null)){var u=a.getSeriesByIndex(o);if(u){var f=u.getData(),v=sl([f.getItemModel(s),u,(u.coordinateSystem||{}).model],this._tooltipModel);if(v.get("trigger")==="axis")return n.dispatchAction({type:"updateAxisPointer",seriesIndex:o,dataIndex:s,position:i.position}),!0}}},t.prototype._tryShow=function(e,a){var n=e.target,i=this._tooltipModel;if(i){this._lastX=e.offsetX,this._lastY=e.offsetY;var o=e.dataByCoordSys;if(o&&o.length)this._showAxisTooltip(o,e);else if(n){var s=ut(n);if(s.ssrType==="legend")return;this._lastDataByCoordSys=null;var l,u;Di(n,function(f){if(f.tooltipDisabled)return l=u=null,!0;l||u||(ut(f).dataIndex!=null?l=f:ut(f).tooltipConfig!=null&&(u=f))},!0),l?this._showSeriesItemTooltip(e,l,a):u?this._showComponentItemTooltip(e,u,a):this._hide(a)}else this._lastDataByCoordSys=null,this._hide(a)}},t.prototype._showOrMove=function(e,a){var n=e.get("showDelay");a=$(a,this),clearTimeout(this._showTimout),n>0?this._showTimout=setTimeout(a,n):a()},t.prototype._showAxisTooltip=function(e,a){var n=this._ecModel,i=this._tooltipModel,o=[a.offsetX,a.offsetY],s=sl([a.tooltipOption],i),l=this._renderMode,u=[],f=ue("section",{blocks:[],noHeader:!0}),v=[],h=new sp;A(e,function(m){A(m.dataByAxis,function(_){var S=n.getComponent(_.axisDim+"Axis",_.axisIndex),x=_.value;if(!(!S||x==null)){var b=DP(x,S.axis,n,_.seriesDataIndices,_.valueLabelOpt),w=ue("section",{header:b,noHeader:!sr(b),sortBlocks:!0,blocks:[]});f.blocks.push(w),A(_.seriesDataIndices,function(T){var C=n.getSeriesByIndex(T.seriesIndex),M=T.dataIndexInside,D=C.getDataParams(M);if(!(D.dataIndex<0)){D.axisDim=_.axisDim,D.axisIndex=_.axisIndex,D.axisType=_.axisType,D.axisId=_.axisId,D.axisValue=Qv(S.axis,{value:x}),D.axisValueLabel=b,D.marker=h.makeTooltipMarker("item",Yi(D.color),l);var I=hS(C.formatTooltip(M,!0,null)),L=I.frag;if(L){var P=sl([C],i).get("valueFormatter");w.blocks.push(P?G({valueFormatter:P},L):L)}I.text&&v.push(I.text),u.push(D)}})}})}),f.blocks.reverse(),v.reverse();var c=a.position,p=s.get("order"),d=mS(f,h,l,p,n.get("useUTC"),s.get("textStyle"));d&&v.unshift(d);var g=l==="richText"?`

`:"<br/>",y=v.join(g);this._showOrMove(s,function(){this._updateContentNotChangedOnAxis(e,u)?this._updatePosition(s,c,o[0],o[1],this._tooltipContent,u):this._showTooltipContent(s,y,u,Math.random()+"",o[0],o[1],c,null,h)})},t.prototype._showSeriesItemTooltip=function(e,a,n){var i=this._ecModel,o=ut(a),s=o.seriesIndex,l=i.getSeriesByIndex(s),u=o.dataModel||l,f=o.dataIndex,v=o.dataType,h=u.getData(v),c=this._renderMode,p=e.positionDefault,d=sl([h.getItemModel(f),u,l&&(l.coordinateSystem||{}).model],this._tooltipModel,p?{position:p}:null),g=d.get("trigger");if(!(g!=null&&g!=="item")){var y=u.getDataParams(f,v),m=new sp;y.marker=m.makeTooltipMarker("item",Yi(y.color),c);var _=hS(u.formatTooltip(f,!1,v)),S=d.get("order"),x=d.get("valueFormatter"),b=_.frag,w=b?mS(x?G({valueFormatter:x},b):b,m,c,S,i.get("useUTC"),d.get("textStyle")):_.text,T="item_"+u.name+"_"+f;this._showOrMove(d,function(){this._showTooltipContent(d,w,y,T,e.offsetX,e.offsetY,e.position,e.target,m)}),n({type:"showTip",dataIndexInside:f,dataIndex:h.getRawIndex(f),seriesIndex:s,from:this.uid})}},t.prototype._showComponentItemTooltip=function(e,a,n){var i=this._renderMode==="html",o=ut(a),s=o.tooltipConfig,l=s.option||{},u=l.encodeHTMLContent;if(X(l)){var f=l;l={content:f,formatter:f},u=!0}u&&i&&l.content&&(l=et(l),l.content=ze(l.content));var v=[l],h=this._ecModel.getComponent(o.componentMainType,o.componentIndex);h&&v.push(h),v.push({formatter:l.content});var c=e.positionDefault,p=sl(v,this._tooltipModel,c?{position:c}:null),d=p.get("content"),g=Math.random()+"",y=new sp;this._showOrMove(p,function(){var m=et(p.get("formatterParams")||{});this._showTooltipContent(p,d,m,g,e.offsetX,e.offsetY,e.position,a,y)}),n({type:"showTip",from:this.uid})},t.prototype._showTooltipContent=function(e,a,n,i,o,s,l,u,f){if(this._ticket="",!(!e.get("showContent")||!e.get("show"))){var v=this._tooltipContent;v.setEnterable(e.get("enterable"));var h=e.get("formatter");l=l||e.get("position");var c=a,p=this._getNearestPoint([o,s],n,e.get("trigger"),e.get("borderColor"),e.get("defaultBorderColor",!0)),d=p.color;if(h)if(X(h)){var g=e.ecModel.get("useUTC"),y=W(n)?n[0]:n,m=y&&y.axisType&&y.axisType.indexOf("time")>=0;c=h,m&&(c=Lu(y.axisValue,c,g)),c=Ym(c,n,!0)}else if(tt(h)){var _=$(function(S,x){S===this._ticket&&(v.setContent(x,f,e,d,l),this._updatePosition(e,l,o,s,v,n,u))},this);this._ticket=i,c=h(n,i,_)}else c=h;v.setContent(c,f,e,d,l),v.show(e,d),this._updatePosition(e,l,o,s,v,n,u)}},t.prototype._getNearestPoint=function(e,a,n,i,o){if(n==="axis"||W(a))return{color:i||o};if(!W(a))return{color:i||a.color||a.borderColor}},t.prototype._updatePosition=function(e,a,n,i,o,s,l){var u=this._api.getWidth(),f=this._api.getHeight();a=a||e.get("position");var v=o.getSize(),h=e.get("align"),c=e.get("verticalAlign"),p=l&&l.getBoundingRect().clone();if(l&&p.applyTransform(l.transform),tt(a)&&(a=a([n,i],s,o.el,p,{viewSize:[u,f],contentSize:v.slice()})),W(a))n=Z(a[0],u),i=Z(a[1],f);else if(it(a)){var d=a;d.width=v[0],d.height=v[1];var g=Xt(d,{width:u,height:f});n=g.x,i=g.y,h=null,c=null}else if(X(a)&&l){var y=QZ(a,p,v,e.get("borderWidth"));n=y[0],i=y[1]}else{var y=jZ(n,i,o,u,f,h?null:20,c?null:20);n=y[0],i=y[1]}if(h&&(n-=JT(h)?v[0]/2:h==="right"?v[0]:0),c&&(i-=JT(c)?v[1]/2:c==="bottom"?v[1]:0),XP(e)){var y=JZ(n,i,o,u,f);n=y[0],i=y[1]}o.moveTo(n,i)},t.prototype._updateContentNotChangedOnAxis=function(e,a){var n=this._lastDataByCoordSys,i=this._cbParamsList,o=!!n&&n.length===e.length;return o&&A(n,function(s,l){var u=s.dataByAxis||[],f=e[l]||{},v=f.dataByAxis||[];o=o&&u.length===v.length,o&&A(u,function(h,c){var p=v[c]||{},d=h.seriesDataIndices||[],g=p.seriesDataIndices||[];o=o&&h.value===p.value&&h.axisType===p.axisType&&h.axisId===p.axisId&&d.length===g.length,o&&A(d,function(y,m){var _=g[m];o=o&&y.seriesIndex===_.seriesIndex&&y.dataIndex===_.dataIndex}),i&&A(h.seriesDataIndices,function(y){var m=y.seriesIndex,_=a[m],S=i[m];_&&S&&S.data!==_.data&&(o=!1)})})}),this._lastDataByCoordSys=e,this._cbParamsList=a,!!o},t.prototype._hide=function(e){this._lastDataByCoordSys=null,e({type:"hideTip",from:this.uid})},t.prototype.dispose=function(e,a){Tt.node||!a.getDom()||(tu(this,"_updatePosition"),this._tooltipContent.dispose(),Iy("itemTooltip",a))},t.type="tooltip",t}(Wt);function sl(r,t,e){var a=t.ecModel,n;e?(n=new wt(e,a,a),n=new wt(t.option,n,a)):n=t;for(var i=r.length-1;i>=0;i--){var o=r[i];o&&(o instanceof wt&&(o=o.get("tooltip",!0)),X(o)&&(o={formatter:o}),o&&(n=new wt(o,n,a)))}return n}function jT(r,t){return r.dispatchAction||$(t.dispatchAction,t)}function jZ(r,t,e,a,n,i,o){var s=e.getSize(),l=s[0],u=s[1];return i!=null&&(r+l+i+2>a?r-=l+i:r+=i),o!=null&&(t+u+o>n?t-=u+o:t+=o),[r,t]}function JZ(r,t,e,a,n){var i=e.getSize(),o=i[0],s=i[1];return r=Math.min(r+o,a)-o,t=Math.min(t+s,n)-s,r=Math.max(r,0),t=Math.max(t,0),[r,t]}function QZ(r,t,e,a){var n=e[0],i=e[1],o=Math.ceil(Math.SQRT2*a)+8,s=0,l=0,u=t.width,f=t.height;switch(r){case"inside":s=t.x+u/2-n/2,l=t.y+f/2-i/2;break;case"top":s=t.x+u/2-n/2,l=t.y-i-o;break;case"bottom":s=t.x+u/2-n/2,l=t.y+f+o;break;case"left":s=t.x-n-o,l=t.y+f/2-i/2;break;case"right":s=t.x+u+o,l=t.y+f/2-i/2}return[s,l]}function JT(r){return r==="center"||r==="middle"}function t9(r,t,e){var a=pm(r).queryOptionMap,n=a.keys()[0];if(!(!n||n==="series")){var i=ds(t,n,a.get(n),{useDefault:!1,enableAll:!1,enableNone:!1}),o=i.models[0];if(o){var s=e.getViewOfComponentModel(o),l;if(s.group.traverse(function(u){var f=ut(u).tooltipConfig;if(f&&f.name===r.name)return l=u,!0}),l)return{componentMainType:n,componentIndex:o.componentIndex,el:l}}}}function e9(r){mt(zu),r.registerComponentModel(BZ),r.registerComponentView(KZ),r.registerAction({type:"showTip",event:"showTip",update:"tooltip:manuallyShowTip"},jt),r.registerAction({type:"hideTip",event:"hideTip",update:"tooltip:manuallyHideTip"},jt)}var r9=["rect","polygon","keep","clear"];function a9(r,t){var e=Ft(r?r.brush:[]);if(e.length){var a=[];A(e,function(l){var u=l.hasOwnProperty("toolbox")?l.toolbox:[];u instanceof Array&&(a=a.concat(u))});var n=r&&r.toolbox;W(n)&&(n=n[0]),n||(n={feature:{}},r.toolbox=[n]);var i=n.feature||(n.feature={}),o=i.brush||(i.brush={}),s=o.type||(o.type=[]);s.push.apply(s,a),n9(s),t&&!s.length&&s.push.apply(s,r9)}}function n9(r){var t={};A(r,function(e){t[e]=1}),r.length=0,A(t,function(e,a){r.push(a)})}var QT=A;function tC(r){if(r){for(var t in r)if(r.hasOwnProperty(t))return!0}}function Vy(r,t,e){var a={};return QT(t,function(i){var o=a[i]=n();QT(r[i],function(s,l){if(_e.isValidType(l)){var u={type:l,visual:s};e&&e(u,i),o[l]=new _e(u),l==="opacity"&&(u=et(u),u.type="colorAlpha",o.__hidden.__alphaForOpacity=new _e(u))}})}),a;function n(){var i=function(){};i.prototype.__hidden=i.prototype;var o=new i;return o}}function jP(r,t,e){var a;A(e,function(n){t.hasOwnProperty(n)&&tC(t[n])&&(a=!0)}),a&&A(e,function(n){t.hasOwnProperty(n)&&tC(t[n])?r[n]=et(t[n]):delete r[n]})}function i9(r,t,e,a,n,i){var o={};A(r,function(v){var h=_e.prepareVisualTypes(t[v]);o[v]=h});var s;function l(v){return r0(e,s,v)}function u(v,h){KD(e,s,v,h)}e.each(f);function f(v,h){s=v;var c=e.getRawDataItem(s);if(!(c&&c.visualMap===!1))for(var p=a.call(n,v),d=t[p],g=o[p],y=0,m=g.length;y<m;y++){var _=g[y];d[_]&&d[_].applyVisual(v,l,u)}}}function o9(r,t,e,a){var n={};return A(r,function(i){var o=_e.prepareVisualTypes(t[i]);n[i]=o}),{progress:function(o,s){var l;a!=null&&(l=s.getDimensionIndex(a));function u(x){return r0(s,v,x)}function f(x,b){KD(s,v,x,b)}for(var v,h=s.getStore();(v=o.next())!=null;){var c=s.getRawDataItem(v);if(!(c&&c.visualMap===!1))for(var p=a!=null?h.get(l,v):v,d=e(p),g=t[d],y=n[d],m=0,_=y.length;m<_;m++){var S=y[m];g[S]&&g[S].applyVisual(p,u,f)}}}}}function s9(r){var t=r.brushType,e={point:function(a){return eC[t].point(a,e,r)},rect:function(a){return eC[t].rect(a,e,r)}};return e}var eC={lineX:rC(0),lineY:rC(1),rect:{point:function(r,t,e){return r&&e.boundingRect.contain(r[0],r[1])},rect:function(r,t,e){return r&&e.boundingRect.intersect(r)}},polygon:{point:function(r,t,e){return r&&e.boundingRect.contain(r[0],r[1])&&Si(e.range,r[0],r[1])},rect:function(r,t,e){var a=e.range;if(!r||a.length<=1)return!1;var n=r.x,i=r.y,o=r.width,s=r.height,l=a[0];if(Si(a,n,i)||Si(a,n+o,i)||Si(a,n,i+s)||Si(a,n+o,i+s)||lt.create(r).contain(l[0],l[1])||gl(n,i,n+o,i,a)||gl(n,i,n,i+s,a)||gl(n+o,i,n+o,i+s,a)||gl(n,i+s,n+o,i+s,a))return!0}}};function rC(r){var t=["x","y"],e=["width","height"];return{point:function(a,n,i){if(a){var o=i.range,s=a[r];return ll(s,o)}},rect:function(a,n,i){if(a){var o=i.range,s=[a[t[r]],a[t[r]]+a[e[r]]];return s[1]<s[0]&&s.reverse(),ll(s[0],o)||ll(s[1],o)||ll(o[0],s)||ll(o[1],s)}}}}function ll(r,t){return t[0]<=r&&r<=t[1]}var aC=["inBrush","outOfBrush"],Md="__ecBrushSelect",Gy="__ecInBrushSelectEvent";function JP(r){r.eachComponent({mainType:"brush"},function(t){var e=t.brushTargetManager=new m_(t.option,r);e.setInputRanges(t.areas,r)})}function l9(r,t,e){var a=[],n,i;r.eachComponent({mainType:"brush"},function(o){e&&e.type==="takeGlobalCursor"&&o.setBrushOption(e.key==="brush"?e.brushOption:{brushType:!1})}),JP(r),r.eachComponent({mainType:"brush"},function(o,s){var l={brushId:o.id,brushIndex:s,brushName:o.name,areas:et(o.areas),selected:[]};a.push(l);var u=o.option,f=u.brushLink,v=[],h=[],c=[],p=!1;s||(n=u.throttleType,i=u.throttleDelay);var d=U(o.areas,function(x){var b=h9[x.brushType],w=nt({boundingRect:b?b(x):void 0},x);return w.selectors=s9(w),w}),g=Vy(o.option,aC,function(x){x.mappingMethod="fixed"});W(f)&&A(f,function(x){v[x]=1});function y(x){return f==="all"||!!v[x]}function m(x){return!!x.length}r.eachSeries(function(x,b){var w=c[b]=[];x.subType==="parallel"?_(x,b):S(x,b,w)});function _(x,b){var w=x.coordinateSystem;p=p||w.hasAxisBrushed(),y(b)&&w.eachActiveState(x.getData(),function(T,C){T==="active"&&(h[C]=1)})}function S(x,b,w){if(!(!x.brushSelector||v9(o,b))&&(A(d,function(C){o.brushTargetManager.controlSeries(C,x,r)&&w.push(C),p=p||m(w)}),y(b)&&m(w))){var T=x.getData();T.each(function(C){nC(x,w,T,C)&&(h[C]=1)})}}r.eachSeries(function(x,b){var w={seriesId:x.id,seriesIndex:b,seriesName:x.name,dataIndex:[]};l.selected.push(w);var T=c[b],C=x.getData(),M=y(b)?function(D){return h[D]?(w.dataIndex.push(C.getRawIndex(D)),"inBrush"):"outOfBrush"}:function(D){return nC(x,T,C,D)?(w.dataIndex.push(C.getRawIndex(D)),"inBrush"):"outOfBrush"};(y(b)?p:m(T))&&i9(aC,g,C,M)})}),u9(t,n,i,a,e)}function u9(r,t,e,a,n){if(n){var i=r.getZr();if(!i[Gy]){i[Md]||(i[Md]=f9);var o=As(i,Md,e,t);o(r,a)}}}function f9(r,t){if(!r.isDisposed()){var e=r.getZr();e[Gy]=!0,r.dispatchAction({type:"brushSelect",batch:t}),e[Gy]=!1}}function nC(r,t,e,a){for(var n=0,i=t.length;n<i;n++){var o=t[n];if(r.brushSelector(a,e,o.selectors,o))return!0}}function v9(r,t){var e=r.option.seriesIndex;return e!=null&&e!=="all"&&(W(e)?gt(e,t)<0:t!==e)}var h9={rect:function(r){return iC(r.range)},polygon:function(r){for(var t,e=r.range,a=0,n=e.length;a<n;a++){t=t||[[1/0,-1/0],[1/0,-1/0]];var i=e[a];i[0]<t[0][0]&&(t[0][0]=i[0]),i[0]>t[0][1]&&(t[0][1]=i[0]),i[1]<t[1][0]&&(t[1][0]=i[1]),i[1]>t[1][1]&&(t[1][1]=i[1])}return t&&iC(t)}};function iC(r){return new lt(r[0][0],r[1][0],r[0][1]-r[0][0],r[1][1]-r[1][0])}var c9=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(e,a){this.ecModel=e,this.api=a,this.model,(this._brushController=new W0(a.getZr())).on("brush",$(this._onBrush,this)).mount()},t.prototype.render=function(e,a,n,i){this.model=e,this._updateController(e,a,n,i)},t.prototype.updateTransform=function(e,a,n,i){JP(a),this._updateController(e,a,n,i)},t.prototype.updateVisual=function(e,a,n,i){this.updateTransform(e,a,n,i)},t.prototype.updateView=function(e,a,n,i){this._updateController(e,a,n,i)},t.prototype._updateController=function(e,a,n,i){(!i||i.$from!==e.id)&&this._brushController.setPanels(e.brushTargetManager.makePanelOpts(n)).enableBrush(e.brushOption).updateCovers(e.areas.slice())},t.prototype.dispose=function(){this._brushController.dispose()},t.prototype._onBrush=function(e){var a=this.model.id,n=this.model.brushTargetManager.setOutputRanges(e.areas,this.ecModel);(!e.isEnd||e.removeOnClick)&&this.api.dispatchAction({type:"brush",brushId:a,areas:et(n),$from:a}),e.isEnd&&this.api.dispatchAction({type:"brushEnd",brushId:a,areas:et(n),$from:a})},t.type="brush",t}(Wt),p9=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.areas=[],e.brushOption={},e}return t.prototype.optionUpdated=function(e,a){var n=this.option;!a&&jP(n,e,["inBrush","outOfBrush"]);var i=n.inBrush=n.inBrush||{};n.outOfBrush=n.outOfBrush||{color:this.option.defaultOutOfBrushColor},i.hasOwnProperty("liftZ")||(i.liftZ=5)},t.prototype.setAreas=function(e){e&&(this.areas=U(e,function(a){return oC(this.option,a)},this))},t.prototype.setBrushOption=function(e){this.brushOption=oC(this.option,e),this.brushType=this.brushOption.brushType},t.type="brush",t.dependencies=["geo","grid","xAxis","yAxis","parallel","series"],t.defaultOption={seriesIndex:"all",brushType:"rect",brushMode:"single",transformable:!0,brushStyle:{borderWidth:1,color:N.color.backgroundTint,borderColor:N.color.borderTint},throttleType:"fixRate",throttleDelay:0,removeOnClick:!0,z:1e4,defaultOutOfBrushColor:N.color.disabled},t}(xt);function oC(r,t){return yt({brushType:r.brushType,brushMode:r.brushMode,transformable:r.transformable,brushStyle:new wt(r.brushStyle).getItemStyle(),removeOnClick:r.removeOnClick,z:r.z},t,!0)}var d9=["rect","polygon","lineX","lineY","keep","clear"],g9=function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.render=function(e,a,n){var i,o,s;a.eachComponent({mainType:"brush"},function(l){i=l.brushType,o=l.brushOption.brushMode||"single",s=s||!!l.areas.length}),this._brushType=i,this._brushMode=o,A(e.get("type",!0),function(l){e.setIconStatus(l,(l==="keep"?o==="multiple":l==="clear"?s:l===i)?"emphasis":"normal")})},t.prototype.updateView=function(e,a,n){this.render(e,a,n)},t.prototype.getIcons=function(){var e=this.model,a=e.get("icon",!0),n={};return A(e.get("type",!0),function(i){a[i]&&(n[i]=a[i])}),n},t.prototype.onclick=function(e,a,n){var i=this._brushType,o=this._brushMode;n==="clear"?(a.dispatchAction({type:"axisAreaSelect",intervals:[]}),a.dispatchAction({type:"brush",command:"clear",areas:[]})):a.dispatchAction({type:"takeGlobalCursor",key:"brush",brushOption:{brushType:n==="keep"?i:i===n?!1:n,brushMode:n==="keep"?o==="multiple"?"single":"multiple":o}})},t.getDefaultOption=function(e){var a={show:!0,type:d9.slice(),icon:{rect:"M7.3,34.7 M0.4,10V-0.2h9.8 M89.6,10V-0.2h-9.8 M0.4,60v10.2h9.8 M89.6,60v10.2h-9.8 M12.3,22.4V10.5h13.1 M33.6,10.5h7.8 M49.1,10.5h7.8 M77.5,22.4V10.5h-13 M12.3,31.1v8.2 M77.7,31.1v8.2 M12.3,47.6v11.9h13.1 M33.6,59.5h7.6 M49.1,59.5 h7.7 M77.5,47.6v11.9h-13",polygon:"M55.2,34.9c1.7,0,3.1,1.4,3.1,3.1s-1.4,3.1-3.1,3.1 s-3.1-1.4-3.1-3.1S53.5,34.9,55.2,34.9z M50.4,51c1.7,0,3.1,1.4,3.1,3.1c0,1.7-1.4,3.1-3.1,3.1c-1.7,0-3.1-1.4-3.1-3.1 C47.3,52.4,48.7,51,50.4,51z M55.6,37.1l1.5-7.8 M60.1,13.5l1.6-8.7l-7.8,4 M59,19l-1,5.3 M24,16.1l6.4,4.9l6.4-3.3 M48.5,11.6 l-5.9,3.1 M19.1,12.8L9.7,5.1l1.1,7.7 M13.4,29.8l1,7.3l6.6,1.6 M11.6,18.4l1,6.1 M32.8,41.9 M26.6,40.4 M27.3,40.2l6.1,1.6 M49.9,52.1l-5.6-7.6l-4.9-1.2",lineX:"M15.2,30 M19.7,15.6V1.9H29 M34.8,1.9H40.4 M55.3,15.6V1.9H45.9 M19.7,44.4V58.1H29 M34.8,58.1H40.4 M55.3,44.4 V58.1H45.9 M12.5,20.3l-9.4,9.6l9.6,9.8 M3.1,29.9h16.5 M62.5,20.3l9.4,9.6L62.3,39.7 M71.9,29.9H55.4",lineY:"M38.8,7.7 M52.7,12h13.2v9 M65.9,26.6V32 M52.7,46.3h13.2v-9 M24.9,12H11.8v9 M11.8,26.6V32 M24.9,46.3H11.8v-9 M48.2,5.1l-9.3-9l-9.4,9.2 M38.9-3.9V12 M48.2,53.3l-9.3,9l-9.4-9.2 M38.9,62.3V46.4",keep:"M4,10.5V1h10.3 M20.7,1h6.1 M33,1h6.1 M55.4,10.5V1H45.2 M4,17.3v6.6 M55.6,17.3v6.6 M4,30.5V40h10.3 M20.7,40 h6.1 M33,40h6.1 M55.4,30.5V40H45.2 M21,18.9h62.9v48.6H21V18.9z",clear:"M22,14.7l30.9,31 M52.9,14.7L22,45.7 M4.7,16.8V4.2h13.1 M26,4.2h7.8 M41.6,4.2h7.8 M70.3,16.8V4.2H57.2 M4.7,25.9v8.6 M70.3,25.9v8.6 M4.7,43.2v12.6h13.1 M26,55.8h7.8 M41.6,55.8h7.8 M70.3,43.2v12.6H57.2"},title:e.getLocaleModel().get(["toolbox","brush","title"])};return a},t}(wr);function y9(r){r.registerComponentView(c9),r.registerComponentModel(p9),r.registerPreprocessor(a9),r.registerVisual(r.PRIORITY.VISUAL.BRUSH,l9),r.registerAction({type:"brush",event:"brush",update:"updateVisual"},function(t,e){e.eachComponent({mainType:"brush",query:t},function(a){a.setAreas(t.areas)})}),r.registerAction({type:"brushSelect",event:"brushSelected",update:"none"},jt),r.registerAction({type:"brushEnd",event:"brushEnd",update:"none"},jt),No("brush",g9)}var m9=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.layoutMode={type:"box",ignoreSize:!0},e}return t.type="title",t.defaultOption={z:6,show:!0,text:"",target:"blank",subtext:"",subtarget:"blank",left:"center",top:N.size.m,backgroundColor:N.color.transparent,borderColor:N.color.primary,borderWidth:0,padding:5,itemGap:10,textStyle:{fontSize:18,fontWeight:"bold",color:N.color.primary},subtextStyle:{fontSize:12,color:N.color.quaternary}},t}(xt),_9=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n){if(this.group.removeAll(),!!e.get("show")){var i=this.group,o=e.getModel("textStyle"),s=e.getModel("subtextStyle"),l=e.get("textAlign"),u=Q(e.get("textBaseline"),e.get("textVerticalAlign")),f=new At({style:Gt(o,{text:e.get("text"),fill:o.getTextColor()},{disableBox:!0}),z2:10}),v=f.getBoundingRect(),h=e.get("subtext"),c=new At({style:Gt(s,{text:h,fill:s.getTextColor(),y:v.height+e.get("itemGap"),verticalAlign:"top"},{disableBox:!0}),z2:10}),p=e.get("link"),d=e.get("sublink"),g=e.get("triggerEvent",!0);f.silent=!p&&!g,c.silent=!d&&!g,p&&f.on("click",function(){Hv(p,"_"+e.get("target"))}),d&&c.on("click",function(){Hv(d,"_"+e.get("subtarget"))}),ut(f).eventData=ut(c).eventData=g?{componentType:"title",componentIndex:e.componentIndex}:null,i.add(f),h&&i.add(c);var y=i.getBoundingRect(),m=e.getBoxLayoutParams();m.width=y.width,m.height=y.height;var _=pe(e,n),S=Xt(m,_.refContainer,e.get("padding"));l||(l=e.get("left")||e.get("right"),l==="middle"&&(l="center"),l==="right"?S.x+=S.width:l==="center"&&(S.x+=S.width/2)),u||(u=e.get("top")||e.get("bottom"),u==="center"&&(u="middle"),u==="bottom"?S.y+=S.height:u==="middle"&&(S.y+=S.height/2),u=u||"top"),i.x=S.x,i.y=S.y,i.markRedraw();var x={align:l,verticalAlign:u};f.setStyle(x),c.setStyle(x),y=i.getBoundingRect();var b=S.margin,w=e.getItemStyle(["color","opacity"]);w.fill=e.get("backgroundColor");var T=new _t({shape:{x:y.x-b[3],y:y.y-b[0],width:y.width+b[1]+b[3],height:y.height+b[0]+b[2],r:e.get("borderRadius")},style:w,subPixelOptimize:!0,silent:!0});i.add(T)}},t.type="title",t}(Wt);function S9(r){r.registerComponentModel(m9),r.registerComponentView(_9)}var sC=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.layoutMode="box",e}return t.prototype.init=function(e,a,n){this.mergeDefaultAndTheme(e,n),this._initData()},t.prototype.mergeOption=function(e){r.prototype.mergeOption.apply(this,arguments),this._initData()},t.prototype.setCurrentIndex=function(e){e==null&&(e=this.option.currentIndex);var a=this._data.count();this.option.loop?e=(e%a+a)%a:(e>=a&&(e=a-1),e<0&&(e=0)),this.option.currentIndex=e},t.prototype.getCurrentIndex=function(){return this.option.currentIndex},t.prototype.isIndexMax=function(){return this.getCurrentIndex()>=this._data.count()-1},t.prototype.setPlayState=function(e){this.option.autoPlay=!!e},t.prototype.getPlayState=function(){return!!this.option.autoPlay},t.prototype._initData=function(){var e=this.option,a=e.data||[],n=e.axisType,i=this._names=[],o;n==="category"?(o=[],A(a,function(u,f){var v=ve(ps(u),""),h;it(u)?(h=et(u),h.value=f):h=f,o.push(h),i.push(v)})):o=a;var s={category:"ordinal",time:"time",value:"number"}[n]||"number",l=this._data=new Ue([{name:"value",type:s}],this);l.initData(o,i)},t.prototype.getData=function(){return this._data},t.prototype.getCategories=function(){if(this.get("axisType")==="category")return this._names.slice()},t.type="timeline",t.defaultOption={z:4,show:!0,axisType:"time",realtime:!0,left:"20%",top:null,right:"20%",bottom:0,width:null,height:40,padding:N.size.m,controlPosition:"left",autoPlay:!1,rewind:!1,loop:!0,playInterval:2e3,currentIndex:0,itemStyle:{},label:{color:N.color.secondary},data:[]},t}(xt),QP=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="timeline.slider",t.defaultOption=Vn(sC.defaultOption,{backgroundColor:"rgba(0,0,0,0)",borderColor:N.color.border,borderWidth:0,orient:"horizontal",inverse:!1,tooltip:{trigger:"item"},symbol:"circle",symbolSize:12,lineStyle:{show:!0,width:2,color:N.color.accent10},label:{position:"auto",show:!0,interval:"auto",rotate:0,color:N.color.tertiary},itemStyle:{color:N.color.accent20,borderWidth:0},checkpointStyle:{symbol:"circle",symbolSize:15,color:N.color.accent50,borderColor:N.color.accent50,borderWidth:0,shadowBlur:0,shadowOffsetX:0,shadowOffsetY:0,shadowColor:"rgba(0, 0, 0, 0)",animation:!0,animationDuration:300,animationEasing:"quinticInOut"},controlStyle:{show:!0,showPlayBtn:!0,showPrevBtn:!0,showNextBtn:!0,itemSize:24,itemGap:12,position:"left",playIcon:"path://M15 0C23.2843 0 30 6.71573 30 15C30 23.2843 23.2843 30 15 30C6.71573 30 0 23.2843 0 15C0 6.71573 6.71573 0 15 0ZM15 3C8.37258 3 3 8.37258 3 15C3 21.6274 8.37258 27 15 27C21.6274 27 27 21.6274 27 15C27 8.37258 21.6274 3 15 3ZM11.5 10.6699C11.5 9.90014 12.3333 9.41887 13 9.80371L20.5 14.1338C21.1667 14.5187 21.1667 15.4813 20.5 15.8662L13 20.1963C12.3333 20.5811 11.5 20.0999 11.5 19.3301V10.6699Z",stopIcon:"path://M15 0C23.2843 0 30 6.71573 30 15C30 23.2843 23.2843 30 15 30C6.71573 30 0 23.2843 0 15C0 6.71573 6.71573 0 15 0ZM15 3C8.37258 3 3 8.37258 3 15C3 21.6274 8.37258 27 15 27C21.6274 27 27 21.6274 27 15C27 8.37258 21.6274 3 15 3ZM11.5 10C12.3284 10 13 10.6716 13 11.5V18.5C13 19.3284 12.3284 20 11.5 20C10.6716 20 10 19.3284 10 18.5V11.5C10 10.6716 10.6716 10 11.5 10ZM18.5 10C19.3284 10 20 10.6716 20 11.5V18.5C20 19.3284 19.3284 20 18.5 20C17.6716 20 17 19.3284 17 18.5V11.5C17 10.6716 17.6716 10 18.5 10Z",nextIcon:"path://M0.838834 18.7383C0.253048 18.1525 0.253048 17.2028 0.838834 16.617L7.55635 9.89949L0.838834 3.18198C0.253048 2.59619 0.253048 1.64645 0.838834 1.06066C1.42462 0.474874 2.37437 0.474874 2.96015 1.06066L10.7383 8.83883L10.8412 8.95277C11.2897 9.50267 11.2897 10.2963 10.8412 10.8462L10.7383 10.9602L2.96015 18.7383C2.37437 19.3241 1.42462 19.3241 0.838834 18.7383Z",prevIcon:"path://M10.9602 1.06066C11.5459 1.64645 11.5459 2.59619 10.9602 3.18198L4.24264 9.89949L10.9602 16.617C11.5459 17.2028 11.5459 18.1525 10.9602 18.7383C10.3744 19.3241 9.42462 19.3241 8.83883 18.7383L1.06066 10.9602L0.957771 10.8462C0.509245 10.2963 0.509245 9.50267 0.957771 8.95277L1.06066 8.83883L8.83883 1.06066C9.42462 0.474874 10.3744 0.474874 10.9602 1.06066Z",prevBtnSize:18,nextBtnSize:18,color:N.color.accent50,borderColor:N.color.accent50,borderWidth:0},emphasis:{label:{show:!0,color:N.color.accent60},itemStyle:{color:N.color.accent60,borderColor:N.color.accent60},controlStyle:{color:N.color.accent70,borderColor:N.color.accent70}},progress:{lineStyle:{color:N.color.accent30},itemStyle:{color:N.color.accent40}},data:[]}),t}(sC);Qt(QP,tc.prototype);var x9=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="timeline",t}(Wt),b9=function(r){z(t,r);function t(e,a,n,i){var o=r.call(this,e,a,n)||this;return o.type=i||"value",o}return t.prototype.getLabelModel=function(){return this.model.getModel("label")},t.prototype.isHorizontal=function(){return this.model.get("orient")==="horizontal"},t}($r),Dd=Math.PI,lC=St(),w9=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(e,a){this.api=a},t.prototype.render=function(e,a,n){if(this.model=e,this.api=n,this.ecModel=a,this.group.removeAll(),e.get("show",!0)){var i=this._layout(e,n),o=this._createGroup("_mainGroup"),s=this._createGroup("_labelGroup"),l=this._axis=this._createAxis(i,e);e.formatTooltip=function(u){var f=l.scale.getLabel({value:u});return ue("nameValue",{noName:!0,value:f})},A(["AxisLine","AxisTick","Control","CurrentPointer"],function(u){this["_render"+u](i,o,l,e)},this),this._renderAxisLabel(i,s,l,e),this._position(i,e)}this._doPlayStop(),this._updateTicksStatus()},t.prototype.remove=function(){this._clearTimer(),this.group.removeAll()},t.prototype.dispose=function(){this._clearTimer()},t.prototype._layout=function(e,a){var n=e.get(["label","position"]),i=e.get("orient"),o=C9(e,a),s;n==null||n==="auto"?s=i==="horizontal"?o.y+o.height/2<a.getHeight()/2?"-":"+":o.x+o.width/2<a.getWidth()/2?"+":"-":X(n)?s={horizontal:{top:"-",bottom:"+"},vertical:{left:"-",right:"+"}}[i][n]:s=n;var l={horizontal:"center",vertical:s>=0||s==="+"?"left":"right"},u={horizontal:s>=0||s==="+"?"top":"bottom",vertical:"middle"},f={horizontal:0,vertical:Dd/2},v=i==="vertical"?o.height:o.width,h=e.getModel("controlStyle"),c=h.get("show",!0),p=c?h.get("itemSize"):0,d=c?h.get("itemGap"):0,g=p+d,y=e.get(["label","rotate"])||0;y=y*Dd/180;var m,_,S,x=h.get("position",!0),b=c&&h.get("showPlayBtn",!0),w=c&&h.get("showPrevBtn",!0),T=c&&h.get("showNextBtn",!0),C=0,M=v;x==="left"||x==="bottom"?(b&&(m=[0,0],C+=g),w&&(_=[C,0],C+=g),T&&(S=[M-p,0],M-=g)):(b&&(m=[M-p,0],M-=g),w&&(_=[0,0],C+=g),T&&(S=[M-p,0],M-=g));var D=[C,M];return e.get("inverse")&&D.reverse(),{viewRect:o,mainLength:v,orient:i,rotation:f[i],labelRotation:y,labelPosOpt:s,labelAlign:e.get(["label","align"])||l[i],labelBaseline:e.get(["label","verticalAlign"])||e.get(["label","baseline"])||u[i],playPosition:m,prevBtnPosition:_,nextBtnPosition:S,axisExtent:D,controlSize:p,controlGap:d}},t.prototype._position=function(e,a){var n=this._mainGroup,i=this._labelGroup,o=e.viewRect;if(e.orient==="vertical"){var s=me(),l=o.x,u=o.y+o.height;Ur(s,s,[-l,-u]),Qa(s,s,-Dd/2),Ur(s,s,[l,u]),o=o.clone(),o.applyTransform(s)}var f=m(o),v=m(n.getBoundingRect()),h=m(i.getBoundingRect()),c=[n.x,n.y],p=[i.x,i.y];p[0]=c[0]=f[0][0];var d=e.labelPosOpt;if(d==null||X(d)){var g=d==="+"?0:1;_(c,v,f,1,g),_(p,h,f,1,1-g)}else{var g=d>=0?0:1;_(c,v,f,1,g),p[1]=c[1]+d}n.setPosition(c),i.setPosition(p),n.rotation=i.rotation=e.rotation,y(n),y(i);function y(S){S.originX=f[0][0]-S.x,S.originY=f[1][0]-S.y}function m(S){return[[S.x,S.x+S.width],[S.y,S.y+S.height]]}function _(S,x,b,w,T){S[w]+=b[w][T]-x[w][T]}},t.prototype._createAxis=function(e,a){var n=a.getData(),i=a.get("axisType"),o=T9(a,i);o.getTicks=function(){return n.mapArray(["value"],function(u){return{value:u}})};var s=n.getDataExtent("value");o.setExtent(s[0],s[1]),o.calcNiceTicks();var l=new b9("value",o,e.axisExtent,i);return l.model=a,l},t.prototype._createGroup=function(e){var a=this[e]=new rt;return this.group.add(a),a},t.prototype._renderAxisLine=function(e,a,n,i){var o=n.getExtent();if(i.get(["lineStyle","show"])){var s=new ne({shape:{x1:o[0],y1:0,x2:o[1],y2:0},style:G({lineCap:"round"},i.getModel("lineStyle").getLineStyle()),silent:!0,z2:1});a.add(s);var l=this._progressLine=new ne({shape:{x1:o[0],x2:this._currentPointer?this._currentPointer.x:o[0],y1:0,y2:0},style:nt({lineCap:"round",lineWidth:s.style.lineWidth},i.getModel(["progress","lineStyle"]).getLineStyle()),silent:!0,z2:1});a.add(l)}},t.prototype._renderAxisTick=function(e,a,n,i){var o=this,s=i.getData(),l=n.scale.getTicks();this._tickSymbols=[],A(l,function(u){var f=n.dataToCoord(u.value),v=s.getItemModel(u.value),h=v.getModel("itemStyle"),c=v.getModel(["emphasis","itemStyle"]),p=v.getModel(["progress","itemStyle"]),d={x:f,y:0,onclick:$(o._changeTimeline,o,u.value)},g=uC(v,h,a,d);g.ensureState("emphasis").style=c.getItemStyle(),g.ensureState("progress").style=p.getItemStyle(),Cn(g);var y=ut(g);v.get("tooltip")?(y.dataIndex=u.value,y.dataModel=i):y.dataIndex=y.dataModel=null,o._tickSymbols.push(g)})},t.prototype._renderAxisLabel=function(e,a,n,i){var o=this,s=n.getLabelModel();if(s.get("show")){var l=i.getData(),u=n.getViewLabels();this._tickLabels=[],A(u,function(f){var v=f.tickValue,h=l.getItemModel(v),c=h.getModel("label"),p=h.getModel(["emphasis","label"]),d=h.getModel(["progress","label"]),g=n.dataToCoord(f.tickValue),y=new At({x:g,y:0,rotation:e.labelRotation-e.rotation,onclick:$(o._changeTimeline,o,v),silent:!1,style:Gt(c,{text:f.formattedLabel,align:e.labelAlign,verticalAlign:e.labelBaseline})});y.ensureState("emphasis").style=Gt(p),y.ensureState("progress").style=Gt(d),a.add(y),Cn(y),lC(y).dataIndex=v,o._tickLabels.push(y)})}},t.prototype._renderControl=function(e,a,n,i){var o=e.controlSize,s=e.rotation,l=i.getModel("controlStyle").getItemStyle(),u=i.getModel(["emphasis","controlStyle"]).getItemStyle(),f=i.getPlayState(),v=i.get("inverse",!0);h(e.nextBtnPosition,"next",$(this._changeTimeline,this,v?"-":"+")),h(e.prevBtnPosition,"prev",$(this._changeTimeline,this,v?"+":"-")),h(e.playPosition,f?"stop":"play",$(this._handlePlayClick,this,!f),!0);function h(c,p,d,g){if(c){var y=Yr(Q(i.get(["controlStyle",p+"BtnSize"]),o),o),m=[0,-y/2,y,y],_=A9(i,p+"Icon",m,{x:c[0],y:c[1],originX:o/2,originY:0,rotation:g?-s:0,rectHover:!0,style:l,onclick:d});_.ensureState("emphasis").style=u,a.add(_),Cn(_)}}},t.prototype._renderCurrentPointer=function(e,a,n,i){var o=i.getData(),s=i.getCurrentIndex(),l=o.getItemModel(s).getModel("checkpointStyle"),u=this,f={onCreate:function(v){v.draggable=!0,v.drift=$(u._handlePointerDrag,u),v.ondragend=$(u._handlePointerDragend,u),fC(v,u._progressLine,s,n,i,!0)},onUpdate:function(v){fC(v,u._progressLine,s,n,i)}};this._currentPointer=uC(l,l,this._mainGroup,{},this._currentPointer,f)},t.prototype._handlePlayClick=function(e){this._clearTimer(),this.api.dispatchAction({type:"timelinePlayChange",playState:e,from:this.uid})},t.prototype._handlePointerDrag=function(e,a,n){this._clearTimer(),this._pointerChangeTimeline([n.offsetX,n.offsetY])},t.prototype._handlePointerDragend=function(e){this._pointerChangeTimeline([e.offsetX,e.offsetY],!0)},t.prototype._pointerChangeTimeline=function(e,a){var n=this._toAxisCoord(e)[0],i=this._axis,o=lr(i.getExtent().slice());n>o[1]&&(n=o[1]),n<o[0]&&(n=o[0]),this._currentPointer.x=n,this._currentPointer.markRedraw();var s=this._progressLine;s&&(s.shape.x2=n,s.dirty());var l=this._findNearestTick(n),u=this.model;(a||l!==u.getCurrentIndex()&&u.get("realtime"))&&this._changeTimeline(l)},t.prototype._doPlayStop=function(){var e=this;this._clearTimer(),this.model.getPlayState()&&(this._timer=setTimeout(function(){var a=e.model;e._changeTimeline(a.getCurrentIndex()+(a.get("rewind",!0)?-1:1))},this.model.get("playInterval")))},t.prototype._toAxisCoord=function(e){var a=this._mainGroup.getLocalTransform();return Hr(e,a,!0)},t.prototype._findNearestTick=function(e){var a=this.model.getData(),n=1/0,i,o=this._axis;return a.each(["value"],function(s,l){var u=o.dataToCoord(s),f=Math.abs(u-e);f<n&&(n=f,i=l)}),i},t.prototype._clearTimer=function(){this._timer&&(clearTimeout(this._timer),this._timer=null)},t.prototype._changeTimeline=function(e){var a=this.model.getCurrentIndex();e==="+"?e=a+1:e==="-"&&(e=a-1),this.api.dispatchAction({type:"timelineChange",currentIndex:e,from:this.uid})},t.prototype._updateTicksStatus=function(){var e=this.model.getCurrentIndex(),a=this._tickSymbols,n=this._tickLabels;if(a)for(var i=0;i<a.length;i++)a&&a[i]&&a[i].toggleState("progress",i<e);if(n)for(var i=0;i<n.length;i++)n&&n[i]&&n[i].toggleState("progress",lC(n[i]).dataIndex<=e)},t.type="timeline.slider",t}(x9);function T9(r,t){if(t=t||r.get("type"),t)switch(t){case"category":return new is({ordinalMeta:r.getCategories(),extent:[1/0,-1/0]});case"time":return new c0({locale:r.ecModel.getLocaleModel(),useUTC:r.ecModel.get("useUTC")});default:return new ja}}function C9(r,t){return Xt(r.getBoxLayoutParams(),pe(r,t).refContainer,r.get("padding"))}function A9(r,t,e,a){var n=a.style,i=Ss(r.get(["controlStyle",t]),a||{},new lt(e[0],e[1],e[2],e[3]));return n&&i.setStyle(n),i}function uC(r,t,e,a,n,i){var o=t.get("color");if(n)n.setColor(o),e.add(n),i&&i.onUpdate(n);else{var s=r.get("symbol");n=ie(s,-1,-1,2,2,o),n.setStyle("strokeNoScale",!0),e.add(n),i&&i.onCreate(n)}var l=t.getItemStyle(["color"]);n.setStyle(l),a=yt({rectHover:!0,z2:100},a,!0);var u=Ms(r.get("symbolSize"));a.scaleX=u[0]/2,a.scaleY=u[1]/2;var f=to(r.get("symbolOffset"),u);f&&(a.x=(a.x||0)+f[0],a.y=(a.y||0)+f[1]);var v=r.get("symbolRotate");return a.rotation=(v||0)*Math.PI/180||0,n.attr(a),n.updateTransform(),n}function fC(r,t,e,a,n,i){if(!r.dragging){var o=n.getModel("checkpointStyle"),s=a.dataToCoord(n.getData().get("value",e));if(i||!o.get("animation",!0))r.attr({x:s,y:0}),t&&t.attr({shape:{x2:s}});else{var l={duration:o.get("animationDuration",!0),easing:o.get("animationEasing",!0)};r.stopAnimation(null,!0),r.animateTo({x:s,y:0},l),t&&t.animateTo({shape:{x2:s}},l)}}}function M9(r){r.registerAction({type:"timelineChange",event:"timelineChanged",update:"prepareAndUpdate"},function(t,e,a){var n=e.getComponent("timeline");return n&&t.currentIndex!=null&&(n.setCurrentIndex(t.currentIndex),!n.get("loop",!0)&&n.isIndexMax()&&n.getPlayState()&&(n.setPlayState(!1),a.dispatchAction({type:"timelinePlayChange",playState:!1,from:t.from}))),e.resetOption("timeline",{replaceMerge:n.get("replaceMerge",!0)}),nt({currentIndex:n.option.currentIndex},t)}),r.registerAction({type:"timelinePlayChange",event:"timelinePlayChanged",update:"update"},function(t,e){var a=e.getComponent("timeline");a&&t.playState!=null&&a.setPlayState(t.playState)})}function D9(r){var t=r&&r.timeline;W(t)||(t=t?[t]:[]),A(t,function(e){e&&L9(e)})}function L9(r){var t=r.type,e={number:"value",time:"time"};if(e[t]&&(r.axisType=e[t],delete r.type),vC(r),wi(r,"controlPosition")){var a=r.controlStyle||(r.controlStyle={});wi(a,"position")||(a.position=r.controlPosition),a.position==="none"&&!wi(a,"show")&&(a.show=!1,delete a.position),delete r.controlPosition}A(r.data||[],function(n){it(n)&&!W(n)&&(!wi(n,"value")&&wi(n,"name")&&(n.value=n.name),vC(n))})}function vC(r){var t=r.itemStyle||(r.itemStyle={}),e=t.emphasis||(t.emphasis={}),a=r.label||r.label||{},n=a.normal||(a.normal={}),i={normal:1,emphasis:1};A(a,function(o,s){!i[s]&&!wi(n,s)&&(n[s]=o)}),e.label&&!wi(a,"emphasis")&&(a.emphasis=e.label,delete e.label)}function wi(r,t){return r.hasOwnProperty(t)}function I9(r){r.registerComponentModel(QP),r.registerComponentView(w9),r.registerSubTypeDefaulter("timeline",function(){return"slider"}),M9(r),r.registerPreprocessor(D9)}function x_(r,t){if(!r)return!1;for(var e=W(r)?r:[r],a=0;a<e.length;a++)if(e[a]&&e[a][t])return!0;return!1}function Xf(r){Vi(r,"label",["show"])}var $f=St(),xa=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.createdBySelf=!1,e.preventAutoZ=!0,e}return t.prototype.init=function(e,a,n){this.mergeDefaultAndTheme(e,n),this._mergeOption(e,n,!1,!0)},t.prototype.isAnimationEnabled=function(){if(Tt.node)return!1;var e=this.__hostSeries;return this.getShallow("animation")&&e&&e.isAnimationEnabled()},t.prototype.mergeOption=function(e,a){this._mergeOption(e,a,!1,!1)},t.prototype._mergeOption=function(e,a,n,i){var o=this.mainType;n||a.eachSeries(function(s){var l=s.get(this.mainType,!0),u=$f(s)[o];if(!l||!l.data){$f(s)[o]=null;return}u?u._mergeOption(l,a,!0):(i&&Xf(l),A(l.data,function(f){f instanceof Array?(Xf(f[0]),Xf(f[1])):Xf(f)}),u=this.createMarkerModelFromSeries(l,this,a),G(u,{mainType:this.mainType,seriesIndex:s.seriesIndex,name:s.name,createdBySelf:!0}),u.__hostSeries=s),$f(s)[o]=u},this)},t.prototype.formatTooltip=function(e,a,n){var i=this.getData(),o=this.getRawValue(e),s=i.getName(e);return ue("section",{header:this.name,blocks:[ue("nameValue",{name:s,value:o,noName:!s,noValue:o==null})]})},t.prototype.getData=function(){return this._data},t.prototype.setData=function(e){this._data=e},t.prototype.getDataParams=function(e,a){var n=tc.prototype.getDataParams.call(this,e,a),i=this.__hostSeries;return i&&(n.seriesId=i.id,n.seriesName=i.name,n.seriesType=i.subType),n},t.getMarkerModelFromSeries=function(e,a){return $f(e)[a]},t.type="marker",t.dependencies=["series","grid","polar","geo"],t}(xt);Qt(xa,tc.prototype);var P9=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.createMarkerModelFromSeries=function(e,a,n){return new t(e,a,n)},t.type="markPoint",t.defaultOption={z:5,symbol:"pin",symbolSize:50,tooltip:{trigger:"item"},label:{show:!0,position:"inside"},itemStyle:{borderWidth:2},emphasis:{label:{show:!0}}},t}(xa);function Fy(r){return!(isNaN(parseFloat(r.x))&&isNaN(parseFloat(r.y)))}function R9(r){return!isNaN(parseFloat(r.x))&&!isNaN(parseFloat(r.y))}function qf(r,t,e,a,n,i,o){var s=[],l=Ka(t,n),u=l?t.getCalculationInfo("stackResultDimension"):n,f=wh(t,u,r),v=t.hostModel,h=v.indicesOfNearest(e,u,f)[0];s[i]=t.get(a,h),s[o]=t.get(u,h);var c=t.get(n,h),p=zr(t.get(n,h));return p=Math.min(p,20),p>=0&&(s[o]=+s[o].toFixed(p)),[s,c]}var Kf={min:pt(qf,"min"),max:pt(qf,"max"),average:pt(qf,"average"),median:pt(qf,"median")};function gu(r,t){if(t){var e=r.getData(),a=r.coordinateSystem,n=a&&a.dimensions;if(!R9(t)&&!W(t.coord)&&W(n)){var i=tR(t,e,a,r);if(t=et(t),t.type&&Kf[t.type]&&i.baseAxis&&i.valueAxis){var o=gt(n,i.baseAxis.dim),s=gt(n,i.valueAxis.dim),l=Kf[t.type](e,i.valueAxis.dim,i.baseDataDim,i.valueDataDim,o,s);t.coord=l[0],t.value=l[1]}else t.coord=[t.xAxis!=null?t.xAxis:t.radiusAxis,t.yAxis!=null?t.yAxis:t.angleAxis]}if(t.coord==null||!W(n)){t.coord=[];var u=r.getBaseAxis();if(u&&t.type&&Kf[t.type]){var f=a.getOtherAxis(u);f&&(t.value=wh(e,e.mapDimension(f.dim),t.type))}}else for(var v=t.coord,h=0;h<2;h++)Kf[v[h]]&&(v[h]=wh(e,e.mapDimension(n[h]),v[h]));return t}}function tR(r,t,e,a){var n={};return r.valueIndex!=null||r.valueDim!=null?(n.valueDataDim=r.valueIndex!=null?t.getDimension(r.valueIndex):r.valueDim,n.valueAxis=e.getAxis(k9(a,n.valueDataDim)),n.baseAxis=e.getOtherAxis(n.valueAxis),n.baseDataDim=t.mapDimension(n.baseAxis.dim)):(n.baseAxis=a.getBaseAxis(),n.valueAxis=e.getOtherAxis(n.baseAxis),n.baseDataDim=t.mapDimension(n.baseAxis.dim),n.valueDataDim=t.mapDimension(n.valueAxis.dim)),n}function k9(r,t){var e=r.getData().getDimensionInfo(t);return e&&e.coordDim}function yu(r,t){return r&&r.containData&&t.coord&&!Fy(t)?r.containData(t.coord):!0}function E9(r,t,e){return r&&r.containZone&&t.coord&&e.coord&&!Fy(t)&&!Fy(e)?r.containZone(t.coord,e.coord):!0}function eR(r,t){return r?function(e,a,n,i){var o=i<2?e.coord&&e.coord[i]:e.value;return Dn(o,t[i])}:function(e,a,n,i){return Dn(e.value,t[i])}}function wh(r,t,e){if(e==="average"){var a=0,n=0;return r.each(t,function(i,o){isNaN(i)||(a+=i,n++)}),a/n}else return e==="median"?r.getMedian(t):r.getDataExtent(t)[e==="max"?1:0]}var Ld=St(),b_=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(){this.markerGroupMap=j()},t.prototype.render=function(e,a,n){var i=this,o=this.markerGroupMap;o.each(function(s){Ld(s).keep=!1}),a.eachSeries(function(s){var l=xa.getMarkerModelFromSeries(s,i.type);l&&i.renderSeries(s,l,a,n)}),o.each(function(s){!Ld(s).keep&&i.group.remove(s.group)}),O9(a,o,this.type)},t.prototype.markKeep=function(e){Ld(e).keep=!0},t.prototype.toggleBlurSeries=function(e,a){var n=this;A(e,function(i){var o=xa.getMarkerModelFromSeries(i,n.type);if(o){var s=o.getData();s.eachItemGraphicEl(function(l){l&&(a?yM(l):bm(l))})}})},t.type="marker",t}(Wt);function O9(r,t,e){r.eachSeries(function(a){var n=xa.getMarkerModelFromSeries(a,e),i=t.get(a.id);if(n&&i&&i.group){var o=Ui(n),s=o.z,l=o.zlevel;Kh(i.group,s,l)}})}function hC(r,t,e){var a=t.coordinateSystem,n=e.getWidth(),i=e.getHeight(),o=a&&a.getArea&&a.getArea();r.each(function(s){var l=r.getItemModel(s),u=l.get("relativeTo")==="coordinate",f=u?o?o.width:0:n,v=u?o?o.height:0:i,h=u&&o?o.x:0,c=u&&o?o.y:0,p,d=Z(l.get("x"),f)+h,g=Z(l.get("y"),v)+c;if(!isNaN(d)&&!isNaN(g))p=[d,g];else if(t.getMarkerPosition)p=t.getMarkerPosition(r.getValues(r.dimensions,s));else if(a){var y=r.get(a.dimensions[0],s),m=r.get(a.dimensions[1],s);p=a.dataToPoint([y,m])}isNaN(d)||(p[0]=d),isNaN(g)||(p[1]=g),r.setItemLayout(s,p)})}var N9=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.updateTransform=function(e,a,n){a.eachSeries(function(i){var o=xa.getMarkerModelFromSeries(i,"markPoint");o&&(hC(o.getData(),i,n),this.markerGroupMap.get(i.id).updateLayout())},this)},t.prototype.renderSeries=function(e,a,n,i){var o=e.coordinateSystem,s=e.id,l=e.getData(),u=this.markerGroupMap,f=u.get(s)||u.set(s,new Eu),v=B9(o,e,a);a.setData(v),hC(a.getData(),e,i),v.each(function(h){var c=v.getItemModel(h),p=c.getShallow("symbol"),d=c.getShallow("symbolSize"),g=c.getShallow("symbolRotate"),y=c.getShallow("symbolOffset"),m=c.getShallow("symbolKeepAspect");if(tt(p)||tt(d)||tt(g)||tt(y)){var _=a.getRawValue(h),S=a.getDataParams(h);tt(p)&&(p=p(_,S)),tt(d)&&(d=d(_,S)),tt(g)&&(g=g(_,S)),tt(y)&&(y=y(_,S))}var x=c.getModel("itemStyle").getItemStyle(),b=c.get("z2"),w=Pu(l,"color");x.fill||(x.fill=w),v.setItemVisual(h,{z2:Q(b,0),symbol:p,symbolSize:d,symbolRotate:g,symbolOffset:y,symbolKeepAspect:m,style:x})}),f.updateData(v),this.group.add(f.group),v.eachItemGraphicEl(function(h){h.traverse(function(c){ut(c).dataModel=a})}),this.markKeep(f),f.group.silent=a.get("silent")||e.get("silent")},t.type="markPoint",t}(b_);function B9(r,t,e){var a;r?a=U(r&&r.dimensions,function(s){var l=t.getData().getDimensionInfo(t.getData().mapDimension(s))||{};return G(G({},l),{name:s,ordinalMeta:null})}):a=[{name:"value",type:"float"}];var n=new Ue(a,e),i=U(e.get("data"),pt(gu,t));r&&(i=Pt(i,pt(yu,r)));var o=eR(!!r,a);return n.initData(i,null,o),n}function z9(r){r.registerComponentModel(P9),r.registerComponentView(N9),r.registerPreprocessor(function(t){x_(t.series,"markPoint")&&(t.markPoint=t.markPoint||{})})}var V9=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.createMarkerModelFromSeries=function(e,a,n){return new t(e,a,n)},t.type="markLine",t.defaultOption={z:5,symbol:["circle","arrow"],symbolSize:[8,16],symbolOffset:0,precision:2,tooltip:{trigger:"item"},label:{show:!0,position:"end",distance:5},lineStyle:{type:"dashed"},emphasis:{label:{show:!0},lineStyle:{width:3}},animationEasing:"linear"},t}(xa),jf=St(),G9=function(r,t,e,a){var n=r.getData(),i;if(W(a))i=a;else{var o=a.type;if(o==="min"||o==="max"||o==="average"||o==="median"||a.xAxis!=null||a.yAxis!=null){var s=void 0,l=void 0;if(a.yAxis!=null||a.xAxis!=null)s=t.getAxis(a.yAxis!=null?"y":"x"),l=Ce(a.yAxis,a.xAxis);else{var u=tR(a,n,t,r);s=u.valueAxis;var f=f0(n,u.valueDataDim);l=wh(n,f,o)}var v=s.dim==="x"?0:1,h=1-v,c=et(a),p={coord:[]};c.type=null,c.coord=[],c.coord[h]=-1/0,p.coord[h]=1/0;var d=e.get("precision");d>=0&&Mt(l)&&(l=+l.toFixed(Math.min(d,20))),c.coord[v]=p.coord[v]=l,i=[c,p,{type:o,valueIndex:a.valueIndex,value:l}]}else i=[]}var g=[gu(r,i[0]),gu(r,i[1]),G({},i[2])];return g[2].type=g[2].type||null,yt(g[2],g[0]),yt(g[2],g[1]),g};function Th(r){return!isNaN(r)&&!isFinite(r)}function cC(r,t,e,a){var n=1-r,i=a.dimensions[r];return Th(t[n])&&Th(e[n])&&t[r]===e[r]&&a.getAxis(i).containData(t[r])}function F9(r,t){if(r.type==="cartesian2d"){var e=t[0].coord,a=t[1].coord;if(e&&a&&(cC(1,e,a,r)||cC(0,e,a,r)))return!0}return yu(r,t[0])&&yu(r,t[1])}function Id(r,t,e,a,n){var i=a.coordinateSystem,o=r.getItemModel(t),s,l=Z(o.get("x"),n.getWidth()),u=Z(o.get("y"),n.getHeight());if(!isNaN(l)&&!isNaN(u))s=[l,u];else{if(a.getMarkerPosition)s=a.getMarkerPosition(r.getValues(r.dimensions,t));else{var f=i.dimensions,v=r.get(f[0],t),h=r.get(f[1],t);s=i.dataToPoint([v,h])}if(Rn(i,"cartesian2d")){var c=i.getAxis("x"),p=i.getAxis("y"),f=i.dimensions;Th(r.get(f[0],t))?s[0]=c.toGlobalCoord(c.getExtent()[e?0:1]):Th(r.get(f[1],t))&&(s[1]=p.toGlobalCoord(p.getExtent()[e?0:1]))}isNaN(l)||(s[0]=l),isNaN(u)||(s[1]=u)}r.setItemLayout(t,s)}var H9=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.updateTransform=function(e,a,n){a.eachSeries(function(i){var o=xa.getMarkerModelFromSeries(i,"markLine");if(o){var s=o.getData(),l=jf(o).from,u=jf(o).to;l.each(function(f){Id(l,f,!0,i,n),Id(u,f,!1,i,n)}),s.each(function(f){s.setItemLayout(f,[l.getItemLayout(f),u.getItemLayout(f)])}),this.markerGroupMap.get(i.id).updateLayout()}},this)},t.prototype.renderSeries=function(e,a,n,i){var o=e.coordinateSystem,s=e.id,l=e.getData(),u=this.markerGroupMap,f=u.get(s)||u.set(s,new F0);this.group.add(f.group);var v=W9(o,e,a),h=v.from,c=v.to,p=v.line;jf(a).from=h,jf(a).to=c,a.setData(p);var d=a.get("symbol"),g=a.get("symbolSize"),y=a.get("symbolRotate"),m=a.get("symbolOffset");W(d)||(d=[d,d]),W(g)||(g=[g,g]),W(y)||(y=[y,y]),W(m)||(m=[m,m]),v.from.each(function(S){_(h,S,!0),_(c,S,!1)}),p.each(function(S){var x=p.getItemModel(S),b=x.getModel("lineStyle").getLineStyle();p.setItemLayout(S,[h.getItemLayout(S),c.getItemLayout(S)]);var w=x.get("z2");b.stroke==null&&(b.stroke=h.getItemVisual(S,"style").fill),p.setItemVisual(S,{z2:Q(w,0),fromSymbolKeepAspect:h.getItemVisual(S,"symbolKeepAspect"),fromSymbolOffset:h.getItemVisual(S,"symbolOffset"),fromSymbolRotate:h.getItemVisual(S,"symbolRotate"),fromSymbolSize:h.getItemVisual(S,"symbolSize"),fromSymbol:h.getItemVisual(S,"symbol"),toSymbolKeepAspect:c.getItemVisual(S,"symbolKeepAspect"),toSymbolOffset:c.getItemVisual(S,"symbolOffset"),toSymbolRotate:c.getItemVisual(S,"symbolRotate"),toSymbolSize:c.getItemVisual(S,"symbolSize"),toSymbol:c.getItemVisual(S,"symbol"),style:b})}),f.updateData(p),v.line.eachItemGraphicEl(function(S){ut(S).dataModel=a,S.traverse(function(x){ut(x).dataModel=a})});function _(S,x,b){var w=S.getItemModel(x);Id(S,x,b,e,i);var T=w.getModel("itemStyle").getItemStyle();T.fill==null&&(T.fill=Pu(l,"color")),S.setItemVisual(x,{symbolKeepAspect:w.get("symbolKeepAspect"),symbolOffset:Q(w.get("symbolOffset",!0),m[b?0:1]),symbolRotate:Q(w.get("symbolRotate",!0),y[b?0:1]),symbolSize:Q(w.get("symbolSize"),g[b?0:1]),symbol:Q(w.get("symbol",!0),d[b?0:1]),style:T})}this.markKeep(f),f.group.silent=a.get("silent")||e.get("silent")},t.type="markLine",t}(b_);function W9(r,t,e){var a;r?a=U(r&&r.dimensions,function(u){var f=t.getData().getDimensionInfo(t.getData().mapDimension(u))||{};return G(G({},f),{name:u,ordinalMeta:null})}):a=[{name:"value",type:"float"}];var n=new Ue(a,e),i=new Ue(a,e),o=new Ue([],e),s=U(e.get("data"),pt(G9,t,r,e));r&&(s=Pt(s,pt(F9,r)));var l=eR(!!r,a);return n.initData(U(s,function(u){return u[0]}),null,l),i.initData(U(s,function(u){return u[1]}),null,l),o.initData(U(s,function(u){return u[2]})),o.hasItemOption=!0,{from:n,to:i,line:o}}function U9(r){r.registerComponentModel(V9),r.registerComponentView(H9),r.registerPreprocessor(function(t){x_(t.series,"markLine")&&(t.markLine=t.markLine||{})})}var Y9=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.createMarkerModelFromSeries=function(e,a,n){return new t(e,a,n)},t.type="markArea",t.defaultOption={z:1,tooltip:{trigger:"item"},animation:!1,label:{show:!0,position:"top"},itemStyle:{borderWidth:0},emphasis:{label:{show:!0,position:"top"}}},t}(xa),Jf=St(),Z9=function(r,t,e,a){var n=a[0],i=a[1];if(!(!n||!i)){var o=gu(r,n),s=gu(r,i),l=o.coord,u=s.coord;l[0]=Ce(l[0],-1/0),l[1]=Ce(l[1],-1/0),u[0]=Ce(u[0],1/0),u[1]=Ce(u[1],1/0);var f=kh([{},o,s]);return f.coord=[o.coord,s.coord],f.x0=o.x,f.y0=o.y,f.x1=s.x,f.y1=s.y,f}};function Ch(r){return!isNaN(r)&&!isFinite(r)}function pC(r,t,e,a){var n=1-r;return Ch(t[n])&&Ch(e[n])}function X9(r,t){var e=t.coord[0],a=t.coord[1],n={coord:e,x:t.x0,y:t.y0},i={coord:a,x:t.x1,y:t.y1};return Rn(r,"cartesian2d")?e&&a&&(pC(1,e,a)||pC(0,e,a))?!0:E9(r,n,i):yu(r,n)||yu(r,i)}function dC(r,t,e,a,n){var i=a.coordinateSystem,o=r.getItemModel(t),s,l=Z(o.get(e[0]),n.getWidth()),u=Z(o.get(e[1]),n.getHeight());if(!isNaN(l)&&!isNaN(u))s=[l,u];else{if(a.getMarkerPosition){var f=r.getValues(["x0","y0"],t),v=r.getValues(["x1","y1"],t),h=i.clampData(f),c=i.clampData(v),p=[];e[0]==="x0"?p[0]=h[0]>c[0]?v[0]:f[0]:p[0]=h[0]>c[0]?f[0]:v[0],e[1]==="y0"?p[1]=h[1]>c[1]?v[1]:f[1]:p[1]=h[1]>c[1]?f[1]:v[1],s=a.getMarkerPosition(p,e,!0)}else{var d=r.get(e[0],t),g=r.get(e[1],t),y=[d,g];i.clampData&&i.clampData(y,y),s=i.dataToPoint(y,!0)}if(Rn(i,"cartesian2d")){var m=i.getAxis("x"),_=i.getAxis("y"),d=r.get(e[0],t),g=r.get(e[1],t);Ch(d)?s[0]=m.toGlobalCoord(m.getExtent()[e[0]==="x0"?0:1]):Ch(g)&&(s[1]=_.toGlobalCoord(_.getExtent()[e[1]==="y0"?0:1]))}isNaN(l)||(s[0]=l),isNaN(u)||(s[1]=u)}return s}var gC=[["x0","y0"],["x1","y0"],["x1","y1"],["x0","y1"]],$9=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.updateTransform=function(e,a,n){a.eachSeries(function(i){var o=xa.getMarkerModelFromSeries(i,"markArea");if(o){var s=o.getData();s.each(function(l){var u=U(gC,function(v){return dC(s,l,v,i,n)});s.setItemLayout(l,u);var f=s.getItemGraphicEl(l);f.setShape("points",u)})}},this)},t.prototype.renderSeries=function(e,a,n,i){var o=e.coordinateSystem,s=e.id,l=e.getData(),u=this.markerGroupMap,f=u.get(s)||u.set(s,{group:new rt});this.group.add(f.group),this.markKeep(f);var v=q9(o,e,a);a.setData(v),v.each(function(h){var c=U(gC,function(M){return dC(v,h,M,e,i)}),p=o.getAxis("x").scale,d=o.getAxis("y").scale,g=p.getExtent(),y=d.getExtent(),m=[p.parse(v.get("x0",h)),p.parse(v.get("x1",h))],_=[d.parse(v.get("y0",h)),d.parse(v.get("y1",h))];lr(m),lr(_);var S=!(g[0]>m[1]||g[1]<m[0]||y[0]>_[1]||y[1]<_[0]),x=!S;v.setItemLayout(h,{points:c,allClipped:x});var b=v.getItemModel(h),w=b.getModel("itemStyle").getItemStyle(),T=b.get("z2"),C=Pu(l,"color");w.fill||(w.fill=C,X(w.fill)&&(w.fill=Ul(w.fill,.4))),w.stroke||(w.stroke=C),v.setItemVisual(h,"style",w),v.setItemVisual(h,"z2",Q(T,0))}),v.diff(Jf(f).data).add(function(h){var c=v.getItemLayout(h),p=v.getItemVisual(h,"z2");if(!c.allClipped){var d=new Ee({z2:Q(p,0),shape:{points:c.points}});v.setItemGraphicEl(h,d),f.group.add(d)}}).update(function(h,c){var p=Jf(f).data.getItemGraphicEl(c),d=v.getItemLayout(h),g=v.getItemVisual(h,"z2");d.allClipped?p&&f.group.remove(p):(p?Lt(p,{z2:Q(g,0),shape:{points:d.points}},a,h):p=new Ee({shape:{points:d.points}}),v.setItemGraphicEl(h,p),f.group.add(p))}).remove(function(h){var c=Jf(f).data.getItemGraphicEl(h);f.group.remove(c)}).execute(),v.eachItemGraphicEl(function(h,c){var p=v.getItemModel(c),d=v.getItemVisual(c,"style");h.useStyle(v.getItemVisual(c,"style")),Se(h,ce(p),{labelFetcher:a,labelDataIndex:c,defaultText:v.getName(c)||"",inheritColor:X(d.fill)?Ul(d.fill,1):N.color.neutral99}),he(h,p),$t(h,null,null,p.get(["emphasis","disabled"])),ut(h).dataModel=a}),Jf(f).data=v,f.group.silent=a.get("silent")||e.get("silent")},t.type="markArea",t}(b_);function q9(r,t,e){var a,n,i=["x0","y0","x1","y1"];if(r){var o=U(r&&r.dimensions,function(u){var f=t.getData(),v=f.getDimensionInfo(f.mapDimension(u))||{};return G(G({},v),{name:u,ordinalMeta:null})});n=U(i,function(u,f){return{name:u,type:o[f%2].type}}),a=new Ue(n,e)}else n=[{name:"value",type:"float"}],a=new Ue(n,e);var s=U(e.get("data"),pt(Z9,t,r,e));r&&(s=Pt(s,pt(X9,r)));var l=r?function(u,f,v,h){var c=u.coord[Math.floor(h/2)][h%2];return Dn(c,n[h])}:function(u,f,v,h){return Dn(u.value,n[h])};return a.initData(s,null,l),a.hasItemOption=!0,a}function K9(r){r.registerComponentModel(Y9),r.registerComponentView($9),r.registerPreprocessor(function(t){x_(t.series,"markArea")&&(t.markArea=t.markArea||{})})}var j9=function(r,t){if(t==="all")return{type:"all",title:r.getLocaleModel().get(["legend","selector","all"])};if(t==="inverse")return{type:"inverse",title:r.getLocaleModel().get(["legend","selector","inverse"])}},Hy=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.layoutMode={type:"box",ignoreSize:!0},e}return t.prototype.init=function(e,a,n){this.mergeDefaultAndTheme(e,n),e.selected=e.selected||{},this._updateSelector(e)},t.prototype.mergeOption=function(e,a){r.prototype.mergeOption.call(this,e,a),this._updateSelector(e)},t.prototype._updateSelector=function(e){var a=e.selector,n=this.ecModel;a===!0&&(a=e.selector=["all","inverse"]),W(a)&&A(a,function(i,o){X(i)&&(i={type:i}),a[o]=yt(i,j9(n,i.type))})},t.prototype.optionUpdated=function(){this._updateData(this.ecModel);var e=this._data;if(e[0]&&this.get("selectedMode")==="single"){for(var a=!1,n=0;n<e.length;n++){var i=e[n].get("name");if(this.isSelected(i)){this.select(i),a=!0;break}}!a&&this.select(e[0].get("name"))}},t.prototype._updateData=function(e){var a=[],n=[];e.eachRawSeries(function(l){var u=l.name;n.push(u);var f;if(l.legendVisualProvider){var v=l.legendVisualProvider,h=v.getAllNames();e.isSeriesFiltered(l)||(n=n.concat(h)),h.length?a=a.concat(h):f=!0}else f=!0;f&&cm(l)&&a.push(l.name)}),this._availableNames=n;var i=this.get("data")||a,o=j(),s=U(i,function(l){return(X(l)||Mt(l))&&(l={name:l}),o.get(l.name)?null:(o.set(l.name,!0),new wt(l,this,this.ecModel))},this);this._data=Pt(s,function(l){return!!l})},t.prototype.getData=function(){return this._data},t.prototype.select=function(e){var a=this.option.selected,n=this.get("selectedMode");if(n==="single"){var i=this._data;A(i,function(o){a[o.get("name")]=!1})}a[e]=!0},t.prototype.unSelect=function(e){this.get("selectedMode")!=="single"&&(this.option.selected[e]=!1)},t.prototype.toggleSelected=function(e){var a=this.option.selected;a.hasOwnProperty(e)||(a[e]=!0),this[a[e]?"unSelect":"select"](e)},t.prototype.allSelect=function(){var e=this._data,a=this.option.selected;A(e,function(n){a[n.get("name",!0)]=!0})},t.prototype.inverseSelect=function(){var e=this._data,a=this.option.selected;A(e,function(n){var i=n.get("name",!0);a.hasOwnProperty(i)||(a[i]=!0),a[i]=!a[i]})},t.prototype.isSelected=function(e){var a=this.option.selected;return!(a.hasOwnProperty(e)&&!a[e])&&gt(this._availableNames,e)>=0},t.prototype.getOrient=function(){return this.get("orient")==="vertical"?{index:1,name:"vertical"}:{index:0,name:"horizontal"}},t.type="legend.plain",t.dependencies=["series"],t.defaultOption={z:4,show:!0,orient:"horizontal",left:"center",bottom:N.size.m,align:"auto",backgroundColor:N.color.transparent,borderColor:N.color.border,borderRadius:0,borderWidth:0,padding:5,itemGap:8,itemWidth:25,itemHeight:14,symbolRotate:"inherit",symbolKeepAspect:!0,inactiveColor:N.color.disabled,inactiveBorderColor:N.color.disabled,inactiveBorderWidth:"auto",itemStyle:{color:"inherit",opacity:"inherit",borderColor:"inherit",borderWidth:"auto",borderCap:"inherit",borderJoin:"inherit",borderDashOffset:"inherit",borderMiterLimit:"inherit"},lineStyle:{width:"auto",color:"inherit",inactiveColor:N.color.disabled,inactiveWidth:2,opacity:"inherit",type:"inherit",cap:"inherit",join:"inherit",dashOffset:"inherit",miterLimit:"inherit"},textStyle:{color:N.color.secondary},selectedMode:!0,selector:!1,selectorLabel:{show:!0,borderRadius:10,padding:[3,5,3,5],fontSize:12,fontFamily:"sans-serif",color:N.color.tertiary,borderWidth:1,borderColor:N.color.border},emphasis:{selectorLabel:{show:!0,color:N.color.quaternary}},selectorPosition:"auto",selectorItemGap:7,selectorButtonGap:10,tooltip:{show:!1},triggerEvent:!1},t}(xt),Lo=pt,Wy=A,Qf=rt,rR=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.newlineDisabled=!1,e}return t.prototype.init=function(){this.group.add(this._contentGroup=new Qf),this.group.add(this._selectorGroup=new Qf),this._isFirstRender=!0},t.prototype.getContentGroup=function(){return this._contentGroup},t.prototype.getSelectorGroup=function(){return this._selectorGroup},t.prototype.render=function(e,a,n){var i=this._isFirstRender;if(this._isFirstRender=!1,this.resetInner(),!!e.get("show",!0)){var o=e.get("align"),s=e.get("orient");(!o||o==="auto")&&(o=e.get("left")==="right"&&s==="vertical"?"right":"left");var l=e.get("selector",!0),u=e.get("selectorPosition",!0);l&&(!u||u==="auto")&&(u=s==="horizontal"?"end":"start"),this.renderInner(o,e,a,n,l,s,u);var f=pe(e,n).refContainer,v=e.getBoxLayoutParams(),h=e.get("padding"),c=Xt(v,f,h),p=this.layoutInner(e,o,c,i,l,u),d=Xt(nt({width:p.width,height:p.height},v),f,h);this.group.x=d.x-p.x,this.group.y=d.y-p.y,this.group.markRedraw(),this.group.add(this._backgroundEl=UP(p,e))}},t.prototype.resetInner=function(){this.getContentGroup().removeAll(),this._backgroundEl&&this.group.remove(this._backgroundEl),this.getSelectorGroup().removeAll()},t.prototype.renderInner=function(e,a,n,i,o,s,l){var u=this.getContentGroup(),f=j(),v=a.get("selectedMode"),h=a.get("triggerEvent"),c=[];n.eachRawSeries(function(p){!p.get("legendHoverLink")&&c.push(p.id)}),Wy(a.getData(),function(p,d){var g=this,y=p.get("name");if(!this.newlineDisabled&&(y===""||y===`
`)){var m=new Qf;m.newline=!0,u.add(m);return}var _=n.getSeriesByName(y)[0];if(!f.get(y))if(_){var S=_.getData(),x=S.getVisual("legendLineStyle")||{},b=S.getVisual("legendIcon"),w=S.getVisual("style"),T=this._createItem(_,y,d,p,a,e,x,w,b,v,i);T.on("click",Lo(yC,y,null,i,c)).on("mouseover",Lo(Uy,_.name,null,i,c)).on("mouseout",Lo(Yy,_.name,null,i,c)),n.ssr&&T.eachChild(function(C){var M=ut(C);M.seriesIndex=_.seriesIndex,M.dataIndex=d,M.ssrType="legend"}),h&&T.eachChild(function(C){g.packEventData(C,a,_,d,y)}),f.set(y,!0)}else n.eachRawSeries(function(C){var M=this;if(!f.get(y)&&C.legendVisualProvider){var D=C.legendVisualProvider;if(!D.containName(y))return;var I=D.indexOfName(y),L=D.getItemVisual(I,"style"),P=D.getItemVisual(I,"legendIcon"),k=Ve(L.fill);k&&k[3]===0&&(k[3]=.2,L=G(G({},L),{fill:Cr(k,"rgba")}));var R=this._createItem(C,y,d,p,a,e,{},L,P,v,i);R.on("click",Lo(yC,null,y,i,c)).on("mouseover",Lo(Uy,null,y,i,c)).on("mouseout",Lo(Yy,null,y,i,c)),n.ssr&&R.eachChild(function(O){var E=ut(O);E.seriesIndex=C.seriesIndex,E.dataIndex=d,E.ssrType="legend"}),h&&R.eachChild(function(O){M.packEventData(O,a,C,d,y)}),f.set(y,!0)}},this)},this),o&&this._createSelector(o,a,i,s,l)},t.prototype.packEventData=function(e,a,n,i,o){var s={componentType:"legend",componentIndex:a.componentIndex,dataIndex:i,value:o,seriesIndex:n.seriesIndex};ut(e).eventData=s},t.prototype._createSelector=function(e,a,n,i,o){var s=this.getSelectorGroup();Wy(e,function(u){var f=u.type,v=new At({style:{x:0,y:0,align:"center",verticalAlign:"middle"},onclick:function(){n.dispatchAction({type:f==="all"?"legendAllSelect":"legendInverseSelect",legendId:a.id})}});s.add(v);var h=a.getModel("selectorLabel"),c=a.getModel(["emphasis","selectorLabel"]);Se(v,{normal:h,emphasis:c},{defaultText:u.title}),Cn(v)})},t.prototype._createItem=function(e,a,n,i,o,s,l,u,f,v,h){var c=e.visualDrawType,p=o.get("itemWidth"),d=o.get("itemHeight"),g=o.isSelected(a),y=i.get("symbolRotate"),m=i.get("symbolKeepAspect"),_=i.get("icon");f=_||f||"roundRect";var S=J9(f,i,l,u,c,g,h),x=new Qf,b=i.getModel("textStyle");if(tt(e.getLegendIcon)&&(!_||_==="inherit"))x.add(e.getLegendIcon({itemWidth:p,itemHeight:d,icon:f,iconRotate:y,itemStyle:S.itemStyle,lineStyle:S.lineStyle,symbolKeepAspect:m}));else{var w=_==="inherit"&&e.getData().getVisual("symbol")?y==="inherit"?e.getData().getVisual("symbolRotate"):y:0;x.add(Q9({itemWidth:p,itemHeight:d,icon:f,iconRotate:w,itemStyle:S.itemStyle,symbolKeepAspect:m}))}var T=s==="left"?p+5:-5,C=s,M=o.get("formatter"),D=a;X(M)&&M?D=M.replace("{name}",a??""):tt(M)&&(D=M(a));var I=g?b.getTextColor():i.get("inactiveColor");x.add(new At({style:Gt(b,{text:D,x:T,y:d/2,fill:I,align:C,verticalAlign:"middle"},{inheritColor:I})}));var L=new _t({shape:x.getBoundingRect(),style:{fill:"transparent"}}),P=i.getModel("tooltip");return P.get("show")&&en({el:L,componentModel:o,itemName:a,itemTooltipOption:P.option}),x.add(L),x.eachChild(function(k){k.silent=!0}),L.silent=!v,this.getContentGroup().add(x),Cn(x),x.__legendDataIndex=n,x},t.prototype.layoutInner=function(e,a,n,i,o,s){var l=this.getContentGroup(),u=this.getSelectorGroup();Ei(e.get("orient"),l,e.get("itemGap"),n.width,n.height);var f=l.getBoundingRect(),v=[-f.x,-f.y];if(u.markRedraw(),l.markRedraw(),o){Ei("horizontal",u,e.get("selectorItemGap",!0));var h=u.getBoundingRect(),c=[-h.x,-h.y],p=e.get("selectorButtonGap",!0),d=e.getOrient().index,g=d===0?"width":"height",y=d===0?"height":"width",m=d===0?"y":"x";s==="end"?c[d]+=f[g]+p:v[d]+=h[g]+p,c[1-d]+=f[y]/2-h[y]/2,u.x=c[0],u.y=c[1],l.x=v[0],l.y=v[1];var _={x:0,y:0};return _[g]=f[g]+p+h[g],_[y]=Math.max(f[y],h[y]),_[m]=Math.min(0,h[m]+c[1-d]),_}else return l.x=v[0],l.y=v[1],this.group.getBoundingRect()},t.prototype.remove=function(){this.getContentGroup().removeAll(),this._isFirstRender=!0},t.type="legend.plain",t}(Wt);function J9(r,t,e,a,n,i,o){function s(g,y){g.lineWidth==="auto"&&(g.lineWidth=y.lineWidth>0?2:0),Wy(g,function(m,_){g[_]==="inherit"&&(g[_]=y[_])})}var l=t.getModel("itemStyle"),u=l.getItemStyle(),f=r.lastIndexOf("empty",0)===0?"fill":"stroke",v=l.getShallow("decal");u.decal=!v||v==="inherit"?a.decal:ns(v,o),u.fill==="inherit"&&(u.fill=a[n]),u.stroke==="inherit"&&(u.stroke=a[f]),u.opacity==="inherit"&&(u.opacity=(n==="fill"?a:e).opacity),s(u,a);var h=t.getModel("lineStyle"),c=h.getLineStyle();if(s(c,e),u.fill==="auto"&&(u.fill=a.fill),u.stroke==="auto"&&(u.stroke=a.fill),c.stroke==="auto"&&(c.stroke=a.fill),!i){var p=t.get("inactiveBorderWidth"),d=u[f];u.lineWidth=p==="auto"?a.lineWidth>0&&d?2:0:u.lineWidth,u.fill=t.get("inactiveColor"),u.stroke=t.get("inactiveBorderColor"),c.stroke=h.get("inactiveColor"),c.lineWidth=h.get("inactiveWidth")}return{itemStyle:u,lineStyle:c}}function Q9(r){var t=r.icon||"roundRect",e=ie(t,0,0,r.itemWidth,r.itemHeight,r.itemStyle.fill,r.symbolKeepAspect);return e.setStyle(r.itemStyle),e.rotation=(r.iconRotate||0)*Math.PI/180,e.setOrigin([r.itemWidth/2,r.itemHeight/2]),t.indexOf("empty")>-1&&(e.style.stroke=e.style.fill,e.style.fill=N.color.neutral00,e.style.lineWidth=2),e}function yC(r,t,e,a){Yy(r,t,e,a),e.dispatchAction({type:"legendToggleSelect",name:r??t}),Uy(r,t,e,a)}function aR(r){for(var t=r.getZr().storage.getDisplayList(),e,a=0,n=t.length;a<n&&!(e=t[a].states.emphasis);)a++;return e&&e.hoverLayer}function Uy(r,t,e,a){aR(e)||e.dispatchAction({type:"highlight",seriesName:r,name:t,excludeSeriesId:a})}function Yy(r,t,e,a){aR(e)||e.dispatchAction({type:"downplay",seriesName:r,name:t,excludeSeriesId:a})}function tX(r){var t=r.findComponents({mainType:"legend"});t&&t.length&&r.filterSeries(function(e){for(var a=0;a<t.length;a++)if(!t[a].isSelected(e.name))return!1;return!0})}function ul(r,t,e){var a=r==="allSelect"||r==="inverseSelect",n={},i=[];e.eachComponent({mainType:"legend",query:t},function(s){a?s[r]():s[r](t.name),mC(s,n),i.push(s.componentIndex)});var o={};return e.eachComponent("legend",function(s){A(n,function(l,u){s[l?"select":"unSelect"](u)}),mC(s,o)}),a?{selected:o,legendIndex:i}:{name:t.name,selected:o}}function mC(r,t){var e=t||{};return A(r.getData(),function(a){var n=a.get("name");if(!(n===`
`||n==="")){var i=r.isSelected(n);q(e,n)?e[n]=e[n]&&i:e[n]=i}}),e}function eX(r){r.registerAction("legendToggleSelect","legendselectchanged",pt(ul,"toggleSelected")),r.registerAction("legendAllSelect","legendselectall",pt(ul,"allSelect")),r.registerAction("legendInverseSelect","legendinverseselect",pt(ul,"inverseSelect")),r.registerAction("legendSelect","legendselected",pt(ul,"select")),r.registerAction("legendUnSelect","legendunselected",pt(ul,"unSelect"))}function nR(r){r.registerComponentModel(Hy),r.registerComponentView(rR),r.registerProcessor(r.PRIORITY.PROCESSOR.SERIES_FILTER,tX),r.registerSubTypeDefaulter("legend",function(){return"plain"}),eX(r)}var rX=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.setScrollDataIndex=function(e){this.option.scrollDataIndex=e},t.prototype.init=function(e,a,n){var i=Ji(e);r.prototype.init.call(this,e,a,n),_C(this,e,i)},t.prototype.mergeOption=function(e,a){r.prototype.mergeOption.call(this,e,a),_C(this,this.option,e)},t.type="legend.scroll",t.defaultOption=Vn(Hy.defaultOption,{scrollDataIndex:0,pageButtonItemGap:5,pageButtonGap:null,pageButtonPosition:"end",pageFormatter:"{current}/{total}",pageIcons:{horizontal:["M0,0L12,-10L12,10z","M0,0L-12,-10L-12,10z"],vertical:["M0,0L20,0L10,-20z","M0,0L20,0L10,20z"]},pageIconColor:N.color.accent50,pageIconInactiveColor:N.color.accent10,pageIconSize:15,pageTextStyle:{color:N.color.tertiary},animationDurationUpdate:800}),t}(Hy);function _C(r,t,e){var a=r.getOrient(),n=[1,1];n[a.index]=0,_a(t,e,{type:"box",ignoreSize:!!n})}var SC=rt,Pd=["width","height"],Rd=["x","y"],aX=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.newlineDisabled=!0,e._currentIndex=0,e}return t.prototype.init=function(){r.prototype.init.call(this),this.group.add(this._containerGroup=new SC),this._containerGroup.add(this.getContentGroup()),this.group.add(this._controllerGroup=new SC)},t.prototype.resetInner=function(){r.prototype.resetInner.call(this),this._controllerGroup.removeAll(),this._containerGroup.removeClipPath(),this._containerGroup.__rectSize=null},t.prototype.renderInner=function(e,a,n,i,o,s,l){var u=this;r.prototype.renderInner.call(this,e,a,n,i,o,s,l);var f=this._controllerGroup,v=a.get("pageIconSize",!0),h=W(v)?v:[v,v];p("pagePrev",0);var c=a.getModel("pageTextStyle");f.add(new At({name:"pageText",style:{text:"xx/xx",fill:c.getTextColor(),font:c.getFont(),verticalAlign:"middle",align:"center"},silent:!0})),p("pageNext",1);function p(d,g){var y=d+"DataIndex",m=Ss(a.get("pageIcons",!0)[a.getOrient().name][g],{onclick:$(u._pageGo,u,y,a,i)},{x:-h[0]/2,y:-h[1]/2,width:h[0],height:h[1]});m.name=d,f.add(m)}},t.prototype.layoutInner=function(e,a,n,i,o,s){var l=this.getSelectorGroup(),u=e.getOrient().index,f=Pd[u],v=Rd[u],h=Pd[1-u],c=Rd[1-u];o&&Ei("horizontal",l,e.get("selectorItemGap",!0));var p=e.get("selectorButtonGap",!0),d=l.getBoundingRect(),g=[-d.x,-d.y],y=et(n);o&&(y[f]=n[f]-d[f]-p);var m=this._layoutContentAndController(e,i,y,u,f,h,c,v);if(o){if(s==="end")g[u]+=m[f]+p;else{var _=d[f]+p;g[u]-=_,m[v]-=_}m[f]+=d[f]+p,g[1-u]+=m[c]+m[h]/2-d[h]/2,m[h]=Math.max(m[h],d[h]),m[c]=Math.min(m[c],d[c]+g[1-u]),l.x=g[0],l.y=g[1],l.markRedraw()}return m},t.prototype._layoutContentAndController=function(e,a,n,i,o,s,l,u){var f=this.getContentGroup(),v=this._containerGroup,h=this._controllerGroup;Ei(e.get("orient"),f,e.get("itemGap"),i?n.width:null,i?null:n.height),Ei("horizontal",h,e.get("pageButtonItemGap",!0));var c=f.getBoundingRect(),p=h.getBoundingRect(),d=this._showController=c[o]>n[o],g=[-c.x,-c.y];a||(g[i]=f[u]);var y=[0,0],m=[-p.x,-p.y],_=Q(e.get("pageButtonGap",!0),e.get("itemGap",!0));if(d){var S=e.get("pageButtonPosition",!0);S==="end"?m[i]+=n[o]-p[o]:y[i]+=p[o]+_}m[1-i]+=c[s]/2-p[s]/2,f.setPosition(g),v.setPosition(y),h.setPosition(m);var x={x:0,y:0};if(x[o]=d?n[o]:c[o],x[s]=Math.max(c[s],p[s]),x[l]=Math.min(0,p[l]+m[1-i]),v.__rectSize=n[o],d){var b={x:0,y:0};b[o]=Math.max(n[o]-p[o]-_,0),b[s]=x[s],v.setClipPath(new _t({shape:b})),v.__rectSize=b[o]}else h.eachChild(function(T){T.attr({invisible:!0,silent:!0})});var w=this._getPageInfo(e);return w.pageIndex!=null&&Lt(f,{x:w.contentPosition[0],y:w.contentPosition[1]},d?e:null),this._updatePageInfoView(e,w),x},t.prototype._pageGo=function(e,a,n){var i=this._getPageInfo(a)[e];i!=null&&n.dispatchAction({type:"legendScroll",scrollDataIndex:i,legendId:a.id})},t.prototype._updatePageInfoView=function(e,a){var n=this._controllerGroup;A(["pagePrev","pageNext"],function(f){var v=f+"DataIndex",h=a[v]!=null,c=n.childOfName(f);c&&(c.setStyle("fill",h?e.get("pageIconColor",!0):e.get("pageIconInactiveColor",!0)),c.cursor=h?"pointer":"default")});var i=n.childOfName("pageText"),o=e.get("pageFormatter"),s=a.pageIndex,l=s!=null?s+1:0,u=a.pageCount;i&&o&&i.setStyle("text",X(o)?o.replace("{current}",l==null?"":l+"").replace("{total}",u==null?"":u+""):o({current:l,total:u}))},t.prototype._getPageInfo=function(e){var a=e.get("scrollDataIndex",!0),n=this.getContentGroup(),i=this._containerGroup.__rectSize,o=e.getOrient().index,s=Pd[o],l=Rd[o],u=this._findTargetItemIndex(a),f=n.children(),v=f[u],h=f.length,c=h?1:0,p={contentPosition:[n.x,n.y],pageCount:c,pageIndex:c-1,pagePrevDataIndex:null,pageNextDataIndex:null};if(!v)return p;var d=S(v);p.contentPosition[o]=-d.s;for(var g=u+1,y=d,m=d,_=null;g<=h;++g)_=S(f[g]),(!_&&m.e>y.s+i||_&&!x(_,y.s))&&(m.i>y.i?y=m:y=_,y&&(p.pageNextDataIndex==null&&(p.pageNextDataIndex=y.i),++p.pageCount)),m=_;for(var g=u-1,y=d,m=d,_=null;g>=-1;--g)_=S(f[g]),(!_||!x(m,_.s))&&y.i<m.i&&(m=y,p.pagePrevDataIndex==null&&(p.pagePrevDataIndex=y.i),++p.pageCount,++p.pageIndex),y=_;return p;function S(b){if(b){var w=b.getBoundingRect(),T=w[l]+b[l];return{s:T,e:T+w[s],i:b.__legendDataIndex}}}function x(b,w){return b.e>=w&&b.s<=w+i}},t.prototype._findTargetItemIndex=function(e){if(!this._showController)return 0;var a,n=this.getContentGroup(),i;return n.eachChild(function(o,s){var l=o.__legendDataIndex;i==null&&l!=null&&(i=s),l===e&&(a=s)}),a??i},t.type="legend.scroll",t}(rR);function nX(r){r.registerAction("legendScroll","legendscroll",function(t,e){var a=t.scrollDataIndex;a!=null&&e.eachComponent({mainType:"legend",subType:"scroll",query:t},function(n){n.setScrollDataIndex(a)})})}function iX(r){mt(nR),r.registerComponentModel(rX),r.registerComponentView(aX),nX(r)}function oX(r){mt(nR),mt(iX)}var sX=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="dataZoom.inside",t.defaultOption=Vn(du.defaultOption,{disabled:!1,zoomLock:!1,zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!1,preventDefaultMouseMove:!0}),t}(du),w_=St();function lX(r,t,e){w_(r).coordSysRecordMap.each(function(a){var n=a.dataZoomInfoMap.get(t.uid);n&&(n.getRange=e)})}function uX(r,t){for(var e=w_(r).coordSysRecordMap,a=e.keys(),n=0;n<a.length;n++){var i=a[n],o=e.get(i),s=o.dataZoomInfoMap;if(s){var l=t.uid,u=s.get(l);u&&(s.removeKey(l),s.keys().length||iR(e,o))}}}function iR(r,t){if(t){r.removeKey(t.model.uid);var e=t.controller;e&&e.dispose()}}function fX(r,t){var e={model:t,containsPoint:pt(hX,t),dispatchAction:pt(vX,r),dataZoomInfoMap:null,controller:null},a=e.controller=new ao(r.getZr());return A(["pan","zoom","scrollMove"],function(n){a.on(n,function(i){var o=[];e.dataZoomInfoMap.each(function(s){if(i.isAvailableBehavior(s.model.option)){var l=(s.getRange||{})[n],u=l&&l(s.dzReferCoordSysInfo,e.model.mainType,e.controller,i);!s.model.get("disabled",!0)&&u&&o.push({dataZoomId:s.model.id,start:u[0],end:u[1]})}}),o.length&&e.dispatchAction(o)})}),e}function vX(r,t){r.isDisposed()||r.dispatchAction({type:"dataZoom",animation:{easing:"cubicOut",duration:100},batch:t})}function hX(r,t,e,a){return r.coordinateSystem.containPoint([e,a])}function cX(r,t,e){var a,n="type_",i={type_true:2,type_move:1,type_false:0,type_undefined:-1},o=!0;return r.each(function(s){var l=s.model,u=l.get("disabled",!0)?!1:l.get("zoomLock",!0)?"move":!0;i[n+u]>i[n+a]&&(a=u),o=o&&l.get("preventDefaultMouseMove",!0)}),{controlType:a,opt:{zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!0,preventDefaultMouseMove:!!o,api:e,zInfo:{component:t.model},triggerInfo:{roamTrigger:null,isInSelf:t.containsPoint}}}}function pX(r){r.registerProcessor(r.PRIORITY.PROCESSOR.FILTER,function(t,e){var a=w_(e),n=a.coordSysRecordMap||(a.coordSysRecordMap=j());n.each(function(i){i.dataZoomInfoMap=null}),t.eachComponent({mainType:"dataZoom",subType:"inside"},function(i){var o=FP(i);A(o.infoList,function(s){var l=s.model.uid,u=n.get(l)||n.set(l,fX(e,s.model)),f=u.dataZoomInfoMap||(u.dataZoomInfoMap=j());f.set(i.uid,{dzReferCoordSysInfo:s,model:i,getRange:null})})}),n.each(function(i){var o=i.controller,s,l=i.dataZoomInfoMap;if(l){var u=l.keys()[0];u!=null&&(s=l.get(u))}if(!s){iR(n,i);return}var f=cX(l,i,e);o.enable(f.controlType,f.opt),As(i,"dispatchAction",s.model.get("throttle",!0),"fixRate")})})}var dX=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="dataZoom.inside",e}return t.prototype.render=function(e,a,n){if(r.prototype.render.apply(this,arguments),e.noTarget()){this._clear();return}this.range=e.getPercentRange(),lX(n,e,{pan:$(kd.pan,this),zoom:$(kd.zoom,this),scrollMove:$(kd.scrollMove,this)})},t.prototype.dispose=function(){this._clear(),r.prototype.dispose.apply(this,arguments)},t.prototype._clear=function(){uX(this.api,this.dataZoomModel),this.range=null},t.type="dataZoom.inside",t}(d_),kd={zoom:function(r,t,e,a){var n=this.range,i=n.slice(),o=r.axisModels[0];if(o){var s=Ed[t](null,[a.originX,a.originY],o,e,r),l=(s.signal>0?s.pixelStart+s.pixelLength-s.pixel:s.pixel-s.pixelStart)/s.pixelLength*(i[1]-i[0])+i[0],u=Math.max(1/a.scale,0);i[0]=(i[0]-l)*u+l,i[1]=(i[1]-l)*u+l;var f=this.dataZoomModel.findRepresentativeAxisProxy().getMinMaxSpan();if(kn(0,i,[0,100],0,f.minSpan,f.maxSpan),this.range=i,n[0]!==i[0]||n[1]!==i[1])return i}},pan:xC(function(r,t,e,a,n,i){var o=Ed[a]([i.oldX,i.oldY],[i.newX,i.newY],t,n,e);return o.signal*(r[1]-r[0])*o.pixel/o.pixelLength}),scrollMove:xC(function(r,t,e,a,n,i){var o=Ed[a]([0,0],[i.scrollDelta,i.scrollDelta],t,n,e);return o.signal*(r[1]-r[0])*i.scrollDelta})};function xC(r){return function(t,e,a,n){var i=this.range,o=i.slice(),s=t.axisModels[0];if(s){var l=r(o,s,t,e,a,n);if(kn(l,o,[0,100],"all"),this.range=o,i[0]!==o[0]||i[1]!==o[1])return o}}}var Ed={grid:function(r,t,e,a,n){var i=e.axis,o={},s=n.model.coordinateSystem.getRect();return r=r||[0,0],i.dim==="x"?(o.pixel=t[0]-r[0],o.pixelLength=s.width,o.pixelStart=s.x,o.signal=i.inverse?1:-1):(o.pixel=t[1]-r[1],o.pixelLength=s.height,o.pixelStart=s.y,o.signal=i.inverse?-1:1),o},polar:function(r,t,e,a,n){var i=e.axis,o={},s=n.model.coordinateSystem,l=s.getRadiusAxis().getExtent(),u=s.getAngleAxis().getExtent();return r=r?s.pointToCoord(r):[0,0],t=s.pointToCoord(t),e.mainType==="radiusAxis"?(o.pixel=t[0]-r[0],o.pixelLength=l[1]-l[0],o.pixelStart=l[0],o.signal=i.inverse?1:-1):(o.pixel=t[1]-r[1],o.pixelLength=u[1]-u[0],o.pixelStart=u[0],o.signal=i.inverse?-1:1),o},singleAxis:function(r,t,e,a,n){var i=e.axis,o=n.model.coordinateSystem.getRect(),s={};return r=r||[0,0],i.orient==="horizontal"?(s.pixel=t[0]-r[0],s.pixelLength=o.width,s.pixelStart=o.x,s.signal=i.inverse?1:-1):(s.pixel=t[1]-r[1],s.pixelLength=o.height,s.pixelStart=o.y,s.signal=i.inverse?-1:1),s}};function oR(r){g_(r),r.registerComponentModel(sX),r.registerComponentView(dX),pX(r)}var gX=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="dataZoom.slider",t.layoutMode="box",t.defaultOption=Vn(du.defaultOption,{show:!0,right:"ph",top:"ph",width:"ph",height:"ph",left:null,bottom:null,borderColor:N.color.accent10,borderRadius:0,backgroundColor:N.color.transparent,dataBackground:{lineStyle:{color:N.color.accent30,width:.5},areaStyle:{color:N.color.accent20,opacity:.2}},selectedDataBackground:{lineStyle:{color:N.color.accent40,width:.5},areaStyle:{color:N.color.accent20,opacity:.3}},fillerColor:"rgba(135,175,274,0.2)",handleIcon:"path://M-9.35,34.56V42m0-40V9.5m-2,0h4a2,2,0,0,1,2,2v21a2,2,0,0,1-2,2h-4a2,2,0,0,1-2-2v-21A2,2,0,0,1-11.35,9.5Z",handleSize:"100%",handleStyle:{color:N.color.neutral00,borderColor:N.color.accent20},moveHandleSize:7,moveHandleIcon:"path://M-320.9-50L-320.9-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-348-41-339-50-320.9-50z M-212.3-50L-212.3-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-239.4-41-230.4-50-212.3-50z M-103.7-50L-103.7-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-130.9-41-121.8-50-103.7-50z",moveHandleStyle:{color:N.color.accent40,opacity:.5},showDetail:!0,showDataShadow:"auto",realtime:!0,zoomLock:!1,textStyle:{color:N.color.tertiary},brushSelect:!0,brushStyle:{color:N.color.accent30,opacity:.3},emphasis:{handleLabel:{show:!0},handleStyle:{borderColor:N.color.accent40},moveHandleStyle:{opacity:.8}},defaultLocationEdgeGap:15}),t}(du),fl=_t,yX=1,Od=30,mX=7,vl="horizontal",bC="vertical",_X=5,SX=["line","bar","candlestick","scatter"],xX={easing:"cubicOut",duration:100,delay:0},bX=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e._displayables={},e}return t.prototype.init=function(e,a){this.api=a,this._onBrush=$(this._onBrush,this),this._onBrushEnd=$(this._onBrushEnd,this)},t.prototype.render=function(e,a,n,i){if(r.prototype.render.apply(this,arguments),As(this,"_dispatchZoomAction",e.get("throttle"),"fixRate"),this._orient=e.getOrient(),e.get("show")===!1){this.group.removeAll();return}if(e.noTarget()){this._clear(),this.group.removeAll();return}(!i||i.type!=="dataZoom"||i.from!==this.uid)&&this._buildView(),this._updateView()},t.prototype.dispose=function(){this._clear(),r.prototype.dispose.apply(this,arguments)},t.prototype._clear=function(){tu(this,"_dispatchZoomAction");var e=this.api.getZr();e.off("mousemove",this._onBrush),e.off("mouseup",this._onBrushEnd)},t.prototype._buildView=function(){var e=this.group;e.removeAll(),this._brushing=!1,this._displayables.brushRect=null,this._resetLocation(),this._resetInterval();var a=this._displayables.sliderGroup=new rt;this._renderBackground(),this._renderHandle(),this._renderDataShadow(),e.add(a),this._positionGroup()},t.prototype._resetLocation=function(){var e=this.dataZoomModel,a=this.api,n=e.get("brushSelect"),i=n?mX:0,o=pe(e,a).refContainer,s=this._findCoordRect(),l=e.get("defaultLocationEdgeGap",!0)||0,u=this._orient===vl?{right:o.width-s.x-s.width,top:o.height-Od-l-i,width:s.width,height:Od}:{right:l,top:s.y,width:Od,height:s.height},f=Ji(e.option);A(["right","top","width","height"],function(h){f[h]==="ph"&&(f[h]=u[h])});var v=Xt(f,o);this._location={x:v.x,y:v.y},this._size=[v.width,v.height],this._orient===bC&&this._size.reverse()},t.prototype._positionGroup=function(){var e=this.group,a=this._location,n=this._orient,i=this.dataZoomModel.getFirstTargetAxisModel(),o=i&&i.get("inverse"),s=this._displayables.sliderGroup,l=(this._dataShadowInfo||{}).otherAxisInverse;s.attr(n===vl&&!o?{scaleY:l?1:-1,scaleX:1}:n===vl&&o?{scaleY:l?1:-1,scaleX:-1}:n===bC&&!o?{scaleY:l?-1:1,scaleX:1,rotation:Math.PI/2}:{scaleY:l?-1:1,scaleX:-1,rotation:Math.PI/2});var u=e.getBoundingRect([s]);e.x=a.x-u.x,e.y=a.y-u.y,e.markRedraw()},t.prototype._getViewExtent=function(){return[0,this._size[0]]},t.prototype._renderBackground=function(){var e=this.dataZoomModel,a=this._size,n=this._displayables.sliderGroup,i=e.get("brushSelect");n.add(new fl({silent:!0,shape:{x:0,y:0,width:a[0],height:a[1]},style:{fill:e.get("backgroundColor")},z2:-40}));var o=new fl({shape:{x:0,y:0,width:a[0],height:a[1]},style:{fill:"transparent"},z2:0,onclick:$(this._onClickPanel,this)}),s=this.api.getZr();i?(o.on("mousedown",this._onBrushStart,this),o.cursor="crosshair",s.on("mousemove",this._onBrush),s.on("mouseup",this._onBrushEnd)):(s.off("mousemove",this._onBrush),s.off("mouseup",this._onBrushEnd)),n.add(o)},t.prototype._renderDataShadow=function(){var e=this._dataShadowInfo=this._prepareDataShadowInfo();if(this._displayables.dataShadowSegs=[],!e)return;var a=this._size,n=this._shadowSize||[],i=e.series,o=i.getRawData(),s=i.getShadowDim&&i.getShadowDim(),l=s&&o.getDimensionInfo(s)?i.getShadowDim():e.otherDim;if(l==null)return;var u=this._shadowPolygonPts,f=this._shadowPolylinePts;if(o!==this._shadowData||l!==this._shadowDim||a[0]!==n[0]||a[1]!==n[1]){var v=o.getDataExtent(e.thisDim),h=o.getDataExtent(l),c=(h[1]-h[0])*.3;h=[h[0]-c,h[1]+c];var p=[0,a[1]],d=[0,a[0]],g=[[a[0],0],[0,0]],y=[],m=d[1]/Math.max(1,o.count()-1),_=a[0]/(v[1]-v[0]),S=e.thisAxis.type==="time",x=-m,b=Math.round(o.count()/a[0]),w;o.each([e.thisDim,l],function(I,L,P){if(b>0&&P%b){S||(x+=m);return}x=S?(+I-v[0])*_:x+m;var k=L==null||isNaN(L)||L==="",R=k?0:Rt(L,h,p,!0);k&&!w&&P?(g.push([g[g.length-1][0],0]),y.push([y[y.length-1][0],0])):!k&&w&&(g.push([x,0]),y.push([x,0])),k||(g.push([x,R]),y.push([x,R])),w=k}),u=this._shadowPolygonPts=g,f=this._shadowPolylinePts=y}this._shadowData=o,this._shadowDim=l,this._shadowSize=[a[0],a[1]];var T=this.dataZoomModel;function C(I){var L=T.getModel(I?"selectedDataBackground":"dataBackground"),P=new rt,k=new Ee({shape:{points:u},segmentIgnoreThreshold:1,style:L.getModel("areaStyle").getAreaStyle(),silent:!0,z2:-20}),R=new Ae({shape:{points:f},segmentIgnoreThreshold:1,style:L.getModel("lineStyle").getLineStyle(),silent:!0,z2:-19});return P.add(k),P.add(R),P}for(var M=0;M<3;M++){var D=C(M===1);this._displayables.sliderGroup.add(D),this._displayables.dataShadowSegs.push(D)}},t.prototype._prepareDataShadowInfo=function(){var e=this.dataZoomModel,a=e.get("showDataShadow");if(a!==!1){var n,i=this.ecModel;return e.eachTargetAxis(function(o,s){var l=e.getAxisProxy(o,s).getTargetSeriesModels();A(l,function(u){if(!n&&!(a!==!0&&gt(SX,u.get("type"))<0)){var f=i.getComponent(xn(o),s).axis,v=wX(o),h,c=u.coordinateSystem;v!=null&&c.getOtherAxis&&(h=c.getOtherAxis(f).inverse),v=u.getData().mapDimension(v);var p=u.getData().mapDimension(o);n={thisAxis:f,series:u,thisDim:p,otherDim:v,otherAxisInverse:h}}},this)},this),n}},t.prototype._renderHandle=function(){var e=this.group,a=this._displayables,n=a.handles=[null,null],i=a.handleLabels=[null,null],o=this._displayables.sliderGroup,s=this._size,l=this.dataZoomModel,u=this.api,f=l.get("borderRadius")||0,v=l.get("brushSelect"),h=a.filler=new fl({silent:v,style:{fill:l.get("fillerColor")},textConfig:{position:"inside"}});o.add(h),o.add(new fl({silent:!0,subPixelOptimize:!0,shape:{x:0,y:0,width:s[0],height:s[1],r:f},style:{stroke:l.get("dataBackgroundColor")||l.get("borderColor"),lineWidth:yX,fill:N.color.transparent}})),A([0,1],function(_){var S=l.get("handleIcon");!Yv[S]&&S.indexOf("path://")<0&&S.indexOf("image://")<0&&(S="path://"+S);var x=ie(S,-1,0,2,2,null,!0);x.attr({cursor:TX(this._orient),draggable:!0,drift:$(this._onDragMove,this,_),ondragend:$(this._onDragEnd,this),onmouseover:$(this._showDataInfo,this,!0),onmouseout:$(this._showDataInfo,this,!1),z2:5});var b=x.getBoundingRect(),w=l.get("handleSize");this._handleHeight=Z(w,this._size[1]),this._handleWidth=b.width/b.height*this._handleHeight,x.setStyle(l.getModel("handleStyle").getItemStyle()),x.style.strokeNoScale=!0,x.rectHover=!0,x.ensureState("emphasis").style=l.getModel(["emphasis","handleStyle"]).getItemStyle(),Cn(x);var T=l.get("handleColor");T!=null&&(x.style.fill=T),o.add(n[_]=x);var C=l.getModel("textStyle"),M=l.get("handleLabel")||{},D=M.show||!1;e.add(i[_]=new At({silent:!0,invisible:!D,style:Gt(C,{x:0,y:0,text:"",verticalAlign:"middle",align:"center",fill:C.getTextColor(),font:C.getFont()}),z2:10}))},this);var c=h;if(v){var p=Z(l.get("moveHandleSize"),s[1]),d=a.moveHandle=new _t({style:l.getModel("moveHandleStyle").getItemStyle(),silent:!0,shape:{r:[0,0,2,2],y:s[1]-.5,height:p}}),g=p*.8,y=a.moveHandleIcon=ie(l.get("moveHandleIcon"),-g/2,-g/2,g,g,N.color.neutral00,!0);y.silent=!0,y.y=s[1]+p/2-.5,d.ensureState("emphasis").style=l.getModel(["emphasis","moveHandleStyle"]).getItemStyle();var m=Math.min(s[1]/2,Math.max(p,10));c=a.moveZone=new _t({invisible:!0,shape:{y:s[1]-m,height:p+m}}),c.on("mouseover",function(){u.enterEmphasis(d)}).on("mouseout",function(){u.leaveEmphasis(d)}),o.add(d),o.add(y),o.add(c)}c.attr({draggable:!0,cursor:"default",drift:$(this._onDragMove,this,"all"),ondragstart:$(this._showDataInfo,this,!0),ondragend:$(this._onDragEnd,this),onmouseover:$(this._showDataInfo,this,!0),onmouseout:$(this._showDataInfo,this,!1)})},t.prototype._resetInterval=function(){var e=this._range=this.dataZoomModel.getPercentRange(),a=this._getViewExtent();this._handleEnds=[Rt(e[0],[0,100],a,!0),Rt(e[1],[0,100],a,!0)]},t.prototype._updateInterval=function(e,a){var n=this.dataZoomModel,i=this._handleEnds,o=this._getViewExtent(),s=n.findRepresentativeAxisProxy().getMinMaxSpan(),l=[0,100];kn(a,i,o,n.get("zoomLock")?"all":e,s.minSpan!=null?Rt(s.minSpan,l,o,!0):null,s.maxSpan!=null?Rt(s.maxSpan,l,o,!0):null);var u=this._range,f=this._range=lr([Rt(i[0],o,l,!0),Rt(i[1],o,l,!0)]);return!u||u[0]!==f[0]||u[1]!==f[1]},t.prototype._updateView=function(e){var a=this._displayables,n=this._handleEnds,i=lr(n.slice()),o=this._size;A([0,1],function(c){var p=a.handles[c],d=this._handleHeight;p.attr({scaleX:d/2,scaleY:d/2,x:n[c]+(c?-1:1),y:o[1]/2-d/2})},this),a.filler.setShape({x:i[0],y:0,width:i[1]-i[0],height:o[1]});var s={x:i[0],width:i[1]-i[0]};a.moveHandle&&(a.moveHandle.setShape(s),a.moveZone.setShape(s),a.moveZone.getBoundingRect(),a.moveHandleIcon&&a.moveHandleIcon.attr("x",s.x+s.width/2));for(var l=a.dataShadowSegs,u=[0,i[0],i[1],o[0]],f=0;f<l.length;f++){var v=l[f],h=v.getClipPath();h||(h=new _t,v.setClipPath(h)),h.setShape({x:u[f],y:0,width:u[f+1]-u[f],height:o[1]})}this._updateDataInfo(e)},t.prototype._updateDataInfo=function(e){var a=this.dataZoomModel,n=this._displayables,i=n.handleLabels,o=this._orient,s=["",""];if(a.get("showDetail")){var l=a.findRepresentativeAxisProxy();if(l){var u=l.getAxisModel().axis,f=this._range,v=e?l.calculateDataWindow({start:f[0],end:f[1]}).valueWindow:l.getDataValueWindow();s=[this._formatLabel(v[0],u),this._formatLabel(v[1],u)]}}var h=lr(this._handleEnds.slice());c.call(this,0),c.call(this,1);function c(p){var d=An(n.handles[p].parent,this.group),g=qh(p===0?"right":"left",d),y=this._handleWidth/2+_X,m=Hr([h[p]+(p===0?-y:y),this._size[1]/2],d);i[p].setStyle({x:m[0],y:m[1],verticalAlign:o===vl?"middle":g,align:o===vl?g:"center",text:s[p]})}},t.prototype._formatLabel=function(e,a){var n=this.dataZoomModel,i=n.get("labelFormatter"),o=n.get("labelPrecision");(o==null||o==="auto")&&(o=a.getPixelPrecision());var s=e==null||isNaN(e)?"":a.type==="category"||a.type==="time"?a.scale.getLabel({value:Math.round(e)}):e.toFixed(Math.min(o,20));return tt(i)?i(e,s):X(i)?i.replace("{value}",s):s},t.prototype._showDataInfo=function(e){var a=this.dataZoomModel.get("handleLabel")||{},n=a.show||!1,i=this.dataZoomModel.getModel(["emphasis","handleLabel"]),o=i.get("show")||!1,s=e||this._dragging?o:n,l=this._displayables,u=l.handleLabels;u[0].attr("invisible",!s),u[1].attr("invisible",!s),l.moveHandle&&this.api[s?"enterEmphasis":"leaveEmphasis"](l.moveHandle,1)},t.prototype._onDragMove=function(e,a,n,i){this._dragging=!0,Za(i.event);var o=this._displayables.sliderGroup.getLocalTransform(),s=Hr([a,n],o,!0),l=this._updateInterval(e,s[0]),u=this.dataZoomModel.get("realtime");this._updateView(!u),l&&u&&this._dispatchZoomAction(!0)},t.prototype._onDragEnd=function(){this._dragging=!1,this._showDataInfo(!1);var e=this.dataZoomModel.get("realtime");!e&&this._dispatchZoomAction(!1)},t.prototype._onClickPanel=function(e){var a=this._size,n=this._displayables.sliderGroup.transformCoordToLocal(e.offsetX,e.offsetY);if(!(n[0]<0||n[0]>a[0]||n[1]<0||n[1]>a[1])){var i=this._handleEnds,o=(i[0]+i[1])/2,s=this._updateInterval("all",n[0]-o);this._updateView(),s&&this._dispatchZoomAction(!1)}},t.prototype._onBrushStart=function(e){var a=e.offsetX,n=e.offsetY;this._brushStart=new st(a,n),this._brushing=!0,this._brushStartTime=+new Date},t.prototype._onBrushEnd=function(e){if(this._brushing){var a=this._displayables.brushRect;if(this._brushing=!1,!!a){a.attr("ignore",!0);var n=a.shape,i=+new Date;if(!(i-this._brushStartTime<200&&Math.abs(n.width)<5)){var o=this._getViewExtent(),s=[0,100],l=this._handleEnds=[n.x,n.x+n.width],u=this.dataZoomModel.findRepresentativeAxisProxy().getMinMaxSpan();kn(0,l,o,0,u.minSpan!=null?Rt(u.minSpan,s,o,!0):null,u.maxSpan!=null?Rt(u.maxSpan,s,o,!0):null),this._range=lr([Rt(l[0],o,s,!0),Rt(l[1],o,s,!0)]),this._updateView(),this._dispatchZoomAction(!1)}}}},t.prototype._onBrush=function(e){this._brushing&&(Za(e.event),this._updateBrushRect(e.offsetX,e.offsetY))},t.prototype._updateBrushRect=function(e,a){var n=this._displayables,i=this.dataZoomModel,o=n.brushRect;o||(o=n.brushRect=new fl({silent:!0,style:i.getModel("brushStyle").getItemStyle()}),n.sliderGroup.add(o)),o.attr("ignore",!1);var s=this._brushStart,l=this._displayables.sliderGroup,u=l.transformCoordToLocal(e,a),f=l.transformCoordToLocal(s.x,s.y),v=this._size;u[0]=Math.max(Math.min(v[0],u[0]),0),o.setShape({x:f[0],y:0,width:u[0]-f[0],height:v[1]})},t.prototype._dispatchZoomAction=function(e){var a=this._range;this.api.dispatchAction({type:"dataZoom",from:this.uid,dataZoomId:this.dataZoomModel.id,animation:e?xX:null,start:a[0],end:a[1]})},t.prototype._findCoordRect=function(){var e,a=FP(this.dataZoomModel).infoList;if(!e&&a.length){var n=a[0].model.coordinateSystem;e=n.getRect&&n.getRect()}if(!e){var i=this.api.getWidth(),o=this.api.getHeight();e={x:i*.2,y:o*.2,width:i*.6,height:o*.6}}return e},t.type="dataZoom.slider",t}(d_);function wX(r){var t={x:"y",y:"x",radius:"angle",angle:"radius"};return t[r]}function TX(r){return r==="vertical"?"ns-resize":"ew-resize"}function sR(r){r.registerComponentModel(gX),r.registerComponentView(bX),g_(r)}function CX(r){mt(oR),mt(sR)}var lR={get:function(r,t,e){var a=et((AX[r]||{})[t]);return e&&W(a)?a[a.length-1]:a}},AX={color:{active:["#006edd","#e0ffff"],inactive:[N.color.transparent]},colorHue:{active:[0,360],inactive:[0,0]},colorSaturation:{active:[.3,1],inactive:[0,0]},colorLightness:{active:[.9,.5],inactive:[0,0]},colorAlpha:{active:[.3,1],inactive:[0,0]},opacity:{active:[.3,1],inactive:[0,0]},symbol:{active:["circle","roundRect","diamond"],inactive:["none"]},symbolSize:{active:[10,50],inactive:[0,0]}},wC=_e.mapVisual,MX=_e.eachVisual,DX=W,TC=A,LX=lr,IX=Rt,Ah=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.stateList=["inRange","outOfRange"],e.replacableOptionKeys=["inRange","outOfRange","target","controller","color"],e.layoutMode={type:"box",ignoreSize:!0},e.dataBound=[-1/0,1/0],e.targetVisuals={},e.controllerVisuals={},e}return t.prototype.init=function(e,a,n){this.mergeDefaultAndTheme(e,n)},t.prototype.optionUpdated=function(e,a){var n=this.option;!a&&jP(n,e,this.replacableOptionKeys),this.textStyleModel=this.getModel("textStyle"),this.resetItemSize(),this.completeVisualOption()},t.prototype.resetVisual=function(e){var a=this.stateList;e=$(e,this),this.controllerVisuals=Vy(this.option.controller,a,e),this.targetVisuals=Vy(this.option.target,a,e)},t.prototype.getItemSymbol=function(){return null},t.prototype.getTargetSeriesIndices=function(){var e=this.option.seriesId,a=this.option.seriesIndex;a==null&&e==null&&(a="all");var n=ds(this.ecModel,"series",{index:a,id:e},{useDefault:!1,enableAll:!0,enableNone:!1}).models;return U(n,function(i){return i.componentIndex})},t.prototype.eachTargetSeries=function(e,a){A(this.getTargetSeriesIndices(),function(n){var i=this.ecModel.getSeriesByIndex(n);i&&e.call(a,i)},this)},t.prototype.isTargetSeries=function(e){var a=!1;return this.eachTargetSeries(function(n){n===e&&(a=!0)}),a},t.prototype.formatValueText=function(e,a,n){var i=this.option,o=i.precision,s=this.dataBound,l=i.formatter,u;n=n||["<",">"],W(e)&&(e=e.slice(),u=!0);var f=a?e:u?[v(e[0]),v(e[1])]:v(e);if(X(l))return l.replace("{value}",u?f[0]:f).replace("{value2}",u?f[1]:f);if(tt(l))return u?l(e[0],e[1]):l(e);if(u)return e[0]===s[0]?n[0]+" "+f[1]:e[1]===s[1]?n[1]+" "+f[0]:f[0]+" - "+f[1];return f;function v(h){return h===s[0]?"min":h===s[1]?"max":(+h).toFixed(Math.min(o,20))}},t.prototype.resetExtent=function(){var e=this.option,a=LX([e.min,e.max]);this._dataExtent=a},t.prototype.getDataDimensionIndex=function(e){var a=this.option.dimension;if(a!=null)return e.getDimensionIndex(a);for(var n=e.dimensions,i=n.length-1;i>=0;i--){var o=n[i],s=e.getDimensionInfo(o);if(!s.isCalculationCoord)return s.storeDimIndex}},t.prototype.getExtent=function(){return this._dataExtent.slice()},t.prototype.completeVisualOption=function(){var e=this.ecModel,a=this.option,n={inRange:a.inRange,outOfRange:a.outOfRange},i=a.target||(a.target={}),o=a.controller||(a.controller={});yt(i,n),yt(o,n);var s=this.isCategory();l.call(this,i),l.call(this,o),u.call(this,i,"inRange","outOfRange"),f.call(this,o);function l(v){DX(a.color)&&!v.inRange&&(v.inRange={color:a.color.slice().reverse()}),v.inRange=v.inRange||{color:e.get("gradientColor")}}function u(v,h,c){var p=v[h],d=v[c];p&&!d&&(d=v[c]={},TC(p,function(g,y){if(_e.isValidType(y)){var m=lR.get(y,"inactive",s);m!=null&&(d[y]=m,y==="color"&&!d.hasOwnProperty("opacity")&&!d.hasOwnProperty("colorAlpha")&&(d.opacity=[0,0]))}}))}function f(v){var h=(v.inRange||{}).symbol||(v.outOfRange||{}).symbol,c=(v.inRange||{}).symbolSize||(v.outOfRange||{}).symbolSize,p=this.get("inactiveColor"),d=this.getItemSymbol(),g=d||"roundRect";TC(this.stateList,function(y){var m=this.itemSize,_=v[y];_||(_=v[y]={color:s?p:[p]}),_.symbol==null&&(_.symbol=h&&et(h)||(s?g:[g])),_.symbolSize==null&&(_.symbolSize=c&&et(c)||(s?m[0]:[m[0],m[0]])),_.symbol=wC(_.symbol,function(b){return b==="none"?g:b});var S=_.symbolSize;if(S!=null){var x=-1/0;MX(S,function(b){b>x&&(x=b)}),_.symbolSize=wC(S,function(b){return IX(b,[0,x],[0,m[0]],!0)})}},this)}},t.prototype.resetItemSize=function(){this.itemSize=[parseFloat(this.get("itemWidth")),parseFloat(this.get("itemHeight"))]},t.prototype.isCategory=function(){return!!this.option.categories},t.prototype.setSelected=function(e){},t.prototype.getSelected=function(){return null},t.prototype.getValueState=function(e){return null},t.prototype.getVisualMeta=function(e){return null},t.type="visualMap",t.dependencies=["series"],t.defaultOption={show:!0,z:4,min:0,max:200,left:0,right:null,top:null,bottom:0,itemWidth:null,itemHeight:null,inverse:!1,orient:"vertical",backgroundColor:N.color.transparent,borderColor:N.color.borderTint,contentColor:N.color.theme[0],inactiveColor:N.color.disabled,borderWidth:0,padding:N.size.m,textGap:10,precision:0,textStyle:{color:N.color.secondary}},t}(xt),CC=[20,140],PX=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.optionUpdated=function(e,a){r.prototype.optionUpdated.apply(this,arguments),this.resetExtent(),this.resetVisual(function(n){n.mappingMethod="linear",n.dataExtent=this.getExtent()}),this._resetRange()},t.prototype.resetItemSize=function(){r.prototype.resetItemSize.apply(this,arguments);var e=this.itemSize;(e[0]==null||isNaN(e[0]))&&(e[0]=CC[0]),(e[1]==null||isNaN(e[1]))&&(e[1]=CC[1])},t.prototype._resetRange=function(){var e=this.getExtent(),a=this.option.range;!a||a.auto?(e.auto=1,this.option.range=e):W(a)&&(a[0]>a[1]&&a.reverse(),a[0]=Math.max(a[0],e[0]),a[1]=Math.min(a[1],e[1]))},t.prototype.completeVisualOption=function(){r.prototype.completeVisualOption.apply(this,arguments),A(this.stateList,function(e){var a=this.option.controller[e].symbolSize;a&&a[0]!==a[1]&&(a[0]=a[1]/3)},this)},t.prototype.setSelected=function(e){this.option.range=e.slice(),this._resetRange()},t.prototype.getSelected=function(){var e=this.getExtent(),a=lr((this.get("range")||[]).slice());return a[0]>e[1]&&(a[0]=e[1]),a[1]>e[1]&&(a[1]=e[1]),a[0]<e[0]&&(a[0]=e[0]),a[1]<e[0]&&(a[1]=e[0]),a},t.prototype.getValueState=function(e){var a=this.option.range,n=this.getExtent(),i=Q(this.option.unboundedRange,!0);return(i&&a[0]<=n[0]||a[0]<=e)&&(i&&a[1]>=n[1]||e<=a[1])?"inRange":"outOfRange"},t.prototype.findTargetDataIndices=function(e){var a=[];return this.eachTargetSeries(function(n){var i=[],o=n.getData();o.each(this.getDataDimensionIndex(o),function(s,l){e[0]<=s&&s<=e[1]&&i.push(l)},this),a.push({seriesId:n.id,dataIndex:i})},this),a},t.prototype.getVisualMeta=function(e){var a=AC(this,"outOfRange",this.getExtent()),n=AC(this,"inRange",this.option.range.slice()),i=[];function o(c,p){i.push({value:c,color:e(c,p)})}for(var s=0,l=0,u=n.length,f=a.length;l<f&&(!n.length||a[l]<=n[0]);l++)a[l]<n[s]&&o(a[l],"outOfRange");for(var v=1;s<u;s++,v=0)v&&i.length&&o(n[s],"outOfRange"),o(n[s],"inRange");for(var v=1;l<f;l++)(!n.length||n[n.length-1]<a[l])&&(v&&(i.length&&o(i[i.length-1].value,"outOfRange"),v=0),o(a[l],"outOfRange"));var h=i.length;return{stops:i,outerColors:[h?i[0].color:"transparent",h?i[h-1].color:"transparent"]}},t.type="visualMap.continuous",t.defaultOption=Vn(Ah.defaultOption,{align:"auto",calculable:!1,hoverLink:!0,realtime:!0,handleIcon:"path://M-11.39,9.77h0a3.5,3.5,0,0,1-3.5,3.5h-22a3.5,3.5,0,0,1-3.5-3.5h0a3.5,3.5,0,0,1,3.5-3.5h22A3.5,3.5,0,0,1-11.39,9.77Z",handleSize:"120%",handleStyle:{borderColor:N.color.neutral00,borderWidth:1},indicatorIcon:"circle",indicatorSize:"50%",indicatorStyle:{borderColor:N.color.neutral00,borderWidth:2,shadowBlur:2,shadowOffsetX:1,shadowOffsetY:1,shadowColor:N.color.shadow}}),t}(Ah);function AC(r,t,e){if(e[0]===e[1])return e.slice();for(var a=200,n=(e[1]-e[0])/a,i=e[0],o=[],s=0;s<=a&&i<e[1];s++)o.push(i),i+=n;return o.push(e[1]),o}var uR=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.autoPositionValues={left:1,right:1,top:1,bottom:1},e}return t.prototype.init=function(e,a){this.ecModel=e,this.api=a},t.prototype.render=function(e,a,n,i){if(this.visualMapModel=e,e.get("show")===!1){this.group.removeAll();return}this.doRender(e,a,n,i)},t.prototype.renderBackground=function(e){var a=this.visualMapModel,n=ws(a.get("padding")||0),i=e.getBoundingRect();e.add(new _t({z2:-1,silent:!0,shape:{x:i.x-n[3],y:i.y-n[0],width:i.width+n[3]+n[1],height:i.height+n[0]+n[2]},style:{fill:a.get("backgroundColor"),stroke:a.get("borderColor"),lineWidth:a.get("borderWidth")}}))},t.prototype.getControllerVisual=function(e,a,n){n=n||{};var i=n.forceState,o=this.visualMapModel,s={};if(a==="color"){var l=o.get("contentColor");s.color=l}function u(c){return s[c]}function f(c,p){s[c]=p}var v=o.controllerVisuals[i||o.getValueState(e)],h=_e.prepareVisualTypes(v);return A(h,function(c){var p=v[c];n.convertOpacityToAlpha&&c==="opacity"&&(c="colorAlpha",p=v.__alphaForOpacity),_e.dependsOn(c,a)&&p&&p.applyVisual(e,u,f)}),s[a]},t.prototype.positionGroup=function(e){var a=this.visualMapModel,n=this.api,i=pe(a,n).refContainer;Jh(e,a.getBoxLayoutParams(),i)},t.prototype.doRender=function(e,a,n,i){},t.type="visualMap",t}(Wt),MC=[["left","right","width"],["top","bottom","height"]];function fR(r,t,e){var a=r.option,n=a.align;if(n!=null&&n!=="auto")return n;for(var i={width:t.getWidth(),height:t.getHeight()},o=a.orient==="horizontal"?1:0,s=MC[o],l=[0,null,10],u={},f=0;f<3;f++)u[MC[1-o][f]]=l[f],u[s[f]]=f===2?e[0]:a[s[f]];var v=[["x","width",3],["y","height",0]][o],h=Xt(u,i,a.padding);return s[(h.margin[v[2]]||0)+h[v[0]]+h[v[1]]*.5<i[v[1]]*.5?0:1]}function Sv(r,t){return A(r||[],function(e){e.dataIndex!=null&&(e.dataIndexInside=e.dataIndex,e.dataIndex=null),e.highlightKey="visualMap"+(t?t.componentIndex:"")}),r}var aa=Rt,RX=A,DC=Math.min,Nd=Math.max,kX=12,EX=6,OX=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e._shapes={},e._dataInterval=[],e._handleEnds=[],e._hoverLinkDataIndices=[],e}return t.prototype.init=function(e,a){r.prototype.init.call(this,e,a),this._hoverLinkFromSeriesMouseOver=$(this._hoverLinkFromSeriesMouseOver,this),this._hideIndicator=$(this._hideIndicator,this)},t.prototype.doRender=function(e,a,n,i){(!i||i.type!=="selectDataRange"||i.from!==this.uid)&&this._buildView()},t.prototype._buildView=function(){this.group.removeAll();var e=this.visualMapModel,a=this.group;this._orient=e.get("orient"),this._useHandle=e.get("calculable"),this._resetInterval(),this._renderBar(a);var n=e.get("text");this._renderEndsText(a,n,0),this._renderEndsText(a,n,1),this._updateView(!0),this.renderBackground(a),this._updateView(),this._enableHoverLinkToSeries(),this._enableHoverLinkFromSeries(),this.positionGroup(a)},t.prototype._renderEndsText=function(e,a,n){if(a){var i=a[1-n];i=i!=null?i+"":"";var o=this.visualMapModel,s=o.get("textGap"),l=o.itemSize,u=this._shapes.mainGroup,f=this._applyTransform([l[0]/2,n===0?-s:l[1]+s],u),v=this._applyTransform(n===0?"bottom":"top",u),h=this._orient,c=this.visualMapModel.textStyleModel;this.group.add(new At({style:Gt(c,{x:f[0],y:f[1],verticalAlign:c.get("verticalAlign")||(h==="horizontal"?"middle":v),align:c.get("align")||(h==="horizontal"?v:"center"),text:i})}))}},t.prototype._renderBar=function(e){var a=this.visualMapModel,n=this._shapes,i=a.itemSize,o=this._orient,s=this._useHandle,l=fR(a,this.api,i),u=n.mainGroup=this._createBarGroup(l),f=new rt;u.add(f),f.add(n.outOfRange=LC()),f.add(n.inRange=LC(null,s?PC(this._orient):null,$(this._dragHandle,this,"all",!1),$(this._dragHandle,this,"all",!0))),f.setClipPath(new _t({shape:{x:0,y:0,width:i[0],height:i[1],r:3}}));var v=a.textStyleModel.getTextRect("国"),h=Nd(v.width,v.height);s&&(n.handleThumbs=[],n.handleLabels=[],n.handleLabelPoints=[],this._createHandle(a,u,0,i,h,o),this._createHandle(a,u,1,i,h,o)),this._createIndicator(a,u,i,h,o),e.add(u)},t.prototype._createHandle=function(e,a,n,i,o,s){var l=$(this._dragHandle,this,n,!1),u=$(this._dragHandle,this,n,!0),f=Yr(e.get("handleSize"),i[0]),v=ie(e.get("handleIcon"),-f/2,-f/2,f,f,null,!0),h=PC(this._orient);v.attr({cursor:h,draggable:!0,drift:l,ondragend:u,onmousemove:function(y){Za(y.event)}}),v.x=i[0]/2,v.useStyle(e.getModel("handleStyle").getItemStyle()),v.setStyle({strokeNoScale:!0,strokeFirst:!0}),v.style.lineWidth*=2,v.ensureState("emphasis").style=e.getModel(["emphasis","handleStyle"]).getItemStyle(),Ai(v,!0),a.add(v);var c=this.visualMapModel.textStyleModel,p=new At({cursor:h,draggable:!0,drift:l,onmousemove:function(y){Za(y.event)},ondragend:u,style:Gt(c,{x:0,y:0,text:""})});p.ensureState("blur").style={opacity:.1},p.stateTransition={duration:200},this.group.add(p);var d=[f,0],g=this._shapes;g.handleThumbs[n]=v,g.handleLabelPoints[n]=d,g.handleLabels[n]=p},t.prototype._createIndicator=function(e,a,n,i,o){var s=Yr(e.get("indicatorSize"),n[0]),l=ie(e.get("indicatorIcon"),-s/2,-s/2,s,s,null,!0);l.attr({cursor:"move",invisible:!0,silent:!0,x:n[0]/2});var u=e.getModel("indicatorStyle").getItemStyle();if(l instanceof xe){var f=l.style;l.useStyle(G({image:f.image,x:f.x,y:f.y,width:f.width,height:f.height},u))}else l.useStyle(u);a.add(l);var v=this.visualMapModel.textStyleModel,h=new At({silent:!0,invisible:!0,style:Gt(v,{x:0,y:0,text:""})});this.group.add(h);var c=[(o==="horizontal"?i/2:EX)+n[0]/2,0],p=this._shapes;p.indicator=l,p.indicatorLabel=h,p.indicatorLabelPoint=c,this._firstShowIndicator=!0},t.prototype._dragHandle=function(e,a,n,i){if(this._useHandle){if(this._dragging=!a,!a){var o=this._applyTransform([n,i],this._shapes.mainGroup,!0);this._updateInterval(e,o[1]),this._hideIndicator(),this._updateView()}a===!this.visualMapModel.get("realtime")&&this.api.dispatchAction({type:"selectDataRange",from:this.uid,visualMapId:this.visualMapModel.id,selected:this._dataInterval.slice()}),a?!this._hovering&&this._clearHoverLinkToSeries():IC(this.visualMapModel)&&this._doHoverLinkToSeries(this._handleEnds[e],!1)}},t.prototype._resetInterval=function(){var e=this.visualMapModel,a=this._dataInterval=e.getSelected(),n=e.getExtent(),i=[0,e.itemSize[1]];this._handleEnds=[aa(a[0],n,i,!0),aa(a[1],n,i,!0)]},t.prototype._updateInterval=function(e,a){a=a||0;var n=this.visualMapModel,i=this._handleEnds,o=[0,n.itemSize[1]];kn(a,i,o,e,0);var s=n.getExtent();this._dataInterval=[aa(i[0],o,s,!0),aa(i[1],o,s,!0)]},t.prototype._updateView=function(e){var a=this.visualMapModel,n=a.getExtent(),i=this._shapes,o=[0,a.itemSize[1]],s=e?o:this._handleEnds,l=this._createBarVisual(this._dataInterval,n,s,"inRange"),u=this._createBarVisual(n,n,o,"outOfRange");i.inRange.setStyle({fill:l.barColor}).setShape("points",l.barPoints),i.outOfRange.setStyle({fill:u.barColor}).setShape("points",u.barPoints),this._updateHandle(s,l)},t.prototype._createBarVisual=function(e,a,n,i){var o={forceState:i,convertOpacityToAlpha:!0},s=this._makeColorGradient(e,o),l=[this.getControllerVisual(e[0],"symbolSize",o),this.getControllerVisual(e[1],"symbolSize",o)],u=this._createBarPoints(n,l);return{barColor:new Ki(0,0,0,1,s),barPoints:u,handlesColor:[s[0].color,s[s.length-1].color]}},t.prototype._makeColorGradient=function(e,a){var n=100,i=[],o=(e[1]-e[0])/n;i.push({color:this.getControllerVisual(e[0],"color",a),offset:0});for(var s=1;s<n;s++){var l=e[0]+o*s;if(l>e[1])break;i.push({color:this.getControllerVisual(l,"color",a),offset:s/n})}return i.push({color:this.getControllerVisual(e[1],"color",a),offset:1}),i},t.prototype._createBarPoints=function(e,a){var n=this.visualMapModel.itemSize;return[[n[0]-a[0],e[0]],[n[0],e[0]],[n[0],e[1]],[n[0]-a[1],e[1]]]},t.prototype._createBarGroup=function(e){var a=this._orient,n=this.visualMapModel.get("inverse");return new rt(a==="horizontal"&&!n?{scaleX:e==="bottom"?1:-1,rotation:Math.PI/2}:a==="horizontal"&&n?{scaleX:e==="bottom"?-1:1,rotation:-Math.PI/2}:a==="vertical"&&!n?{scaleX:e==="left"?1:-1,scaleY:-1}:{scaleX:e==="left"?1:-1})},t.prototype._updateHandle=function(e,a){if(this._useHandle){var n=this._shapes,i=this.visualMapModel,o=n.handleThumbs,s=n.handleLabels,l=i.itemSize,u=i.getExtent(),f=this._applyTransform("left",n.mainGroup);RX([0,1],function(v){var h=o[v];h.setStyle("fill",a.handlesColor[v]),h.y=e[v];var c=aa(e[v],[0,l[1]],u,!0),p=this.getControllerVisual(c,"symbolSize");h.scaleX=h.scaleY=p/l[0],h.x=l[0]-p/2;var d=Hr(n.handleLabelPoints[v],An(h,this.group));if(this._orient==="horizontal"){var g=f==="left"||f==="top"?(l[0]-p)/2:(l[0]-p)/-2;d[1]+=g}s[v].setStyle({x:d[0],y:d[1],text:i.formatValueText(this._dataInterval[v]),verticalAlign:"middle",align:this._orient==="vertical"?this._applyTransform("left",n.mainGroup):"center"})},this)}},t.prototype._showIndicator=function(e,a,n,i){var o=this.visualMapModel,s=o.getExtent(),l=o.itemSize,u=[0,l[1]],f=this._shapes,v=f.indicator;if(v){v.attr("invisible",!1);var h={convertOpacityToAlpha:!0},c=this.getControllerVisual(e,"color",h),p=this.getControllerVisual(e,"symbolSize"),d=aa(e,s,u,!0),g=l[0]-p/2,y={x:v.x,y:v.y};v.y=d,v.x=g;var m=Hr(f.indicatorLabelPoint,An(v,this.group)),_=f.indicatorLabel;_.attr("invisible",!1);var S=this._applyTransform("left",f.mainGroup),x=this._orient,b=x==="horizontal";_.setStyle({text:(n||"")+o.formatValueText(a),verticalAlign:b?S:"middle",align:b?"center":S});var w={x:g,y:d,style:{fill:c}},T={style:{x:m[0],y:m[1]}};if(o.ecModel.isAnimationEnabled()&&!this._firstShowIndicator){var C={duration:100,easing:"cubicInOut",additive:!0};v.x=y.x,v.y=y.y,v.animateTo(w,C),_.animateTo(T,C)}else v.attr(w),_.attr(T);this._firstShowIndicator=!1;var M=this._shapes.handleLabels;if(M)for(var D=0;D<M.length;D++)this.api.enterBlur(M[D])}},t.prototype._enableHoverLinkToSeries=function(){var e=this;this._shapes.mainGroup.on("mousemove",function(a){if(e._hovering=!0,!e._dragging){var n=e.visualMapModel.itemSize,i=e._applyTransform([a.offsetX,a.offsetY],e._shapes.mainGroup,!0,!0);i[1]=DC(Nd(0,i[1]),n[1]),e._doHoverLinkToSeries(i[1],0<=i[0]&&i[0]<=n[0])}}).on("mouseout",function(){e._hovering=!1,!e._dragging&&e._clearHoverLinkToSeries()})},t.prototype._enableHoverLinkFromSeries=function(){var e=this.api.getZr();this.visualMapModel.option.hoverLink?(e.on("mouseover",this._hoverLinkFromSeriesMouseOver,this),e.on("mouseout",this._hideIndicator,this)):this._clearHoverLinkFromSeries()},t.prototype._doHoverLinkToSeries=function(e,a){var n=this.visualMapModel,i=n.itemSize;if(n.option.hoverLink){var o=[0,i[1]],s=n.getExtent();e=DC(Nd(o[0],e),o[1]);var l=NX(n,s,o),u=[e-l,e+l],f=aa(e,o,s,!0),v=[aa(u[0],o,s,!0),aa(u[1],o,s,!0)];u[0]<o[0]&&(v[0]=-1/0),u[1]>o[1]&&(v[1]=1/0),a&&(v[0]===-1/0?this._showIndicator(f,v[1],"< ",l):v[1]===1/0?this._showIndicator(f,v[0],"> ",l):this._showIndicator(f,f,"≈ ",l));var h=this._hoverLinkDataIndices,c=[];(a||IC(n))&&(c=this._hoverLinkDataIndices=n.findTargetDataIndices(v));var p=DE(h,c);this._dispatchHighDown("downplay",Sv(p[0],n)),this._dispatchHighDown("highlight",Sv(p[1],n))}},t.prototype._hoverLinkFromSeriesMouseOver=function(e){var a;if(Di(e.target,function(l){var u=ut(l);if(u.dataIndex!=null)return a=u,!0},!0),!!a){var n=this.ecModel.getSeriesByIndex(a.seriesIndex),i=this.visualMapModel;if(i.isTargetSeries(n)){var o=n.getData(a.dataType),s=o.getStore().get(i.getDataDimensionIndex(o),a.dataIndex);isNaN(s)||this._showIndicator(s,s)}}},t.prototype._hideIndicator=function(){var e=this._shapes;e.indicator&&e.indicator.attr("invisible",!0),e.indicatorLabel&&e.indicatorLabel.attr("invisible",!0);var a=this._shapes.handleLabels;if(a)for(var n=0;n<a.length;n++)this.api.leaveBlur(a[n])},t.prototype._clearHoverLinkToSeries=function(){this._hideIndicator();var e=this._hoverLinkDataIndices;this._dispatchHighDown("downplay",Sv(e,this.visualMapModel)),e.length=0},t.prototype._clearHoverLinkFromSeries=function(){this._hideIndicator();var e=this.api.getZr();e.off("mouseover",this._hoverLinkFromSeriesMouseOver),e.off("mouseout",this._hideIndicator)},t.prototype._applyTransform=function(e,a,n,i){var o=An(a,i?null:this.group);return W(e)?Hr(e,o,n):qh(e,o,n)},t.prototype._dispatchHighDown=function(e,a){a&&a.length&&this.api.dispatchAction({type:e,batch:a})},t.prototype.dispose=function(){this._clearHoverLinkFromSeries(),this._clearHoverLinkToSeries()},t.type="visualMap.continuous",t}(uR);function LC(r,t,e,a){return new Ee({shape:{points:r},draggable:!!e,cursor:t,drift:e,onmousemove:function(n){Za(n.event)},ondragend:a})}function NX(r,t,e){var a=kX/2,n=r.get("hoverLinkDataSize");return n&&(a=aa(n,t,e,!0)/2),a}function IC(r){var t=r.get("hoverLinkOnHandle");return!!(t??r.get("realtime"))}function PC(r){return r==="vertical"?"ns-resize":"ew-resize"}var BX={type:"selectDataRange",event:"dataRangeSelected",update:"update"},zX=function(r,t){t.eachComponent({mainType:"visualMap",query:r},function(e){e.setSelected(r.selected)})},VX=[{createOnAllSeries:!0,reset:function(r,t){var e=[];return t.eachComponent("visualMap",function(a){var n=r.pipelineContext;!a.isTargetSeries(r)||n&&n.large||e.push(o9(a.stateList,a.targetVisuals,$(a.getValueState,a),a.getDataDimensionIndex(r.getData())))}),e}},{createOnAllSeries:!0,reset:function(r,t){var e=r.getData(),a=[];t.eachComponent("visualMap",function(n){if(n.isTargetSeries(r)){var i=n.getVisualMeta($(GX,null,r,n))||{stops:[],outerColors:[]},o=n.getDataDimensionIndex(e);o>=0&&(i.dimension=o,a.push(i))}}),r.getData().setVisual("visualMeta",a)}}];function GX(r,t,e,a){for(var n=t.targetVisuals[a],i=_e.prepareVisualTypes(n),o={color:Pu(r.getData(),"color")},s=0,l=i.length;s<l;s++){var u=i[s],f=n[u==="opacity"?"__alphaForOpacity":u];f&&f.applyVisual(e,v,h)}return o.color;function v(c){return o[c]}function h(c,p){o[c]=p}}var RC=A;function FX(r){var t=r&&r.visualMap;W(t)||(t=t?[t]:[]),RC(t,function(e){if(e){Io(e,"splitList")&&!Io(e,"pieces")&&(e.pieces=e.splitList,delete e.splitList);var a=e.pieces;a&&W(a)&&RC(a,function(n){it(n)&&(Io(n,"start")&&!Io(n,"min")&&(n.min=n.start),Io(n,"end")&&!Io(n,"max")&&(n.max=n.end))})}})}function Io(r,t){return r&&r.hasOwnProperty&&r.hasOwnProperty(t)}var kC=!1;function vR(r){kC||(kC=!0,r.registerSubTypeDefaulter("visualMap",function(t){return!t.categories&&(!(t.pieces?t.pieces.length>0:t.splitNumber>0)||t.calculable)?"continuous":"piecewise"}),r.registerAction(BX,zX),A(VX,function(t){r.registerVisual(r.PRIORITY.VISUAL.COMPONENT,t)}),r.registerPreprocessor(FX))}function hR(r){r.registerComponentModel(PX),r.registerComponentView(OX),vR(r)}var HX=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e._pieceList=[],e}return t.prototype.optionUpdated=function(e,a){r.prototype.optionUpdated.apply(this,arguments),this.resetExtent();var n=this._mode=this._determineMode();this._pieceList=[],WX[this._mode].call(this,this._pieceList),this._resetSelected(e,a);var i=this.option.categories;this.resetVisual(function(o,s){n==="categories"?(o.mappingMethod="category",o.categories=et(i)):(o.dataExtent=this.getExtent(),o.mappingMethod="piecewise",o.pieceList=U(this._pieceList,function(l){return l=et(l),s!=="inRange"&&(l.visual=null),l}))})},t.prototype.completeVisualOption=function(){var e=this.option,a={},n=_e.listVisualTypes(),i=this.isCategory();A(e.pieces,function(s){A(n,function(l){s.hasOwnProperty(l)&&(a[l]=1)})}),A(a,function(s,l){var u=!1;A(this.stateList,function(f){u=u||o(e,f,l)||o(e.target,f,l)},this),!u&&A(this.stateList,function(f){(e[f]||(e[f]={}))[l]=lR.get(l,f==="inRange"?"active":"inactive",i)})},this);function o(s,l,u){return s&&s[l]&&s[l].hasOwnProperty(u)}r.prototype.completeVisualOption.apply(this,arguments)},t.prototype._resetSelected=function(e,a){var n=this.option,i=this._pieceList,o=(a?n:e).selected||{};if(n.selected=o,A(i,function(l,u){var f=this.getSelectedMapKey(l);o.hasOwnProperty(f)||(o[f]=!0)},this),n.selectedMode==="single"){var s=!1;A(i,function(l,u){var f=this.getSelectedMapKey(l);o[f]&&(s?o[f]=!1:s=!0)},this)}},t.prototype.getItemSymbol=function(){return this.get("itemSymbol")},t.prototype.getSelectedMapKey=function(e){return this._mode==="categories"?e.value+"":e.index+""},t.prototype.getPieceList=function(){return this._pieceList},t.prototype._determineMode=function(){var e=this.option;return e.pieces&&e.pieces.length>0?"pieces":this.option.categories?"categories":"splitNumber"},t.prototype.setSelected=function(e){this.option.selected=et(e)},t.prototype.getValueState=function(e){var a=_e.findPieceIndex(e,this._pieceList);return a!=null&&this.option.selected[this.getSelectedMapKey(this._pieceList[a])]?"inRange":"outOfRange"},t.prototype.findTargetDataIndices=function(e){var a=[],n=this._pieceList;return this.eachTargetSeries(function(i){var o=[],s=i.getData();s.each(this.getDataDimensionIndex(s),function(l,u){var f=_e.findPieceIndex(l,n);f===e&&o.push(u)},this),a.push({seriesId:i.id,dataIndex:o})},this),a},t.prototype.getRepresentValue=function(e){var a;if(this.isCategory())a=e.value;else if(e.value!=null)a=e.value;else{var n=e.interval||[];a=n[0]===-1/0&&n[1]===1/0?0:(n[0]+n[1])/2}return a},t.prototype.getVisualMeta=function(e){if(this.isCategory())return;var a=[],n=["",""],i=this;function o(f,v){var h=i.getRepresentValue({interval:f});v||(v=i.getValueState(h));var c=e(h,v);f[0]===-1/0?n[0]=c:f[1]===1/0?n[1]=c:a.push({value:f[0],color:c},{value:f[1],color:c})}var s=this._pieceList.slice();if(!s.length)s.push({interval:[-1/0,1/0]});else{var l=s[0].interval[0];l!==-1/0&&s.unshift({interval:[-1/0,l]}),l=s[s.length-1].interval[1],l!==1/0&&s.push({interval:[l,1/0]})}var u=-1/0;return A(s,function(f){var v=f.interval;v&&(v[0]>u&&o([u,v[0]],"outOfRange"),o(v.slice()),u=v[1])},this),{stops:a,outerColors:n}},t.type="visualMap.piecewise",t.defaultOption=Vn(Ah.defaultOption,{selected:null,minOpen:!1,maxOpen:!1,align:"auto",itemWidth:20,itemHeight:14,itemSymbol:"roundRect",pieces:null,categories:null,splitNumber:5,selectedMode:"multiple",itemGap:10,hoverLink:!0}),t}(Ah),WX={splitNumber:function(r){var t=this.option,e=Math.min(t.precision,20),a=this.getExtent(),n=t.splitNumber;n=Math.max(parseInt(n,10),1),t.splitNumber=n;for(var i=(a[1]-a[0])/n;+i.toFixed(e)!==i&&e<5;)e++;t.precision=e,i=+i.toFixed(e),t.minOpen&&r.push({interval:[-1/0,a[0]],close:[0,0]});for(var o=0,s=a[0];o<n;s+=i,o++){var l=o===n-1?a[1]:s+i;r.push({interval:[s,l],close:[1,1]})}t.maxOpen&&r.push({interval:[a[1],1/0],close:[0,0]}),vg(r),A(r,function(u,f){u.index=f,u.text=this.formatValueText(u.interval)},this)},categories:function(r){var t=this.option;A(t.categories,function(e){r.push({text:this.formatValueText(e,!0),value:e})},this),EC(t,r)},pieces:function(r){var t=this.option;A(t.pieces,function(e,a){it(e)||(e={value:e});var n={text:"",index:a};if(e.label!=null&&(n.text=e.label),e.hasOwnProperty("value")){var i=n.value=e.value;n.interval=[i,i],n.close=[1,1]}else{for(var o=n.interval=[],s=n.close=[0,0],l=[1,0,1],u=[-1/0,1/0],f=[],v=0;v<2;v++){for(var h=[["gte","gt","min"],["lte","lt","max"]][v],c=0;c<3&&o[v]==null;c++)o[v]=e[h[c]],s[v]=l[c],f[v]=c===2;o[v]==null&&(o[v]=u[v])}f[0]&&o[1]===1/0&&(s[0]=0),f[1]&&o[0]===-1/0&&(s[1]=0),o[0]===o[1]&&s[0]&&s[1]&&(n.value=o[0])}n.visual=_e.retrieveVisuals(e),r.push(n)},this),EC(t,r),vg(r),A(r,function(e){var a=e.close,n=[["<","≤"][a[1]],[">","≥"][a[0]]];e.text=e.text||this.formatValueText(e.value!=null?e.value:e.interval,!1,n)},this)}};function EC(r,t){var e=r.inverse;(r.orient==="vertical"?!e:e)&&t.reverse()}var UX=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.doRender=function(){var e=this.group;e.removeAll();var a=this.visualMapModel,n=a.get("textGap"),i=a.textStyleModel,o=this._getItemAlign(),s=a.itemSize,l=this._getViewData(),u=l.endsText,f=Ce(a.get("showLabel",!0),!u),v=!a.get("selectedMode");u&&this._renderEndsText(e,u[0],s,f,o),A(l.viewPieceList,function(h){var c=h.piece,p=new rt;p.onclick=$(this._onItemClick,this,c),this._enableHoverLink(p,h.indexInModelPieceList);var d=a.getRepresentValue(c);if(this._createItemSymbol(p,d,[0,0,s[0],s[1]],v),f){var g=this.visualMapModel.getValueState(d),y=i.get("align")||o;p.add(new At({style:Gt(i,{x:y==="right"?-n:s[0]+n,y:s[1]/2,text:c.text,verticalAlign:i.get("verticalAlign")||"middle",align:y,opacity:Q(i.get("opacity"),g==="outOfRange"?.5:1)}),silent:v}))}e.add(p)},this),u&&this._renderEndsText(e,u[1],s,f,o),Ei(a.get("orient"),e,a.get("itemGap")),this.renderBackground(e),this.positionGroup(e)},t.prototype._enableHoverLink=function(e,a){var n=this;e.on("mouseover",function(){return i("highlight")}).on("mouseout",function(){return i("downplay")});var i=function(o){var s=n.visualMapModel;s.option.hoverLink&&n.api.dispatchAction({type:o,batch:Sv(s.findTargetDataIndices(a),s)})}},t.prototype._getItemAlign=function(){var e=this.visualMapModel,a=e.option;if(a.orient==="vertical")return fR(e,this.api,e.itemSize);var n=a.align;return(!n||n==="auto")&&(n="left"),n},t.prototype._renderEndsText=function(e,a,n,i,o){if(a){var s=new rt,l=this.visualMapModel.textStyleModel;s.add(new At({style:Gt(l,{x:i?o==="right"?n[0]:0:n[0]/2,y:n[1]/2,verticalAlign:"middle",align:i?o:"center",text:a})})),e.add(s)}},t.prototype._getViewData=function(){var e=this.visualMapModel,a=U(e.getPieceList(),function(s,l){return{piece:s,indexInModelPieceList:l}}),n=e.get("text"),i=e.get("orient"),o=e.get("inverse");return(i==="horizontal"?o:!o)?a.reverse():n&&(n=n.slice().reverse()),{viewPieceList:a,endsText:n}},t.prototype._createItemSymbol=function(e,a,n,i){var o=ie(this.getControllerVisual(a,"symbol"),n[0],n[1],n[2],n[3],this.getControllerVisual(a,"color"));o.silent=i,e.add(o)},t.prototype._onItemClick=function(e){var a=this.visualMapModel,n=a.option,i=n.selectedMode;if(i){var o=et(n.selected),s=a.getSelectedMapKey(e);i==="single"||i===!0?(o[s]=!0,A(o,function(l,u){o[u]=u===s})):o[s]=!o[s],this.api.dispatchAction({type:"selectDataRange",from:this.uid,visualMapId:this.visualMapModel.id,selected:o})}},t.type="visualMap.piecewise",t}(uR);function cR(r){r.registerComponentModel(HX),r.registerComponentView(UX),vR(r)}function YX(r){mt(hR),mt(cR)}var ZX=function(){function r(t){this._thumbnailModel=t}return r.prototype.reset=function(t){this._renderVersion=t.getMainProcessVersion()},r.prototype.renderContent=function(t){var e=t.api.getViewOfComponentModel(this._thumbnailModel);e&&(t.group.silent=!0,e.renderContent({group:t.group,targetTrans:t.targetTrans,z2Range:zM(t.group),roamType:t.roamType,viewportRect:t.viewportRect,renderVersion:this._renderVersion}))},r.prototype.updateWindow=function(t,e){var a=e.getViewOfComponentModel(this._thumbnailModel);a&&a.updateWindow({targetTrans:t,renderVersion:this._renderVersion})},r}(),XX=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.preventAutoZ=!0,e}return t.prototype.optionUpdated=function(e,a){this._updateBridge()},t.prototype._updateBridge=function(){var e=this._birdge=this._birdge||new ZX(this);if(this._target=null,this.ecModel.eachSeries(function(n){iw(n,null)}),this.shouldShow()){var a=this.getTarget();iw(a.baseMapProvider,e)}},t.prototype.shouldShow=function(){return this.getShallow("show",!0)},t.prototype.getBridge=function(){return this._birdge},t.prototype.getTarget=function(){if(this._target)return this._target;var e=this.getReferringComponents("series",{useDefault:!1,enableAll:!1,enableNone:!1}).models[0];return e?e.subType!=="graph"&&(e=null):e=this.ecModel.queryComponents({mainType:"series",subType:"graph"})[0],this._target={baseMapProvider:e},this._target},t.type="thumbnail",t.layoutMode="box",t.dependencies=["series","geo"],t.defaultOption={show:!0,right:1,bottom:1,height:"25%",width:"25%",itemStyle:{borderColor:N.color.border,borderWidth:2},windowStyle:{borderWidth:1,color:N.color.neutral30,borderColor:N.color.neutral40,opacity:.3},z:10},t}(xt),$X=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,a,n){if(this._api=n,this._model=e,this._coordSys||(this._coordSys=new no),!this._isEnabled()){this._clear();return}this._renderVersion=n.getMainProcessVersion();var i=this.group;i.removeAll();var o=e.getModel("itemStyle"),s=o.getItemStyle();s.fill==null&&(s.fill=a.get("backgroundColor")||N.color.neutral00);var l=pe(e,n).refContainer,u=Xt(iD(e,!0),l),f=s.lineWidth||0,v=this._contentRect=Wi(u.clone(),f/2,!0,!0),h=new rt;i.add(h),h.setClipPath(new _t({shape:v.plain()}));var c=this._targetGroup=new rt;h.add(c);var p=u.plain();p.r=o.getShallow("borderRadius",!0),i.add(this._bgRect=new _t({style:s,shape:p,silent:!1,cursor:"grab"}));var d=e.getModel("windowStyle"),g=d.getShallow("borderRadius",!0);h.add(this._windowRect=new _t({shape:{x:0,y:0,width:0,height:0,r:g},style:d.getItemStyle(),silent:!1,cursor:"grab"})),this._dealRenderContent(),this._dealUpdateWindow(),NC(e,this)},t.prototype.renderContent=function(e){this._bridgeRendered=e,this._isEnabled()&&(this._dealRenderContent(),this._dealUpdateWindow(),NC(this._model,this))},t.prototype._dealRenderContent=function(){var e=this._bridgeRendered;if(!(!e||e.renderVersion!==this._renderVersion)){var a=this._targetGroup,n=this._coordSys,i=this._contentRect;if(a.removeAll(),!!e){var o=e.group,s=o.getBoundingRect();a.add(o),this._bgRect.z2=e.z2Range.min-10,n.setBoundingRect(s.x,s.y,s.width,s.height);var l=Xt({left:"center",top:"center",aspect:s.width/s.height},i);n.setViewRect(l.x,l.y,l.width,l.height),o.attr(n.getTransformInfo().raw),this._windowRect.z2=e.z2Range.max+10,this._resetRoamController(e.roamType)}}},t.prototype.updateWindow=function(e){var a=this._bridgeRendered;a&&a.renderVersion===e.renderVersion&&(a.targetTrans=e.targetTrans),this._isEnabled()&&this._dealUpdateWindow()},t.prototype._dealUpdateWindow=function(){var e=this._bridgeRendered;if(!(!e||e.renderVersion!==this._renderVersion)){var a=Dr([],e.targetTrans),n=Gr([],this._coordSys.transform,a);this._transThisToTarget=Dr([],n);var i=e.viewportRect;i?i=i.clone():i=new lt(0,0,this._api.getWidth(),this._api.getHeight()),i.applyTransform(n);var o=this._windowRect,s=o.shape.r;o.setShape(nt({r:s},i))}},t.prototype._resetRoamController=function(e){var a=this,n=this._api,i=this._roamController;if(i||(i=this._roamController=new ao(n.getZr())),!e||!this._isEnabled()){i.disable();return}i.enable(e,{api:n,zInfo:{component:this._model},triggerInfo:{roamTrigger:null,isInSelf:function(o,s,l){return a._contentRect.contain(s,l)}}}),i.off("pan").off("zoom").on("pan",$(this._onPan,this)).on("zoom",$(this._onZoom,this))},t.prototype._onPan=function(e){var a=this._transThisToTarget;if(!(!this._isEnabled()||!a)){var n=Jt([],[e.oldX,e.oldY],a),i=Jt([],[e.oldX-e.dx,e.oldY-e.dy],a);this._api.dispatchAction(OC(this._model.getTarget().baseMapProvider,{dx:i[0]-n[0],dy:i[1]-n[1]}))}},t.prototype._onZoom=function(e){var a=this._transThisToTarget;if(!(!this._isEnabled()||!a)){var n=Jt([],[e.originX,e.originY],a);this._api.dispatchAction(OC(this._model.getTarget().baseMapProvider,{zoom:1/e.scale,originX:n[0],originY:n[1]}))}},t.prototype._isEnabled=function(){var e=this._model;if(!e||!e.shouldShow())return!1;var a=e.getTarget().baseMapProvider;return!!a},t.prototype._clear=function(){this.group.removeAll(),this._bridgeRendered=null,this._roamController&&this._roamController.disable()},t.prototype.remove=function(){this._clear()},t.prototype.dispose=function(){this._clear()},t.type="thumbnail",t}(Wt);function OC(r,t){var e=r.mainType==="series"?r.subType+"Roam":r.mainType+"Roam",a={type:e};return a[r.mainType+"Id"]=r.id,G(a,t),a}function NC(r,t){var e=Ui(r);Kh(t.group,e.z,e.zlevel)}function qX(r){r.registerComponentModel(XX),r.registerComponentView($X)}var KX={label:{enabled:!0},decal:{show:!1}},BC=St(),jX={};function JX(r,t){var e=r.getModel("aria");if(!e.get("enabled"))return;var a=et(KX);yt(a.label,r.getLocaleModel().get("aria"),!1),yt(e.option,a,!1),n(),i();function n(){var u=e.getModel("decal"),f=u.get("show");if(f){var v=j();r.eachSeries(function(h){if(!h.isColorBySeries()){var c=v.get(h.type);c||(c={},v.set(h.type,c)),BC(h).scope=c}}),r.eachRawSeries(function(h){if(r.isSeriesFiltered(h))return;if(tt(h.enableAriaDecal)){h.enableAriaDecal();return}var c=h.getData();if(h.isColorBySeries()){var m=Rg(h.ecModel,h.name,jX,r.getSeriesCount()),_=c.getVisual("decal");c.setVisual("decal",S(_,m))}else{var p=h.getRawData(),d={},g=BC(h).scope;c.each(function(x){var b=c.getRawIndex(x);d[b]=x});var y=p.count();p.each(function(x){var b=d[x],w=p.getName(x)||x+"",T=Rg(h.ecModel,w,g,y),C=c.getItemVisual(b,"decal");c.setItemVisual(b,"decal",S(C,T))})}function S(x,b){var w=x?G(G({},b),x):b;return w.dirty=!0,w}})}}function i(){var u=t.getZr().dom;if(u){var f=r.getLocaleModel().get("aria"),v=e.getModel("label");if(v.option=nt(v.option,f),!!v.get("enabled")){if(u.setAttribute("role","img"),v.get("description")){u.setAttribute("aria-label",v.get("description"));return}var h=r.getSeriesCount(),c=v.get(["data","maxCount"])||10,p=v.get(["series","maxCount"])||10,d=Math.min(h,p),g;if(!(h<1)){var y=s();if(y){var m=v.get(["general","withTitle"]);g=o(m,{title:y})}else g=v.get(["general","withoutTitle"]);var _=[],S=h>1?v.get(["series","multiple","prefix"]):v.get(["series","single","prefix"]);g+=o(S,{seriesCount:h}),r.eachSeries(function(T,C){if(C<d){var M=void 0,D=T.get("name"),I=D?"withName":"withoutName";M=h>1?v.get(["series","multiple",I]):v.get(["series","single",I]),M=o(M,{seriesId:T.seriesIndex,seriesName:T.get("name"),seriesType:l(T.subType)});var L=T.getData();if(L.count()>c){var P=v.get(["data","partialData"]);M+=o(P,{displayCnt:c})}else M+=v.get(["data","allData"]);for(var k=v.get(["data","separator","middle"]),R=v.get(["data","separator","end"]),O=v.get(["data","excludeDimensionId"]),E=[],B=0;B<L.count();B++)if(B<c){var V=L.getName(B),F=O?Pt(L.getValues(B),function(Y,K){return gt(O,K)===-1}):L.getValues(B),H=v.get(["data",V?"withName":"withoutName"]);E.push(o(H,{name:V,value:F.join(k)}))}M+=E.join(k)+R,_.push(M)}});var x=v.getModel(["series","multiple","separator"]),b=x.get("middle"),w=x.get("end");g+=_.join(b)+w,u.setAttribute("aria-label",g)}}}}function o(u,f){if(!X(u))return u;var v=u;return A(f,function(h,c){v=v.replace(new RegExp("\\{\\s*"+c+"\\s*\\}","g"),h)}),v}function s(){var u=r.get("title");return u&&u.length&&(u=u[0]),u&&u.text}function l(u){var f=r.getLocaleModel().get(["series","typeNames"]);return f[u]||f.chart}}function QX(r){if(!(!r||!r.aria)){var t=r.aria;t.show!=null&&(t.enabled=t.show),t.label=t.label||{},A(["description","general","series","data"],function(e){t[e]!=null&&(t.label[e]=t[e])})}}function t$(r){r.registerPreprocessor(QX),r.registerVisual(r.PRIORITY.VISUAL.ARIA,JX)}var zC={value:"eq","<":"lt","<=":"lte",">":"gt",">=":"gte","=":"eq","!=":"ne","<>":"ne"},e$=function(){function r(t){var e=this._condVal=X(t)?new RegExp(t):lA(t)?t:null;if(e==null){var a="";kt(a)}}return r.prototype.evaluate=function(t){var e=typeof t;return X(e)?this._condVal.test(t):Mt(e)?this._condVal.test(t+""):!1},r}(),r$=function(){function r(){}return r.prototype.evaluate=function(){return this.value},r}(),a$=function(){function r(){}return r.prototype.evaluate=function(){for(var t=this.children,e=0;e<t.length;e++)if(!t[e].evaluate())return!1;return!0},r}(),n$=function(){function r(){}return r.prototype.evaluate=function(){for(var t=this.children,e=0;e<t.length;e++)if(t[e].evaluate())return!0;return!1},r}(),i$=function(){function r(){}return r.prototype.evaluate=function(){return!this.child.evaluate()},r}(),o$=function(){function r(){}return r.prototype.evaluate=function(){for(var t=!!this.valueParser,e=this.getValue,a=e(this.valueGetterParam),n=t?this.valueParser(a):null,i=0;i<this.subCondList.length;i++)if(!this.subCondList[i].evaluate(t?n:a))return!1;return!0},r}();function T_(r,t){if(r===!0||r===!1){var e=new r$;return e.value=r,e}var a="";return pR(r)||kt(a),r.and?VC("and",r,t):r.or?VC("or",r,t):r.not?s$(r,t):l$(r,t)}function VC(r,t,e){var a=t[r],n="";W(a)||kt(n),a.length||kt(n);var i=r==="and"?new a$:new n$;return i.children=U(a,function(o){return T_(o,e)}),i.children.length||kt(n),i}function s$(r,t){var e=r.not,a="";pR(e)||kt(a);var n=new i$;return n.child=T_(e,t),n.child||kt(a),n}function l$(r,t){for(var e="",a=t.prepareGetValue(r),n=[],i=Ct(r),o=r.parser,s=o?MD(o):null,l=0;l<i.length;l++){var u=i[l];if(!(u==="parser"||t.valueGetterAttrMap.get(u))){var f=q(zC,u)?zC[u]:u,v=r[u],h=s?s(v):v,c=FB(f,h)||f==="reg"&&new e$(h);c||kt(e),n.push(c)}}n.length||kt(e);var p=new o$;return p.valueGetterParam=a,p.valueParser=s,p.getValue=t.getValue,p.subCondList=n,p}function pR(r){return it(r)&&!Pe(r)}var u$=function(){function r(t,e){this._cond=T_(t,e)}return r.prototype.evaluate=function(){return this._cond.evaluate()},r}();function f$(r,t){return new u$(r,t)}var v$={type:"echarts:filter",transform:function(r){for(var t=r.upstream,e,a=f$(r.config,{valueGetterAttrMap:j({dimension:!0}),prepareGetValue:function(s){var l="",u=s.dimension;q(s,"dimension")||kt(l);var f=t.getDimensionInfo(u);return f||kt(l),{dimIdx:f.index}},getValue:function(s){return t.retrieveValueFromItem(e,s.dimIdx)}}),n=[],i=0,o=t.count();i<o;i++)e=t.getRawDataItem(i),a.evaluate()&&n.push(e);return{data:n}}},h$={type:"echarts:sort",transform:function(r){var t=r.upstream,e=r.config,a="",n=Ft(e);n.length||kt(a);var i=[];A(n,function(f){var v=f.dimension,h=f.order,c=f.parser,p=f.incomparable;if(v==null&&kt(a),h!=="asc"&&h!=="desc"&&kt(a),p&&p!=="min"&&p!=="max"){var d="";kt(d)}if(h!=="asc"&&h!=="desc"){var g="";kt(g)}var y=t.getDimensionInfo(v);y||kt(a);var m=c?MD(c):null;c&&!m&&kt(a),i.push({dimIdx:y.index,parser:m,comparator:new LD(h,p)})});var o=t.sourceFormat;o!==Me&&o!==cr&&kt(a);for(var s=[],l=0,u=t.count();l<u;l++)s.push(t.getRawDataItem(l));return s.sort(function(f,v){for(var h=0;h<i.length;h++){var c=i[h],p=t.retrieveValueFromItem(f,c.dimIdx),d=t.retrieveValueFromItem(v,c.dimIdx);c.parser&&(p=c.parser(p),d=c.parser(d));var g=c.comparator.evaluate(p,d);if(g!==0)return g}return 0}),{data:s}}};function c$(r){r.registerTransform(v$),r.registerTransform(h$)}var p$=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="dataset",e}return t.prototype.init=function(e,a,n){r.prototype.init.call(this,e,a,n),this._sourceManager=new kD(this),gS(this)},t.prototype.mergeOption=function(e,a){r.prototype.mergeOption.call(this,e,a),gS(this)},t.prototype.optionUpdated=function(){this._sourceManager.dirty()},t.prototype.getSourceManager=function(){return this._sourceManager},t.type="dataset",t.defaultOption={seriesLayoutBy:Wr},t}(xt),d$=function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="dataset",e}return t.type="dataset",t}(Wt);function g$(r){r.registerComponentModel(p$),r.registerComponentView(d$)}var ea=ma.CMD;function Wo(r,t){return Math.abs(r-t)<1e-5}function Zy(r){var t=r.data,e=r.len(),a=[],n,i=0,o=0,s=0,l=0;function u(L,P){n&&n.length>2&&a.push(n),n=[L,P]}function f(L,P,k,R){Wo(L,k)&&Wo(P,R)||n.push(L,P,k,R,k,R)}function v(L,P,k,R,O,E){var B=Math.abs(P-L),V=Math.tan(B/4)*4/3,F=P<L?-1:1,H=Math.cos(L),Y=Math.sin(L),K=Math.cos(P),ft=Math.sin(P),It=H*O+k,Ot=Y*E+R,vt=K*O+k,at=ft*E+R,dt=O*V*F,J=E*V*F;n.push(It-dt*Y,Ot+J*H,vt+dt*ft,at-J*K,vt,at)}for(var h,c,p,d,g=0;g<e;){var y=t[g++],m=g===1;switch(m&&(i=t[g],o=t[g+1],s=i,l=o,(y===ea.L||y===ea.C||y===ea.Q)&&(n=[s,l])),y){case ea.M:i=s=t[g++],o=l=t[g++],u(s,l);break;case ea.L:h=t[g++],c=t[g++],f(i,o,h,c),i=h,o=c;break;case ea.C:n.push(t[g++],t[g++],t[g++],t[g++],i=t[g++],o=t[g++]);break;case ea.Q:h=t[g++],c=t[g++],p=t[g++],d=t[g++],n.push(i+2/3*(h-i),o+2/3*(c-o),p+2/3*(h-p),d+2/3*(c-d),p,d),i=p,o=d;break;case ea.A:var _=t[g++],S=t[g++],x=t[g++],b=t[g++],w=t[g++],T=t[g++]+w;g+=1;var C=!t[g++];h=Math.cos(w)*x+_,c=Math.sin(w)*b+S,m?(s=h,l=c,u(s,l)):f(i,o,h,c),i=Math.cos(T)*x+_,o=Math.sin(T)*b+S;for(var M=(C?-1:1)*Math.PI/2,D=w;C?D>T:D<T;D+=M){var I=C?Math.max(D+M,T):Math.min(D+M,T);v(D,I,_,S,x,b)}break;case ea.R:s=i=t[g++],l=o=t[g++],h=s+t[g++],c=l+t[g++],u(h,l),f(h,l,h,c),f(h,c,s,c),f(s,c,s,l),f(s,l,h,l);break;case ea.Z:n&&f(i,o,s,l),i=s,o=l;break}}return n&&n.length>2&&a.push(n),a}function Xy(r,t,e,a,n,i,o,s,l,u){if(Wo(r,e)&&Wo(t,a)&&Wo(n,o)&&Wo(i,s)){l.push(o,s);return}var f=2/u,v=f*f,h=o-r,c=s-t,p=Math.sqrt(h*h+c*c);h/=p,c/=p;var d=e-r,g=a-t,y=n-o,m=i-s,_=d*d+g*g,S=y*y+m*m;if(_<v&&S<v){l.push(o,s);return}var x=h*d+c*g,b=-h*y-c*m,w=_-x*x,T=S-b*b;if(w<v&&x>=0&&T<v&&b>=0){l.push(o,s);return}var C=[],M=[];In(r,e,n,o,.5,C),In(t,a,i,s,.5,M),Xy(C[0],M[0],C[1],M[1],C[2],M[2],C[3],M[3],l,u),Xy(C[4],M[4],C[5],M[5],C[6],M[6],C[7],M[7],l,u)}function y$(r,t){var e=Zy(r),a=[];t=t||1;for(var n=0;n<e.length;n++){var i=e[n],o=[],s=i[0],l=i[1];o.push(s,l);for(var u=2;u<i.length;){var f=i[u++],v=i[u++],h=i[u++],c=i[u++],p=i[u++],d=i[u++];Xy(s,l,f,v,h,c,p,d,o,t),s=p,l=d}a.push(o)}return a}function dR(r,t,e){var a=r[t],n=r[1-t],i=Math.abs(a/n),o=Math.ceil(Math.sqrt(i*e)),s=Math.floor(e/o);s===0&&(s=1,o=e);for(var l=[],u=0;u<o;u++)l.push(s);var f=o*s,v=e-f;if(v>0)for(var u=0;u<v;u++)l[u%o]+=1;return l}function GC(r,t,e){for(var a=r.r0,n=r.r,i=r.startAngle,o=r.endAngle,s=Math.abs(o-i),l=s*n,u=n-a,f=l>Math.abs(u),v=dR([l,u],f?0:1,t),h=(f?s:u)/v.length,c=0;c<v.length;c++)for(var p=(f?u:s)/v[c],d=0;d<v[c];d++){var g={};f?(g.startAngle=i+h*c,g.endAngle=i+h*(c+1),g.r0=a+p*d,g.r=a+p*(d+1)):(g.startAngle=i+p*d,g.endAngle=i+p*(d+1),g.r0=a+h*c,g.r=a+h*(c+1)),g.clockwise=r.clockwise,g.cx=r.cx,g.cy=r.cy,e.push(g)}}function m$(r,t,e){for(var a=r.width,n=r.height,i=a>n,o=dR([a,n],i?0:1,t),s=i?"width":"height",l=i?"height":"width",u=i?"x":"y",f=i?"y":"x",v=r[s]/o.length,h=0;h<o.length;h++)for(var c=r[l]/o[h],p=0;p<o[h];p++){var d={};d[u]=h*v,d[f]=p*c,d[s]=v,d[l]=c,d.x+=r.x,d.y+=r.y,e.push(d)}}function FC(r,t,e,a){return r*a-e*t}function _$(r,t,e,a,n,i,o,s){var l=e-r,u=a-t,f=o-n,v=s-i,h=FC(f,v,l,u);if(Math.abs(h)<1e-6)return null;var c=r-n,p=t-i,d=FC(c,p,f,v)/h;return d<0||d>1?null:new st(d*l+r,d*u+t)}function S$(r,t,e){var a=new st;st.sub(a,e,t),a.normalize();var n=new st;st.sub(n,r,t);var i=n.dot(a);return i}function Po(r,t){var e=r[r.length-1];e&&e[0]===t[0]&&e[1]===t[1]||r.push(t)}function x$(r,t,e){for(var a=r.length,n=[],i=0;i<a;i++){var o=r[i],s=r[(i+1)%a],l=_$(o[0],o[1],s[0],s[1],t.x,t.y,e.x,e.y);l&&n.push({projPt:S$(l,t,e),pt:l,idx:i})}if(n.length<2)return[{points:r},{points:r}];n.sort(function(g,y){return g.projPt-y.projPt});var u=n[0],f=n[n.length-1];if(f.idx<u.idx){var v=u;u=f,f=v}for(var h=[u.pt.x,u.pt.y],c=[f.pt.x,f.pt.y],p=[h],d=[c],i=u.idx+1;i<=f.idx;i++)Po(p,r[i].slice());Po(p,c),Po(p,h);for(var i=f.idx+1;i<=u.idx+a;i++)Po(d,r[i%a].slice());return Po(d,h),Po(d,c),[{points:p},{points:d}]}function HC(r){var t=r.points,e=[],a=[];Uh(t,e,a);var n=new lt(e[0],e[1],a[0]-e[0],a[1]-e[1]),i=n.width,o=n.height,s=n.x,l=n.y,u=new st,f=new st;return i>o?(u.x=f.x=s+i/2,u.y=l,f.y=l+o):(u.y=f.y=l+o/2,u.x=s,f.x=s+i),x$(t,u,f)}function Mh(r,t,e,a){if(e===1)a.push(t);else{var n=Math.floor(e/2),i=r(t);Mh(r,i[0],n,a),Mh(r,i[1],e-n,a)}return a}function b$(r,t){for(var e=[],a=0;a<t;a++)e.push(Tm(r));return e}function w$(r,t){t.setStyle(r.style),t.z=r.z,t.z2=r.z2,t.zlevel=r.zlevel}function T$(r){for(var t=[],e=0;e<r.length;)t.push([r[e++],r[e++]]);return t}function C$(r,t){var e=[],a=r.shape,n;switch(r.type){case"rect":m$(a,t,e),n=_t;break;case"sector":GC(a,t,e),n=ke;break;case"circle":GC({r0:0,r:a.r,startAngle:0,endAngle:Math.PI*2,cx:a.cx,cy:a.cy},t,e),n=ke;break;default:var i=r.getComputedTransform(),o=i?Math.sqrt(Math.max(i[0]*i[0]+i[1]*i[1],i[2]*i[2]+i[3]*i[3])):1,s=U(y$(r.getUpdatedPathProxy(),o),function(y){return T$(y)}),l=s.length;if(l===0)Mh(HC,{points:s[0]},t,e);else if(l===t)for(var u=0;u<l;u++)e.push({points:s[u]});else{var f=0,v=U(s,function(y){var m=[],_=[];Uh(y,m,_);var S=(_[1]-m[1])*(_[0]-m[0]);return f+=S,{poly:y,area:S}});v.sort(function(y,m){return m.area-y.area});for(var h=t,u=0;u<l;u++){var c=v[u];if(h<=0)break;var p=u===l-1?h:Math.ceil(c.area/f*t);p<0||(Mh(HC,{points:c.poly},p,e),h-=p)}}n=Ee;break}if(!n)return b$(r,t);for(var d=[],u=0;u<e.length;u++){var g=new n;g.setShape(e[u]),w$(r,g),d.push(g)}return d}function A$(r,t){var e=r.length,a=t.length;if(e===a)return[r,t];for(var n=[],i=[],o=e<a?r:t,s=Math.min(e,a),l=Math.abs(a-e)/6,u=(s-2)/6,f=Math.ceil(l/u)+1,v=[o[0],o[1]],h=l,c=2;c<s;){var p=o[c-2],d=o[c-1],g=o[c++],y=o[c++],m=o[c++],_=o[c++],S=o[c++],x=o[c++];if(h<=0){v.push(g,y,m,_,S,x);continue}for(var b=Math.min(h,f-1)+1,w=1;w<=b;w++){var T=w/b;In(p,g,m,S,T,n),In(d,y,_,x,T,i),p=n[3],d=i[3],v.push(n[1],i[1],n[2],i[2],p,d),g=n[5],y=i[5],m=n[6],_=i[6]}h-=b-1}return o===r?[v,t]:[r,v]}function WC(r,t){for(var e=r.length,a=r[e-2],n=r[e-1],i=[],o=0;o<t.length;)i[o++]=a,i[o++]=n;return i}function M$(r,t){for(var e,a,n,i=[],o=[],s=0;s<Math.max(r.length,t.length);s++){var l=r[s],u=t[s],f=void 0,v=void 0;l?u?(e=A$(l,u),f=e[0],v=e[1],a=f,n=v):(v=WC(n||l,l),f=l):(f=WC(a||u,u),v=u),i.push(f),o.push(v)}return[i,o]}function UC(r){for(var t=0,e=0,a=0,n=r.length,i=0,o=n-2;i<n;o=i,i+=2){var s=r[o],l=r[o+1],u=r[i],f=r[i+1],v=s*f-u*l;t+=v,e+=(s+u)*v,a+=(l+f)*v}return t===0?[r[0]||0,r[1]||0]:[e/t/3,a/t/3,t]}function D$(r,t,e,a){for(var n=(r.length-2)/6,i=1/0,o=0,s=r.length,l=s-2,u=0;u<n;u++){for(var f=u*6,v=0,h=0;h<s;h+=2){var c=h===0?f:(f+h-2)%l+2,p=r[c]-e[0],d=r[c+1]-e[1],g=t[h]-a[0],y=t[h+1]-a[1],m=g-p,_=y-d;v+=m*m+_*_}v<i&&(i=v,o=u)}return o}function L$(r){for(var t=[],e=r.length,a=0;a<e;a+=2)t[a]=r[e-a-2],t[a+1]=r[e-a-1];return t}function I$(r,t,e,a){for(var n=[],i,o=0;o<r.length;o++){var s=r[o],l=t[o],u=UC(s),f=UC(l);i==null&&(i=u[2]<0!=f[2]<0);var v=[],h=[],c=0,p=1/0,d=[],g=s.length;i&&(s=L$(s));for(var y=D$(s,l,u,f)*6,m=g-2,_=0;_<m;_+=2){var S=(y+_)%m+2;v[_+2]=s[S]-u[0],v[_+3]=s[S+1]-u[1]}v[0]=s[y]-u[0],v[1]=s[y+1]-u[1];for(var x=a/e,b=-a/2;b<=a/2;b+=x){for(var w=Math.sin(b),T=Math.cos(b),C=0,_=0;_<s.length;_+=2){var M=v[_],D=v[_+1],I=l[_]-f[0],L=l[_+1]-f[1],P=I*T-L*w,k=I*w+L*T;d[_]=P,d[_+1]=k;var R=P-M,O=k-D;C+=R*R+O*O}if(C<p){p=C,c=b;for(var E=0;E<d.length;E++)h[E]=d[E]}}n.push({from:v,to:h,fromCp:u,toCp:f,rotation:-c})}return n}function Dh(r){return r.__isCombineMorphing}var gR="__mOriginal_";function Lh(r,t,e){var a=gR+t,n=r[a]||r[t];r[a]||(r[a]=r[t]);var i=e.replace,o=e.after,s=e.before;r[t]=function(){var l=arguments,u;return s&&s.apply(this,l),i?u=i.apply(this,l):u=n.apply(this,l),o&&o.apply(this,l),u}}function Vl(r,t){var e=gR+t;r[e]&&(r[t]=r[e],r[e]=null)}function YC(r,t){for(var e=0;e<r.length;e++)for(var a=r[e],n=0;n<a.length;){var i=a[n],o=a[n+1];a[n++]=t[0]*i+t[2]*o+t[4],a[n++]=t[1]*i+t[3]*o+t[5]}}function yR(r,t){var e=r.getUpdatedPathProxy(),a=t.getUpdatedPathProxy(),n=M$(Zy(e),Zy(a)),i=n[0],o=n[1],s=r.getComputedTransform(),l=t.getComputedTransform();function u(){this.transform=null}s&&YC(i,s),l&&YC(o,l),Lh(t,"updateTransform",{replace:u}),t.transform=null;var f=I$(i,o,10,Math.PI),v=[];Lh(t,"buildPath",{replace:function(h){for(var c=t.__morphT,p=1-c,d=[],g=0;g<f.length;g++){var y=f[g],m=y.from,_=y.to,S=y.rotation*c,x=y.fromCp,b=y.toCp,w=Math.sin(S),T=Math.cos(S);Ml(d,x,b,c);for(var C=0;C<m.length;C+=2){var M=m[C],D=m[C+1],I=_[C],L=_[C+1],P=M*p+I*c,k=D*p+L*c;v[C]=P*T-k*w+d[0],v[C+1]=P*w+k*T+d[1]}var R=v[0],O=v[1];h.moveTo(R,O);for(var C=2;C<m.length;){var I=v[C++],L=v[C++],E=v[C++],B=v[C++],V=v[C++],F=v[C++];R===I&&O===L&&E===V&&B===F?h.lineTo(V,F):h.bezierCurveTo(I,L,E,B,V,F),R=V,O=F}}}})}function C_(r,t,e){if(!r||!t)return t;var a=e.done,n=e.during;yR(r,t),t.__morphT=0;function i(){Vl(t,"buildPath"),Vl(t,"updateTransform"),t.__morphT=-1,t.createPathProxy(),t.dirtyShape()}return t.animateTo({__morphT:1},nt({during:function(o){t.dirtyShape(),n&&n(o)},done:function(){i(),a&&a()}},e)),t}function P$(r,t,e,a,n,i){var o=16;r=n===e?0:Math.round(32767*(r-e)/(n-e)),t=i===a?0:Math.round(32767*(t-a)/(i-a));for(var s=0,l,u=(1<<o)/2;u>0;u/=2){var f=0,v=0;(r&u)>0&&(f=1),(t&u)>0&&(v=1),s+=u*u*(3*f^v),v===0&&(f===1&&(r=u-1-r,t=u-1-t),l=r,r=t,t=l)}return s}function Ih(r){var t=1/0,e=1/0,a=-1/0,n=-1/0,i=U(r,function(s){var l=s.getBoundingRect(),u=s.getComputedTransform(),f=l.x+l.width/2+(u?u[4]:0),v=l.y+l.height/2+(u?u[5]:0);return t=Math.min(f,t),e=Math.min(v,e),a=Math.max(f,a),n=Math.max(v,n),[f,v]}),o=U(i,function(s,l){return{cp:s,z:P$(s[0],s[1],t,e,a,n),path:r[l]}});return o.sort(function(s,l){return s.z-l.z}).map(function(s){return s.path})}function mR(r){return C$(r.path,r.count)}function $y(){return{fromIndividuals:[],toIndividuals:[],count:0}}function R$(r,t,e){var a=[];function n(x){for(var b=0;b<x.length;b++){var w=x[b];Dh(w)?n(w.childrenRef()):w instanceof bt&&a.push(w)}}n(r);var i=a.length;if(!i)return $y();var o=e.dividePath||mR,s=o({path:t,count:i});if(s.length!==i)return console.error("Invalid morphing: unmatched splitted path"),$y();a=Ih(a),s=Ih(s);for(var l=e.done,u=e.during,f=e.individualDelay,v=new Ba,h=0;h<i;h++){var c=a[h],p=s[h];p.parent=t,p.copyTransform(v),f||yR(c,p)}t.__isCombineMorphing=!0,t.childrenRef=function(){return s};function d(x){for(var b=0;b<s.length;b++)s[b].addSelfToZr(x)}Lh(t,"addSelfToZr",{after:function(x){d(x)}}),Lh(t,"removeSelfFromZr",{after:function(x){for(var b=0;b<s.length;b++)s[b].removeSelfFromZr(x)}});function g(){t.__isCombineMorphing=!1,t.__morphT=-1,t.childrenRef=null,Vl(t,"addSelfToZr"),Vl(t,"removeSelfFromZr")}var y=s.length;if(f)for(var m=y,_=function(){m--,m===0&&(g(),l&&l())},h=0;h<y;h++){var S=f?nt({delay:(e.delay||0)+f(h,y,a[h],s[h]),done:_},e):e;C_(a[h],s[h],S)}else t.__morphT=0,t.animateTo({__morphT:1},nt({during:function(x){for(var b=0;b<y;b++){var w=s[b];w.__morphT=t.__morphT,w.dirtyShape()}u&&u(x)},done:function(){g();for(var x=0;x<r.length;x++)Vl(r[x],"updateTransform");l&&l()}},e));return t.__zr&&d(t.__zr),{fromIndividuals:a,toIndividuals:s,count:y}}function k$(r,t,e){var a=t.length,n=[],i=e.dividePath||mR;function o(c){for(var p=0;p<c.length;p++){var d=c[p];Dh(d)?o(d.childrenRef()):d instanceof bt&&n.push(d)}}if(Dh(r)){o(r.childrenRef());var s=n.length;if(s<a)for(var l=0,u=s;u<a;u++)n.push(Tm(n[l++%s]));n.length=a}else{n=i({path:r,count:a});for(var f=r.getComputedTransform(),u=0;u<n.length;u++)n[u].setLocalTransform(f);if(n.length!==a)return console.error("Invalid morphing: unmatched splitted path"),$y()}n=Ih(n),t=Ih(t);for(var v=e.individualDelay,u=0;u<a;u++){var h=v?nt({delay:(e.delay||0)+v(u,a,n[u],t[u])},e):e;C_(n[u],t[u],h)}return{fromIndividuals:n,toIndividuals:t,count:t.length}}function ZC(r){return W(r[0])}function XC(r,t){for(var e=[],a=r.length,n=0;n<a;n++)e.push({one:r[n],many:[]});for(var n=0;n<t.length;n++){var i=t[n].length,o=void 0;for(o=0;o<i;o++)e[o%a].many.push(t[n][o])}for(var s=0,n=a-1;n>=0;n--)if(!e[n].many.length){var l=e[s].many;if(l.length<=1)if(s)s=0;else return e;var i=l.length,u=Math.ceil(i/2);e[n].many=l.slice(u,i),e[s].many=l.slice(0,u),s++}return e}var E$={clone:function(r){for(var t=[],e=1-Math.pow(1-r.path.style.opacity,1/r.count),a=0;a<r.count;a++){var n=Tm(r.path);n.setStyle("opacity",e),t.push(n)}return t},split:null};function Bd(r,t,e,a,n,i){if(!r.length||!t.length)return;var o=_s("update",a,n);if(!(o&&o.duration>0))return;var s=a.getModel("universalTransition").get("delay"),l=Object.assign({setToFinal:!0},o),u,f;ZC(r)&&(u=r,f=t),ZC(t)&&(u=t,f=r);function v(y,m,_,S,x){var b=y.many,w=y.one;if(b.length===1&&!x){var T=m?b[0]:w,C=m?w:b[0];if(Dh(T))v({many:[T],one:C},!0,_,S,!0);else{var M=s?nt({delay:s(_,S)},l):l;C_(T,C,M),i(T,C,T,C,M)}}else for(var D=nt({dividePath:E$[e],individualDelay:s&&function(O,E,B,V){return s(O+_,S)}},l),I=m?R$(b,w,D):k$(w,b,D),L=I.fromIndividuals,P=I.toIndividuals,k=L.length,R=0;R<k;R++){var M=s?nt({delay:s(R,k)},l):l;i(L[R],P[R],m?b[R]:y.one,m?y.one:b[R],M)}}for(var h=u?u===r:r.length>t.length,c=u?XC(f,u):XC(h?t:r,[h?r:t]),p=0,d=0;d<c.length;d++)p+=c[d].many.length;for(var g=0,d=0;d<c.length;d++)v(c[d],h,g,p),g+=c[d].many.length}function _i(r){if(!r)return[];if(W(r)){for(var t=[],e=0;e<r.length;e++)t.push(_i(r[e]));return t}var a=[];return r.traverse(function(n){n instanceof bt&&!n.disableMorphing&&!n.invisible&&!n.ignore&&a.push(n)}),a}var _R=1e4,O$=0,$C=1,qC=2,N$=St();function B$(r,t){for(var e=r.dimensions,a=0;a<e.length;a++){var n=r.getDimensionInfo(e[a]);if(n&&n.otherDims[t]===0)return e[a]}}function z$(r,t,e){var a=r.getDimensionInfo(e),n=a&&a.ordinalMeta;if(a){var i=r.get(a.name,t);return n&&n.categories[i]||i+""}}function KC(r,t,e,a){var n=a?"itemChildGroupId":"itemGroupId",i=B$(r,n);if(i){var o=z$(r,t,i);return o}var s=r.getRawDataItem(t),l=a?"childGroupId":"groupId";if(s&&s[l])return s[l]+"";if(!a)return e||r.getId(t)}function jC(r){var t=[];return A(r,function(e){var a=e.data,n=e.dataGroupId;if(!(a.count()>_R))for(var i=a.getIndices(),o=0;o<i.length;o++)t.push({data:a,groupId:KC(a,o,n,!1),childGroupId:KC(a,o,n,!0),divide:e.divide,dataIndex:o})}),t}function zd(r,t,e){r.traverse(function(a){a instanceof bt&&Yt(a,{style:{opacity:0}},t,{dataIndex:e,isFrom:!0})})}function Vd(r){if(r.parent){var t=r.getComputedTransform();r.setLocalTransform(t),r.parent.remove(r)}}function Ro(r){r.stopAnimation(),r.isGroup&&r.traverse(function(t){t.stopAnimation()})}function V$(r,t,e){var a=_s("update",e,t);a&&r.traverse(function(n){if(n instanceof Lr){var i=dN(n);i&&n.animateFrom({style:i},a)}})}function G$(r,t){var e=r.length;if(e!==t.length)return!1;for(var a=0;a<e;a++){var n=r[a],i=t[a];if(n.data.getId(n.dataIndex)!==i.data.getId(i.dataIndex))return!1}return!0}function SR(r,t,e){var a=jC(r),n=jC(t);function i(_,S,x,b,w){(x||_)&&S.animateFrom({style:x&&x!==_?G(G({},x.style),_.style):_.style},w)}var o=!1,s=O$,l=j(),u=j();a.forEach(function(_){_.groupId&&l.set(_.groupId,!0),_.childGroupId&&u.set(_.childGroupId,!0)});for(var f=0;f<n.length;f++){var v=n[f].groupId;if(u.get(v)){s=$C;break}var h=n[f].childGroupId;if(h&&l.get(h)){s=qC;break}}function c(_,S){return function(x){var b=x.data,w=x.dataIndex;return S?b.getId(w):_?s===$C?x.childGroupId:x.groupId:s===qC?x.childGroupId:x.groupId}}var p=G$(a,n),d={};if(!p)for(var f=0;f<n.length;f++){var g=n[f],y=g.data.getItemGraphicEl(g.dataIndex);y&&(d[y.id]=!0)}function m(_,S){var x=a[S],b=n[_],w=b.data.hostModel,T=x.data.getItemGraphicEl(x.dataIndex),C=b.data.getItemGraphicEl(b.dataIndex);if(T===C){C&&V$(C,b.dataIndex,w);return}T&&d[T.id]||C&&(Ro(C),T?(Ro(T),Vd(T),o=!0,Bd(_i(T),_i(C),b.divide,w,_,i)):zd(C,w,_))}new qa(a,n,c(!0,p),c(!1,p),null,"multiple").update(m).updateManyToOne(function(_,S){var x=n[_],b=x.data,w=b.hostModel,T=b.getItemGraphicEl(x.dataIndex),C=Pt(U(S,function(M){return a[M].data.getItemGraphicEl(a[M].dataIndex)}),function(M){return M&&M!==T&&!d[M.id]});T&&(Ro(T),C.length?(A(C,function(M){Ro(M),Vd(M)}),o=!0,Bd(_i(C),_i(T),x.divide,w,_,i)):zd(T,w,x.dataIndex))}).updateOneToMany(function(_,S){var x=a[S],b=x.data.getItemGraphicEl(x.dataIndex);if(!(b&&d[b.id])){var w=Pt(U(_,function(C){return n[C].data.getItemGraphicEl(n[C].dataIndex)}),function(C){return C&&C!==b}),T=n[_[0]].data.hostModel;w.length&&(A(w,function(C){return Ro(C)}),b?(Ro(b),Vd(b),o=!0,Bd(_i(b),_i(w),x.divide,T,_[0],i)):A(w,function(C){return zd(C,T,_[0])}))}}).updateManyToMany(function(_,S){new qa(S,_,function(x){return a[x].data.getId(a[x].dataIndex)},function(x){return n[x].data.getId(n[x].dataIndex)}).update(function(x,b){m(_[x],S[b])}).execute()}).execute(),o&&A(t,function(_){var S=_.data,x=S.hostModel,b=x&&e.getViewOfSeriesModel(x),w=_s("update",x,0);b&&x.isAnimationEnabled()&&w&&w.duration>0&&b.group.traverse(function(T){T instanceof bt&&!T.animators.length&&T.animateFrom({style:{opacity:0}},w)})})}function JC(r){var t=r.getModel("universalTransition").get("seriesKey");return t||r.id}function QC(r){return W(r)?r.sort().join(","):r}function pn(r){if(r.hostModel)return r.hostModel.getModel("universalTransition").get("divideShape")}function F$(r,t){var e=j(),a=j(),n=j();return A(r.oldSeries,function(i,o){var s=r.oldDataGroupIds[o],l=r.oldData[o],u=JC(i),f=QC(u);a.set(f,{dataGroupId:s,data:l}),W(u)&&A(u,function(v){n.set(v,{key:f,dataGroupId:s,data:l})})}),A(t.updatedSeries,function(i){if(i.isUniversalTransitionEnabled()&&i.isAnimationEnabled()){var o=i.get("dataGroupId"),s=i.getData(),l=JC(i),u=QC(l),f=a.get(u);if(f)e.set(u,{oldSeries:[{dataGroupId:f.dataGroupId,divide:pn(f.data),data:f.data}],newSeries:[{dataGroupId:o,divide:pn(s),data:s}]});else if(W(l)){var v=[];A(l,function(p){var d=a.get(p);d.data&&v.push({dataGroupId:d.dataGroupId,divide:pn(d.data),data:d.data})}),v.length&&e.set(u,{oldSeries:v,newSeries:[{dataGroupId:o,data:s,divide:pn(s)}]})}else{var h=n.get(l);if(h){var c=e.get(h.key);c||(c={oldSeries:[{dataGroupId:h.dataGroupId,data:h.data,divide:pn(h.data)}],newSeries:[]},e.set(h.key,c)),c.newSeries.push({dataGroupId:o,data:s,divide:pn(s)})}}}}),e}function tA(r,t){for(var e=0;e<r.length;e++){var a=t.seriesIndex!=null&&t.seriesIndex===r[e].seriesIndex||t.seriesId!=null&&t.seriesId===r[e].id;if(a)return e}}function H$(r,t,e,a){var n=[],i=[];A(Ft(r.from),function(o){var s=tA(t.oldSeries,o);s>=0&&n.push({dataGroupId:t.oldDataGroupIds[s],data:t.oldData[s],divide:pn(t.oldData[s]),groupIdDim:o.dimension})}),A(Ft(r.to),function(o){var s=tA(e.updatedSeries,o);if(s>=0){var l=e.updatedSeries[s].getData();i.push({dataGroupId:t.oldDataGroupIds[s],data:l,divide:pn(l),groupIdDim:o.dimension})}}),n.length>0&&i.length>0&&SR(n,i,a)}function W$(r){r.registerUpdateLifecycle("series:beforeupdate",function(t,e,a){A(Ft(a.seriesTransition),function(n){A(Ft(n.to),function(i){for(var o=a.updatedSeries,s=0;s<o.length;s++)(i.seriesIndex!=null&&i.seriesIndex===o[s].seriesIndex||i.seriesId!=null&&i.seriesId===o[s].id)&&(o[s][cv]=!0)})})}),r.registerUpdateLifecycle("series:transition",function(t,e,a){var n=N$(e);if(n.oldSeries&&a.updatedSeries&&a.optionChanged){var i=a.seriesTransition;if(i)A(Ft(i),function(c){H$(c,n,a,e)});else{var o=F$(n,a);A(o.keys(),function(c){var p=o.get(c);SR(p.oldSeries,p.newSeries,e)})}A(a.updatedSeries,function(c){c[cv]&&(c[cv]=!1)})}for(var s=t.getSeries(),l=n.oldSeries=[],u=n.oldDataGroupIds=[],f=n.oldData=[],v=0;v<s.length;v++){var h=s[v].getData();h.count()<_R&&(l.push(s[v]),u.push(s[v].get("dataGroupId")),f.push(h))}})}var U$=function(){function r(){this.breaks=[],this._elapsedExtent=[1/0,-1/0]}return r.prototype.setBreaks=function(t){this.breaks=t.breaks},r.prototype.update=function(t){Z$(this,t);var e=this._elapsedExtent;e[0]=this.elapse(t[0]),e[1]=this.elapse(t[1])},r.prototype.hasBreaks=function(){return!!this.breaks.length},r.prototype.calcNiceTickMultiple=function(t,e){for(var a=0;a<this.breaks.length;a++){var n=this.breaks[a];if(n.vmin<t&&t<n.vmax){var i=e(t,n.vmax);return i}}return 0},r.prototype.getExtentSpan=function(){return this._elapsedExtent[1]-this._elapsedExtent[0]},r.prototype.normalize=function(t){var e=this._elapsedExtent[1]-this._elapsedExtent[0];return e===0?.5:(this.elapse(t)-this._elapsedExtent[0])/e},r.prototype.scale=function(t){return this.unelapse(t*(this._elapsedExtent[1]-this._elapsedExtent[0])+this._elapsedExtent[0])},r.prototype.elapse=function(t){for(var e=eA,a=rA,n=!0,i=0;i<this.breaks.length;i++){var o=this.breaks[i];if(t<=o.vmax){t>o.vmin?e+=o.vmin-a+(t-o.vmin)/(o.vmax-o.vmin)*o.gapReal:e+=t-a,a=o.vmax,n=!1;break}e+=o.vmin-a+o.gapReal,a=o.vmax}return n&&(e+=t-a),e},r.prototype.unelapse=function(t){for(var e=eA,a=rA,n=!0,i=0,o=0;o<this.breaks.length;o++){var s=this.breaks[o],l=e+s.vmin-a,u=l+s.gapReal;if(t<=u){t>l?i=s.vmin+(t-l)/(u-l)*(s.vmax-s.vmin):i=a+t-e,a=s.vmax,n=!1;break}e=u,a=s.vmax}return n&&(i=a+t-e),i},r}();function Y$(){return new U$}var eA=0,rA=0;function Z$(r,t){var e=0,a={tpAbs:{span:0,val:0},tpPrct:{span:0,val:0}},n=function(){return{has:!1,span:NaN,inExtFrac:NaN,val:NaN}},i={S:{tpAbs:n(),tpPrct:n()},E:{tpAbs:n(),tpPrct:n()}};A(r.breaks,function(s){var l=s.gapParsed;l.type==="tpPrct"&&(e+=l.val);var u=A_(s,t);if(u){var f=u.vmin!==s.vmin,v=u.vmax!==s.vmax,h=u.vmax-u.vmin;if(!(f&&v))if(f||v){var c=f?"S":"E";i[c][l.type].has=!0,i[c][l.type].span=h,i[c][l.type].inExtFrac=h/(s.vmax-s.vmin),i[c][l.type].val=l.val}else a[l.type].span+=h,a[l.type].val+=l.val}});var o=e*(0+(t[1]-t[0])+(a.tpAbs.val-a.tpAbs.span)+(i.S.tpAbs.has?(i.S.tpAbs.val-i.S.tpAbs.span)*i.S.tpAbs.inExtFrac:0)+(i.E.tpAbs.has?(i.E.tpAbs.val-i.E.tpAbs.span)*i.E.tpAbs.inExtFrac:0)-a.tpPrct.span-(i.S.tpPrct.has?i.S.tpPrct.span*i.S.tpPrct.inExtFrac:0)-(i.E.tpPrct.has?i.E.tpPrct.span*i.E.tpPrct.inExtFrac:0))/(1-a.tpPrct.val-(i.S.tpPrct.has?i.S.tpPrct.val*i.S.tpPrct.inExtFrac:0)-(i.E.tpPrct.has?i.E.tpPrct.val*i.E.tpPrct.inExtFrac:0));A(r.breaks,function(s){var l=s.gapParsed;l.type==="tpPrct"&&(s.gapReal=e!==0?Math.max(o,0)*l.val/e:0),l.type==="tpAbs"&&(s.gapReal=l.val),s.gapReal==null&&(s.gapReal=0)})}function X$(r,t,e,a,n,i){r!=="no"&&A(e,function(o){var s=A_(o,i);if(s)for(var l=t.length-1;l>=0;l--){var u=t[l],f=a(u),v=n*3/4;f>s.vmin-v&&f<s.vmax+v&&(r!=="preserve_extent_bound"||f!==i[0]&&f!==i[1])&&t.splice(l,1)}})}function $$(r,t,e,a){A(t,function(n){var i=A_(n,e);i&&(r.push({value:i.vmin,break:{type:"vmin",parsedBreak:i},time:a?a(i):void 0}),r.push({value:i.vmax,break:{type:"vmax",parsedBreak:i},time:a?a(i):void 0}))}),t.length&&r.sort(function(n,i){return n.value-i.value})}function A_(r,t){var e=Math.max(r.vmin,t[0]),a=Math.min(r.vmax,t[1]);return e<a||e===a&&e>t[0]&&e<t[1]?{vmin:e,vmax:a,breakOption:r.breakOption,gapParsed:r.gapParsed,gapReal:r.gapReal}:null}function qy(r,t,e){var a=[];if(!r)return{breaks:a};function n(o,s){return o>=0&&o<1-1e-5}A(r,function(o){if(!(!o||o.start==null||o.end==null)&&!o.isExpanded){var s={breakOption:et(o),vmin:t(o.start),vmax:t(o.end),gapParsed:{type:"tpAbs",val:0},gapReal:null};if(o.gap!=null){var l=!1;if(X(o.gap)){var u=sr(o.gap);if(u.match(/%$/)){var f=parseFloat(u)/100;n(f)||(f=0),s.gapParsed.type="tpPrct",s.gapParsed.val=f,l=!0}}if(!l){var v=t(o.gap);(!isFinite(v)||v<0)&&(v=0),s.gapParsed.type="tpAbs",s.gapParsed.val=v}}if(s.vmin===s.vmax&&(s.gapParsed.type="tpAbs",s.gapParsed.val=0),e&&e.noNegative&&A(["vmin","vmax"],function(c){s[c]<0&&(s[c]=0)}),s.vmin>s.vmax){var h=s.vmax;s.vmax=s.vmin,s.vmin=h}a.push(s)}}),a.sort(function(o,s){return o.vmin-s.vmin});var i=-1/0;return A(a,function(o,s){i>o.vmin&&(a[s]=null),i=o.vmax}),{breaks:a.filter(function(o){return!!o})}}function M_(r,t){return Ky(t)===Ky(r)}function Ky(r){return r.start+"_\0_"+r.end}function q$(r,t,e){var a=[];A(r,function(i,o){var s=t(i);s&&s.type==="vmin"&&a.push([o])}),A(r,function(i,o){var s=t(i);if(s&&s.type==="vmax"){var l=Nn(a,function(u){return M_(t(r[u[0]]).parsedBreak.breakOption,s.parsedBreak.breakOption)});l&&l.push(o)}});var n=[];return A(a,function(i){i.length===2&&n.push(e?i:[r[i[0]],r[i[1]]])}),n}function K$(r,t,e,a){var n,i;if(r.break){var o=r.break.parsedBreak,s=Nn(e,function(v){return M_(v.breakOption,r.break.parsedBreak.breakOption)}),l=a(Math.pow(t,o.vmin),s.vmin),u=a(Math.pow(t,o.vmax),s.vmax),f={type:o.gapParsed.type,val:o.gapParsed.type==="tpAbs"?ae(Math.pow(t,o.vmin+o.gapParsed.val))-l:o.gapParsed.val};n={type:r.break.type,parsedBreak:{breakOption:o.breakOption,vmin:l,vmax:u,gapParsed:f,gapReal:o.gapReal}},i=s[r.break.type]}return{brkRoundingCriterion:i,vBreak:n}}function j$(r,t,e){var a={noNegative:!0},n=qy(r,e,a),i=qy(r,e,a),o=Math.log(t);return i.breaks=U(i.breaks,function(s){var l=Math.log(s.vmin)/o,u=Math.log(s.vmax)/o,f={type:s.gapParsed.type,val:s.gapParsed.type==="tpAbs"?Math.log(s.vmin+s.gapParsed.val)/o-l:s.gapParsed.val};return{vmin:l,vmax:u,gapParsed:f,gapReal:s.gapReal,breakOption:s.breakOption}}),{parsedOriginal:n,parsedLogged:i}}var J$={vmin:"start",vmax:"end"};function Q$(r,t){return t&&(r=r||{},r.break={type:J$[t.type],start:t.parsedBreak.vmin,end:t.parsedBreak.vmax}),r}function tq(){ON({createScaleBreakContext:Y$,pruneTicksByBreak:X$,addBreaksToTicks:$$,parseAxisBreakOption:qy,identifyAxisBreak:M_,serializeAxisBreakIdentifier:Ky,retrieveAxisBreakPairs:q$,getTicksLogTransformBreak:K$,logarithmicParseBreaksFromOption:j$,makeAxisLabelFormatterParamBreak:Q$})}var aA=St();function eq(r,t){var e=Nn(r,function(a){return se().identifyAxisBreak(a.parsedBreak.breakOption,t.breakOption)});return e||r.push(e={zigzagRandomList:[],parsedBreak:t,shouldRemove:!1}),e}function rq(r){A(r,function(t){return t.shouldRemove=!0})}function aq(r){for(var t=r.length-1;t>=0;t--)r[t].shouldRemove&&r.splice(t,1)}function nq(r,t,e,a,n){var i=e.axis;if(i.scale.isBlank()||!se())return;var o=se().retrieveAxisBreakPairs(i.scale.getTicks({breakTicks:"only_break"}),function(C){return C.break},!1);if(!o.length)return;var s=e.getModel("breakArea"),l=s.get("zigzagAmplitude"),u=s.get("zigzagMinSpan"),f=s.get("zigzagMaxSpan");u=Math.max(2,u||0),f=Math.max(u,f||0);var v=s.get("expandOnClick"),h=s.get("zigzagZ"),c=s.getModel("itemStyle"),p=c.getItemStyle(),d=p.stroke,g=p.lineWidth,y=p.lineDash,m=p.fill,_=new rt({ignoreModelZ:!0}),S=i.isHorizontal(),x=aA(t).visualList||(aA(t).visualList=[]);rq(x);for(var b=function(C){var M=o[C][0].break.parsedBreak,D=[];D[0]=i.toGlobalCoord(i.dataToCoord(M.vmin,!0)),D[1]=i.toGlobalCoord(i.dataToCoord(M.vmax,!0)),D[1]<D[0]&&D.reverse();var I=eq(x,M);I.shouldRemove=!1;var L=new rt;T(I.zigzagRandomList,L,D[0],D[1],S,M),v&&L.on("click",function(){var P={type:ic,breaks:[{start:M.breakOption.start,end:M.breakOption.end}]};P[i.dim+"AxisIndex"]=e.componentIndex,n.dispatchAction(P)}),L.silent=!v,_.add(L)},w=0;w<o.length;w++)b(w);r.add(_),aq(x);function T(C,M,D,I,L,P){var k={stroke:d,lineWidth:g,lineDash:y,fill:"none"},R=L?0:1,O=1-R,E=a[ct[O]]+a[le[O]];function B(zt){var Dt=[],Et=[];Dt[R]=Et[R]=zt,Dt[O]=a[ct[O]],Et[O]=E;var Vt={x1:Dt[0],y1:Dt[1],x2:Et[0],y2:Et[1]};return Zh(Vt,Vt,{lineWidth:1}),Dt[0]=Vt.x1,Dt[1]=Vt.y1,Dt[R]}D=B(D),I=B(I);for(var V=[],F=[],H=!0,Y=a[ct[O]],K=0;;K++){var ft=Y===a[ct[O]],It=Y>=E;It&&(Y=E);var Ot=[],vt=[];Ot[R]=D,vt[R]=I,!ft&&!It&&(Ot[R]+=H?-l:l,vt[R]-=H?l:-l),Ot[O]=Y,vt[O]=Y,V.push(Ot),F.push(vt);var at=void 0;if(K<C.length?at=C[K]:(at=Math.random(),C.push(at)),Y+=at*(f-u)+u,H=!H,It)break}var dt=se().serializeAxisBreakIdentifier(P.breakOption);if(M.add(new Ae({anid:"break_a_"+dt,shape:{points:V},style:k,z:h})),P.gapReal!==0){M.add(new Ae({anid:"break_b_"+dt,shape:{points:F},style:k,z:h}));var J=F.slice();J.reverse();var ht=V.concat(J);M.add(new Ee({anid:"break_c_"+dt,shape:{points:ht},style:{fill:m,opacity:p.opacity},z:h}))}}}function iq(r,t,e,a){var n=r.axis,i=e.transform;Re(a.style);var o=n.getExtent();n.inverse&&(o=o.slice(),o.reverse());var s=se().retrieveAxisBreakPairs(n.scale.getTicks({breakTicks:"only_break"}),function(g){return g.break},!1),l=U(s,function(g){var y=g[0].break.parsedBreak,m=[n.dataToCoord(y.vmin,!0),n.dataToCoord(y.vmax,!0)];return m[0]>m[1]&&m.reverse(),{coordPair:m,brkId:se().serializeAxisBreakIdentifier(y.breakOption)}});l.sort(function(g,y){return g.coordPair[0]-y.coordPair[0]});for(var u=o[0],f=null,v=0;v<l.length;v++){var h=l[v],c=Math.max(h.coordPair[0],o[0]),p=Math.min(h.coordPair[1],o[1]);u<=c&&d(u,c,f,h),u=p,f=h}u<=o[1]&&d(u,o[1],f,null);function d(g,y,m,_){function S(D,I){i&&(Jt(D,D,i),Jt(I,I,i))}function x(D,I){var L={x1:D[0],y1:D[1],x2:I[0],y2:I[1]};Zh(L,L,a.style),D[0]=L.x1,D[1]=L.y1,I[0]=L.x2,I[1]=L.y2}var b=[g,0],w=[y,0],T=[g,5],C=[y,5];S(b,T),x(b,T),S(w,C),x(w,C),x(b,w);var M=new ne(G({shape:{x1:b[0],y1:b[1],x2:w[0],y2:w[1]}},a));t.add(M),M.anid="breakLine_"+(m?m.brkId:"\0")+"_\0_"+(_?_.brkId:"\0")}}function oq(r,t,e){if(Nn(e,function(m){return!m}))return;var a=new st;if(!ac(e[0],e[1],a,{direction:-(r?t+Math.PI:t),touchThreshold:0,bidirectional:!1}))return;var n=me();Qa(n,n,-t);var i=U(e,function(m){return m.transform?Gr(me(),n,m.transform):n});function o(m){var _=e[0].localRect,S=new st(_[le[m]]*i[0][0],_[le[m]]*i[0][1]);return Math.abs(S.y)<1e-5}var s=.5;if(o(0)||o(1)){var l=U(e,function(m,_){var S=m.localRect.clone();return S.applyTransform(i[_]),S}),u=new st;u.copy(e[0].label).add(e[1].label).scale(.5),u.transform(n);var f=a.clone().transform(n),v=l[0].x+l[1].x+(f.x>=0?l[0].width:l[1].width),h=(v+f.x)/2-u.x,c=Math.min(h,h-f.x),p=Math.max(h,h-f.x),d=p<0?p:c>0?c:0;s=(h-d)/f.x}var g=new st,y=new st;st.scale(g,a,-s),st.scale(y,a,1-s),jg(e[0],g),jg(e[1],y)}function sq(r,t){var e={breaks:[]};return A(t.breaks,function(a){if(a){var n=Nn(r.get("breaks",!0),function(s){return se().identifyAxisBreak(s,a)});if(n){var i=t.type,o={isExpanded:!!n.isExpanded};n.isExpanded=i===ic?!0:i===F2?!1:i===H2?!n.isExpanded:n.isExpanded,e.breaks.push({start:n.start,end:n.end,isExpanded:!!n.isExpanded,old:o})}}}),e}function lq(){aF({adjustBreakLabelPair:oq,buildAxisBreakLine:iq,rectCoordBuildBreakAxis:nq,updateModelAxisBreak:sq})}function uq(r){uF(r),tq(),lq()}function fq(){IF(vq)}function vq(r,t){A(r,function(e){if(!e.model.get(["axisLabel","inside"])){var a=hq(e);if(a){var n=e.isHorizontal()?"height":"width",i=e.model.get(["axisLabel","margin"]);t[n]-=a[n]+i,e.position==="top"?t.y+=a.height+i:e.position==="left"&&(t.x+=a.width+i)}}})}function hq(r){var t=r.model,e=r.scale;if(!t.get(["axisLabel","show"])||e.isBlank())return;var a,n,i=e.getExtent();e instanceof is?n=e.count():(a=e.getTicks(),n=a.length);var o=r.getLabelModel(),s=Ls(r),l,u=1;n>40&&(u=Math.ceil(n/40));for(var f=0;f<n;f+=u){var v=a?a[f]:{value:i[0]+f},h=s(v,f),c=o.getTextRect(h),p=d(c,o.get("rotate")||0);l?l.union(p):l=p}return l;function d(g,y){var m=y*Math.PI/180,_=g.width,S=g.height,x=_*Math.abs(Math.cos(m))+Math.abs(S*Math.sin(m)),b=_*Math.abs(Math.sin(m))+Math.abs(S*Math.cos(m)),w=new lt(g.x,g.y,x,b);return w}}mt([e3]);mt([KG]);mt([x3,N3,Z3,qF,oH,qH,b4,iW,AW,kW,VW,XW,GU,f8,x8,B8,F8,j8,n6,d6,x6,P6,dY]);mt(EY);mt(i7);mt(pI);mt(y7);mt(tP);mt(x7);mt(F7);mt(K7);mt(NZ);mt(e9);mt(zu);mt(y9);mt(S9);mt(I9);mt(z9);mt(U9);mt(K9);mt(oX);mt(CX);mt(oR);mt(sR);mt(YX);mt(hR);mt(cR);mt(qX);mt(t$);mt(c$);mt(g$);mt(W$);mt(gG);mt(uq);mt(fq);mt(KF);export{$r as Axis,Nt as ChartView,xt as ComponentModel,Wt as ComponentView,Ue as List,wt as Model,TV as PRIORITY,Bt as SeriesModel,gq as color,xq as connect,Lq as dataTool,_q as dependencies,bq as disConnect,IV as disconnect,wq as dispose,Tt as env,Vq as extendChartView,Nq as extendComponentModel,Bq as extendComponentView,zq as extendSeriesModel,Eq as format,Cq as getCoordinateSystemDimensions,mL as getInstanceByDom,Tq as getInstanceById,Dq as getMap,kq as graphic,Iq as helper,Sq as init,tL as innerDrawElementOnCanvas,dq as matrix,Pq as number,H5 as parseGeoJSON,H5 as parseGeoJson,Ta as registerAction,kV as registerCoordinateSystem,Aq as registerCustomSeries,EV as registerLayout,bL as registerLoading,ZM as registerLocale,OV as registerMap,PV as registerPostInit,RV as registerPostUpdate,SL as registerPreprocessor,xL as registerProcessor,_L as registerTheme,NV as registerTransform,s0 as registerUpdateLifecycle,eo as registerVisual,Mq as setCanvasCreator,LR as setPlatformAPI,e0 as throttle,Rq as time,mt as use,Oq as util,pq as vector,mq as version,cq as zrUtil,yq as zrender};
