// Force strict mode and setup for ESM
"use strict";
import {
  init_esbuild_shims
} from "./chunk-5O2XNYP6.js";
import "./chunk-J2S4EL5Y.js";

// packages/cli/src/i18n/locales/zh.js
init_esbuild_shims();
var zh_default = {
  "Cannot disable an extension-provided MCP server here.": "\u65E0\u6CD5\u5728\u6B64\u5904\u7981\u7528\u6269\u5C55\u63D0\u4F9B\u7684 MCP \u670D\u52A1\u5668\u3002",
  'Cleared authentication for "{{name}}".': '\u5DF2\u6E05\u7A7A "{{name}}" \u7684\u8BA4\u8BC1\u4FE1\u606F\u3002',
  'MCP "{{name}}" disabled for all projects.': 'MCP "{{name}}" \u5DF2\u5728\u6240\u6709\u9879\u76EE\u4E2D\u7981\u7528\u3002',
  'Enable extension "{{name}}" to manage this MCP server.': '\u542F\u7528\u6269\u5C55 "{{name}}" \u540E\u624D\u80FD\u7BA1\u7406\u6B64 MCP \u670D\u52A1\u5668\u3002',
  "Extension-provided MCP servers cannot be favorited.": "\u6269\u5C55\u63D0\u4F9B\u7684 MCP \u670D\u52A1\u5668\u65E0\u6CD5\u5355\u72EC\u6536\u85CF\u3002",
  "User level": "\u7528\u6237\u7EA7",
  "Project level": "\u9879\u76EE\u7EA7",
  "Clipboard image paste is unavailable because the native clipboard module could not be loaded. Reinstall Qwen Code or use the npm installation method.": "\u526A\u8D34\u677F\u56FE\u7247\u7C98\u8D34\u4E0D\u53EF\u7528\uFF0C\u56E0\u4E3A\u539F\u751F\u526A\u8D34\u677F\u6A21\u5757\u52A0\u8F7D\u5931\u8D25\u3002\u8BF7\u91CD\u65B0\u5B89\u88C5 Qwen Code\uFF0C\u6216\u6539\u7528 npm \u5B89\u88C5\u65B9\u5F0F\u3002",
  // ==========================================================================
  // Extensions manager dialog (Installed / Discover / Sources tabs)
  // ==========================================================================
  " \xB7 {{marketplace}} (Tab to clear)": " \xB7 {{marketplace}}\uFF08Tab \u6E05\u9664\uFF09",
  '"{{name}}" {{state}}.': '"{{name}}" {{state}}\u3002',
  "(Tab / \u2190\u2192 to switch)": "(Tab / \u2190\u2192 \u5207\u6362)",
  "+ Add new marketplace": "+ \u6DFB\u52A0\u65B0\u5E02\u573A\u6E90",
  "+ Install a new extension": "+ \u5B89\u88C5\u4E00\u4E2A\u65B0\u6269\u5C55",
  Actions: "\u64CD\u4F5C",
  "Add Marketplace": "\u6DFB\u52A0\u5E02\u573A\u6E90",
  "Add a marketplace in the Sources tab to discover extensions.": "\u5728\u201C\u6765\u6E90\u201D\u6807\u7B7E\u9875\u4E2D\u6DFB\u52A0\u5E02\u573A\u6E90\u4EE5\u53D1\u73B0\u6269\u5C55\u3002",
  "Add new": "\u65B0\u589E",
  "Add to Favorites": "\u6DFB\u52A0\u5230\u6536\u85CF",
  'Added "{{name}}" to favorites.': '\u5DF2\u5C06 "{{name}}" \u6DFB\u52A0\u5230\u6536\u85CF\u3002',
  'Added marketplace "{{name}}".': '\u5DF2\u6DFB\u52A0\u5E02\u573A\u6E90 "{{name}}"\u3002',
  "Adding...": "\u6DFB\u52A0\u4E2D...",
  "Back to extension list": "\u8FD4\u56DE\u6269\u5C55\u5217\u8868",
  "Browse extensions ({{count}})": "\u6D4F\u89C8\u6269\u5C55\uFF08{{count}}\uFF09",
  "By: {{a}}": "\u4F5C\u8005\uFF1A{{a}}",
  "Change scope": "\u66F4\u6539\u4F5C\u7528\u57DF",
  'Change scope for "{{name}}":': '\u66F4\u6539 "{{name}}" \u7684\u4F5C\u7528\u57DF\uFF1A',
  "Changing scope...": "\u6B63\u5728\u66F4\u6539\u4F5C\u7528\u57DF...",
  'Uninstalling "{{name}}"...': '\u6B63\u5728\u5378\u8F7D "{{name}}"...',
  'Update available for "{{name}}".': '"{{name}}" \u6709\u53EF\u7528\u66F4\u65B0\u3002',
  '"{{name}}" is already up to date.': '"{{name}}" \u5DF2\u662F\u6700\u65B0\u3002',
  'Checking "{{name}}" for updates...': '\u6B63\u5728\u68C0\u67E5 "{{name}}" \u7684\u66F4\u65B0...',
  '"{{name}}" does not support update checks.': '"{{name}}" \u4E0D\u652F\u6301\u68C0\u67E5\u66F4\u65B0\u3002',
  '"{{name}}" cannot be update-checked (Claude marketplace plugins update by reinstalling).': '"{{name}}" \u65E0\u6CD5\u68C0\u67E5\u66F4\u65B0\uFF08Claude \u5E02\u573A\u6E90\u63D2\u4EF6\u9700\u5378\u8F7D\u540E\u91CD\u88C5\u6765\u66F4\u65B0\uFF09\u3002',
  'Failed to check "{{name}}" for updates.': '\u68C0\u67E5 "{{name}}" \u7684\u66F4\u65B0\u5931\u8D25\u3002',
  "Claude plugin marketplace": "Claude \u63D2\u4EF6\u5E02\u573A",
  Commands: "\u547D\u4EE4",
  "Components:": "\u7EC4\u4EF6\uFF1A",
  "Could not load this marketplace.": "\u65E0\u6CD5\u52A0\u8F7D\u8BE5\u5E02\u573A\u6E90\u3002",
  "Current: {{scope}}": "\u5F53\u524D\uFF1A{{scope}}",
  Disabled: "\u5DF2\u7981\u7528",
  Discover: "\u53D1\u73B0",
  'Disabling "{{name}}"...': '\u6B63\u5728\u7981\u7528 "{{name}}"...',
  'Disabling MCP "{{name}}"...': '\u6B63\u5728\u7981\u7528 MCP "{{name}}"...',
  "Discover extensions": "\u53D1\u73B0\u6269\u5C55",
  "Discovering extensions...": "\u6B63\u5728\u53D1\u73B0\u6269\u5C55...",
  'Enabling "{{name}}"...': '\u6B63\u5728\u542F\u7528 "{{name}}"...',
  'Enabling MCP "{{name}}"...': '\u6B63\u5728\u542F\u7528 MCP "{{name}}"...',
  "Enter extension source:": "\u8F93\u5165\u6269\u5C55\u6765\u6E90\uFF1A",
  "Enter marketplace source (Claude format):": "\u8F93\u5165\u5E02\u573A\u6E90\u5730\u5740\uFF08Claude \u683C\u5F0F\uFF09\uFF1A",
  "Examples:": "\u793A\u4F8B\uFF1A",
  "Extension details": "\u6269\u5C55\u8BE6\u60C5",
  "Extension v{{version}}": "\u6269\u5C55 v{{version}}",
  "Extensions are not available in this environment.": "\u5F53\u524D\u73AF\u5883\u4E2D\u6269\u5C55\u4E0D\u53EF\u7528\u3002",
  "Failed to open {{url}}": "\u6253\u5F00 {{url}} \u5931\u8D25",
  Favorites: "\u6536\u85CF",
  "Global (User Scope)": "\u5168\u5C40\uFF08\u7528\u6237\u4F5C\u7528\u57DF\uFF09",
  "Install Extension": "\u5B89\u88C5\u6269\u5C55",
  "Install for the current workspace (project scope)": "\u4E3A\u5F53\u524D\u5DE5\u4F5C\u533A\u5B89\u88C5\uFF08\u9879\u76EE\u4F5C\u7528\u57DF\uFF09",
  "Install for you (user scope)": "\u5168\u5C40\u5B89\u88C5\uFF08\u7528\u6237\u4F5C\u7528\u57DF\uFF09",
  "Install {{count}} extension(s) to which scope?": "\u5C06 {{count}} \u4E2A\u6269\u5C55\u5B89\u88C5\u5230\u54EA\u4E2A\u4F5C\u7528\u57DF\uFF1F",
  Installed: "\u5DF2\u5B89\u88C5",
  'Installed extension "{{name}}".': '\u5DF2\u5B89\u88C5\u6269\u5C55 "{{name}}"\u3002',
  "Installed extensions ({{count}}):": "\u5DF2\u5B89\u88C5\u7684\u6269\u5C55\uFF08{{count}}\uFF09\uFF1A",
  "Installed {{count}} extension(s).": "\u5DF2\u5B89\u88C5 {{count}} \u4E2A\u6269\u5C55\u3002",
  "{{name}}: installed, but the scope rollback failed \u2014 it may be disabled at all scopes; re-enable it from the Installed tab.": "{{name}}\uFF1A\u5DF2\u5B89\u88C5,\u4F46\u4F5C\u7528\u57DF\u56DE\u6EDA\u5931\u8D25 \u2014\u2014 \u8BE5\u6269\u5C55\u53EF\u80FD\u5728\u6240\u6709\u4F5C\u7528\u57DF\u5747\u88AB\u7981\u7528;\u8BF7\u5728\u201C\u5DF2\u5B89\u88C5\u201D\u9875\u91CD\u65B0\u542F\u7528\u3002",
  'Could not change scope, and the rollback also failed \u2014 "{{name}}" may be disabled at all scopes. Re-enable it from the Installed tab. ({{error}})': "\u65E0\u6CD5\u66F4\u6539\u4F5C\u7528\u57DF,\u4E14\u56DE\u6EDA\u4E5F\u5931\u8D25 \u2014\u2014\u201C{{name}}\u201D\u53EF\u80FD\u5728\u6240\u6709\u4F5C\u7528\u57DF\u5747\u88AB\u7981\u7528\u3002\u8BF7\u5728\u201C\u5DF2\u5B89\u88C5\u201D\u9875\u91CD\u65B0\u542F\u7528\u3002({{error}})",
  "Installed {{ok}}, failed {{fail}}: {{detail}}": "\u6210\u529F {{ok}} \u4E2A\uFF0C\u5931\u8D25 {{fail}} \u4E2A\uFF1A{{detail}}",
  "Installing...": "\u5B89\u88C5\u4E2D...",
  "Last updated: {{date}}": "\u6700\u8FD1\u66F4\u65B0\uFF1A{{date}}",
  MCP: "MCP",
  'MCP "{{name}}" {{state}}.': 'MCP "{{name}}" {{state}}\u3002',
  "MCP servers": "MCP \u670D\u52A1\u5668",
  "Mark for Update": "\u6807\u8BB0\u4E3A\u5F85\u66F4\u65B0",
  Marketplaces: "\u5E02\u573A\u6E90",
  "No extensions discovered.": "\u672A\u53D1\u73B0\u4EFB\u4F55\u6269\u5C55\u3002",
  "No extensions match your search.": "\u6CA1\u6709\u4E0E\u641C\u7D22\u5339\u914D\u7684\u6269\u5C55\u3002",
  "No extensions or marketplaces added yet.": "\u5C1A\u672A\u6DFB\u52A0\u4EFB\u4F55\u6269\u5C55\u6216\u5E02\u573A\u6E90\u3002",
  "No homepage available.": "\u6CA1\u6709\u53EF\u7528\u7684\u4E3B\u9875\u3002",
  "No installable extensions selected.": "\u672A\u9009\u62E9\u53EF\u5B89\u88C5\u7684\u6269\u5C55\u3002",
  "No plugins or MCP servers installed.": "\u5C1A\u672A\u5B89\u88C5\u4EFB\u4F55\u63D2\u4EF6\u6216 MCP \u670D\u52A1\u5668\u3002",
  None: "\u65E0",
  "Note: Uninstall permanently removes this extension.": "\u6CE8\u610F\uFF1A\u5378\u8F7D\u5C06\u6C38\u4E45\u79FB\u9664\u6B64\u6269\u5C55\u3002",
  "Open homepage": "\u6253\u5F00\u4E3B\u9875",
  "Project (Workspace)": "\u9879\u76EE\uFF08\u5DE5\u4F5C\u533A\uFF09",
  "Refreshed {{count}} extension(s).": "\u5DF2\u5237\u65B0 {{count}} \u4E2A\u6269\u5C55\u3002",
  "Remove from Favorites": "\u4ECE\u6536\u85CF\u4E2D\u79FB\u9664",
  "Remove marketplace": "\u79FB\u9664\u5E02\u573A\u6E90",
  'Remove marketplace "{{name}}"?': '\u79FB\u9664\u5E02\u573A\u6E90 "{{name}}"\uFF1F',
  'Removed "{{name}}" from favorites.': '\u5DF2\u5C06 "{{name}}" \u4ECE\u6536\u85CF\u4E2D\u79FB\u9664\u3002',
  'Removed marketplace "{{name}}".': '\u5DF2\u79FB\u9664\u5E02\u573A\u6E90 "{{name}}"\u3002',
  "Scope:": "\u4F5C\u7528\u57DF\uFF1A",
  'Set "{{name}}" scope to {{scope}}.': '\u5DF2\u5C06 "{{name}}" \u7684\u4F5C\u7528\u57DF\u8BBE\u4E3A {{scope}}\u3002',
  Sources: "\u6765\u6E90",
  "Type to search \xB7 Space to toggle \xB7 Enter to view \xB7 Ctrl+R refresh \xB7 Esc to go back": "\u8F93\u5165\u4EE5\u641C\u7D22 \xB7 Space \u5207\u6362 \xB7 Enter \u67E5\u770B \xB7 Ctrl+R \u5237\u65B0 \xB7 Esc \u8FD4\u56DE",
  Uninstall: "\u5378\u8F7D",
  'Uninstalled "{{name}}".': '\u5DF2\u5378\u8F7D "{{name}}"\u3002',
  "Update Now": "\u7ACB\u5373\u66F4\u65B0",
  "Update marketplace": "\u66F4\u65B0\u5E02\u573A\u6E90",
  "Update marketplace (last updated {{date}})": "\u66F4\u65B0\u5E02\u573A\u6E90\uFF08\u6700\u8FD1\u66F4\u65B0 {{date}}\uFF09",
  'Could not update marketplace "{{name}}".': '\u65E0\u6CD5\u66F4\u65B0\u5E02\u573A\u6E90 "{{name}}"\u3002',
  'Updated "{{name}}".': '\u5DF2\u66F4\u65B0 "{{name}}"\u3002',
  'Updated marketplace "{{name}}".': '\u5DF2\u66F4\u65B0\u5E02\u573A\u6E90 "{{name}}"\u3002',
  "Use the Discover tab to find and install plugins.": "\u4F7F\u7528\u201C\u53D1\u73B0\u201D\u6807\u7B7E\u9875\u67E5\u627E\u5E76\u5B89\u88C5\u6269\u5C55\u3002",
  "Version: {{v}}": "\u7248\u672C\uFF1A{{v}}",
  "Will install:": "\u5C06\u5B89\u88C5\uFF1A",
  "Would open: {{url}}": "\u5C06\u6253\u5F00\uFF1A{{url}}",
  "Y/Enter to confirm \xB7 N/Esc to cancel": "Y/Enter \u786E\u8BA4 \xB7 N/Esc \u53D6\u6D88",
  "Press R to retry \xB7 Esc to go back": "\u6309 R \u91CD\u8BD5 \xB7 Esc \u8FD4\u56DE",
  "Enter to select \xB7 R refresh \xB7 Esc to go back": "Enter \u9009\u62E9 \xB7 R \u5237\u65B0 \xB7 Esc \u8FD4\u56DE",
  "from {{marketplace}}": "\u6765\u81EA {{marketplace}}",
  installed: "\u5DF2\u5B89\u88C5",
  "{{count}} Agents": "{{count}} \u4E2A\u667A\u80FD\u4F53",
  "{{count}} Commands": "{{count}} \u4E2A\u547D\u4EE4",
  "{{count}} MCP": "{{count}} \u4E2A MCP",
  "{{count}} Skills": "{{count}} \u4E2A\u6280\u80FD",
  "{{count}} available extensions": "{{count}} \u4E2A\u53EF\u7528\u6269\u5C55",
  "\u2191 more above": "\u2191 \u4E0A\u65B9\u66F4\u591A",
  "\u2191\u2193 navigate \xB7 Enter open \xB7 d remove marketplace \xB7 Esc close": "\u2191\u2193 \u5BFC\u822A \xB7 Enter \u6253\u5F00 \xB7 d \u79FB\u9664\u5E02\u573A\u6E90 \xB7 Esc \u5173\u95ED",
  "\u2191\u2193 navigate \xB7 Enter select \xB7 Esc close": "\u2191\u2193 \u5BFC\u822A \xB7 Enter \u9009\u62E9 \xB7 Esc \u5173\u95ED",
  "\u2191\u2193 navigate \xB7 Enter select \xB7 d remove marketplace \xB7 Esc close": "\u2191\u2193 \u5BFC\u822A \xB7 Enter \u9009\u62E9 \xB7 d \u79FB\u9664\u5E02\u573A\u6E90 \xB7 Esc \u5173\u95ED",
  "\u2191\u2193 navigate \xB7 Space enable/disable \xB7 f favorite \xB7 Enter details \xB7 Esc close": "\u2191\u2193 \u5BFC\u822A \xB7 Space \u542F\u7528/\u7981\u7528 \xB7 f \u6536\u85CF \xB7 Enter \u67E5\u770B\u8BE6\u60C5 \xB7 Esc \u5173\u95ED",
  "\u2193 more below": "\u2193 \u4E0B\u65B9\u66F4\u591A",
  "\u26A0 Make sure you trust an extension before installing, updating, or using it. We cannot verify what MCP servers, files, or other software an extension includes, or that it works as intended. See the extension homepage for more information.": "\u26A0 \u5728\u5B89\u88C5\u3001\u66F4\u65B0\u6216\u4F7F\u7528\u6269\u5C55\u524D\uFF0C\u8BF7\u786E\u4FDD\u4F60\u4FE1\u4EFB\u5B83\u3002\u6211\u4EEC\u65E0\u6CD5\u9A8C\u8BC1\u6269\u5C55\u5305\u542B\u54EA\u4E9B MCP \u670D\u52A1\u5668\u3001\u6587\u4EF6\u6216\u5176\u4ED6\u8F6F\u4EF6\uFF0C\u4E5F\u65E0\u6CD5\u4FDD\u8BC1\u5176\u6309\u9884\u671F\u5DE5\u4F5C\u3002\u66F4\u591A\u4FE1\u606F\u8BF7\u67E5\u770B\u6269\u5C55\u4E3B\u9875\u3002",
  // ============================================================================
  // Tool display names (chat-stream badge labels)
  // ----------------------------------------------------------------------------
  // Keyed by `toolDisplayName.<English display name>` (from core
  // `ToolDisplayNames`). The namespace prevents collisions with same-spelled
  // generic UI strings (e.g. a standalone "Shell"). A missing key falls back to
  // the English display name via `localizeToolDisplayName`. Proper tool names /
  // acronyms are kept in English (Agent, Grep, Glob, LSP), as is a product name
  // inside an otherwise-translated label (e.g. `Notebook`).
  // ============================================================================
  "toolDisplayName.Edit": "\u7F16\u8F91",
  "toolDisplayName.WriteFile": "\u5199\u5165\u6587\u4EF6",
  "toolDisplayName.ReadFile": "\u8BFB\u53D6\u6587\u4EF6",
  "toolDisplayName.ZoomImage": "\u7F29\u653E\u56FE\u50CF",
  "toolDisplayName.Grep": "Grep",
  "toolDisplayName.Glob": "Glob",
  "toolDisplayName.Shell": "\u8FD0\u884C\u547D\u4EE4",
  "toolDisplayName.Shell Command": "Shell \u547D\u4EE4",
  "toolDisplayName.TodoList": "\u4EFB\u52A1\u6E05\u5355",
  "toolDisplayName.Goal": "\u76EE\u6807",
  "toolDisplayName.UpdateGoal": "\u66F4\u65B0\u76EE\u6807",
  "toolDisplayName.SaveMemory": "\u4FDD\u5B58\u8BB0\u5FC6",
  "toolDisplayName.Agent": "Agent",
  "toolDisplayName.Artifact": "\u5236\u54C1",
  "toolDisplayName.RecordArtifact": "\u8BB0\u5F55\u5236\u54C1",
  "toolDisplayName.DisplayImage": "\u663E\u793A\u56FE\u7247",
  "toolDisplayName.Skill": "\u6280\u80FD",
  "toolDisplayName.EnterPlanMode": "\u8FDB\u5165\u8BA1\u5212\u6A21\u5F0F",
  "toolDisplayName.ExitPlanMode": "\u9000\u51FA\u8BA1\u5212\u6A21\u5F0F",
  "toolDisplayName.WebFetch": "\u7F51\u7EDC\u6293\u53D6",
  "toolDisplayName.WebSearch": "\u7F51\u7EDC\u641C\u7D22",
  "toolDisplayName.ListFiles": "\u5217\u51FA\u6587\u4EF6",
  "toolDisplayName.Lsp": "LSP",
  "toolDisplayName.AskUserQuestion": "\u8BE2\u95EE\u7528\u6237",
  "toolDisplayName.CronCreate": "\u521B\u5EFA\u5B9A\u65F6\u4EFB\u52A1",
  "toolDisplayName.CronList": "\u5B9A\u65F6\u4EFB\u52A1\u5217\u8868",
  "toolDisplayName.CronDelete": "\u5220\u9664\u5B9A\u65F6\u4EFB\u52A1",
  "toolDisplayName.LoopWakeup": "\u5FAA\u73AF\u5524\u9192",
  "toolDisplayName.CreateSubSession": "\u521B\u5EFA\u5B50\u4F1A\u8BDD",
  "toolDisplayName.ListAgents": "\u5217\u51FA Agent",
  "toolDisplayName.TaskCreate": "\u521B\u5EFA\u4EFB\u52A1",
  "toolDisplayName.TaskUpdate": "\u66F4\u65B0\u4EFB\u52A1",
  "toolDisplayName.TaskList": "\u4EFB\u52A1\u5217\u8868",
  "toolDisplayName.TaskStop": "\u505C\u6B62\u4EFB\u52A1",
  "toolDisplayName.TeamCreate": "\u521B\u5EFA\u56E2\u961F",
  "toolDisplayName.TeamDelete": "\u5220\u9664\u56E2\u961F",
  "toolDisplayName.TeamPlanApproval": "\u56E2\u961F\u8BA1\u5212\u5BA1\u6279",
  "toolDisplayName.SendMessage": "\u53D1\u9001\u6D88\u606F",
  "toolDisplayName.StructuredOutput": "\u7ED3\u6784\u5316\u8F93\u51FA",
  "toolDisplayName.Monitor": "\u76D1\u63A7",
  "toolDisplayName.NotebookEdit": "\u7F16\u8F91 Notebook",
  "toolDisplayName.ToolSearch": "\u5DE5\u5177\u641C\u7D22",
  "toolDisplayName.EnterWorktree": "\u8FDB\u5165 Worktree",
  "toolDisplayName.ExitWorktree": "\u9000\u51FA Worktree",
  "toolDisplayName.Workflow": "\u5DE5\u4F5C\u6D41",
  "toolDisplayName.ReadMcpResource": "\u8BFB\u53D6 MCP \u8D44\u6E90",
  "toolDisplayName.ImageGen": "\u56FE\u50CF\u751F\u6210",
  // ============================================================================
  // Help / UI Components
  // ============================================================================
  // Attachment hints
  "\u2191 to manage attachments": "\u2191 \u7BA1\u7406\u9644\u4EF6",
  "\u2190 \u2192 select, Delete to remove, \u2193 to exit": "\u2190 \u2192 \u9009\u62E9\uFF0CDelete \u5220\u9664\uFF0C\u2193 \u9000\u51FA",
  "Attachments: ": "\u9644\u4EF6\uFF1A",
  "Basics:": "\u57FA\u7840\u529F\u80FD\uFF1A",
  "Add context": "\u6DFB\u52A0\u4E0A\u4E0B\u6587",
  "Use {{symbol}} to specify files for context (e.g., {{example}}) to target specific files or folders.": "\u4F7F\u7528 {{symbol}} \u6307\u5B9A\u6587\u4EF6\u4F5C\u4E3A\u4E0A\u4E0B\u6587\uFF08\u4F8B\u5982\uFF0C{{example}}\uFF09\uFF0C\u7528\u4E8E\u5B9A\u4F4D\u7279\u5B9A\u6587\u4EF6\u6216\u6587\u4EF6\u5939",
  "@": "@",
  "@src/myFile.ts": "@src/myFile.ts",
  "Shell mode": "Shell \u6A21\u5F0F",
  "YOLO mode": "YOLO \u6A21\u5F0F",
  "Auto mode": "\u81EA\u52A8\u6A21\u5F0F",
  "auto_mode.entry_notice": "\u5DF2\u542F\u7528\u81EA\u52A8\u6A21\u5F0F\u3002\n   LLM \u5206\u7C7B\u5668\u4F1A\u8BC4\u4F30\u6BCF\u6B21\u5DE5\u5177\u8C03\u7528 \u2014 \u5B89\u5168\u64CD\u4F5C\u5C06\u81EA\u52A8\u6279\u51C6\uFF0C\n   \u6709\u98CE\u9669\u7684\u64CD\u4F5C\u5C06\u88AB\u963B\u6B62\u3002\u9000\u51FA\uFF1AShift+Tab \u6216 /approval-mode default\u3002",
  "plan mode": "\u89C4\u5212\u6A21\u5F0F",
  "auto-accept edits": "\u81EA\u52A8\u63A5\u53D7\u7F16\u8F91",
  "Accepting edits": "\u63A5\u53D7\u7F16\u8F91",
  "(shift + tab to cycle)": "(Shift + Tab \u5207\u6362)",
  "(tab to cycle)": "(\u6309 Tab \u5207\u6362)",
  "Execute shell commands via {{symbol}} (e.g., {{example1}}) or use natural language (e.g., {{example2}}).": "\u901A\u8FC7 {{symbol}} \u6267\u884C shell \u547D\u4EE4\uFF08\u4F8B\u5982\uFF0C{{example1}}\uFF09\u6216\u4F7F\u7528\u81EA\u7136\u8BED\u8A00\uFF08\u4F8B\u5982\uFF0C{{example2}}\uFF09",
  "!": "!",
  "!npm run start": "!npm run start",
  "Commands:": "\u547D\u4EE4\uFF1A",
  "shell command": "shell \u547D\u4EE4",
  "Model Context Protocol command (from external servers)": "Model Context Protocol \u547D\u4EE4\uFF08\u6765\u81EA\u5916\u90E8\u670D\u52A1\u5668\uFF09",
  "Keyboard Shortcuts:": "\u952E\u76D8\u5FEB\u6377\u952E\uFF1A",
  "Toggle this help display": "\u5207\u6362\u6B64\u5E2E\u52A9\u663E\u793A",
  "Toggle shell mode": "\u5207\u6362\u547D\u4EE4\u884C\u6A21\u5F0F",
  "Open command menu": "\u6253\u5F00\u547D\u4EE4\u83DC\u5355",
  "Add file context": "\u6DFB\u52A0\u6587\u4EF6\u4E0A\u4E0B\u6587",
  "Accept suggestion / Autocomplete": "\u63A5\u53D7\u5EFA\u8BAE / \u81EA\u52A8\u8865\u5168",
  "Reverse search history": "\u53CD\u5411\u641C\u7D22\u5386\u53F2",
  "Press ? again to close": "\u518D\u6B21\u6309 ? \u5173\u95ED",
  // Keyboard shortcuts panel descriptions
  "for shell mode": "\u547D\u4EE4\u884C\u6A21\u5F0F",
  "for commands": "\u547D\u4EE4\u83DC\u5355",
  "for file paths": "\u6587\u4EF6\u8DEF\u5F84",
  "to clear input": "\u6E05\u7A7A\u8F93\u5165",
  "to cycle approvals": "\u5207\u6362\u5BA1\u6279\u6A21\u5F0F",
  "to quit": "\u9000\u51FA",
  "for newline": "\u6362\u884C",
  "to clear screen": "\u6E05\u5C4F",
  "to search history": "\u641C\u7D22\u5386\u53F2",
  "to paste images": "\u7C98\u8D34\u56FE\u7247",
  "for external editor": "\u5916\u90E8\u7F16\u8F91\u5668",
  "to expand details": "\u5C55\u5F00\u8BE6\u60C5",
  "Jump through words in the input": "\u5728\u8F93\u5165\u4E2D\u6309\u5355\u8BCD\u8DF3\u8F6C",
  "Close dialogs, cancel requests, or quit application": "\u5173\u95ED\u5BF9\u8BDD\u6846\u3001\u53D6\u6D88\u8BF7\u6C42\u6216\u9000\u51FA\u5E94\u7528\u7A0B\u5E8F",
  "New line": "\u6362\u884C",
  "New line (Alt+Enter works for certain linux distros)": "\u6362\u884C\uFF08\u67D0\u4E9B Linux \u53D1\u884C\u7248\u652F\u6301 Alt+Enter\uFF09",
  "Clear the screen": "\u6E05\u5C4F",
  "Open input in external editor": "\u5728\u5916\u90E8\u7F16\u8F91\u5668\u4E2D\u6253\u5F00\u8F93\u5165",
  "Send message": "\u53D1\u9001\u6D88\u606F",
  "Initializing...": "\u6B63\u5728\u521D\u59CB\u5316...",
  "Connecting to MCP servers... ({{connected}}/{{total}})": "\u6B63\u5728\u8FDE\u63A5\u5230 MCP servers... ({{connected}}/{{total}})",
  "Type your message or @path/to/file": "\u8F93\u5165\u60A8\u7684\u6D88\u606F\u6216 @ \u6587\u4EF6\u8DEF\u5F84",
  "? for shortcuts": "\u6309 ? \u67E5\u770B\u5FEB\u6377\u952E",
  "Pasting\u2026": "\u6B63\u5728\u7C98\u8D34\u2026",
  "Press 'i' for INSERT mode and 'Esc' for NORMAL mode.": "\u6309 'i' \u8FDB\u5165\u63D2\u5165\u6A21\u5F0F\uFF0C\u6309 'Esc' \u8FDB\u5165\u666E\u901A\u6A21\u5F0F",
  "Cancel operation / Clear input (double press)": "\u53D6\u6D88\u64CD\u4F5C / \u6E05\u7A7A\u8F93\u5165\uFF08\u53CC\u51FB\uFF09",
  "Cycle approval modes": "\u5FAA\u73AF\u5207\u6362\u5BA1\u6279\u6A21\u5F0F",
  "Cycle through your prompt history": "\u5FAA\u73AF\u6D4F\u89C8\u63D0\u793A\u5386\u53F2",
  "For a full list of shortcuts, see {{docPath}}": "\u5B8C\u6574\u5FEB\u6377\u952E\u5217\u8868\uFF0C\u8BF7\u53C2\u9605 {{docPath}}",
  "docs/keyboard-shortcuts.md": "docs/keyboard-shortcuts.md",
  "for help on Qwen Code": "\u83B7\u53D6 Qwen Code \u5E2E\u52A9",
  "show version info": "\u663E\u793A\u7248\u672C\u4FE1\u606F",
  "show paths for current session files and logs": "\u663E\u793A\u5F53\u524D\u4F1A\u8BDD\u6587\u4EF6\u548C\u65E5\u5FD7\u8DEF\u5F84",
  "submit a bug report": "\u63D0\u4EA4\u9519\u8BEF\u62A5\u544A",
  Status: "\u72B6\u6001",
  // ============================================================================
  // System Information Fields
  // ============================================================================
  "Qwen Code": "Qwen Code",
  Runtime: "\u8FD0\u884C\u73AF\u5883",
  OS: "\u64CD\u4F5C\u7CFB\u7EDF",
  Auth: "\u8BA4\u8BC1",
  Model: "\u6A21\u578B",
  "Fast Model": "\u5FEB\u901F\u6A21\u578B",
  Sandbox: "\u6C99\u7BB1",
  "Session ID": "\u4F1A\u8BDD ID",
  "Base URL": "Base URL",
  Proxy: "\u4EE3\u7406",
  "Memory Usage": "\u5185\u5B58\u4F7F\u7528",
  "IDE Client": "IDE \u5BA2\u6237\u7AEF",
  // ============================================================================
  // Commands - General
  // ============================================================================
  "Analyzes the project and creates a tailored QWEN.md file.": "\u5206\u6790\u9879\u76EE\u5E76\u521B\u5EFA\u5B9A\u5236\u7684 QWEN.md \u6587\u4EF6",
  "List available Qwen Code tools. Usage: /tools [desc]": "\u5217\u51FA\u53EF\u7528\u7684 Qwen Code \u5DE5\u5177\u3002\u7528\u6CD5\uFF1A/tools [desc]",
  "Open the skills panel (browse, search, toggle, pick).": "\u6253\u5F00\u6280\u80FD\u9762\u677F\uFF08\u6D4F\u89C8\u3001\u641C\u7D22\u3001\u542F\u505C\u3001\u9009\u62E9\uFF09\u3002",
  "Move this session to a new working directory": "\u5C06\u6B64\u4F1A\u8BDD\u79FB\u52A8\u5230\u65B0\u7684\u5DE5\u4F5C\u76EE\u5F55",
  // SkillsManagerDialog (`/skills` 弹出的面板)
  "Manage Skills": "\u7BA1\u7406\u6280\u80FD",
  "Skills configuration saved.": "\u6280\u80FD\u914D\u7F6E\u5DF2\u4FDD\u5B58\u3002",
  "Skills configuration saved, but refresh failed: {{error}}. Restart to ensure the new state is applied.": "\u6280\u80FD\u914D\u7F6E\u5DF2\u4FDD\u5B58\uFF0C\u4F46\u5237\u65B0\u5931\u8D25\uFF1A{{error}}\u3002\u8BF7\u91CD\u542F\u4EE5\u786E\u4FDD\u65B0\u72B6\u6001\u751F\u6548\u3002",
  "Workspace is untrusted; workspace settings are ignored by the merged config. Run /trust first to persist skills changes here, or edit ~/.qwen/settings.json directly to manage skills at user scope.": "\u5F53\u524D\u5DE5\u4F5C\u533A\u672A\u53D7\u4FE1\u4EFB\uFF0C\u5DE5\u4F5C\u533A\u8BBE\u7F6E\u4F1A\u88AB\u5408\u5E76\u914D\u7F6E\u5FFD\u7565\u3002\u8BF7\u5148\u6267\u884C /trust\uFF0C\u6216\u76F4\u63A5\u7F16\u8F91 ~/.qwen/settings.json \u5728\u7528\u6237\u8303\u56F4\u7BA1\u7406\u6280\u80FD\u3002",
  "SkillManager not available.": "SkillManager \u4E0D\u53EF\u7528\u3002",
  "Loading skills\u2026": "\u6B63\u5728\u52A0\u8F7D\u6280\u80FD\u2026",
  "Failed to load skills: {{error}}": "\u52A0\u8F7D\u6280\u80FD\u5931\u8D25\uFF1A{{error}}",
  "Failed to save skills configuration: {{error}}": "\u4FDD\u5B58\u6280\u80FD\u914D\u7F6E\u5931\u8D25\uFF1A{{error}}",
  "All available skills are disabled. Edit ~/.qwen/settings.json or .qwen/settings.json (skills.disabled) to re-enable.": "\u6240\u6709\u53EF\u7528\u6280\u80FD\u5747\u5DF2\u7981\u7528\u3002\u8BF7\u7F16\u8F91 ~/.qwen/settings.json \u6216 .qwen/settings.json\uFF08skills.disabled\uFF09\u4EE5\u91CD\u65B0\u542F\u7528\u3002",
  "Press esc to close.": "\u6309 Esc \u5173\u95ED\u3002",
  "{{count}} skills \xB7 ": "{{count}} \u4E2A\u6280\u80FD \xB7 ",
  "{{matched}} / {{total}} skills \xB7 ": "{{matched}} / {{total}} \u4E2A\u6280\u80FD \xB7 ",
  "Space toggle \xB7 Enter pick (fill input) \xB7 Esc save & exit \xB7 workspace scope": "\u7A7A\u683C \u542F\u505C \xB7 \u56DE\u8F66 \u9009\u4E2D(\u586B\u5165\u8F93\u5165\u6846) \xB7 Esc \u4FDD\u5B58\u5E76\u9000\u51FA \xB7 \u5DE5\u4F5C\u533A\u8303\u56F4",
  "Search:": "\u641C\u7D22\uFF1A",
  "type to filter\u2026": "\u8F93\u5165\u4EE5\u8FC7\u6EE4\u2026",
  "No skills are currently available.": "\u5F53\u524D\u6CA1\u6709\u53EF\u7528\u7684\u6280\u80FD\u3002",
  "All available skills are locked at a higher scope (see below).": "\u6240\u6709\u53EF\u7528\u6280\u80FD\u90FD\u88AB\u66F4\u9AD8\u8303\u56F4\u9501\u5B9A\uFF08\u8BE6\u89C1\u4E0B\u65B9\uFF09\u3002",
  "No skills match the search.": "\u6CA1\u6709\u5339\u914D\u641C\u7D22\u7684\u6280\u80FD\u3002",
  "Locked by higher-scope settings (cannot toggle here):": "\u88AB\u66F4\u9AD8\u8303\u56F4\u8BBE\u7F6E\u9501\u5B9A\uFF08\u6B64\u5904\u65E0\u6CD5\u5207\u6362\uFF09\uFF1A",
  "higher scope": "\u66F4\u9AD8\u8303\u56F4",
  "  {{name}} {{description}}  [locked: {{scope}}]": "  {{name}} {{description}}  [\u5DF2\u9501\u5B9A\uFF1A{{scope}}]",
  "\u2191/\u2193 navigate \xB7 backspace edits search": "\u2191/\u2193 \u5BFC\u822A \xB7 \u9000\u683C \u7F16\u8F91\u641C\u7D22",
  // Note: Project / User / Extension are already translated elsewhere in
  // this file. `Bundled` is new — only the SkillsManagerDialog uses it
  // as a level label so far.
  Bundled: "\u5185\u7F6E",
  "Available Qwen Code CLI tools:": "\u53EF\u7528\u7684 Qwen Code CLI \u5DE5\u5177\uFF1A",
  "No tools available": "\u6CA1\u6709\u53EF\u7528\u5DE5\u5177",
  "View or change the approval mode for tool usage": "\u67E5\u770B\u6216\u66F4\u6539\u5DE5\u5177\u4F7F\u7528\u7684\u5BA1\u6279\u6A21\u5F0F",
  'Invalid approval mode "{{arg}}". Valid modes: {{modes}}': '\u65E0\u6548\u7684\u5BA1\u6279\u6A21\u5F0F "{{arg}}"\u3002\u6709\u6548\u6A21\u5F0F\uFF1A{{modes}}',
  'Approval mode set to "{{mode}}"': '\u5BA1\u6279\u6A21\u5F0F\u5DF2\u8BBE\u7F6E\u4E3A "{{mode}}"',
  "View or change the language setting": "\u67E5\u770B\u6216\u66F4\u6539\u8BED\u8A00\u8BBE\u7F6E",
  "List background tasks (text dump \u2014 interactive dialog opens via the footer pill)": "\u5217\u51FA\u540E\u53F0\u4EFB\u52A1\uFF08\u6587\u672C\u5217\u8868\uFF1B\u4EA4\u4E92\u5F0F\u5BF9\u8BDD\u6846\u53EF\u901A\u8FC7\u9875\u811A\u4E2D\u7684\u201C\u540E\u53F0\u4EFB\u52A1\u201D\u5165\u53E3\u6253\u5F00\uFF09",
  "Delete a previous session": "\u5220\u9664\u5148\u524D\u7684\u4F1A\u8BDD",
  "Run installation and environment diagnostics": "\u8FD0\u884C\u5B89\u88C5\u548C\u73AF\u5883\u8BCA\u65AD",
  "Browse dynamic model catalogs and choose which models stay enabled locally": "\u6D4F\u89C8\u52A8\u6001\u6A21\u578B\u76EE\u5F55\uFF0C\u5E76\u9009\u62E9\u5728\u672C\u5730\u4FDD\u6301\u542F\u7528\u7684\u6A21\u578B",
  "Generate a one-line session recap now": "\u7ACB\u5373\u751F\u6210\u4E00\u6761\u5355\u884C\u4F1A\u8BDD\u56DE\u987E",
  "Rename the current conversation. --auto lets the fast model pick a title.": "\u91CD\u547D\u540D\u5F53\u524D\u5BF9\u8BDD\u3002--auto \u4F1A\u8BA9\u5FEB\u901F\u6A21\u578B\u81EA\u52A8\u751F\u6210\u6807\u9898\u3002",
  "Rewind conversation to a previous turn": "\u5C06\u5BF9\u8BDD\u56DE\u9000\u5230\u4E4B\u524D\u7684\u67D0\u4E00\u8F6E",
  "Rewind Conversation": "\u56DE\u9000\u5BF9\u8BDD",
  "No user turns to rewind to.": "\u6CA1\u6709\u53EF\u56DE\u9000\u7684\u7528\u6237\u5BF9\u8BDD\u8F6E\u6B21\u3002",
  "Rewind to: ": "\u56DE\u9000\u5230\uFF1A",
  "Restore code and conversation": "\u6062\u590D\u4EE3\u7801\u548C\u5BF9\u8BDD",
  "Restore conversation only": "\u4EC5\u6062\u590D\u5BF9\u8BDD",
  "Restore code only": "\u4EC5\u6062\u590D\u4EE3\u7801",
  "Never mind": "\u7B97\u4E86",
  "Computing file changes...": "\u6B63\u5728\u8BA1\u7B97\u6587\u4EF6\u53D8\u66F4...",
  "Restoring...": "\u6B63\u5728\u6062\u590D...",
  "Restored {{count}} file(s).": "\u5DF2\u6062\u590D {{count}} \u4E2A\u6587\u4EF6\u3002",
  "Failed to restore files: {{error}}": "\u6062\u590D\u6587\u4EF6\u5931\u8D25\uFF1A{{error}}",
  "Rewind failed: {{error}}": "\u56DE\u9000\u5931\u8D25\uFF1A{{error}}",
  "Cannot rewind conversation: no active model client.": "\u65E0\u6CD5\u56DE\u9000\u5BF9\u8BDD\uFF1A\u6A21\u578B\u5BA2\u6237\u7AEF\u672A\u6FC0\u6D3B\u3002",
  "Code restored, but conversation could not be rewound (no active client).": "\u4EE3\u7801\u5DF2\u6062\u590D\uFF0C\u4F46\u5BF9\u8BDD\u65E0\u6CD5\u56DE\u9000\uFF08\u6A21\u578B\u5BA2\u6237\u7AEF\u672A\u6FC0\u6D3B\uFF09\u3002",
  "Conversation rewound. Edit your prompt and press Enter to continue.": "\u5BF9\u8BDD\u5DF2\u56DE\u9000\u3002\u4FEE\u6539\u4F60\u7684\u63D0\u793A\u540E\u6309\u56DE\u8F66\u7EE7\u7EED\u3002",
  "Rewinding does not affect files edited manually or via shell commands.": "\u56DE\u9000\u4E0D\u4F1A\u5F71\u54CD\u624B\u5DE5\u7F16\u8F91\u6216\u901A\u8FC7 shell \u547D\u4EE4\u4FEE\u6539\u7684\u6587\u4EF6\u3002",
  "Cannot rewind to a turn that was compressed. Try a more recent turn.": "\u65E0\u6CD5\u56DE\u9000\u5230\u5DF2\u88AB\u538B\u7F29\u7684\u8F6E\u6B21\uFF0C\u8BF7\u5C1D\u8BD5\u66F4\u8FD1\u4E00\u4E9B\u7684\u8F6E\u6B21\u3002",
  "File restore is unavailable for this turn (no captured file changes, or this turn predates the current session).": "\u8BE5\u8F6E\u6B21\u65E0\u6CD5\u6062\u590D\u6587\u4EF6\uFF08\u6CA1\u6709\u6355\u83B7\u5230\u6587\u4EF6\u53D8\u66F4\uFF0C\u6216\u8BE5\u8F6E\u6B21\u5C5E\u4E8E\u672C\u6B21\u4F1A\u8BDD\u4E4B\u524D\uFF09\u3002",
  "(+{{insertions}} -{{deletions}} in {{count}} file)": "(+{{insertions}} -{{deletions}}\uFF0C{{count}} \u4E2A\u6587\u4EF6)",
  "(+{{insertions}} -{{deletions}} in {{count}} files)": "(+{{insertions}} -{{deletions}}\uFF0C{{count}} \u4E2A\u6587\u4EF6)",
  "Failed to restore {{count}} file(s): {{files}}": "\u6062\u590D {{count}} \u4E2A\u6587\u4EF6\u5931\u8D25\uFF1A{{files}}",
  "Cannot restore files: this turn was created before file checkpointing was enabled.": "\u65E0\u6CD5\u6062\u590D\u6587\u4EF6\uFF1A\u8BE5\u8F6E\u5BF9\u8BDD\u521B\u5EFA\u65F6\u5C1A\u672A\u542F\u7528\u6587\u4EF6\u68C0\u67E5\u70B9\u529F\u80FD\u3002",
  "No files needed to be restored.": "\u6CA1\u6709\u6587\u4EF6\u9700\u8981\u6062\u590D\u3002",
  "\u2191\u2193 to navigate \xB7 Enter to select \xB7 Esc to go back": "\u2191\u2193 \u5BFC\u822A \xB7 Enter \u9009\u62E9 \xB7 Esc \u8FD4\u56DE",
  "\u2191\u2193 to navigate \xB7 Enter to select \xB7 Esc to cancel": "\u2191\u2193 \u5BFC\u822A \xB7 Enter \u9009\u62E9 \xB7 Esc \u53D6\u6D88",
  "Enter/Y to confirm \xB7 Esc/N to go back": "Enter/Y \u786E\u8BA4 \xB7 Esc/N \u8FD4\u56DE",
  "change the theme": "\u66F4\u6539\u4E3B\u9898",
  "Select Theme": "\u9009\u62E9\u4E3B\u9898",
  Preview: "\u9884\u89C8",
  "(Use Enter to select, Tab to configure scope)": "\uFF08\u4F7F\u7528 Enter \u9009\u62E9\uFF0CTab \u914D\u7F6E\u4F5C\u7528\u57DF\uFF09",
  "(Use Enter to apply scope, Tab to go back)": "\uFF08\u4F7F\u7528 Enter \u5E94\u7528\u4F5C\u7528\u57DF\uFF0CTab \u8FD4\u56DE\uFF09",
  "Theme configuration unavailable due to NO_COLOR env variable.": "\u7531\u4E8E NO_COLOR \u73AF\u5883\u53D8\u91CF\uFF0C\u4E3B\u9898\u914D\u7F6E\u4E0D\u53EF\u7528\u3002",
  'Theme "{{themeName}}" not found.': '\u672A\u627E\u5230\u4E3B\u9898 "{{themeName}}"\u3002',
  'Theme "{{themeName}}" not found in selected scope.': '\u5728\u6240\u9009\u4F5C\u7528\u57DF\u4E2D\u672A\u627E\u5230\u4E3B\u9898 "{{themeName}}"\u3002',
  "Clear conversation history and free up context": "\u6E05\u9664\u5BF9\u8BDD\u5386\u53F2\u5E76\u91CA\u653E\u4E0A\u4E0B\u6587",
  "Compresses the context by replacing it with a summary.": "\u901A\u8FC7\u6458\u8981\u66FF\u6362\u6765\u538B\u7F29\u4E0A\u4E0B\u6587",
  "Fast context compression without AI. Strips old tool outputs and thinking parts.": "\u65E0\u9700 AI \u7684\u5FEB\u901F\u4E0A\u4E0B\u6587\u538B\u7F29\u3002\u6E05\u7406\u65E7\u5DE5\u5177\u8F93\u51FA\u5E76\u5265\u79BB\u601D\u8003\u8FC7\u7A0B\u3002",
  "open full Qwen Code documentation in your browser": "\u5728\u6D4F\u89C8\u5668\u4E2D\u6253\u5F00\u5B8C\u6574\u7684 Qwen Code \u6587\u6863",
  "Configuration not available.": "\u914D\u7F6E\u4E0D\u53EF\u7528",
  "Connect an LLM provider": "\u8FDE\u63A5 LLM \u63D0\u4F9B\u5546",
  "Copy to clipboard: reply, code (by lang), LaTeX, or Mermaid. N = Nth-latest message, index = block number": "\u590D\u5236\u5230\u526A\u8D34\u677F\uFF1AAI \u56DE\u590D\u3001\u4EE3\u7801\u5757\uFF08\u53EF\u6309\u8BED\u8A00\u7B5B\u9009\uFF09\u3001LaTeX \u6216 Mermaid\u3002N \u4E3A\u5012\u6570\u7B2C N \u6761\u6D88\u606F\uFF0Cindex \u4E3A\u4EE3\u7801\u5757\u5E8F\u53F7",
  "Show working-tree change stats versus HEAD": "\u663E\u793A\u5DE5\u4F5C\u533A\u76F8\u5BF9 HEAD \u7684\u53D8\u66F4\u7EDF\u8BA1",
  "Could not determine current working directory.": "\u65E0\u6CD5\u786E\u5B9A\u5F53\u524D\u5DE5\u4F5C\u76EE\u5F55\u3002",
  "Failed to compute git diff stats": "\u8BA1\u7B97 git diff \u7EDF\u8BA1\u5931\u8D25",
  "No diff available. Either this is not a git repository, HEAD is missing, or a merge/rebase/cherry-pick/revert is in progress.": "\u65E0\u53EF\u7528 diff\u3002\u53EF\u80FD\u4E0D\u662F Git \u4ED3\u5E93\u3001HEAD \u7F3A\u5931\uFF0C\u6216\u6B63\u5728\u6267\u884C merge/rebase/cherry-pick/revert\u3002",
  "Clean working tree \u2014 no changes against HEAD.": "\u5DE5\u4F5C\u533A\u5E72\u51C0 \u2014\u2014 \u4E0E HEAD \u65E0\u5DEE\u5F02\u3002",
  "{{count}} file changed, +{{added}} / -{{removed}}": "{{count}} \u4E2A\u6587\u4EF6\u53D8\u66F4\uFF0C+{{added}} / -{{removed}}",
  "{{count}} files changed, +{{added}} / -{{removed}}": "{{count}} \u4E2A\u6587\u4EF6\u53D8\u66F4\uFF0C+{{added}} / -{{removed}}",
  "{{count}} file changed": "{{count}} \u4E2A\u6587\u4EF6\u53D8\u66F4",
  "{{count}} files changed": "{{count}} \u4E2A\u6587\u4EF6\u53D8\u66F4",
  "\u2026and {{hidden}} more (showing first {{shown}})": "\u2026\u8FD8\u6709 {{hidden}} \u4E2A\uFF08\u4EC5\u663E\u793A\u524D {{shown}} \u4E2A\uFF09",
  "(binary)": "\uFF08\u4E8C\u8FDB\u5236\uFF09",
  "(binary, new)": "\uFF08\u4E8C\u8FDB\u5236\uFF0C\u65B0\u589E\uFF09",
  "(new)": "\uFF08\u65B0\u589E\uFF09",
  "(new, partial)": "\uFF08\u65B0\u589E\uFF0C\u90E8\u5206\u7EDF\u8BA1\uFF09",
  "(deleted)": "\uFF08\u5DF2\u5220\u9664\uFF09",
  "(binary, deleted)": "\uFF08\u4E8C\u8FDB\u5236\uFF0C\u5DF2\u5220\u9664\uFF09",
  // ============================================================================
  // Commands - Agents
  // ============================================================================
  "Manage subagents for specialized task delegation.": "\u7BA1\u7406\u7528\u4E8E\u4E13\u95E8\u4EFB\u52A1\u59D4\u6D3E\u7684\u5B50\u667A\u80FD\u4F53",
  "Manage existing subagents (view, edit, delete).": "\u7BA1\u7406\u73B0\u6709\u5B50\u667A\u80FD\u4F53\uFF08\u67E5\u770B\u3001\u7F16\u8F91\u3001\u5220\u9664\uFF09",
  "Create a new subagent with guided setup.": "\u901A\u8FC7\u5F15\u5BFC\u5F0F\u8BBE\u7F6E\u521B\u5EFA\u65B0\u7684\u5B50\u667A\u80FD\u4F53",
  "Create a reusable skill from a knowledge source (file, URL, conversation, or text).": "\u4ECE\u77E5\u8BC6\u6E90\uFF08\u6587\u4EF6\u3001URL\u3001\u5BF9\u8BDD\u6216\u6587\u672C\uFF09\u521B\u5EFA\u53EF\u590D\u7528\u7684\u6280\u80FD\u3002",
  "The current model or provider does not support native video input for /learn. Switch to a video-capable model on an OpenAI-compatible provider and try again.": "\u5F53\u524D\u6A21\u578B\u6216\u63D0\u4F9B\u5546\u4E0D\u652F\u6301 /learn \u7684\u539F\u751F\u89C6\u9891\u8F93\u5165\u3002\u8BF7\u5207\u6362\u5230 OpenAI \u517C\u5BB9\u63D0\u4F9B\u5546\u4E0A\u7684\u89C6\u9891\u6A21\u578B\u540E\u91CD\u8BD5\u3002",
  "YouTube page URLs cannot be sent as native video input. Download the video into your workspace and pass the local video file path to /learn.": "YouTube \u9875\u9762\u94FE\u63A5\u4E0D\u80FD\u4F5C\u4E3A\u539F\u751F\u89C6\u9891\u8F93\u5165\u53D1\u9001\u3002\u8BF7\u5C06\u89C6\u9891\u4E0B\u8F7D\u5230\u5DE5\u4F5C\u533A\u5185\uFF0C\u518D\u5C06\u672C\u5730\u89C6\u9891\u6587\u4EF6\u8DEF\u5F84\u4F20\u7ED9 /learn\u3002",
  "The local video could not be attached for /learn.": "\u65E0\u6CD5\u4E3A /learn \u9644\u52A0\u672C\u5730\u89C6\u9891\u3002",
  // ============================================================================
  // Agents - Management Dialog
  // ============================================================================
  Agents: "\u667A\u80FD\u4F53",
  "Choose Action": "\u9009\u62E9\u64CD\u4F5C",
  "Edit {{name}}": "\u7F16\u8F91 {{name}}",
  "Edit Tools: {{name}}": "\u7F16\u8F91\u5DE5\u5177: {{name}}",
  "Edit Color: {{name}}": "\u7F16\u8F91\u989C\u8272: {{name}}",
  "Delete {{name}}": "\u5220\u9664 {{name}}",
  "Unknown Step": "\u672A\u77E5\u6B65\u9AA4",
  "Esc to close": "\u6309 Esc \u5173\u95ED",
  Transcript: "\u5B8C\u6574\u8BB0\u5F55",
  "Read {{count}} file": "\u8BFB\u53D6\u4E86 {{count}} \u4E2A\u6587\u4EF6",
  "Read {{count}} files": "\u8BFB\u53D6\u4E86 {{count}} \u4E2A\u6587\u4EF6",
  "Reading {{count}} file": "\u6B63\u5728\u8BFB\u53D6 {{count}} \u4E2A\u6587\u4EF6",
  "Reading {{count}} files": "\u6B63\u5728\u8BFB\u53D6 {{count}} \u4E2A\u6587\u4EF6",
  "Edited {{count}} file": "\u7F16\u8F91\u4E86 {{count}} \u4E2A\u6587\u4EF6",
  "Edited {{count}} files": "\u7F16\u8F91\u4E86 {{count}} \u4E2A\u6587\u4EF6",
  "Editing {{count}} file": "\u6B63\u5728\u7F16\u8F91 {{count}} \u4E2A\u6587\u4EF6",
  "Editing {{count}} files": "\u6B63\u5728\u7F16\u8F91 {{count}} \u4E2A\u6587\u4EF6",
  "Wrote {{count}} file": "\u5199\u5165\u4E86 {{count}} \u4E2A\u6587\u4EF6",
  "Wrote {{count}} files": "\u5199\u5165\u4E86 {{count}} \u4E2A\u6587\u4EF6",
  "Writing {{count}} file": "\u6B63\u5728\u5199\u5165 {{count}} \u4E2A\u6587\u4EF6",
  "Writing {{count}} files": "\u6B63\u5728\u5199\u5165 {{count}} \u4E2A\u6587\u4EF6",
  "Searched {{count}} pattern": "\u641C\u7D22\u4E86 {{count}} \u4E2A\u6A21\u5F0F",
  "Searched {{count}} patterns": "\u641C\u7D22\u4E86 {{count}} \u4E2A\u6A21\u5F0F",
  "Searching {{count}} pattern": "\u6B63\u5728\u641C\u7D22 {{count}} \u4E2A\u6A21\u5F0F",
  "Searching {{count}} patterns": "\u6B63\u5728\u641C\u7D22 {{count}} \u4E2A\u6A21\u5F0F",
  "Listed {{count}} directory": "\u5217\u51FA\u4E86 {{count}} \u4E2A\u76EE\u5F55",
  "Listed {{count}} directories": "\u5217\u51FA\u4E86 {{count}} \u4E2A\u76EE\u5F55",
  "Listing {{count}} directory": "\u6B63\u5728\u5217\u51FA {{count}} \u4E2A\u76EE\u5F55",
  "Listing {{count}} directories": "\u6B63\u5728\u5217\u51FA {{count}} \u4E2A\u76EE\u5F55",
  "Ran {{count}} command": "\u8FD0\u884C\u4E86 {{count}} \u4E2A\u547D\u4EE4",
  "Ran {{count}} commands": "\u8FD0\u884C\u4E86 {{count}} \u4E2A\u547D\u4EE4",
  "Running {{count}} command": "\u6B63\u5728\u8FD0\u884C {{count}} \u4E2A\u547D\u4EE4",
  "Running {{count}} commands": "\u6B63\u5728\u8FD0\u884C {{count}} \u4E2A\u547D\u4EE4",
  "Ran {{count}} agent": "\u8FD0\u884C\u4E86 {{count}} \u4E2A\u667A\u80FD\u4F53",
  "Ran {{count}} agents": "\u8FD0\u884C\u4E86 {{count}} \u4E2A\u667A\u80FD\u4F53",
  "Running {{count}} agent": "\u6B63\u5728\u8FD0\u884C {{count}} \u4E2A\u667A\u80FD\u4F53",
  "Running {{count}} agents": "\u6B63\u5728\u8FD0\u884C {{count}} \u4E2A\u667A\u80FD\u4F53",
  "Used {{count}} tool": "\u4F7F\u7528\u4E86 {{count}} \u4E2A\u5DE5\u5177",
  "Used {{count}} tools": "\u4F7F\u7528\u4E86 {{count}} \u4E2A\u5DE5\u5177",
  "Using {{count}} tool": "\u6B63\u5728\u4F7F\u7528 {{count}} \u4E2A\u5DE5\u5177",
  "Using {{count}} tools": "\u6B63\u5728\u4F7F\u7528 {{count}} \u4E2A\u5DE5\u5177",
  "Enter to select, \u2191\u2193 to navigate, Esc to close": "Enter \u9009\u62E9\uFF0C\u2191\u2193 \u5BFC\u822A\uFF0CEsc \u5173\u95ED",
  "Esc to go back": "\u6309 Esc \u8FD4\u56DE",
  "Enter to confirm, Esc to cancel": "Enter \u786E\u8BA4\uFF0CEsc \u53D6\u6D88",
  "Enter to select, \u2191\u2193 to navigate, Esc to go back": "Enter \u9009\u62E9\uFF0C\u2191\u2193 \u5BFC\u822A\uFF0CEsc \u8FD4\u56DE",
  "Enter to submit, Esc to go back": "Enter \u63D0\u4EA4\uFF0CEsc \u8FD4\u56DE",
  "Invalid step: {{step}}": "\u65E0\u6548\u6B65\u9AA4: {{step}}",
  "No subagents found.": "\u672A\u627E\u5230\u5B50\u667A\u80FD\u4F53\u3002",
  "Use '/agents create' to create your first subagent.": "\u4F7F\u7528 '/agents create' \u521B\u5EFA\u60A8\u7684\u7B2C\u4E00\u4E2A\u5B50\u667A\u80FD\u4F53\u3002",
  "(built-in)": "\uFF08\u5185\u7F6E\uFF09",
  "(overridden by project level agent)": "\uFF08\u5DF2\u88AB\u9879\u76EE\u7EA7\u667A\u80FD\u4F53\u8986\u76D6\uFF09",
  "Project Level ({{path}})": "\u9879\u76EE\u7EA7 ({{path}})",
  "User Level ({{path}})": "\u7528\u6237\u7EA7 ({{path}})",
  "Built-in Agents": "\u5185\u7F6E\u667A\u80FD\u4F53",
  "Extension Agents": "\u6269\u5C55\u667A\u80FD\u4F53",
  "Using: {{count}} agents": "\u4F7F\u7528\u4E2D: {{count}} \u4E2A\u667A\u80FD\u4F53",
  "View Agent": "\u67E5\u770B\u667A\u80FD\u4F53",
  "Edit Agent": "\u7F16\u8F91\u667A\u80FD\u4F53",
  "Delete Agent": "\u5220\u9664\u667A\u80FD\u4F53",
  Back: "\u8FD4\u56DE",
  "No agent selected": "\u672A\u9009\u62E9\u667A\u80FD\u4F53",
  "File Path: ": "\u6587\u4EF6\u8DEF\u5F84: ",
  "Tools: ": "\u5DE5\u5177: ",
  "Color: ": "\u989C\u8272: ",
  "Description:": "\u63CF\u8FF0:",
  "System Prompt:": "\u7CFB\u7EDF\u63D0\u793A:",
  "Open in editor": "\u5728\u7F16\u8F91\u5668\u4E2D\u6253\u5F00",
  "Edit tools": "\u7F16\u8F91\u5DE5\u5177",
  "Edit color": "\u7F16\u8F91\u989C\u8272",
  "\u2717 Error:": "\u2717 \u9519\u8BEF:",
  'Are you sure you want to delete agent "{{name}}"?': '\u60A8\u786E\u5B9A\u8981\u5220\u9664\u667A\u80FD\u4F53 "{{name}}" \u5417\uFF1F',
  // ============================================================================
  // Agents - Creation Wizard
  // ============================================================================
  "Project Level (.qwen/agents/)": "\u9879\u76EE\u7EA7 (.qwen/agents/)",
  "User Level (~/.qwen/agents/)": "\u7528\u6237\u7EA7 (~/.qwen/agents/)",
  "\u2713 Subagent Created Successfully!": "\u2713 \u5B50\u667A\u80FD\u4F53\u521B\u5EFA\u6210\u529F\uFF01",
  'Subagent "{{name}}" has been saved to {{level}} level.': '\u5B50\u667A\u80FD\u4F53 "{{name}}" \u5DF2\u4FDD\u5B58\u5230 {{level}} \u7EA7\u522B\u3002',
  "Name: ": "\u540D\u79F0: ",
  "Location: ": "\u4F4D\u7F6E: ",
  "\u2717 Error saving subagent:": "\u2717 \u4FDD\u5B58\u5B50\u667A\u80FD\u4F53\u65F6\u51FA\u9519:",
  "Warnings:": "\u8B66\u544A:",
  'Name "{{name}}" already exists at {{level}} level - will overwrite existing subagent': '\u540D\u79F0 "{{name}}" \u5728 {{level}} \u7EA7\u522B\u5DF2\u5B58\u5728 - \u5C06\u8986\u76D6\u73B0\u6709\u5B50\u667A\u80FD\u4F53',
  'Name "{{name}}" exists at user level - project level will take precedence': '\u540D\u79F0 "{{name}}" \u5728\u7528\u6237\u7EA7\u522B\u5B58\u5728 - \u9879\u76EE\u7EA7\u522B\u5C06\u4F18\u5148',
  'Name "{{name}}" exists at project level - existing subagent will take precedence': '\u540D\u79F0 "{{name}}" \u5728\u9879\u76EE\u7EA7\u522B\u5B58\u5728 - \u73B0\u6709\u5B50\u667A\u80FD\u4F53\u5C06\u4F18\u5148',
  "Description is over {{length}} characters": "\u63CF\u8FF0\u8D85\u8FC7 {{length}} \u4E2A\u5B57\u7B26",
  "System prompt is over {{length}} characters": "\u7CFB\u7EDF\u63D0\u793A\u8D85\u8FC7 {{length}} \u4E2A\u5B57\u7B26",
  // Agents - Creation Wizard Steps
  "Step {{n}}: Choose Location": "\u6B65\u9AA4 {{n}}: \u9009\u62E9\u4F4D\u7F6E",
  "Step {{n}}: Choose Generation Method": "\u6B65\u9AA4 {{n}}: \u9009\u62E9\u751F\u6210\u65B9\u5F0F",
  "Generate with Qwen Code (Recommended)": "\u4F7F\u7528 Qwen Code \u751F\u6210\uFF08\u63A8\u8350\uFF09",
  "Manual Creation": "\u624B\u52A8\u521B\u5EFA",
  "Describe what this subagent should do and when it should be used. (Be comprehensive for best results)": "\u63CF\u8FF0\u6B64\u5B50\u667A\u80FD\u4F53\u5E94\u8BE5\u505A\u4EC0\u4E48\u4EE5\u53CA\u4F55\u65F6\u4F7F\u7528\u5B83\u3002\uFF08\u4E3A\u4E86\u83B7\u5F97\u6700\u4F73\u6548\u679C\uFF0C\u8BF7\u5168\u9762\u63CF\u8FF0\uFF09",
  "e.g., Expert code reviewer that reviews code based on best practices...": "\u4F8B\u5982\uFF1A\u4E13\u4E1A\u7684\u4EE3\u7801\u5BA1\u67E5\u5458\uFF0C\u6839\u636E\u6700\u4F73\u5B9E\u8DF5\u5BA1\u67E5\u4EE3\u7801...",
  "Generating subagent configuration...": "\u6B63\u5728\u751F\u6210\u5B50\u667A\u80FD\u4F53\u914D\u7F6E...",
  "Failed to generate subagent: {{error}}": "\u751F\u6210\u5B50\u667A\u80FD\u4F53\u5931\u8D25: {{error}}",
  "Step {{n}}: Describe Your Subagent": "\u6B65\u9AA4 {{n}}: \u63CF\u8FF0\u60A8\u7684\u5B50\u667A\u80FD\u4F53",
  "Step {{n}}: Enter Subagent Name": "\u6B65\u9AA4 {{n}}: \u8F93\u5165\u5B50\u667A\u80FD\u4F53\u540D\u79F0",
  "Step {{n}}: Enter System Prompt": "\u6B65\u9AA4 {{n}}: \u8F93\u5165\u7CFB\u7EDF\u63D0\u793A",
  "Step {{n}}: Enter Description": "\u6B65\u9AA4 {{n}}: \u8F93\u5165\u63CF\u8FF0",
  // Agents - Tool Selection
  "Step {{n}}: Select Tools": "\u6B65\u9AA4 {{n}}: \u9009\u62E9\u5DE5\u5177",
  "All Tools (Default)": "\u6240\u6709\u5DE5\u5177\uFF08\u9ED8\u8BA4\uFF09",
  "All Tools": "\u6240\u6709\u5DE5\u5177",
  "Read-only Tools": "\u53EA\u8BFB\u5DE5\u5177",
  "Read & Edit Tools": "\u8BFB\u53D6\u548C\u7F16\u8F91\u5DE5\u5177",
  "Read & Edit & Execution Tools": "\u8BFB\u53D6\u3001\u7F16\u8F91\u548C\u6267\u884C\u5DE5\u5177",
  "All tools selected, including MCP tools": "\u5DF2\u9009\u62E9\u6240\u6709\u5DE5\u5177\uFF0C\u5305\u62EC MCP tools",
  "Selected tools:": "\u5DF2\u9009\u62E9\u7684\u5DE5\u5177:",
  "Read-only tools:": "\u53EA\u8BFB\u5DE5\u5177:",
  "Edit tools:": "\u7F16\u8F91\u5DE5\u5177:",
  "Execution tools:": "\u6267\u884C\u5DE5\u5177:",
  "Step {{n}}: Choose Background Color": "\u6B65\u9AA4 {{n}}: \u9009\u62E9\u80CC\u666F\u989C\u8272",
  "Step {{n}}: Confirm and Save": "\u6B65\u9AA4 {{n}}: \u786E\u8BA4\u5E76\u4FDD\u5B58",
  // Agents - Navigation & Instructions
  "Esc to cancel": "\u6309 Esc \u53D6\u6D88",
  "Press Enter to save, e to save and edit, Esc to go back": "\u6309 Enter \u4FDD\u5B58\uFF0Ce \u4FDD\u5B58\u5E76\u7F16\u8F91\uFF0CEsc \u8FD4\u56DE",
  "Press Enter to continue, {{navigation}}Esc to {{action}}": "\u6309 Enter \u7EE7\u7EED\uFF0C{{navigation}}Esc {{action}}",
  cancel: "\u53D6\u6D88",
  "go back": "\u8FD4\u56DE",
  "\u2191\u2193 to navigate, ": "\u2191\u2193 \u5BFC\u822A\uFF0C",
  "Enter a clear, unique name for this subagent.": "\u4E3A\u6B64\u5B50\u667A\u80FD\u4F53\u8F93\u5165\u4E00\u4E2A\u6E05\u6670\u3001\u552F\u4E00\u7684\u540D\u79F0\u3002",
  "e.g., Code Reviewer": "\u4F8B\u5982\uFF1A\u4EE3\u7801\u5BA1\u67E5\u5458",
  "Name cannot be empty.": "\u540D\u79F0\u4E0D\u80FD\u4E3A\u7A7A\u3002",
  "Write the system prompt that defines this subagent's behavior. Be comprehensive for best results.": "\u7F16\u5199\u5B9A\u4E49\u6B64\u5B50\u667A\u80FD\u4F53\u884C\u4E3A\u7684\u7CFB\u7EDF\u63D0\u793A\u3002\u4E3A\u4E86\u83B7\u5F97\u6700\u4F73\u6548\u679C\uFF0C\u8BF7\u5168\u9762\u63CF\u8FF0\u3002",
  "e.g., You are an expert code reviewer...": "\u4F8B\u5982\uFF1A\u60A8\u662F\u4E00\u4F4D\u4E13\u4E1A\u7684\u4EE3\u7801\u5BA1\u67E5\u5458...",
  "System prompt cannot be empty.": "\u7CFB\u7EDF\u63D0\u793A\u4E0D\u80FD\u4E3A\u7A7A\u3002",
  "Describe when and how this subagent should be used.": "\u63CF\u8FF0\u4F55\u65F6\u4EE5\u53CA\u5982\u4F55\u4F7F\u7528\u6B64\u5B50\u667A\u80FD\u4F53\u3002",
  "e.g., Reviews code for best practices and potential bugs.": "\u4F8B\u5982\uFF1A\u5BA1\u67E5\u4EE3\u7801\u4EE5\u67E5\u627E\u6700\u4F73\u5B9E\u8DF5\u548C\u6F5C\u5728\u9519\u8BEF\u3002",
  "Description cannot be empty.": "\u63CF\u8FF0\u4E0D\u80FD\u4E3A\u7A7A\u3002",
  "Failed to launch editor: {{error}}": "\u542F\u52A8\u7F16\u8F91\u5668\u5931\u8D25: {{error}}",
  "Failed to save and edit subagent: {{error}}": "\u4FDD\u5B58\u5E76\u7F16\u8F91\u5B50\u667A\u80FD\u4F53\u5931\u8D25: {{error}}",
  // ============================================================================
  // Extensions - Management Dialog
  // ============================================================================
  "Manage Extensions": "\u7BA1\u7406\u6269\u5C55",
  "Extension Details": "\u6269\u5C55\u8BE6\u60C5",
  "View Extension": "\u67E5\u770B\u6269\u5C55",
  "Update Extension": "\u66F4\u65B0\u6269\u5C55",
  "Disable Extension": "\u7981\u7528\u6269\u5C55",
  "Enable Extension": "\u542F\u7528\u6269\u5C55",
  "Uninstall Extension": "\u5378\u8F7D\u6269\u5C55",
  "Select Scope": "\u9009\u62E9\u4F5C\u7528\u57DF",
  "User Scope": "\u7528\u6237\u4F5C\u7528\u57DF",
  "Workspace Scope": "\u5DE5\u4F5C\u533A\u4F5C\u7528\u57DF",
  "No extensions found.": "\u672A\u627E\u5230\u6269\u5C55\u3002",
  "Updating...": "\u66F4\u65B0\u4E2D...",
  Unknown: "\u672A\u77E5",
  Error: "\u9519\u8BEF",
  "Stopped because": "\u505C\u6B62\u539F\u56E0",
  "Version:": "\u7248\u672C\uFF1A",
  "Status:": "\u72B6\u6001\uFF1A",
  'Are you sure you want to uninstall extension "{{name}}"?': '\u786E\u5B9A\u8981\u5378\u8F7D\u6269\u5C55 "{{name}}" \u5417\uFF1F',
  "This action cannot be undone.": "\u6B64\u64CD\u4F5C\u65E0\u6CD5\u64A4\u9500\u3002",
  'Extension "{{name}}" updated successfully.': '\u6269\u5C55 "{{name}}" \u66F4\u65B0\u6210\u529F\u3002',
  // Extension dialog - missing keys
  "Name:": "\u540D\u79F0\uFF1A",
  "MCP Servers:": "MCP Servers\uFF1A",
  "Settings:": "\u8BBE\u7F6E\uFF1A",
  active: "\u5DF2\u542F\u7528",
  "View Details": "\u67E5\u770B\u8BE6\u60C5",
  "Update failed:": "\u66F4\u65B0\u5931\u8D25\uFF1A",
  "Updating {{name}}...": "\u6B63\u5728\u66F4\u65B0 {{name}}...",
  "Update complete!": "\u66F4\u65B0\u5B8C\u6210\uFF01",
  "User (global)": "\u7528\u6237\uFF08\u5168\u5C40\uFF09",
  "Workspace (project-specific)": "\u5DE5\u4F5C\u533A\uFF08\u9879\u76EE\u7279\u5B9A\uFF09",
  'Disable "{{name}}" - Select Scope': '\u7981\u7528 "{{name}}" - \u9009\u62E9\u4F5C\u7528\u57DF',
  'Enable "{{name}}" - Select Scope': '\u542F\u7528 "{{name}}" - \u9009\u62E9\u4F5C\u7528\u57DF',
  "No extension selected": "\u672A\u9009\u62E9\u6269\u5C55",
  "{{count}} extensions installed": "\u5DF2\u5B89\u88C5 {{count}} \u4E2A\u6269\u5C55",
  "Use '/extensions install' to install your first extension.": "\u4F7F\u7528 '/extensions install' \u5B89\u88C5\u60A8\u7684\u7B2C\u4E00\u4E2A\u6269\u5C55\u3002",
  // Update status values
  "up to date": "\u5DF2\u662F\u6700\u65B0",
  "update available": "\u6709\u53EF\u7528\u66F4\u65B0",
  "checking...": "\u68C0\u67E5\u4E2D...",
  "not updatable": "\u4E0D\u53EF\u66F4\u65B0",
  error: "\u9519\u8BEF",
  // ============================================================================
  // Commands - General (continued)
  // ============================================================================
  "Get or set any setting by dot-path key": "\u901A\u8FC7\u70B9\u53F7\u8DEF\u5F84\u952E\u67E5\u770B\u6216\u8BBE\u7F6E\u4EFB\u610F\u914D\u7F6E\u9879",
  'Invalid boolean value: "{{value}}". Use "true" or "false".': '\u65E0\u6548\u7684\u5E03\u5C14\u503C\uFF1A"{{value}}"\u3002\u8BF7\u4F7F\u7528 "true" \u6216 "false"\u3002',
  "Cannot toggle a number setting. Provide a value: key=<number>.": "\u65E0\u6CD5\u5207\u6362\u6570\u5B57\u7C7B\u578B\u7684\u8BBE\u7F6E\u3002\u8BF7\u63D0\u4F9B\u503C\uFF1Akey=<number>\u3002",
  'Invalid number value: "{{value}}".': '\u65E0\u6548\u7684\u6570\u5B57\u503C\uFF1A"{{value}}"\u3002',
  "Cannot toggle a string setting. Provide a value: key=<value>.": "\u65E0\u6CD5\u5207\u6362\u5B57\u7B26\u4E32\u7C7B\u578B\u7684\u8BBE\u7F6E\u3002\u8BF7\u63D0\u4F9B\u503C\uFF1Akey=<value>\u3002",
  "Cannot toggle an enum setting. Provide one of: {{options}}.": "\u65E0\u6CD5\u5207\u6362\u679A\u4E3E\u7C7B\u578B\u7684\u8BBE\u7F6E\u3002\u8BF7\u63D0\u4F9B\u4EE5\u4E0B\u9009\u9879\u4E4B\u4E00\uFF1A{{options}}\u3002",
  'Invalid enum value: "{{value}}". Valid values: {{options}}.': '\u65E0\u6548\u7684\u679A\u4E3E\u503C\uFF1A"{{value}}"\u3002\u6709\u6548\u503C\uFF1A{{options}}\u3002',
  'Setting "{{type}}" type cannot be set via /config. Edit settings.json directly.': '"{{type}}" \u7C7B\u578B\u7684\u8BBE\u7F6E\u65E0\u6CD5\u901A\u8FC7 /config \u4FEE\u6539\u3002\u8BF7\u76F4\u63A5\u7F16\u8F91 settings.json\u3002',
  'Unsupported setting type: "{{type}}".': '\u4E0D\u652F\u6301\u7684\u8BBE\u7F6E\u7C7B\u578B\uFF1A"{{type}}"\u3002',
  "Available settings:": "\u53EF\u7528\u8BBE\u7F6E\uFF1A",
  'Unknown setting key: "{{key}}". Did you mean "{{suggestion}}"?': '\u672A\u77E5\u7684\u8BBE\u7F6E\u952E\uFF1A"{{key}}"\u3002\u60A8\u662F\u4E0D\u662F\u60F3\u8BBE\u7F6E "{{suggestion}}"\uFF1F',
  'Unknown setting key: "{{key}}".': '\u672A\u77E5\u7684\u8BBE\u7F6E\u952E\uFF1A"{{key}}"\u3002',
  'Failed to set "{{key}}": {{error}}': '\u8BBE\u7F6E "{{key}}" \u5931\u8D25\uFF1A{{error}}',
  "Set {{key}} = {{value}}": "\u5DF2\u8BBE\u7F6E {{key}} = {{value}}",
  "(This setting requires a restart to take effect.)": "\uFF08\u6B64\u8BBE\u7F6E\u9700\u8981\u91CD\u542F\u624D\u80FD\u751F\u6548\u3002\uFF09",
  "(Security-sensitive setting \u2014 verify you are not exposing credentials.)": "\uFF08\u5B89\u5168\u654F\u611F\u8BBE\u7F6E \u2014 \u8BF7\u786E\u8BA4\u60A8\u6CA1\u6709\u6CC4\u9732\u51ED\u636E\u3002\uFF09",
  'Setting tools.approvalMode to "yolo" is blocked via /config for security reasons. Edit settings.json directly if you understand the risks.': '\u51FA\u4E8E\u5B89\u5168\u539F\u56E0\uFF0C\u7981\u6B62\u901A\u8FC7 /config \u5C06 tools.approvalMode \u8BBE\u7F6E\u4E3A "yolo"\u3002\u5982\u679C\u60A8\u4E86\u89E3\u76F8\u5173\u98CE\u9669\uFF0C\u8BF7\u76F4\u63A5\u7F16\u8F91 settings.json\u3002',
  "(empty)": "\uFF08\u7A7A\uFF09",
  "View and edit Qwen Code settings": "\u67E5\u770B\u548C\u7F16\u8F91 Qwen Code \u8BBE\u7F6E",
  Settings: "\u8BBE\u7F6E",
  "To see changes, Qwen Code must be restarted. Press r to exit and apply changes now.": "\u8981\u67E5\u770B\u66F4\u6539\uFF0C\u5FC5\u987B\u91CD\u542F Qwen Code\u3002\u6309 r \u9000\u51FA\u5E76\u7ACB\u5373\u5E94\u7528\u66F4\u6539\u3002",
  // ============================================================================
  // Settings Labels
  // ============================================================================
  "Vim Mode": "Vim \u6A21\u5F0F",
  "Attribution: commit": "\u7F72\u540D\uFF1A\u63D0\u4EA4",
  "Terminal Bell Notification": "\u7EC8\u7AEF\u54CD\u94C3\u901A\u77E5",
  "Enable Usage Statistics": "\u542F\u7528\u4F7F\u7528\u7EDF\u8BA1",
  Theme: "\u4E3B\u9898",
  "Preferred Editor": "\u9996\u9009\u7F16\u8F91\u5668",
  "Auto-connect to IDE": "\u81EA\u52A8\u8FDE\u63A5\u5230 IDE",
  "Debug Keystroke Logging": "\u8C03\u8BD5\u6309\u952E\u8BB0\u5F55",
  "Language: UI": "\u8BED\u8A00\uFF1A\u754C\u9762",
  "Language: Model": "\u8BED\u8A00\uFF1A\u6A21\u578B",
  "Output Format": "\u8F93\u51FA\u683C\u5F0F",
  "Hide Window Title": "\u9690\u85CF\u7A97\u53E3\u6807\u9898",
  "Show Status in Title": "\u5728\u6807\u9898\u4E2D\u663E\u793A\u72B6\u6001",
  "Hide Tips": "\u9690\u85CF\u63D0\u793A",
  "Show Line Numbers in Code": "\u5728\u4EE3\u7801\u4E2D\u663E\u793A\u884C\u53F7",
  "Show Citations": "\u663E\u793A\u5F15\u7528",
  "Custom Witty Phrases": "\u81EA\u5B9A\u4E49\u8BD9\u8C10\u77ED\u8BED",
  "Show Welcome Back Dialog": "\u663E\u793A\u6B22\u8FCE\u56DE\u6765\u5BF9\u8BDD\u6846",
  "Enable User Feedback": "\u542F\u7528\u7528\u6237\u53CD\u9988",
  "How is Qwen doing this session? (optional)": "Qwen \u8FD9\u6B21\u8868\u73B0\u5982\u4F55\uFF1F\uFF08\u53EF\u9009\uFF09",
  Bad: "\u4E0D\u6EE1\u610F",
  Fine: "\u8FD8\u884C",
  Good: "\u6EE1\u610F",
  Dismiss: "\u5FFD\u7565",
  "Screen Reader Mode": "\u5C4F\u5E55\u9605\u8BFB\u5668\u6A21\u5F0F",
  "Max Session Turns": "\u6700\u5927\u4F1A\u8BDD\u8F6E\u6B21",
  "Skip Next Speaker Check": "\u8DF3\u8FC7\u4E0B\u4E00\u4E2A\u8BF4\u8BDD\u8005\u68C0\u67E5",
  "Skip Loop Detection": "\u8DF3\u8FC7\u5FAA\u73AF\u68C0\u6D4B",
  "Skip Startup Context": "\u8DF3\u8FC7\u542F\u52A8\u4E0A\u4E0B\u6587",
  "Enable OpenAI Logging": "\u542F\u7528 OpenAI \u65E5\u5FD7",
  "OpenAI Logging Directory": "OpenAI \u65E5\u5FD7\u76EE\u5F55",
  Timeout: "\u8D85\u65F6",
  "Max Retries": "\u6700\u5927\u91CD\u8BD5\u6B21\u6570",
  "Load Memory From Include Directories": "\u4ECE\u5305\u542B\u76EE\u5F55\u52A0\u8F7D\u5185\u5B58",
  "Respect .gitignore": "\u9075\u5B88 .gitignore",
  "Respect .qwenignore": "\u9075\u5B88 .qwenignore",
  "Enable Recursive File Search": "\u542F\u7528\u9012\u5F52\u6587\u4EF6\u641C\u7D22",
  "Interactive Shell (PTY)": "\u4EA4\u4E92\u5F0F Shell (PTY)",
  "Show Color": "\u663E\u793A\u989C\u8272",
  "Auto Accept": "\u81EA\u52A8\u63A5\u53D7",
  "Use Ripgrep": "\u4F7F\u7528 Ripgrep",
  "Use Builtin Ripgrep": "\u4F7F\u7528\u5185\u7F6E Ripgrep",
  "Tool Output Truncation Threshold": "\u5DE5\u5177\u8F93\u51FA\u622A\u65AD\u9608\u503C",
  "Tool Output Truncation Lines": "\u5DE5\u5177\u8F93\u51FA\u622A\u65AD\u884C\u6570",
  "Folder Trust": "\u6587\u4EF6\u5939\u4FE1\u4EFB",
  "Tool Schema Compliance": "Tool Schema \u517C\u5BB9\u6027",
  // Settings enum options
  "Auto (detect from system)": "\u81EA\u52A8\uFF08\u4ECE\u7CFB\u7EDF\u68C0\u6D4B\uFF09",
  "Auto (follow user input)": "\u81EA\u52A8\uFF08\u8DDF\u968F\u7528\u6237\u8F93\u5165\uFF09",
  "Auto (detect terminal theme)": "\u81EA\u52A8\uFF08\u68C0\u6D4B\u7EC8\u7AEF\u4E3B\u9898\uFF09",
  Auto: "\u81EA\u52A8",
  Text: "\u6587\u672C",
  JSON: "JSON",
  Plan: "\u89C4\u5212",
  "Ask permissions": "\u8BF7\u6C42\u6388\u6743",
  "Auto Edit": "\u81EA\u52A8\u7F16\u8F91",
  YOLO: "YOLO",
  "toggle vim mode on/off": "\u5207\u6362 vim \u6A21\u5F0F\u5F00\u5173",
  "Show usage statistics dashboard.": "\u663E\u793A\u4F7F\u7528\u7EDF\u8BA1\u9762\u677F\u3002",
  "Show model-specific usage statistics.": "\u663E\u793A\u6A21\u578B\u76F8\u5173\u7684\u4F7F\u7528\u7EDF\u8BA1\u4FE1\u606F",
  "Show tool-specific usage statistics.": "\u663E\u793A\u5DE5\u5177\u76F8\u5173\u7684\u4F7F\u7528\u7EDF\u8BA1\u4FE1\u606F",
  "Show skill-specific usage statistics.": "\u663E\u793A\u6280\u80FD\u76F8\u5173\u7684\u4F7F\u7528\u7EDF\u8BA1\u4FE1\u606F",
  "Show daily token usage statistics.": "\u663E\u793A\u6BCF\u65E5 token \u4F7F\u7528\u7EDF\u8BA1\u4FE1\u606F",
  "Show monthly token usage statistics.": "\u663E\u793A\u6BCF\u6708 token \u4F7F\u7528\u7EDF\u8BA1\u4FE1\u606F",
  "Export token usage statistics to CSV or JSON.": "\u5C06 token \u4F7F\u7528\u7EDF\u8BA1\u4FE1\u606F\u5BFC\u51FA\u4E3A CSV \u6216 JSON",
  "No usage data.": "\u6CA1\u6709\u4F7F\u7528\u6570\u636E\u3002",
  "{{label}}: {{tokens}} tokens ({{requests}} requests)": "{{label}}\uFF1A{{tokens}} \u4E2A token\uFF08{{requests}} \u4E2A\u8BF7\u6C42\uFF09",
  "Daily token usage for {{value}}": "{{value}} \u7684\u6BCF\u65E5 token \u4F7F\u7528\u60C5\u51B5",
  "Monthly token usage for {{value}}": "{{value}} \u7684\u6BCF\u6708 token \u4F7F\u7528\u60C5\u51B5",
  "Total: {{tokens}} tokens": "\u603B\u8BA1\uFF1A{{tokens}} \u4E2A token",
  "Requests: {{requests}}": "\u8BF7\u6C42\u6570\uFF1A{{requests}}",
  "Breakdown:": "\u660E\u7EC6\uFF1A",
  "Input: {{tokens}}": "\u8F93\u5165\uFF1A{{tokens}}",
  "Output: {{tokens}}": "\u8F93\u51FA\uFF1A{{tokens}}",
  "Cached (included in Input): {{tokens}}": "\u7F13\u5B58\uFF08\u5DF2\u5305\u542B\u5728\u8F93\u5165\u4E2D\uFF09\uFF1A{{tokens}}",
  "Thoughts: {{tokens}}": "\u601D\u8003\uFF1A{{tokens}}",
  "By model:": "\u6309\u6A21\u578B\uFF1A",
  "By auth type:": "\u6309\u8BA4\u8BC1\u7C7B\u578B\uFF1A",
  "By model/auth type:": "\u6309\u6A21\u578B/\u8BA4\u8BC1\u7C7B\u578B\uFF1A",
  "By source:": "\u6309\u6765\u6E90\uFF1A",
  "Failed to load token usage stats: {{error}}": "\u52A0\u8F7D token \u4F7F\u7528\u7EDF\u8BA1\u4FE1\u606F\u5931\u8D25\uFF1A{{error}}",
  "Expected --format csv or --format json.": "\u5E94\u4E3A --format csv \u6216 --format json\u3002",
  "Expected a file path after --output.": "--output \u540E\u5E94\u63D0\u4F9B\u6587\u4EF6\u8DEF\u5F84\u3002",
  "Unexpected argument: {{argument}}": "\u610F\u5916\u53C2\u6570\uFF1A{{argument}}",
  "Usage: /stats export <daily|monthly> [YYYY-MM-DD|YYYY-MM] [--format csv|json] [--output path]": "\u7528\u6CD5\uFF1A/stats export <daily|monthly> [YYYY-MM-DD|YYYY-MM] [--format csv|json] [--output path]",
  "Token usage export path must be within the project working directory.": "Token \u4F7F\u7528\u5BFC\u51FA\u8DEF\u5F84\u5FC5\u987B\u4F4D\u4E8E\u9879\u76EE\u5DE5\u4F5C\u76EE\u5F55\u5185\u3002",
  "Export target does not exist: {{path}}": "\u5BFC\u51FA\u76EE\u6807\u4E0D\u5B58\u5728\uFF1A{{path}}",
  "Cannot resolve export path within the working directory.": "\u65E0\u6CD5\u5728\u5DE5\u4F5C\u76EE\u5F55\u5185\u89E3\u6790\u5BFC\u51FA\u8DEF\u5F84\u3002",
  "Could not create a temporary export file.": "\u65E0\u6CD5\u521B\u5EFA\u4E34\u65F6\u5BFC\u51FA\u6587\u4EF6\u3002",
  "Token usage exported to {{format}}: {{path}}": "Token \u4F7F\u7528\u60C5\u51B5\u5DF2\u5BFC\u51FA\u4E3A {{format}}\uFF1A{{path}}",
  "Failed to export token usage stats: {{error}}": "\u5BFC\u51FA token \u4F7F\u7528\u7EDF\u8BA1\u4FE1\u606F\u5931\u8D25\uFF1A{{error}}",
  "Unclosed quote in arguments.": "\u53C2\u6570\u4E2D\u5B58\u5728\u672A\u95ED\u5408\u7684\u5F15\u53F7\u3002",
  "Note: generation timing (TTFT/TPS) belongs to generation metrics.": "\u6CE8\u610F\uFF1A\u751F\u6210\u8017\u65F6\uFF08TTFT/TPS\uFF09\u5F52\u5C5E\u4E8E\u751F\u6210\u6307\u6807\u3002",
  "exit the cli": "\u9000\u51FA\u547D\u4EE4\u884C\u754C\u9762",
  "Manage workspace directories": "\u7BA1\u7406\u5DE5\u4F5C\u533A\u76EE\u5F55",
  "Add directories to the workspace. Use comma to separate multiple paths": "\u5C06\u76EE\u5F55\u6DFB\u52A0\u5230\u5DE5\u4F5C\u533A\u3002\u4F7F\u7528\u9017\u53F7\u5206\u9694\u591A\u4E2A\u8DEF\u5F84",
  "Show all directories in the workspace": "\u663E\u793A\u5DE5\u4F5C\u533A\u4E2D\u7684\u6240\u6709\u76EE\u5F55",
  "set external editor preference": "\u8BBE\u7F6E\u5916\u90E8\u7F16\u8F91\u5668\u9996\u9009\u9879",
  "Select Editor": "\u9009\u62E9\u7F16\u8F91\u5668",
  "Editor Preference": "\u7F16\u8F91\u5668\u9996\u9009\u9879",
  "These editors are currently supported. Please note that some editors cannot be used in sandbox mode.": "\u5F53\u524D\u652F\u6301\u4EE5\u4E0B\u7F16\u8F91\u5668\u3002\u8BF7\u6CE8\u610F\uFF0C\u67D0\u4E9B\u7F16\u8F91\u5668\u65E0\u6CD5\u5728\u6C99\u7BB1\u6A21\u5F0F\u4E0B\u4F7F\u7528\u3002",
  "Your preferred editor is:": "\u60A8\u7684\u9996\u9009\u7F16\u8F91\u5668\u662F\uFF1A",
  "Manage extensions": "\u7BA1\u7406\u6269\u5C55",
  "Manage installed extensions": "\u7BA1\u7406\u5DF2\u5B89\u88C5\u7684\u6269\u5C55",
  "Disable an extension": "\u7981\u7528\u6269\u5C55",
  "Enable an extension": "\u542F\u7528\u6269\u5C55",
  "Install an extension from a git repo or local path": "\u4ECE Git \u4ED3\u5E93\u6216\u672C\u5730\u8DEF\u5F84\u5B89\u88C5\u6269\u5C55",
  "Uninstall an extension": "\u5378\u8F7D\u6269\u5C55",
  "No extensions installed.": "\u672A\u5B89\u88C5\u6269\u5C55\u3002",
  'Extension "{{name}}" not found.': '\u672A\u627E\u5230\u6269\u5C55 "{{name}}"\u3002',
  'The scope to install the extension in: "user" (global, default) or "project" (current workspace only).': '\u5B89\u88C5\u6269\u5C55\u7684\u4F5C\u7528\u57DF\uFF1A"user"\uFF08\u5168\u5C40\uFF0C\u9ED8\u8BA4\uFF09\u6216 "project"\uFF08\u4EC5\u5F53\u524D\u5DE5\u4F5C\u533A\uFF09\u3002',
  'Extension "{{name}}" installed successfully and enabled for the current workspace.': '\u6269\u5C55 "{{name}}" \u5B89\u88C5\u6210\u529F\uFF0C\u5E76\u5DF2\u5728\u5F53\u524D\u5DE5\u4F5C\u533A\u542F\u7528\u3002',
  'Marketplace "{{name}}" not found.': '\u672A\u627E\u5230\u5E02\u573A\u6E90 "{{name}}"\u3002',
  "No marketplace sources added yet.": "\u5C1A\u672A\u6DFB\u52A0\u4EFB\u4F55\u5E02\u573A\u6E90\u3002",
  "No marketplaces added yet.": "\u5C1A\u672A\u6DFB\u52A0\u4EFB\u4F55\u5E02\u573A\u6E90\u3002",
  "Adds a marketplace source (Claude format).": "\u6DFB\u52A0\u4E00\u4E2A\u5E02\u573A\u6E90\uFF08Claude \u683C\u5F0F\uFF09\u3002",
  "The marketplace source to add: owner/repo (GitHub), a git or https URL, or a local path.": "\u8981\u6DFB\u52A0\u7684\u5E02\u573A\u6E90\uFF1Aowner/repo\uFF08GitHub\uFF09\u3001git \u6216 https URL\uFF0C\u6216\u672C\u5730\u8DEF\u5F84\u3002",
  "Removes a marketplace source.": "\u79FB\u9664\u4E00\u4E2A\u5E02\u573A\u6E90\u3002",
  "The name of the marketplace to remove.": "\u8981\u79FB\u9664\u7684\u5E02\u573A\u6E90\u540D\u79F0\u3002",
  "Lists configured marketplace sources.": "\u5217\u51FA\u5DF2\u914D\u7F6E\u7684\u5E02\u573A\u6E90\u3002",
  "Re-fetches a marketplace source and its plugin listing.": "\u91CD\u65B0\u62C9\u53D6\u5E02\u573A\u6E90\u53CA\u5176\u63D2\u4EF6\u5217\u8868\u3002",
  "The name of the marketplace to update.": "\u8981\u66F4\u65B0\u7684\u5E02\u573A\u6E90\u540D\u79F0\u3002",
  "Manage marketplace sources for discovering extensions.": "\u7BA1\u7406\u7528\u4E8E\u53D1\u73B0\u6269\u5C55\u7684\u5E02\u573A\u6E90\u3002",
  "You need at least one command before continuing.": "\u9700\u8981\u81F3\u5C11\u63D0\u4F9B\u4E00\u4E2A\u5B50\u547D\u4EE4\u3002",
  "No extensions to update.": "\u6CA1\u6709\u53EF\u66F4\u65B0\u7684\u6269\u5C55\u3002",
  "Usage: /extensions install <source>": "\u7528\u6CD5\uFF1A/extensions install <\u6765\u6E90>",
  'Installing extension from "{{source}}"...': '\u6B63\u5728\u4ECE "{{source}}" \u5B89\u88C5\u6269\u5C55...',
  'Extension "{{name}}" installed successfully.': '\u6269\u5C55 "{{name}}" \u5B89\u88C5\u6210\u529F\u3002',
  'Failed to install extension from "{{source}}": {{error}}': '\u4ECE "{{source}}" \u5B89\u88C5\u6269\u5C55\u5931\u8D25\uFF1A{{error}}',
  "Do you want to continue? [Y/n]: ": "\u662F\u5426\u7EE7\u7EED\uFF1F[Y/n]\uFF1A",
  "Do you want to continue?": "\u662F\u5426\u7EE7\u7EED\uFF1F",
  'Installing extension "{{name}}".': '\u6B63\u5728\u5B89\u88C5\u6269\u5C55 "{{name}}"\u3002',
  "**Extensions may introduce unexpected behavior. Ensure you have investigated the extension source and trust the author.**": "**\u6269\u5C55\u53EF\u80FD\u4F1A\u5F15\u5165\u610F\u5916\u884C\u4E3A\u3002\u8BF7\u786E\u4FDD\u60A8\u5DF2\u8C03\u67E5\u8FC7\u6269\u5C55\u6E90\u5E76\u4FE1\u4EFB\u4F5C\u8005\u3002**",
  "This extension will run the following MCP servers:": "\u6B64\u6269\u5C55\u5C06\u8FD0\u884C\u4EE5\u4E0B MCP servers\uFF1A",
  local: "\u672C\u5730",
  remote: "\u8FDC\u7A0B",
  "This extension will add the following commands: {{commands}}.": "\u6B64\u6269\u5C55\u5C06\u6DFB\u52A0\u4EE5\u4E0B\u547D\u4EE4\uFF1A{{commands}}\u3002",
  "This extension will append info to your QWEN.md context using {{fileName}}": "\u6B64\u6269\u5C55\u5C06\u4F7F\u7528 {{fileName}} \u5411\u60A8\u7684 QWEN.md \u4E0A\u4E0B\u6587\u8FFD\u52A0\u4FE1\u606F",
  "This extension will install the following skills:": "\u6B64\u6269\u5C55\u5C06\u5B89\u88C5\u4EE5\u4E0B\u6280\u80FD\uFF1A",
  "This extension will install the following subagents:": "\u6B64\u6269\u5C55\u5C06\u5B89\u88C5\u4EE5\u4E0B\u5B50\u667A\u80FD\u4F53\uFF1A",
  'Installation cancelled for "{{name}}".': '\u5DF2\u53D6\u6D88\u5B89\u88C5 "{{name}}"\u3002',
  "You are installing an extension from {{originSource}}. Some features may not work perfectly with Qwen Code.": "\u60A8\u6B63\u5728\u5B89\u88C5\u6765\u81EA {{originSource}} \u7684\u6269\u5C55\u3002\u67D0\u4E9B\u529F\u80FD\u53EF\u80FD\u65E0\u6CD5\u5B8C\u7F8E\u517C\u5BB9 Qwen Code\u3002",
  "--ref and --auto-update are not applicable for marketplace extensions.": "--ref \u548C --auto-update \u4E0D\u9002\u7528\u4E8E\u5E02\u573A\u6269\u5C55\u3002",
  'Extension "{{name}}" installed successfully and enabled.': '\u6269\u5C55 "{{name}}" \u5B89\u88C5\u6210\u529F\u5E76\u5DF2\u542F\u7528\u3002',
  "The github URL, local path, or marketplace source (marketplace-url:plugin-name) of the extension to install.": "\u8981\u5B89\u88C5\u7684\u6269\u5C55\u7684 GitHub URL\u3001\u672C\u5730\u8DEF\u5F84\u6216\u5E02\u573A\u6E90\uFF08marketplace-url:plugin-name\uFF09\u3002",
  "The git ref to install from.": "\u8981\u5B89\u88C5\u7684 Git \u5F15\u7528\u3002",
  "--registry is only applicable for npm extensions.": "--registry \u4EC5\u9002\u7528\u4E8E npm \u6269\u5C55\u3002",
  "Custom npm registry URL (only for npm extensions).": "\u81EA\u5B9A\u4E49 npm registry URL\uFF08\u4EC5\u9002\u7528\u4E8E npm \u6269\u5C55\uFF09\u3002",
  "--ref is not applicable for npm extensions. Use @version suffix instead (e.g. @scope/package@1.2.0).": "--ref \u4E0D\u9002\u7528\u4E8E npm \u6269\u5C55\u3002\u8BF7\u6539\u7528 @version \u540E\u7F00\uFF08\u4F8B\u5982 @scope/package@1.2.0\uFF09\u3002",
  "Installs an extension from a git repository URL, local path, scoped npm package (@scope/name), or claude marketplace (marketplace-url:plugin-name).": "\u4ECE Git \u4ED3\u5E93 URL\u3001\u672C\u5730\u8DEF\u5F84\u3001\u5E26\u4F5C\u7528\u57DF\u7684 npm \u5305\uFF08@scope/name\uFF09\u6216 Claude \u5E02\u573A\u6E90\uFF08marketplace-url:plugin-name\uFF09\u5B89\u88C5\u6269\u5C55\u3002",
  Description: "\u63CF\u8FF0",
  "Delete Session": "\u5220\u9664\u4F1A\u8BDD",
  "Enable auto-update for this extension.": "\u4E3A\u6B64\u6269\u5C55\u542F\u7528\u81EA\u52A8\u66F4\u65B0\u3002",
  "Enable pre-release versions for this extension.": "\u4E3A\u6B64\u6269\u5C55\u542F\u7528\u9884\u53D1\u5E03\u7248\u672C\u3002",
  "Acknowledge the security risks of installing an extension and skip the confirmation prompt.": "\u786E\u8BA4\u5B89\u88C5\u6269\u5C55\u7684\u5B89\u5168\u98CE\u9669\u5E76\u8DF3\u8FC7\u786E\u8BA4\u63D0\u793A\u3002",
  "The source argument must be provided.": "\u5FC5\u987B\u63D0\u4F9B\u6765\u6E90\u53C2\u6570\u3002",
  'Extension "{{name}}" successfully uninstalled.': '\u6269\u5C55 "{{name}}" \u5378\u8F7D\u6210\u529F\u3002',
  "Uninstalls an extension.": "\u5378\u8F7D\u6269\u5C55\u3002",
  "The name or source path of the extension to uninstall.": "\u8981\u5378\u8F7D\u7684\u6269\u5C55\u7684\u540D\u79F0\u6216\u6E90\u8DEF\u5F84\u3002",
  "Please include the name of the extension to uninstall as a positional argument.": "\u8BF7\u5C06\u8981\u5378\u8F7D\u7684\u6269\u5C55\u540D\u79F0\u4F5C\u4E3A\u4F4D\u7F6E\u53C2\u6570\u3002",
  "Enables an extension.": "\u542F\u7528\u6269\u5C55\u3002",
  "The name of the extension to enable.": "\u8981\u542F\u7528\u7684\u6269\u5C55\u540D\u79F0\u3002",
  "The scope to enable the extension in. If not set, will be enabled in all scopes.": "\u542F\u7528\u6269\u5C55\u7684\u4F5C\u7528\u57DF\u3002\u5982\u679C\u672A\u8BBE\u7F6E\uFF0C\u5C06\u5728\u6240\u6709\u4F5C\u7528\u57DF\u4E2D\u542F\u7528\u3002",
  'Extension "{{name}}" successfully enabled for scope "{{scope}}".': '\u6269\u5C55 "{{name}}" \u5DF2\u5728\u4F5C\u7528\u57DF "{{scope}}" \u4E2D\u542F\u7528\u3002',
  'Extension "{{name}}" successfully enabled in all scopes.': '\u6269\u5C55 "{{name}}" \u5DF2\u5728\u6240\u6709\u4F5C\u7528\u57DF\u4E2D\u542F\u7528\u3002',
  "Invalid scope: {{scope}}. Please use one of {{scopes}}.": "\u65E0\u6548\u7684\u4F5C\u7528\u57DF\uFF1A{{scope}}\u3002\u8BF7\u4F7F\u7528 {{scopes}} \u4E4B\u4E00\u3002",
  "Disables an extension.": "\u7981\u7528\u6269\u5C55\u3002",
  "The name of the extension to disable.": "\u8981\u7981\u7528\u7684\u6269\u5C55\u540D\u79F0\u3002",
  "The scope to disable the extension in.": "\u7981\u7528\u6269\u5C55\u7684\u4F5C\u7528\u57DF\u3002",
  'Extension "{{name}}" successfully disabled for scope "{{scope}}".': '\u6269\u5C55 "{{name}}" \u5DF2\u5728\u4F5C\u7528\u57DF "{{scope}}" \u4E2D\u7981\u7528\u3002',
  'Extension "{{name}}" successfully updated: {{oldVersion}} \u2192 {{newVersion}}.': '\u6269\u5C55 "{{name}}" \u66F4\u65B0\u6210\u529F\uFF1A{{oldVersion}} \u2192 {{newVersion}}\u3002',
  'Unable to install extension "{{name}}" due to missing install metadata': '\u7531\u4E8E\u7F3A\u5C11\u5B89\u88C5\u5143\u6570\u636E\uFF0C\u65E0\u6CD5\u5B89\u88C5\u6269\u5C55 "{{name}}"',
  'Extension "{{name}}" is already up to date.': '\u6269\u5C55 "{{name}}" \u5DF2\u662F\u6700\u65B0\u7248\u672C\u3002',
  "Updates all extensions or a named extension to the latest version.": "\u5C06\u6240\u6709\u6269\u5C55\u6216\u6307\u5B9A\u6269\u5C55\u66F4\u65B0\u5230\u6700\u65B0\u7248\u672C\u3002",
  "Update all extensions.": "\u66F4\u65B0\u6240\u6709\u6269\u5C55\u3002",
  "The name of the extension to update.": "\u8981\u66F4\u65B0\u7684\u6269\u5C55\u540D\u79F0\u3002",
  "Either an extension name or --all must be provided": "\u5FC5\u987B\u63D0\u4F9B\u6269\u5C55\u540D\u79F0\u6216 --all",
  "List installed extensions": "\u5217\u51FA\u5DF2\u5B89\u88C5\u7684\u6269\u5C55",
  "Lists installed extensions.": "\u5217\u51FA\u5DF2\u5B89\u88C5\u7684\u6269\u5C55\u3002",
  "Path:": "\u8DEF\u5F84\uFF1A",
  "Source:": "\u6765\u6E90\uFF1A",
  "Type:": "\u7C7B\u578B\uFF1A",
  "Ref:": "\u5F15\u7528\uFF1A",
  "Release tag:": "\u53D1\u5E03\u6807\u7B7E\uFF1A",
  "Enabled (User):": "\u5DF2\u542F\u7528\uFF08\u7528\u6237\uFF09\uFF1A",
  "Enabled (Workspace):": "\u5DF2\u542F\u7528\uFF08\u5DE5\u4F5C\u533A\uFF09\uFF1A",
  "Context files:": "\u4E0A\u4E0B\u6587\u6587\u4EF6\uFF1A",
  "Skills:": "\u6280\u80FD\uFF1A",
  "Agents:": "\u667A\u80FD\u4F53\uFF1A",
  "MCP servers:": "MCP servers\uFF1A",
  "Link extension failed to install.": "\u94FE\u63A5\u6269\u5C55\u5B89\u88C5\u5931\u8D25\u3002",
  'Extension "{{name}}" linked successfully and enabled.': '\u6269\u5C55 "{{name}}" \u94FE\u63A5\u6210\u529F\u5E76\u5DF2\u542F\u7528\u3002',
  "Links an extension from a local path. Updates made to the local path will always be reflected.": "\u4ECE\u672C\u5730\u8DEF\u5F84\u94FE\u63A5\u6269\u5C55\u3002\u5BF9\u672C\u5730\u8DEF\u5F84\u7684\u66F4\u65B0\u5C06\u59CB\u7EC8\u53CD\u6620\u3002",
  "The name of the extension to link.": "\u8981\u94FE\u63A5\u7684\u6269\u5C55\u540D\u79F0\u3002",
  "Set a specific setting for an extension.": "\u4E3A\u6269\u5C55\u8BBE\u7F6E\u7279\u5B9A\u914D\u7F6E\u3002",
  "Name of the extension to configure.": "\u8981\u914D\u7F6E\u7684\u6269\u5C55\u540D\u79F0\u3002",
  "The setting to configure (name or env var).": "\u8981\u914D\u7F6E\u7684\u8BBE\u7F6E\uFF08\u540D\u79F0\u6216\u73AF\u5883\u53D8\u91CF\uFF09\u3002",
  "The scope to set the setting in.": "\u8BBE\u7F6E\u914D\u7F6E\u7684\u4F5C\u7528\u57DF\u3002",
  "List all settings for an extension.": "\u5217\u51FA\u6269\u5C55\u7684\u6240\u6709\u8BBE\u7F6E\u3002",
  "Name of the extension.": "\u6269\u5C55\u540D\u79F0\u3002",
  'Extension "{{name}}" has no settings to configure.': '\u6269\u5C55 "{{name}}" \u6CA1\u6709\u53EF\u914D\u7F6E\u7684\u8BBE\u7F6E\u3002',
  'Settings for "{{name}}":': '"{{name}}" \u7684\u8BBE\u7F6E\uFF1A',
  "(workspace)": "\uFF08\u5DE5\u4F5C\u533A\uFF09",
  "(user)": "\uFF08\u7528\u6237\uFF09",
  "[not set]": "\uFF3B\u672A\u8BBE\u7F6E\uFF3D",
  "[value stored in keychain]": "\uFF3B\u503C\u5B58\u50A8\u5728\u94A5\u5319\u4E32\u4E2D\uFF3D",
  "Value:": "\u503C\uFF1A",
  "Manage extension settings.": "\u7BA1\u7406\u6269\u5C55\u8BBE\u7F6E\u3002",
  "You need to specify a command (set or list).": "\u60A8\u9700\u8981\u6307\u5B9A\u547D\u4EE4\uFF08set \u6216 list\uFF09\u3002",
  // ============================================================================
  // Plugin Choice / Marketplace
  // ============================================================================
  "No plugins available in this marketplace.": "\u6B64\u5E02\u573A\u4E2D\u6CA1\u6709\u53EF\u7528\u7684\u63D2\u4EF6\u3002",
  'Select a plugin to install from marketplace "{{name}}":': '\u4ECE\u5E02\u573A "{{name}}" \u4E2D\u9009\u62E9\u8981\u5B89\u88C5\u7684\u63D2\u4EF6\uFF1A',
  "Plugin selection cancelled.": "\u63D2\u4EF6\u9009\u62E9\u5DF2\u53D6\u6D88\u3002",
  'Select a plugin from "{{name}}"': '\u4ECE "{{name}}" \u4E2D\u9009\u62E9\u63D2\u4EF6',
  "Use \u2191\u2193 or j/k to navigate, Enter to select, Escape to cancel": "\u4F7F\u7528 \u2191\u2193 \u6216 j/k \u5BFC\u822A\uFF0CEnter \u9009\u62E9\uFF0CEscape \u53D6\u6D88",
  "{{count}} more above": "\u4E0A\u65B9\u8FD8\u6709 {{count}} \u9879",
  "{{count}} more below": "\u4E0B\u65B9\u8FD8\u6709 {{count}} \u9879",
  "manage IDE integration": "\u7BA1\u7406 IDE \u96C6\u6210",
  "check status of IDE integration": "\u68C0\u67E5 IDE \u96C6\u6210\u72B6\u6001",
  "install required IDE companion for {{ideName}}": "\u5B89\u88C5 {{ideName}} \u6240\u9700\u7684 IDE \u914D\u5957\u5DE5\u5177",
  "enable IDE integration": "\u542F\u7528 IDE \u96C6\u6210",
  "disable IDE integration": "\u7981\u7528 IDE \u96C6\u6210",
  "IDE integration is not supported in your current environment. To use this feature, run Qwen Code in one of these supported IDEs: VS Code or VS Code forks.": "\u60A8\u5F53\u524D\u73AF\u5883\u4E0D\u652F\u6301 IDE \u96C6\u6210\u3002\u8981\u4F7F\u7528\u6B64\u529F\u80FD\uFF0C\u8BF7\u5728\u4EE5\u4E0B\u652F\u6301\u7684 IDE \u4E4B\u4E00\u4E2D\u8FD0\u884C Qwen Code\uFF1AVS Code \u6216 VS Code \u5206\u652F\u7248\u672C\u3002",
  "Set up GitHub Actions": "\u8BBE\u7F6E GitHub Actions",
  "Configure terminal keybindings for multiline input (VS Code, Cursor, Windsurf, Trae)": "\u914D\u7F6E\u7EC8\u7AEF\u6309\u952E\u7ED1\u5B9A\u4EE5\u652F\u6301\u591A\u884C\u8F93\u5165\uFF08VS Code\u3001Cursor\u3001Windsurf\u3001Trae\uFF09",
  "Please restart your terminal for the changes to take effect.": "\u8BF7\u91CD\u542F\u7EC8\u7AEF\u4EE5\u4F7F\u66F4\u6539\u751F\u6548\u3002",
  "Failed to configure terminal: {{error}}": "\u914D\u7F6E\u7EC8\u7AEF\u5931\u8D25\uFF1A{{error}}",
  "Could not determine {{terminalName}} config path on Windows: APPDATA environment variable is not set.": "\u65E0\u6CD5\u786E\u5B9A {{terminalName}} \u5728 Windows \u4E0A\u7684\u914D\u7F6E\u8DEF\u5F84\uFF1A\u672A\u8BBE\u7F6E APPDATA \u73AF\u5883\u53D8\u91CF\u3002",
  "{{terminalName}} keybindings.json exists but is not a valid JSON array. Please fix the file manually or delete it to allow automatic configuration.": "{{terminalName}} keybindings.json \u5B58\u5728\u4F46\u4E0D\u662F\u6709\u6548\u7684 JSON \u6570\u7EC4\u3002\u8BF7\u624B\u52A8\u4FEE\u590D\u6587\u4EF6\u6216\u5220\u9664\u5B83\u4EE5\u5141\u8BB8\u81EA\u52A8\u914D\u7F6E\u3002",
  "File: {{file}}": "\u6587\u4EF6\uFF1A{{file}}",
  "Failed to parse {{terminalName}} keybindings.json. The file contains invalid JSON. Please fix the file manually or delete it to allow automatic configuration.": "\u89E3\u6790 {{terminalName}} keybindings.json \u5931\u8D25\u3002\u6587\u4EF6\u5305\u542B\u65E0\u6548\u7684 JSON\u3002\u8BF7\u624B\u52A8\u4FEE\u590D\u6587\u4EF6\u6216\u5220\u9664\u5B83\u4EE5\u5141\u8BB8\u81EA\u52A8\u914D\u7F6E\u3002",
  "Error: {{error}}": "\u9519\u8BEF\uFF1A{{error}}",
  "Shift+Enter binding already exists": "Shift+Enter \u7ED1\u5B9A\u5DF2\u5B58\u5728",
  "Ctrl+Enter binding already exists": "Ctrl+Enter \u7ED1\u5B9A\u5DF2\u5B58\u5728",
  "Existing keybindings detected. Will not modify to avoid conflicts.": "\u68C0\u6D4B\u5230\u73B0\u6709\u6309\u952E\u7ED1\u5B9A\u3002\u4E3A\u907F\u514D\u51B2\u7A81\uFF0C\u4E0D\u4F1A\u4FEE\u6539\u3002",
  "Please check and modify manually if needed: {{file}}": "\u5982\u6709\u9700\u8981\uFF0C\u8BF7\u624B\u52A8\u68C0\u67E5\u5E76\u4FEE\u6539\uFF1A{{file}}",
  "Added Shift+Enter and Ctrl+Enter keybindings to {{terminalName}}.": "\u5DF2\u4E3A {{terminalName}} \u6DFB\u52A0 Shift+Enter \u548C Ctrl+Enter \u6309\u952E\u7ED1\u5B9A\u3002",
  "Modified: {{file}}": "\u5DF2\u4FEE\u6539\uFF1A{{file}}",
  "{{terminalName}} keybindings already configured.": "{{terminalName}} \u6309\u952E\u7ED1\u5B9A\u5DF2\u914D\u7F6E\u3002",
  "Failed to configure {{terminalName}}.": "\u914D\u7F6E {{terminalName}} \u5931\u8D25\u3002",
  "Your terminal is already configured for an optimal experience with multiline input (Shift+Enter and Ctrl+Enter).": "\u60A8\u7684\u7EC8\u7AEF\u5DF2\u914D\u7F6E\u4E3A\u652F\u6301\u591A\u884C\u8F93\u5165\uFF08Shift+Enter \u548C Ctrl+Enter\uFF09\u7684\u6700\u4F73\u4F53\u9A8C\u3002",
  // ============================================================================
  // Commands - Hooks
  // ============================================================================
  "Manage Qwen Code hooks": "\u7BA1\u7406 Qwen Code Hook",
  "List all configured hooks": "\u5217\u51FA\u6240\u6709\u5DF2\u914D\u7F6E\u7684 Hook",
  // Hooks - Dialog
  Hooks: "Hook",
  "Loading hooks...": "\u6B63\u5728\u52A0\u8F7D Hook...",
  "Error loading hooks:": "\u52A0\u8F7D Hook \u51FA\u9519\uFF1A",
  "Press Escape to close": "\u6309 Escape \u5173\u95ED",
  "Press Escape, Ctrl+C, or Ctrl+D to cancel": "\u6309 Escape\u3001Ctrl+C \u6216 Ctrl+D \u53D6\u6D88",
  "Press Space, Enter, or Escape to dismiss": "\u6309 Space\u3001Enter \u6216 Escape \u5173\u95ED",
  "No hook selected": "\u672A\u9009\u62E9 Hook",
  "Session (temporary)": "\u4F1A\u8BDD\uFF08\u4E34\u65F6\uFF09",
  // Hooks - List Step
  "No hook events found.": "\u672A\u627E\u5230 Hook \u4E8B\u4EF6\u3002",
  "{{count}} hook configured": "{{count}} \u4E2A Hook \u5DF2\u914D\u7F6E",
  "{{count}} hooks configured": "{{count}} \u4E2A Hook \u5DF2\u914D\u7F6E",
  "This menu is read-only. To add or modify hooks, edit settings.json directly or ask Qwen Code.": "\u6B64\u83DC\u5355\u4E3A\u53EA\u8BFB\u3002\u8981\u6DFB\u52A0\u6216\u4FEE\u6539 Hook\uFF0C\u8BF7\u76F4\u63A5\u7F16\u8F91 settings.json \u6216\u8BE2\u95EE Qwen Code\u3002",
  "Enter to select \xB7 Esc to cancel": "Enter \u9009\u62E9 \xB7 Esc \u53D6\u6D88",
  // Hooks - Detail Step
  "Exit codes:": "\u9000\u51FA\u7801\uFF1A",
  "Configured hooks:": "\u5DF2\u914D\u7F6E\u7684 Hook\uFF1A",
  "No hooks configured for this event.": "\u6B64\u4E8B\u4EF6\u672A\u914D\u7F6E Hook\u3002",
  "To add hooks, edit settings.json directly or ask Qwen.": "\u8981\u6DFB\u52A0 Hook\uFF0C\u8BF7\u76F4\u63A5\u7F16\u8F91 settings.json \u6216\u8BE2\u95EE Qwen\u3002",
  "Enter to select \xB7 Esc to go back": "Enter \u9009\u62E9 \xB7 Esc \u8FD4\u56DE",
  // Hooks - Config Detail Step
  "Hook details": "Hook \u8BE6\u60C5",
  "Event:": "\u4E8B\u4EF6\uFF1A",
  "Extension:": "\u6269\u5C55\uFF1A",
  "Desc:": "\u63CF\u8FF0\uFF1A",
  "No hook config selected": "\u672A\u9009\u62E9 Hook \u914D\u7F6E",
  "To modify or remove this hook, edit settings.json directly or ask Qwen to help.": "\u8981\u4FEE\u6539\u6216\u5220\u9664\u6B64 Hook\uFF0C\u8BF7\u76F4\u63A5\u7F16\u8F91 settings.json \u6216\u8BE2\u95EE Qwen\u3002",
  // Hooks - Disabled Step
  "Hook Configuration - Disabled": "Hook \u914D\u7F6E - \u5DF2\u7981\u7528",
  "All hooks are currently disabled. You have {{count}} that are not running.": "\u6240\u6709 Hook \u5F53\u524D\u5DF2\u7981\u7528\u3002\u60A8\u6709 {{count}} \u672A\u8FD0\u884C\u3002",
  "{{count}} configured hook": "{{count}} \u4E2A\u5DF2\u914D\u7F6E\u7684 Hook",
  "{{count}} configured hooks": "{{count}} \u4E2A\u5DF2\u914D\u7F6E\u7684 Hook",
  "When hooks are disabled:": "\u5F53 Hook \u88AB\u7981\u7528\u65F6\uFF1A",
  "No hook commands will execute": "\u4E0D\u4F1A\u6267\u884C\u4EFB\u4F55 Hook \u547D\u4EE4",
  "StatusLine will not be displayed": "\u4E0D\u4F1A\u663E\u793A\u72B6\u6001\u680F",
  "Tool operations will proceed without hook validation": "\u5DE5\u5177\u64CD\u4F5C\u5C06\u5728\u6CA1\u6709 Hook \u9A8C\u8BC1\u7684\u60C5\u51B5\u4E0B\u7EE7\u7EED",
  'To re-enable hooks, remove "disableAllHooks" from settings.json or ask Qwen Code.': '\u8981\u91CD\u65B0\u542F\u7528 Hook\uFF0C\u8BF7\u4ECE settings.json \u4E2D\u5220\u9664 "disableAllHooks" \u6216\u8BE2\u95EE Qwen Code\u3002',
  // Hooks - Source
  Project: "\u9879\u76EE",
  User: "\u7528\u6237",
  Skill: "\u6280\u80FD",
  System: "\u7CFB\u7EDF",
  Extension: "\u6269\u5C55",
  "Local Settings": "\u672C\u5730\u8BBE\u7F6E",
  "User Settings": "\u7528\u6237\u8BBE\u7F6E",
  "System Settings": "\u7CFB\u7EDF\u8BBE\u7F6E",
  Extensions: "\u6269\u5C55",
  // Hooks - Event Descriptions (short)
  "Before tool execution": "\u5DE5\u5177\u6267\u884C\u524D",
  "After tool execution": "\u5DE5\u5177\u6267\u884C\u540E",
  "After tool execution fails": "\u5DE5\u5177\u6267\u884C\u5931\u8D25\u540E",
  "When notifications are sent": "\u53D1\u9001\u901A\u77E5\u65F6",
  "When the user submits a prompt": "\u7528\u6237\u63D0\u4EA4\u63D0\u793A\u65F6",
  "When a slash command expands into a prompt": "\u659C\u6760\u547D\u4EE4\u5C55\u5F00\u4E3A\u63D0\u793A\u65F6",
  "When a new session is started": "\u65B0\u4F1A\u8BDD\u5F00\u59CB\u65F6",
  "Right before Qwen Code concludes its response": "Qwen Code \u7ED3\u675F\u54CD\u5E94\u4E4B\u524D",
  "When a subagent (Agent tool call) is started": "\u5B50\u667A\u80FD\u4F53\uFF08Agent \u5DE5\u5177\u8C03\u7528\uFF09\u542F\u52A8\u65F6",
  "Right before a subagent concludes its response": "\u5B50\u667A\u80FD\u4F53\u7ED3\u675F\u54CD\u5E94\u4E4B\u524D",
  "Before conversation compaction": "\u5BF9\u8BDD\u538B\u7F29\u524D",
  "When a session is ending": "\u4F1A\u8BDD\u7ED3\u675F\u65F6",
  "When a permission dialog is displayed": "\u663E\u793A\u6743\u9650\u5BF9\u8BDD\u6846\u65F6",
  "When a new todo item is created": "\u521B\u5EFA\u65B0\u5F85\u529E\u4E8B\u9879\u65F6",
  "When a todo item is marked as completed": "\u5F85\u529E\u4E8B\u9879\u6807\u8BB0\u4E3A\u5B8C\u6210\u65F6",
  // Hooks - Event Descriptions (detailed)
  "Input to command is JSON of tool call arguments.": "\u547D\u4EE4\u8F93\u5165\u4E3A\u5DE5\u5177\u8C03\u7528\u53C2\u6570\u7684 JSON\u3002",
  'Input to command is JSON with fields "inputs" (tool call arguments) and "response" (tool call response).': '\u547D\u4EE4\u8F93\u5165\u4E3A\u5305\u542B "inputs"\uFF08\u5DE5\u5177\u8C03\u7528\u53C2\u6570\uFF09\u548C "response"\uFF08\u5DE5\u5177\u8C03\u7528\u54CD\u5E94\uFF09\u5B57\u6BB5\u7684 JSON\u3002',
  "Input to command is JSON with tool_name, tool_input, tool_use_id, error, error_type, is_interrupt, and is_timeout.": "\u547D\u4EE4\u8F93\u5165\u4E3A\u5305\u542B tool_name\u3001tool_input\u3001tool_use_id\u3001error\u3001error_type\u3001is_interrupt \u548C is_timeout \u7684 JSON\u3002",
  "Input to command is JSON with notification message and type.": "\u547D\u4EE4\u8F93\u5165\u4E3A\u5305\u542B\u901A\u77E5\u6D88\u606F\u548C\u7C7B\u578B\u7684 JSON\u3002",
  'Input to command is JSON with "prompt" (the current model-bound prompt) and optional "submitted_prompt" (the supported interactive TUI text projection).': '\u547D\u4EE4\u8F93\u5165\u4E3A JSON\uFF0C\u5176\u4E2D\u5305\u542B "prompt"\uFF08\u5F53\u524D\u6A21\u578B\u4FA7\u63D0\u793A\uFF09\u4EE5\u53CA\u53EF\u9009\u7684 "submitted_prompt"\uFF08\u53D7\u652F\u6301\u4EA4\u4E92\u5F0F TUI \u7684\u63D0\u4EA4\u6587\u672C\u6295\u5F71\uFF09\u3002',
  "Input to command is JSON with command_name, command_args, and expanded prompt text.": "\u547D\u4EE4\u8F93\u5165\u4E3A\u5305\u542B command_name\u3001command_args \u548C\u5C55\u5F00\u540E\u63D0\u793A\u6587\u672C\u7684 JSON\u3002",
  "Input to command is JSON with session start source.": "\u547D\u4EE4\u8F93\u5165\u4E3A\u5305\u542B\u4F1A\u8BDD\u542F\u52A8\u6765\u6E90\u7684 JSON\u3002",
  "Input to command is JSON with session end reason.": "\u547D\u4EE4\u8F93\u5165\u4E3A\u5305\u542B\u4F1A\u8BDD\u7ED3\u675F\u539F\u56E0\u7684 JSON\u3002",
  "Input to command is JSON with agent_id and agent_type.": "\u547D\u4EE4\u8F93\u5165\u4E3A\u5305\u542B agent_id \u548C agent_type \u7684 JSON\u3002",
  "Input to command is JSON with agent_id, agent_type, and agent_transcript_path.": "\u547D\u4EE4\u8F93\u5165\u4E3A\u5305\u542B agent_id\u3001agent_type \u548C agent_transcript_path \u7684 JSON\u3002",
  "Input to command is JSON with compaction details.": "\u547D\u4EE4\u8F93\u5165\u4E3A\u5305\u542B\u538B\u7F29\u8BE6\u60C5\u7684 JSON\u3002",
  "Input to command is JSON with tool_name, tool_input, and tool_use_id. Output JSON with hookSpecificOutput containing decision to allow or deny.": "\u547D\u4EE4\u8F93\u5165\u4E3A\u5305\u542B tool_name\u3001tool_input \u548C tool_use_id \u7684 JSON\u3002\u8F93\u51FA\u5305\u542B hookSpecificOutput \u7684 JSON\uFF0C\u5176\u4E2D\u5305\u542B\u5141\u8BB8\u6216\u62D2\u7EDD\u7684\u51B3\u5B9A\u3002",
  "Input to command is JSON with todo_id, todo_content, todo_status, all_todos, and phase. In validation, output JSON with decision (allow/block/deny) and reason. In postWrite, block/deny is ignored.": "\u547D\u4EE4\u8F93\u5165\u4E3A\u5305\u542B todo_id\u3001todo_content\u3001todo_status\u3001all_todos \u548C phase \u7684 JSON\u3002\u5728 validation \u4E2D\uFF0C\u8F93\u51FA\u5305\u542B decision\uFF08allow/block/deny\uFF09\u548C reason \u7684 JSON\u3002\u5728 postWrite \u4E2D\uFF0Cblock/deny \u4F1A\u88AB\u5FFD\u7565\u3002",
  "Input to command is JSON with todo_id, todo_content, previous_status, all_todos, and phase. In validation, output JSON with decision (allow/block/deny) and reason. In postWrite, block/deny is ignored.": "\u547D\u4EE4\u8F93\u5165\u4E3A\u5305\u542B todo_id\u3001todo_content\u3001previous_status\u3001all_todos \u548C phase \u7684 JSON\u3002\u5728 validation \u4E2D\uFF0C\u8F93\u51FA\u5305\u542B decision\uFF08allow/block/deny\uFF09\u548C reason \u7684 JSON\u3002\u5728 postWrite \u4E2D\uFF0Cblock/deny \u4F1A\u88AB\u5FFD\u7565\u3002",
  // Hooks - Exit Code Descriptions
  "stdout/stderr not shown": "stdout/stderr \u4E0D\u663E\u793A",
  "show stderr to model and continue conversation": "\u5411\u6A21\u578B\u663E\u793A stderr \u5E76\u7EE7\u7EED\u5BF9\u8BDD",
  "show stderr to user only": "\u4EC5\u5411\u7528\u6237\u663E\u793A stderr",
  "stdout shown in transcript mode (ctrl+o)": "stdout \u4EE5\u8F6C\u5F55\u6A21\u5F0F\u663E\u793A (ctrl+o)",
  "show stderr to model immediately": "\u7ACB\u5373\u5411\u6A21\u578B\u663E\u793A stderr",
  "show stderr to user only but continue with tool call": "\u4EC5\u5411\u7528\u6237\u663E\u793A stderr \u4F46\u7EE7\u7EED\u5DE5\u5177\u8C03\u7528",
  "block processing, erase original prompt, and show stderr to user only": "\u963B\u6B62\u5904\u7406\uFF0C\u64E6\u9664\u539F\u59CB\u63D0\u793A\uFF0C\u4EC5\u5411\u7528\u6237\u663E\u793A stderr",
  "block expanded prompt submission and show stderr to user only": "\u963B\u6B62\u63D0\u4EA4\u5C55\u5F00\u540E\u7684\u63D0\u793A\uFF0C\u5E76\u4EC5\u5411\u7528\u6237\u663E\u793A stderr",
  "stdout shown to Qwen": "\u5411 Qwen \u663E\u793A stdout",
  "show stderr to user only (blocking errors ignored)": "\u4EC5\u5411\u7528\u6237\u663E\u793A stderr\uFF08\u5FFD\u7565\u963B\u585E\u9519\u8BEF\uFF09",
  "command completes successfully": "\u547D\u4EE4\u6210\u529F\u5B8C\u6210",
  "stdout shown to subagent": "\u5411\u5B50\u667A\u80FD\u4F53\u663E\u793A stdout",
  "show stderr to subagent and continue having it run": "\u5411\u5B50\u667A\u80FD\u4F53\u663E\u793A stderr \u5E76\u7EE7\u7EED\u8FD0\u884C",
  "stdout appended as custom compact instructions": "stdout \u4F5C\u4E3A\u81EA\u5B9A\u4E49\u538B\u7F29\u6307\u4EE4\u8FFD\u52A0",
  "block compaction": "\u963B\u6B62\u538B\u7F29",
  "show stderr to user only but continue with compaction": "\u4EC5\u5411\u7528\u6237\u663E\u793A stderr \u4F46\u7EE7\u7EED\u538B\u7F29",
  "use hook decision if provided": "\u5982\u679C\u63D0\u4F9B\u5219\u4F7F\u7528 Hook \u51B3\u5B9A",
  "allow todo creation": "\u5141\u8BB8\u521B\u5EFA\u5F85\u529E\u4E8B\u9879",
  "block todo creation and show reason to model": "\u963B\u6B62\u521B\u5EFA\u5F85\u529E\u4E8B\u9879\u5E76\u5411\u6A21\u578B\u663E\u793A\u539F\u56E0",
  "allow todo completion": "\u5141\u8BB8\u5B8C\u6210\u5F85\u529E\u4E8B\u9879",
  "block todo completion and show reason to model": "\u963B\u6B62\u5B8C\u6210\u5F85\u529E\u4E8B\u9879\u5E76\u5411\u6A21\u578B\u663E\u793A\u539F\u56E0",
  // Hooks - Messages
  "Config not loaded.": "\u914D\u7F6E\u672A\u52A0\u8F7D\u3002",
  "Hooks are not enabled. Enable hooks in settings to use this feature.": "Hook \u672A\u542F\u7528\u3002\u8BF7\u5728\u8BBE\u7F6E\u4E2D\u542F\u7528 Hook \u4EE5\u4F7F\u7528\u6B64\u529F\u80FD\u3002",
  // ============================================================================
  // Commands - Session Export
  // ============================================================================
  "Export current session message history to a file": "\u5C06\u5F53\u524D\u4F1A\u8BDD\u7684\u6D88\u606F\u8BB0\u5F55\u5BFC\u51FA\u5230\u6587\u4EF6",
  "Export session to HTML format": "\u5C06\u4F1A\u8BDD\u5BFC\u51FA\u4E3A HTML \u6587\u4EF6",
  "Export session to JSON format": "\u5C06\u4F1A\u8BDD\u5BFC\u51FA\u4E3A JSON \u6587\u4EF6",
  "Export session to JSONL format (one message per line)": "\u5C06\u4F1A\u8BDD\u5BFC\u51FA\u4E3A JSONL \u6587\u4EF6\uFF08\u6BCF\u884C\u4E00\u6761\u6D88\u606F\uFF09",
  "Export session to markdown format": "\u5C06\u4F1A\u8BDD\u5BFC\u51FA\u4E3A Markdown \u6587\u4EF6",
  // ============================================================================
  // Commands - Insights
  // ============================================================================
  "generate personalized programming insights from your chat history": "\u6839\u636E\u4F60\u7684\u804A\u5929\u8BB0\u5F55\u751F\u6210\u4E2A\u6027\u5316\u7F16\u7A0B\u6D1E\u5BDF",
  // ============================================================================
  // Commands - Session History
  // ============================================================================
  "Resume a previous session": "\u6062\u590D\u5148\u524D\u4F1A\u8BDD",
  "Fork the current conversation into a new session": "\u5C06\u5F53\u524D\u5BF9\u8BDD\u5206\u652F\u5230\u65B0\u4F1A\u8BDD",
  "Spawn a background agent that inherits the full conversation": "\u542F\u52A8\u7EE7\u627F\u5B8C\u6574\u5BF9\u8BDD\u7684\u540E\u53F0\u667A\u80FD\u4F53",
  "Please provide a directive. Usage: /fork <directive>": "\u8BF7\u63D0\u4F9B\u6307\u4EE4\u3002\u7528\u6CD5\uFF1A/fork <\u6307\u4EE4>",
  "Cannot fork while a response or tool call is in progress. Wait for it to finish or resolve the pending tool call.": "\u54CD\u5E94\u6216\u5DE5\u5177\u8C03\u7528\u6B63\u5728\u8FDB\u884C\u65F6\u65E0\u6CD5\u5206\u652F\u3002\u8BF7\u7B49\u5F85\u5176\u5B8C\u6210\u6216\u5904\u7406\u5F85\u786E\u8BA4\u7684\u5DE5\u5177\u8C03\u7528\u3002",
  "Cannot fork before the first conversation turn.": "\u9996\u6B21\u5BF9\u8BDD\u8F6E\u6B21\u524D\u65E0\u6CD5\u5206\u652F\u3002",
  "The agent tool is unavailable; cannot fork.": "Agent \u5DE5\u5177\u4E0D\u53EF\u7528\uFF1B\u65E0\u6CD5\u5206\u652F\u3002",
  "Failed to launch fork: {{error}}": "\u542F\u52A8\u5206\u652F\u5931\u8D25\uFF1A{{error}}",
  "the background agent could not be started.": "\u540E\u53F0\u667A\u80FD\u4F53\u65E0\u6CD5\u542F\u52A8\u3002",
  "User launched a background fork via /fork: {{directive}}": "\u7528\u6237\u901A\u8FC7 /fork \u542F\u52A8\u4E86\u540E\u53F0\u5206\u652F\uFF1A{{directive}}",
  "Forked into a background agent. It inherits this conversation and runs without blocking \u2014 track it in the background tasks panel; it reports back when done.": "\u5DF2\u5206\u652F\u5230\u540E\u53F0\u667A\u80FD\u4F53\u3002\u5B83\u4F1A\u7EE7\u627F\u6B64\u5BF9\u8BDD\u5E76\u4EE5\u975E\u963B\u585E\u65B9\u5F0F\u8FD0\u884C\uFF0C\u53EF\u5728\u540E\u53F0\u4EFB\u52A1\u9762\u677F\u4E2D\u8DDF\u8E2A\uFF1B\u5B8C\u6210\u540E\u4F1A\u56DE\u62A5\u7ED3\u679C\u3002",
  "Cannot branch while a response or tool call is in progress. Wait for it to finish or resolve the pending tool call.": "\u54CD\u5E94\u6216\u5DE5\u5177\u8C03\u7528\u6B63\u5728\u8FDB\u884C\u65F6\u65E0\u6CD5\u5206\u652F\u3002\u8BF7\u7B49\u5F85\u5176\u5B8C\u6210\u6216\u5904\u7406\u5F85\u786E\u8BA4\u7684\u5DE5\u5177\u8C03\u7528\u3002",
  "No conversation to branch.": "\u6CA1\u6709\u53EF\u5206\u652F\u7684\u5BF9\u8BDD\u3002",
  "Restore a tool call. This will reset the conversation and file history to the state it was in when the tool call was suggested": "\u6062\u590D\u67D0\u6B21\u5DE5\u5177\u8C03\u7528\u3002\u8FD9\u5C06\u628A\u5BF9\u8BDD\u4E0E\u6587\u4EF6\u5386\u53F2\u91CD\u7F6E\u5230\u63D0\u51FA\u8BE5\u5DE5\u5177\u8C03\u7528\u5EFA\u8BAE\u65F6\u7684\u72B6\u6001",
  "Could not detect terminal type. Supported terminals: VS Code, Cursor, Windsurf, and Trae.": "\u65E0\u6CD5\u68C0\u6D4B\u7EC8\u7AEF\u7C7B\u578B\u3002\u652F\u6301\u7684\u7EC8\u7AEF\uFF1AVS Code\u3001Cursor\u3001Windsurf \u548C Trae\u3002",
  'Terminal "{{terminal}}" is not supported yet.': '\u7EC8\u7AEF "{{terminal}}" \u5C1A\u672A\u652F\u6301\u3002',
  // ============================================================================
  // Commands - Language
  // ============================================================================
  "Invalid language. Available: {{options}}": "\u65E0\u6548\u7684\u8BED\u8A00\u3002\u53EF\u7528\u9009\u9879\uFF1A{{options}}",
  "Language subcommands do not accept additional arguments.": "\u8BED\u8A00\u5B50\u547D\u4EE4\u4E0D\u63A5\u53D7\u989D\u5916\u53C2\u6570",
  "Current UI language: {{lang}}": "\u5F53\u524D UI \u8BED\u8A00\uFF1A{{lang}}",
  "Current LLM output language: {{lang}}": "\u5F53\u524D LLM \u8F93\u51FA\u8BED\u8A00\uFF1A{{lang}}",
  "Set UI language": "\u8BBE\u7F6E UI \u8BED\u8A00",
  "Set LLM output language": "\u8BBE\u7F6E LLM \u8F93\u51FA\u8BED\u8A00",
  "Usage: /language ui [{{options}}]": "\u7528\u6CD5\uFF1A/language ui [{{options}}]",
  "Usage: /language output <language>": "\u7528\u6CD5\uFF1A/language output <\u8BED\u8A00>",
  "Example: /language output \u4E2D\u6587": "\u793A\u4F8B\uFF1A/language output \u4E2D\u6587",
  "Example: /language output English": "\u793A\u4F8B\uFF1A/language output English",
  "Example: /language output \u65E5\u672C\u8A9E": "\u793A\u4F8B\uFF1A/language output \u65E5\u672C\u8A9E",
  "UI language changed to {{lang}}": "UI \u8BED\u8A00\u5DF2\u66F4\u6539\u4E3A {{lang}}",
  "LLM output language set to {{lang}}": "LLM \u8F93\u51FA\u8BED\u8A00\u5DF2\u8BBE\u7F6E\u4E3A {{lang}}",
  "Please restart the application for the changes to take effect.": "\u8BF7\u91CD\u542F\u5E94\u7528\u7A0B\u5E8F\u4EE5\u4F7F\u66F4\u6539\u751F\u6548\u3002",
  "Failed to generate LLM output language rule file: {{error}}": "\u751F\u6210 LLM \u8F93\u51FA\u8BED\u8A00\u89C4\u5219\u6587\u4EF6\u5931\u8D25\uFF1A{{error}}",
  "Invalid command. Available subcommands:": "\u65E0\u6548\u7684\u547D\u4EE4\u3002\u53EF\u7528\u7684\u5B50\u547D\u4EE4\uFF1A",
  "Available subcommands:": "\u53EF\u7528\u7684\u5B50\u547D\u4EE4\uFF1A",
  "To request additional UI language packs, please open an issue on GitHub.": "\u5982\u9700\u8BF7\u6C42\u5176\u4ED6 UI \u8BED\u8A00\u5305\uFF0C\u8BF7\u5728 GitHub \u4E0A\u63D0\u4EA4 issue",
  "Available options:": "\u53EF\u7528\u9009\u9879\uFF1A",
  "Set UI language to {{name}}": "\u5C06 UI \u8BED\u8A00\u8BBE\u7F6E\u4E3A {{name}}",
  // ============================================================================
  // Commands - Approval Mode
  // ============================================================================
  "Tool Approval Mode": "\u5DE5\u5177\u5BA1\u6279\u6A21\u5F0F",
  "Analyze only, do not modify files or execute commands": "\u4EC5\u5206\u6790\uFF0C\u4E0D\u4FEE\u6539\u6587\u4EF6\u6216\u6267\u884C\u547D\u4EE4",
  "Require approval for file edits or shell commands": "\u9700\u8981\u6279\u51C6\u6587\u4EF6\u7F16\u8F91\u6216 shell \u547D\u4EE4",
  "Automatically approve file edits": "\u81EA\u52A8\u6279\u51C6\u6587\u4EF6\u7F16\u8F91",
  "Use classifier to automatically approve safe tool calls": "\u4F7F\u7528\u5206\u7C7B\u5668\u81EA\u52A8\u6279\u51C6\u5B89\u5168\u7684\u5DE5\u5177\u8C03\u7528",
  "Automatically approve all tools": "\u81EA\u52A8\u6279\u51C6\u6240\u6709\u5DE5\u5177",
  "Workspace approval mode exists and takes priority. User-level change will have no effect.": "\u5DE5\u4F5C\u533A\u5BA1\u6279\u6A21\u5F0F\u5DF2\u5B58\u5728\u5E76\u5177\u6709\u4F18\u5148\u7EA7\u3002\u7528\u6237\u7EA7\u522B\u7684\u66F4\u6539\u5C06\u65E0\u6548\u3002",
  "Apply To": "\u5E94\u7528\u4E8E",
  "Workspace Settings": "\u5DE5\u4F5C\u533A\u8BBE\u7F6E",
  "Open auto-memory folder": "\u6253\u5F00\u81EA\u52A8\u8BB0\u5FC6\u6587\u4EF6\u5939",
  "Auto-memory: {{status}}": "\u81EA\u52A8\u8BB0\u5FC6\uFF1A{{status}}",
  "Auto-dream: {{status}} \xB7 {{lastDream}} \xB7 /dream to run": "\u81EA\u52A8\u6574\u7406\uFF1A{{status}} \xB7 {{lastDream}} \xB7 /dream \u7ACB\u5373\u8FD0\u884C",
  "Auto-skill: {{status}}": "\u81EA\u52A8\u6280\u80FD\uFF1A{{status}}",
  never: "\u4ECE\u672A",
  on: "\u5F00",
  off: "\u5173",
  "Remove matching entries from managed auto-memory.": "\u4ECE\u6258\u7BA1\u81EA\u52A8\u8BB0\u5FC6\u4E2D\u5220\u9664\u5339\u914D\u7684\u6761\u76EE\u3002",
  "Usage: /forget <memory text to remove>": "\u7528\u6CD5\uFF1A/forget <\u8981\u5220\u9664\u7684\u8BB0\u5FC6\u6587\u672C>",
  "No managed auto-memory entries matched: {{query}}": "\u6CA1\u6709\u5339\u914D\u7684\u6258\u7BA1\u81EA\u52A8\u8BB0\u5FC6\u6761\u76EE\uFF1A{{query}}",
  "Consolidate managed auto-memory topic files.": "\u6574\u7406\u6258\u7BA1\u81EA\u52A8\u8BB0\u5FC6\u4E3B\u9898\u6587\u4EF6",
  "Import MCP servers from Claude configs": "\u4ECE Claude \u914D\u7F6E\u5BFC\u5165 MCP \u670D\u52A1\u5668",
  "Open MCP management dialog": "\u6253\u5F00 MCP \u7BA1\u7406\u5BF9\u8BDD\u6846",
  "Could not retrieve tool registry.": "\u65E0\u6CD5\u68C0\u7D22\u5DE5\u5177\u6CE8\u518C\u8868",
  "Successfully authenticated and refreshed tools for '{{name}}'.": "\u6210\u529F\u8BA4\u8BC1\u5E76\u5237\u65B0\u4E86 '{{name}}' \u7684\u5DE5\u5177",
  "Re-discovering tools from '{{name}}'...": "\u6B63\u5728\u91CD\u65B0\u53D1\u73B0 '{{name}}' \u7684\u5DE5\u5177...",
  "Discovered {{count}} tool(s) from '{{name}}'.": "\u4ECE '{{name}}' \u53D1\u73B0\u4E86 {{count}} \u4E2A\u5DE5\u5177\u3002",
  "Authentication complete. Returning to server details...": "\u8BA4\u8BC1\u5B8C\u6210\uFF0C\u6B63\u5728\u8FD4\u56DE\u670D\u52A1\u5668\u8BE6\u60C5...",
  "Authentication successful.": "\u8BA4\u8BC1\u6210\u529F\u3002",
  // ============================================================================
  // MCP Management Dialog
  // ============================================================================
  "Manage MCP servers": "\u7BA1\u7406 MCP servers",
  "Server Detail": "\u670D\u52A1\u5668\u8BE6\u60C5",
  Tools: "\u5DE5\u5177",
  "Tool Detail": "\u5DE5\u5177\u8BE6\u60C5",
  "Loading...": "\u52A0\u8F7D\u4E2D...",
  "Unknown step": "\u672A\u77E5\u6B65\u9AA4",
  "Esc to back": "Esc \u8FD4\u56DE",
  "\u2191\u2193 to navigate \xB7 Enter to select \xB7 Esc to close": "\u2191\u2193 \u5BFC\u822A \xB7 Enter \u9009\u62E9 \xB7 Esc \u5173\u95ED",
  "\u2191\u2193 to navigate \xB7 Enter to select \xB7 Esc to back": "\u2191\u2193 \u5BFC\u822A \xB7 Enter \u9009\u62E9 \xB7 Esc \u8FD4\u56DE",
  "\u2191\u2193 to navigate \xB7 Enter to confirm \xB7 Esc to back": "\u2191\u2193 \u5BFC\u822A \xB7 Enter \u786E\u8BA4 \xB7 Esc \u8FD4\u56DE",
  "User Settings (global)": "\u7528\u6237\u8BBE\u7F6E\uFF08\u5168\u5C40\uFF09",
  "Workspace Settings (project-specific)": "\u5DE5\u4F5C\u533A\u8BBE\u7F6E\uFF08\u9879\u76EE\u7EA7\uFF09",
  "Disable server:": "\u7981\u7528\u670D\u52A1\u5668\uFF1A",
  "Select where to add the server to the exclude list:": "\u9009\u62E9\u5C06\u670D\u52A1\u5668\u6DFB\u52A0\u5230\u6392\u9664\u5217\u8868\u7684\u4F4D\u7F6E\uFF1A",
  "Press Enter to confirm, Esc to cancel": "\u6309 Enter \u786E\u8BA4\uFF0CEsc \u53D6\u6D88",
  "View tools": "\u67E5\u770B\u5DE5\u5177",
  "View resources": "\u67E5\u770B\u8D44\u6E90",
  Reconnect: "\u91CD\u65B0\u8FDE\u63A5",
  Enable: "\u542F\u7528",
  Disable: "\u7981\u7528",
  Authenticate: "\u8BA4\u8BC1",
  "Re-authenticate": "\u91CD\u65B0\u8BA4\u8BC1",
  "Clear Authentication": "\u6E05\u7A7A\u8BA4\u8BC1",
  disabled: "\u5DF2\u7981\u7528",
  enabled: "\u5DF2\u542F\u7528",
  "Server:": "\u670D\u52A1\u5668\uFF1A",
  "Error:": "\u9519\u8BEF\uFF1A",
  tool: "\u5DE5\u5177",
  tools: "\u4E2A\u5DE5\u5177",
  resource: "\u8D44\u6E90",
  resources: "\u4E2A\u8D44\u6E90",
  connected: "\u5DF2\u8FDE\u63A5",
  connecting: "\u8FDE\u63A5\u4E2D",
  disconnected: "\u5DF2\u65AD\u5F00",
  "needs authentication": "\u9700\u8981\u8BA4\u8BC1",
  // MCP Server List
  "User MCPs": "\u7528\u6237 MCP",
  "Project MCPs": "\u9879\u76EE MCP",
  "Extension MCPs": "\u6269\u5C55 MCP",
  server: "\u4E2A\u670D\u52A1\u5668",
  servers: "\u4E2A\u670D\u52A1\u5668",
  "Add MCP servers to your settings to get started.": "\u8BF7\u5728\u8BBE\u7F6E\u4E2D\u6DFB\u52A0 MCP servers \u4EE5\u5F00\u59CB\u4F7F\u7528\u3002",
  "Run qwen --debug to see error logs": "\u8FD0\u884C qwen --debug \u67E5\u770B\u9519\u8BEF\u65E5\u5FD7",
  // MCP OAuth Authentication
  "OAuth Authentication": "OAuth \u8BA4\u8BC1",
  "Authenticating... Please complete the login in your browser.": "\u8BA4\u8BC1\u4E2D... \u8BF7\u5728\u6D4F\u89C8\u5668\u4E2D\u5B8C\u6210\u767B\u5F55\u3002",
  "Press c to copy the authorization URL to your clipboard.": "\u6309 c \u590D\u5236\u6388\u6743 URL \u5230\u526A\u8D34\u677F\u3002",
  "Copy request sent to your terminal. If paste is empty, copy the URL above manually.": "\u5DF2\u5411\u7EC8\u7AEF\u53D1\u9001\u590D\u5236\u8BF7\u6C42\uFF1B\u82E5\u7C98\u8D34\u4E3A\u7A7A\uFF0C\u8BF7\u624B\u52A8\u590D\u5236\u4E0A\u65B9 URL\u3002",
  "Cannot write to terminal \u2014 copy the URL above manually.": "\u65E0\u6CD5\u5199\u5165\u7EC8\u7AEF\uFF0C\u8BF7\u624B\u52A8\u590D\u5236\u4E0A\u65B9 URL\u3002",
  // MCP Server Detail
  "Command:": "\u547D\u4EE4\uFF1A",
  "Working Directory:": "\u5DE5\u4F5C\u76EE\u5F55\uFF1A",
  "No server selected": "\u672A\u9009\u62E9\u670D\u52A1\u5668",
  prompts: "\u63D0\u793A",
  // MCP Tool List
  "No tools available for this server.": "\u6B64\u670D\u52A1\u5668\u6CA1\u6709\u53EF\u7528\u5DE5\u5177\u3002",
  destructive: "\u7834\u574F\u6027",
  "read-only": "\u53EA\u8BFB",
  "open-world": "\u5F00\u653E\u4E16\u754C",
  idempotent: "\u5E42\u7B49",
  "Tools for {{serverName}}": "{{serverName}} \u7684\u5DE5\u5177",
  "{{current}}/{{total}}": "{{current}}/{{total}}",
  // MCP Tool Detail
  required: "\u5FC5\u9700",
  Parameters: "\u53C2\u6570",
  "No tool selected": "\u672A\u9009\u62E9\u5DE5\u5177",
  Server: "\u670D\u52A1\u5668",
  // MCP Resource List/Detail
  "No resources available for this server.": "\u6B64\u670D\u52A1\u5668\u6CA1\u6709\u53EF\u7528\u8D44\u6E90\u3002",
  "Resources for {{serverName}}": "{{serverName}} \u7684\u8D44\u6E90",
  "No resource selected": "\u672A\u9009\u62E9\u8D44\u6E90",
  "Resource Detail": "\u8D44\u6E90\u8BE6\u60C5",
  "URI:": "URI\uFF1A",
  "MIME Type:": "MIME \u7C7B\u578B\uFF1A",
  "Size:": "\u5927\u5C0F\uFF1A",
  "{{count}} bytes": "{{count}} \u5B57\u8282",
  "Reference in chat": "\u5728\u5BF9\u8BDD\u4E2D\u5F15\u7528",
  "MCP server": "MCP \u670D\u52A1\u5668",
  "MCP resource server": "MCP \u8D44\u6E90\u670D\u52A1\u5668",
  // Invalid tool related translations
  "{{count}} invalid tools": "{{count}} \u4E2A\u65E0\u6548\u5DE5\u5177",
  invalid: "\u65E0\u6548",
  "invalid: {{reason}}": "\u65E0\u6548\uFF1A{{reason}}",
  "missing name": "\u7F3A\u5C11\u540D\u79F0",
  "missing description": "\u7F3A\u5C11\u63CF\u8FF0",
  "(unnamed)": "(\u672A\u547D\u540D)",
  "Warning: This tool cannot be called by the LLM": "\u8B66\u544A\uFF1A\u6B64\u5DE5\u5177\u65E0\u6CD5\u88AB LLM \u8C03\u7528",
  Reason: "\u539F\u56E0",
  "Tools must have both name and description to be used by the LLM.": "\u5DE5\u5177\u5FC5\u987B\u540C\u65F6\u5177\u6709\u540D\u79F0\u548C\u63CF\u8FF0\u624D\u80FD\u88AB LLM \u4F7F\u7528\u3002",
  // ===========================================================
  // Commands - Summary
  // ============================================================================
  "Generate a project summary and save it to .qwen/PROJECT_SUMMARY.md": "\u751F\u6210\u9879\u76EE\u6458\u8981\u5E76\u4FDD\u5B58\u5230 .qwen/PROJECT_SUMMARY.md",
  "No chat client available to generate summary.": "\u6CA1\u6709\u53EF\u7528\u7684\u804A\u5929\u5BA2\u6237\u7AEF\u6765\u751F\u6210\u6458\u8981",
  "Already generating summary, wait for previous request to complete": "\u6B63\u5728\u751F\u6210\u6458\u8981\uFF0C\u8BF7\u7B49\u5F85\u4E0A\u4E00\u4E2A\u8BF7\u6C42\u5B8C\u6210",
  "No conversation found to summarize.": "\u672A\u627E\u5230\u8981\u603B\u7ED3\u7684\u5BF9\u8BDD",
  "Failed to generate project context summary: {{error}}": "\u751F\u6210\u9879\u76EE\u4E0A\u4E0B\u6587\u6458\u8981\u5931\u8D25\uFF1A{{error}}",
  "Saved project summary to {{filePathForDisplay}}.": "\u9879\u76EE\u6458\u8981\u5DF2\u4FDD\u5B58\u5230 {{filePathForDisplay}}",
  "Saving project summary...": "\u6B63\u5728\u4FDD\u5B58\u9879\u76EE\u6458\u8981...",
  "Generating project summary...": "\u6B63\u5728\u751F\u6210\u9879\u76EE\u6458\u8981...",
  "Processing summary...": "\u6B63\u5728\u5904\u7406\u6458\u8981...",
  "Project summary generated and saved successfully!": "\u9879\u76EE\u6458\u8981\u5DF2\u751F\u6210\u5E76\u6210\u529F\u4FDD\u5B58\uFF01",
  "Saved to: {{filePath}}": "\u4FDD\u5B58\u81F3\uFF1A{{filePath}}",
  "Failed to generate summary - no text content received from LLM response": "\u751F\u6210\u6458\u8981\u5931\u8D25 - \u672A\u4ECE LLM \u54CD\u5E94\u4E2D\u63A5\u6536\u5230\u6587\u672C\u5185\u5BB9",
  // ============================================================================
  // Commands - Model
  // ============================================================================
  "Switch the model for this session (--fast for suggestion model, [model-id] to switch immediately).": "\u5207\u6362\u6B64\u4F1A\u8BDD\u7684\u6A21\u578B\uFF08--fast \u53EF\u8BBE\u7F6E\u5EFA\u8BAE\u6A21\u578B\uFF09",
  "Switch the model for this session (--fast for suggestion model, --voice for voice transcription model, [model-id] to switch immediately).": "\u5207\u6362\u6B64\u4F1A\u8BDD\u7684\u6A21\u578B\uFF08--fast \u53EF\u8BBE\u7F6E\u5EFA\u8BAE\u6A21\u578B\uFF0C--voice \u53EF\u8BBE\u7F6E\u8BED\u97F3\u8F6C\u5199\u6A21\u578B\uFF0C[model-id] \u53EF\u7ACB\u5373\u5207\u6362\uFF09",
  "Switch the model for this session (--fast for suggestion model, --voice for voice transcription model, --vision for the vision bridge model, --project to persist to project settings, --global to persist to user settings, [model-id] to switch immediately, or [model-id] [prompt] to run a one-off prompt on another model; the inline prompt is sent verbatim without @file expansion).": "\u5207\u6362\u6B64\u4F1A\u8BDD\u7684\u6A21\u578B\uFF08--fast \u5EFA\u8BAE\u6A21\u578B\uFF0C--voice \u8BED\u97F3\u8F6C\u5199\u6A21\u578B\uFF0C--vision \u89C6\u89C9\u6865\u63A5\u6A21\u578B\uFF0C--project \u6301\u4E45\u5316\u5230\u9879\u76EE\u8BBE\u7F6E\uFF0C--global \u6301\u4E45\u5316\u5230\u7528\u6237\u8BBE\u7F6E\uFF0C[model-id] \u7ACB\u5373\u5207\u6362\uFF0C\u6216\u7528 [model-id] [prompt] \u5728\u53E6\u4E00\u4E2A\u6A21\u578B\u4E0A\u8FD0\u884C\u4E00\u6B21\u6027\u63D0\u793A\uFF1B\u5185\u8054\u63D0\u793A\u6309\u539F\u6587\u53D1\u9001\uFF0C\u4E0D\u5C55\u5F00 @file\uFF09",
  "Switch the model for this session (--fast for suggestion model, --voice for voice transcription model, --vision for the vision bridge model, --compaction for chat compression model, --image for the image generation model, --project to persist to project settings, --global to persist to user settings, [model-id] to switch immediately, or [model-id] [prompt] to run a one-off prompt on another model; the inline prompt is sent verbatim without @file expansion).": "\u5207\u6362\u6B64\u4F1A\u8BDD\u7684\u6A21\u578B\uFF08--fast \u5EFA\u8BAE\u6A21\u578B\uFF0C--voice \u8BED\u97F3\u8F6C\u5199\u6A21\u578B\uFF0C--vision \u89C6\u89C9\u6865\u63A5\u6A21\u578B\uFF0C--compaction \u804A\u5929\u538B\u7F29\u6A21\u578B\uFF0C--image \u56FE\u50CF\u751F\u6210\u6A21\u578B\uFF0C--project \u6301\u4E45\u5316\u5230\u9879\u76EE\u8BBE\u7F6E\uFF0C--global \u6301\u4E45\u5316\u5230\u7528\u6237\u8BBE\u7F6E\uFF0C[model-id] \u7ACB\u5373\u5207\u6362\uFF0C\u6216\u7528 [model-id] [prompt] \u5728\u53E6\u4E00\u4E2A\u6A21\u578B\u4E0A\u8FD0\u884C\u4E00\u6B21\u6027\u63D0\u793A\uFF1B\u5185\u8054\u63D0\u793A\u6309\u539F\u6587\u53D1\u9001\uFF0C\u4E0D\u5C55\u5F00 @file\uFF09",
  "Inline one-shot override isn't supported in this mode \u2014 run '/model {{model}}' first, then send your prompt.": "\u6B64\u6A21\u5F0F\u4E0D\u652F\u6301\u5185\u8054\u4E00\u6B21\u6027\u8986\u76D6\u2014\u2014\u8BF7\u5148\u8FD0\u884C '/model {{model}}'\uFF0C\u518D\u53D1\u9001\u4F60\u7684\u63D0\u793A\u3002",
  "Inline one-shot override can't switch providers. '{{model}}' belongs to a different provider \u2014 run '/model {{model}}' first, then send your prompt.": "\u5185\u8054\u4E00\u6B21\u6027\u8986\u76D6\u65E0\u6CD5\u5207\u6362 provider\u3002'{{model}}' \u5C5E\u4E8E\u53E6\u4E00\u4E2A provider\u2014\u2014\u8BF7\u5148\u8FD0\u884C '/model {{model}}'\uFF0C\u518D\u53D1\u9001\u4F60\u7684\u63D0\u793A\u3002",
  "\u26A0 '{{model}}' is not a known image-capable model; the vision bridge may fail on images.": "\u26A0 '{{model}}' \u4E0D\u662F\u5DF2\u77E5\u7684\u56FE\u50CF\u80FD\u529B\u6A21\u578B\uFF1B\u89C6\u89C9\u6865\u63A5\u5904\u7406\u56FE\u7247\u65F6\u53EF\u80FD\u4F1A\u5931\u8D25\u3002",
  "Set a lighter model for prompt suggestions and speculative execution": "\u8BBE\u7F6E\u7528\u4E8E\u8F93\u5165\u5EFA\u8BAE\u548C\u63A8\u6D4B\u6267\u884C\u7684\u8F7B\u91CF\u6A21\u578B",
  "Toggle voice dictation input": "\u5207\u6362\u8BED\u97F3\u542C\u5199\u8F93\u5165",
  "Set the model for voice transcription": "\u8BBE\u7F6E\u8BED\u97F3\u8F6C\u5199\u6A21\u578B",
  "Set the image-capable model used to transcribe images for a text-only main model": "\u8BBE\u7F6E\u7528\u4E8E\u4E3A\u7EAF\u6587\u672C\u4E3B\u6A21\u578B\u8F6C\u5199\u56FE\u50CF\u7684\u56FE\u50CF\u80FD\u529B\u6A21\u578B",
  "Set the model used to generate images": "\u8BBE\u7F6E\u7528\u4E8E\u751F\u6210\u56FE\u50CF\u7684\u6A21\u578B",
  "Set the model used for chat compression (auto-compaction)": "\u8BBE\u7F6E\u7528\u4E8E\u804A\u5929\u538B\u7F29\uFF08\u81EA\u52A8\u538B\u7F29\uFF09\u7684\u6A21\u578B",
  "Persist the model selection to the project settings (workspace scope)": "\u5C06\u6A21\u578B\u9009\u62E9\u6301\u4E45\u5316\u5230\u9879\u76EE\u8BBE\u7F6E\uFF08\u5DE5\u4F5C\u533A\uFF09",
  "Persist the model selection to the user settings (global scope)": "\u5C06\u6A21\u578B\u9009\u62E9\u6301\u4E45\u5316\u5230\u7528\u6237\u8BBE\u7F6E\uFF08\u5168\u5C40\uFF09",
  "Select Fast Model": "\u9009\u62E9\u5FEB\u901F\u6A21\u578B",
  "Select Vision Model": "\u9009\u62E9\u89C6\u89C9\u6A21\u578B",
  "Select Image Model": "\u9009\u62E9\u56FE\u50CF\u6A21\u578B",
  "Select Compaction Model": "\u9009\u62E9\u538B\u7F29\u6A21\u578B",
  "Select Voice Model": "\u9009\u62E9\u8BED\u97F3\u6A21\u578B",
  "Vision Model": "\u89C6\u89C9\u6A21\u578B",
  "Image Model": "\u56FE\u50CF\u6A21\u578B",
  "Compaction Model": "\u538B\u7F29\u6A21\u578B",
  "Selected compaction model is unavailable.": "\u6240\u9009\u538B\u7F29\u6A21\u578B\u4E0D\u53EF\u7528\u3002",
  "Configure models in settings.modelProviders and ensure the required environment variables are set. In interactive mode, run /auth to configure or switch providers, or run /model --compaction without a model to choose from configured models.": "\u5728 settings.modelProviders \u4E2D\u914D\u7F6E\u6A21\u578B\u5E76\u786E\u4FDD\u8BBE\u7F6E\u4E86\u6240\u9700\u7684\u73AF\u5883\u53D8\u91CF\u3002\u5728\u4EA4\u4E92\u6A21\u5F0F\u4E0B\uFF0C\u8FD0\u884C /auth \u914D\u7F6E\u6216\u5207\u6362 provider\uFF0C\u6216\u8FD0\u884C /model --compaction\uFF08\u4E0D\u5E26\u6A21\u578B\u53C2\u6570\uFF09\u4ECE\u5DF2\u914D\u7F6E\u7684\u6A21\u578B\u4E2D\u9009\u62E9\u3002",
  "Voice Model": "\u8BED\u97F3\u6A21\u578B",
  "Selected voice model is unavailable.": "\u6240\u9009\u8BED\u97F3\u6A21\u578B\u4E0D\u53EF\u7528\u3002",
  "Selected image model is unavailable.": "\u6240\u9009\u56FE\u50CF\u6A21\u578B\u4E0D\u53EF\u7528\u3002",
  "Voice model '{{model}}' is configured more than once. Remove duplicate model ids before selecting it for voice transcription.": "\u8BED\u97F3\u6A21\u578B '{{model}}' \u88AB\u914D\u7F6E\u4E86\u591A\u6B21\u3002\u8BF7\u5148\u79FB\u9664\u91CD\u590D\u7684\u6A21\u578B ID\uFF0C\u518D\u5C06\u5176\u9009\u4E3A\u8BED\u97F3\u8F6C\u5199\u6A21\u578B\u3002",
  "Voice dictation: {{status}} (mode: {{mode}}, {{modelText}}).": "\u8BED\u97F3\u542C\u5199\uFF1A{{status}}\uFF08\u6A21\u5F0F\uFF1A{{mode}}\uFF0C{{modelText}}\uFF09\u3002",
  "model: {{voiceModel}}": "\u6A21\u578B\uFF1A{{voiceModel}}",
  "no voice model selected": "\u672A\u9009\u62E9\u8BED\u97F3\u6A21\u578B",
  "Voice dictation disabled.": "\u8BED\u97F3\u542C\u5199\u5DF2\u7981\u7528\u3002",
  "Usage: /voice [hold|tap|off|status]": "\u7528\u6CD5\uFF1A/voice [hold|tap|off|status]",
  "No voice model selected. Run /model --voice to choose one before enabling voice dictation.": "\u672A\u9009\u62E9\u8BED\u97F3\u6A21\u578B\u3002\u8BF7\u5148\u8FD0\u884C /model --voice \u9009\u62E9\u6A21\u578B\uFF0C\u518D\u542F\u7528\u8BED\u97F3\u542C\u5199\u3002",
  "Voice dictation enabled (tap mode). Tap Space at an empty prompt to start, tap again or pause to stop and submit, using {{voiceModel}}.": "\u8BED\u97F3\u542C\u5199\u5DF2\u542F\u7528\uFF08\u70B9\u51FB\u6A21\u5F0F\uFF09\u3002\u5728\u7A7A\u8F93\u5165\u6846\u4E2D\u70B9\u51FB Space \u5F00\u59CB\uFF0C\u518D\u70B9\u51FB\u4E00\u6B21\u6216\u505C\u987F\u540E\u505C\u6B62\u5E76\u63D0\u4EA4\uFF0C\u4F7F\u7528 {{voiceModel}}\u3002",
  "Voice dictation enabled (hold mode). Hold Space at an empty prompt to dictate with {{voiceModel}}.": "\u8BED\u97F3\u542C\u5199\u5DF2\u542F\u7528\uFF08\u6309\u4F4F\u6A21\u5F0F\uFF09\u3002\u5728\u7A7A\u8F93\u5165\u6846\u4E2D\u6309\u4F4F Space\uFF0C\u4F7F\u7528 {{voiceModel}} \u542C\u5199\u3002",
  "No models are configured.": "\u672A\u914D\u7F6E\u6A21\u578B\u3002",
  "Configured models: {{models}}.": "\u5DF2\u914D\u7F6E\u6A21\u578B\uFF1A{{models}}\u3002",
  "Configure a unique model id in settings.modelProviders or run /model --voice to select an available model.": "\u8BF7\u5728 settings.modelProviders \u4E2D\u914D\u7F6E\u552F\u4E00\u7684\u6A21\u578B ID\uFF0C\u6216\u8FD0\u884C /model --voice \u9009\u62E9\u53EF\u7528\u6A21\u578B\u3002",
  "Voice model '{{modelName}}' is not configured.": "\u8BED\u97F3\u6A21\u578B '{{modelName}}' \u672A\u914D\u7F6E\u3002",
  "Voice model '{{modelName}}' cannot be used for transcription.": "\u8BED\u97F3\u6A21\u578B '{{modelName}}' \u4E0D\u80FD\u7528\u4E8E\u8F6C\u5199\u3002",
  "Voice model '{{modelName}}' cannot be used for transcription. Configure an OpenAI-compatible model with baseUrl in settings.modelProviders.": "\u8BED\u97F3\u6A21\u578B '{{modelName}}' \u4E0D\u80FD\u7528\u4E8E\u8F6C\u5199\u3002\u8BF7\u5728 settings.modelProviders \u4E2D\u914D\u7F6E\u5E26 baseUrl \u7684 OpenAI \u517C\u5BB9\u6A21\u578B\u3002",
  "Configure an OpenAI-compatible model with baseUrl in settings.modelProviders.": "\u8BF7\u5728 settings.modelProviders \u4E2D\u914D\u7F6E\u5E26 baseUrl \u7684 OpenAI \u517C\u5BB9\u6A21\u578B\u3002",
  "Microphone access is denied. Enable it for your terminal in System Settings \u2192 Privacy & Security \u2192 Microphone, then restart voice dictation.": "\u9EA6\u514B\u98CE\u8BBF\u95EE\u88AB\u62D2\u7EDD\u3002\u8BF7\u5728\u7CFB\u7EDF\u8BBE\u7F6E \u2192 \u9690\u79C1\u4E0E\u5B89\u5168\u6027 \u2192 \u9EA6\u514B\u98CE\u4E2D\u5141\u8BB8\u5F53\u524D\u7EC8\u7AEF\u8BBF\u95EE\uFF0C\u7136\u540E\u91CD\u65B0\u542F\u52A8\u8BED\u97F3\u542C\u5199\u3002",
  "Voice dictation is not supported on {{platform}}.": "\u8BED\u97F3\u542C\u5199\u4E0D\u652F\u6301 {{platform}}\u3002",
  "Voice dictation needs microphone access, which is unavailable in this WSL session. Use WSLg/PulseAudio, or run Qwen Code on a host with a microphone.": "\u8BED\u97F3\u542C\u5199\u9700\u8981\u9EA6\u514B\u98CE\u8BBF\u95EE\uFF0C\u4F46\u5F53\u524D WSL \u4F1A\u8BDD\u4E0D\u53EF\u7528\u3002\u8BF7\u4F7F\u7528 WSLg/PulseAudio\uFF0C\u6216\u5728\u5E26\u9EA6\u514B\u98CE\u7684\u5BBF\u4E3B\u673A\u4E0A\u8FD0\u884C Qwen Code\u3002",
  "Voice dictation needs microphone access. macOS will ask the first time you record \u2014 approve it, then start again. Your first recording may be empty while the dialog is open.": "\u8BED\u97F3\u542C\u5199\u9700\u8981\u9EA6\u514B\u98CE\u8BBF\u95EE\u3002macOS \u4F1A\u5728\u4F60\u9996\u6B21\u5F55\u97F3\u65F6\u5F39\u51FA\u6388\u6743\u8BF7\u6C42\u2014\u2014\u8BF7\u540C\u610F\u540E\u91CD\u65B0\u5F00\u59CB\u3002\u5F39\u7A97\u6253\u5F00\u671F\u95F4\u7684\u9996\u6B21\u5F55\u97F3\u53EF\u80FD\u4E3A\u7A7A\u3002",
  "Voice: recording": "\u8BED\u97F3\uFF1A\u5F55\u97F3\u4E2D",
  "Voice: transcribing": "\u8BED\u97F3\uFF1A\u8F6C\u5199\u4E2D",
  "Voice: refining": "\u8BED\u97F3\uFF1A\u4F18\u5316\u4E2D",
  "listening\u2026": "\u8046\u542C\u4E2D\u2026",
  "transcribing\u2026": "\u8F6C\u5199\u4E2D\u2026",
  "refining\u2026": "\u4F18\u5316\u4E2D\u2026",
  "Content generator configuration not available.": "\u5185\u5BB9\u751F\u6210\u5668\u914D\u7F6E\u4E0D\u53EF\u7528",
  "Authentication type not available.": "\u8BA4\u8BC1\u7C7B\u578B\u4E0D\u53EF\u7528",
  "No models available for the current authentication type ({{authType}}).": "\u5F53\u524D\u8BA4\u8BC1\u7C7B\u578B ({{authType}}) \u6CA1\u6709\u53EF\u7528\u7684\u6A21\u578B",
  // Needs translation
  // ============================================================================
  // Commands - Clear
  // ============================================================================
  "Starting a new session, resetting chat, and clearing terminal.": "\u6B63\u5728\u5F00\u59CB\u65B0\u4F1A\u8BDD\uFF0C\u91CD\u7F6E\u804A\u5929\u5E76\u6E05\u5C4F\u3002",
  "Starting a new session and clearing.": "\u6B63\u5728\u5F00\u59CB\u65B0\u4F1A\u8BDD\u5E76\u6E05\u5C4F\u3002",
  // ============================================================================
  // Commands - Compress
  // ============================================================================
  "Already compressing, wait for previous request to complete": "\u6B63\u5728\u538B\u7F29\u4E2D\uFF0C\u8BF7\u7B49\u5F85\u4E0A\u4E00\u4E2A\u8BF7\u6C42\u5B8C\u6210",
  "Failed to compress chat history.": "\u538B\u7F29\u804A\u5929\u5386\u53F2\u5931\u8D25",
  "Failed to compress chat history: {{error}}": "\u538B\u7F29\u804A\u5929\u5386\u53F2\u5931\u8D25\uFF1A{{error}}",
  "Compressing chat history": "\u6B63\u5728\u538B\u7F29\u804A\u5929\u5386\u53F2",
  "Chat history compressed from {{originalTokens}} to {{newTokens}} tokens.": "\u804A\u5929\u5386\u53F2\u5DF2\u4ECE {{originalTokens}} \u4E2A token \u538B\u7F29\u5230 {{newTokens}} \u4E2A token\u3002",
  "Compression was not beneficial for this history size.": "\u5BF9\u4E8E\u6B64\u5386\u53F2\u8BB0\u5F55\u5927\u5C0F\uFF0C\u538B\u7F29\u6CA1\u6709\u76CA\u5904\u3002",
  "Chat history compression did not reduce size. This may indicate issues with the compression prompt.": "\u804A\u5929\u5386\u53F2\u538B\u7F29\u672A\u80FD\u51CF\u5C0F\u5927\u5C0F\u3002\u8FD9\u53EF\u80FD\u8868\u660E\u538B\u7F29\u63D0\u793A\u5B58\u5728\u95EE\u9898\u3002",
  "Could not compress chat history due to a token counting error.": "\u7531\u4E8E token \u8BA1\u6570\u9519\u8BEF\uFF0C\u65E0\u6CD5\u538B\u7F29\u804A\u5929\u5386\u53F2\u3002",
  // ============================================================================
  // Commands - Directory
  // ============================================================================
  "Configuration is not available.": "\u914D\u7F6E\u4E0D\u53EF\u7528\u3002",
  "Please provide at least one path to add.": "\u8BF7\u63D0\u4F9B\u81F3\u5C11\u4E00\u4E2A\u8981\u6DFB\u52A0\u7684\u8DEF\u5F84\u3002",
  "The /directory add command is not supported in restrictive sandbox profiles. Please use --include-directories when starting the session instead.": "/directory add \u547D\u4EE4\u5728\u9650\u5236\u6027\u6C99\u7BB1\u914D\u7F6E\u6587\u4EF6\u4E2D\u4E0D\u53D7\u652F\u6301\u3002\u8BF7\u6539\u4E3A\u5728\u542F\u52A8\u4F1A\u8BDD\u65F6\u4F7F\u7528 --include-directories\u3002",
  "Error adding '{{path}}': {{error}}": "\u6DFB\u52A0 '{{path}}' \u65F6\u51FA\u9519\uFF1A{{error}}",
  "Successfully added QWEN.md files from the following directories if there are:\n- {{directories}}": "\u5982\u679C\u5B58\u5728\uFF0C\u5DF2\u6210\u529F\u4ECE\u4EE5\u4E0B\u76EE\u5F55\u6DFB\u52A0 QWEN.md \u6587\u4EF6\uFF1A\n- {{directories}}",
  "Error refreshing memory: {{error}}": "\u5237\u65B0\u5185\u5B58\u65F6\u51FA\u9519\uFF1A{{error}}",
  "Successfully added directories:\n- {{directories}}": "\u6210\u529F\u6DFB\u52A0\u76EE\u5F55\uFF1A\n- {{directories}}",
  "Current workspace directories:\n{{directories}}": "\u5F53\u524D\u5DE5\u4F5C\u533A\u76EE\u5F55\uFF1A\n{{directories}}",
  // ============================================================================
  // Commands - Docs
  // ============================================================================
  "Please open the following URL in your browser to view the documentation:\n{{url}}": "\u8BF7\u5728\u6D4F\u89C8\u5668\u4E2D\u6253\u5F00\u4EE5\u4E0B URL \u4EE5\u67E5\u770B\u6587\u6863\uFF1A\n{{url}}",
  "Opening documentation in your browser: {{url}}": "\u6B63\u5728\u6D4F\u89C8\u5668\u4E2D\u6253\u5F00\u6587\u6863\uFF1A{{url}}",
  // ============================================================================
  // Dialogs - Tool Confirmation
  // ============================================================================
  "Do you want to proceed?": "\u662F\u5426\u7EE7\u7EED\uFF1F",
  "Yes, allow once": "\u662F\uFF0C\u5141\u8BB8\u4E00\u6B21",
  "Allow always": "\u603B\u662F\u5141\u8BB8",
  Yes: "\u662F",
  No: "\u5426",
  "No (esc)": "\u5426 (esc)",
  "Modify in progress:": "\u6B63\u5728\u4FEE\u6539\uFF1A",
  "Save and close external editor to continue": "\u4FDD\u5B58\u5E76\u5173\u95ED\u5916\u90E8\u7F16\u8F91\u5668\u4EE5\u7EE7\u7EED",
  "Apply this change?": "\u662F\u5426\u5E94\u7528\u6B64\u66F4\u6539\uFF1F",
  "Yes, allow always": "\u662F\uFF0C\u603B\u662F\u5141\u8BB8",
  "Modify with external editor": "\u4F7F\u7528\u5916\u90E8\u7F16\u8F91\u5668\u4FEE\u6539",
  "No, suggest changes (esc)": "\u5426\uFF0C\u5EFA\u8BAE\u66F4\u6539 (esc)",
  "Allow execution of: '{{command}}'?": "\u5141\u8BB8\u6267\u884C\uFF1A'{{command}}'\uFF1F",
  "Always allow in this project": "\u5728\u672C\u9879\u76EE\u4E2D\u603B\u662F\u5141\u8BB8",
  "Always allow {{action}} in this project": "\u5728\u672C\u9879\u76EE\u4E2D\u603B\u662F\u5141\u8BB8{{action}}",
  "Always allow for this user": "\u5BF9\u8BE5\u7528\u6237\u603B\u662F\u5141\u8BB8",
  "Always allow {{action}} for this user": "\u5BF9\u8BE5\u7528\u6237\u603B\u662F\u5141\u8BB8{{action}}",
  "Yes, restore previous mode ({{mode}})": "\u662F\uFF0C\u6062\u590D\u4E4B\u524D\u7684\u6A21\u5F0F ({{mode}})",
  "Yes, and auto-accept edits": "\u662F\uFF0C\u5E76\u81EA\u52A8\u63A5\u53D7\u7F16\u8F91",
  "Yes, and manually approve edits": "\u662F\uFF0C\u5E76\u624B\u52A8\u6279\u51C6\u7F16\u8F91",
  "No, keep planning (esc)": "\u5426\uFF0C\u7EE7\u7EED\u89C4\u5212 (esc)",
  "URLs to fetch:": "\u8981\u83B7\u53D6\u7684 URL\uFF1A",
  "MCP Server: {{server}}": "MCP Server\uFF1A{{server}}",
  "Tool: {{tool}}": "\u5DE5\u5177\uFF1A{{tool}}",
  'Allow execution of MCP tool "{{tool}}" from server "{{server}}"?': '\u5141\u8BB8\u6267\u884C\u6765\u81EA MCP server "{{server}}" \u7684 MCP tool "{{tool}}"\uFF1F',
  // ============================================================================
  // Dialogs - Shell Confirmation
  // ============================================================================
  "Shell Command Execution": "Shell \u547D\u4EE4\u6267\u884C",
  "A custom command wants to run the following shell commands:": "\u81EA\u5B9A\u4E49\u547D\u4EE4\u60F3\u8981\u8FD0\u884C\u4EE5\u4E0B shell \u547D\u4EE4\uFF1A",
  // ============================================================================
  // Dialogs - Welcome Back
  // ============================================================================
  "Current Plan:": "\u5F53\u524D\u8BA1\u5212\uFF1A",
  "Progress: {{done}}/{{total}} tasks completed": "\u8FDB\u5EA6\uFF1A\u5DF2\u5B8C\u6210 {{done}}/{{total}} \u4E2A\u4EFB\u52A1",
  ", {{inProgress}} in progress": "\uFF0C{{inProgress}} \u4E2A\u8FDB\u884C\u4E2D",
  "Pending Tasks:": "\u5F85\u5904\u7406\u4EFB\u52A1\uFF1A",
  "What would you like to do?": "\u60A8\u60F3\u8981\u505A\u4EC0\u4E48\uFF1F",
  "Choose how to proceed with your session:": "\u9009\u62E9\u5982\u4F55\u7EE7\u7EED\u60A8\u7684\u4F1A\u8BDD\uFF1A",
  "Start new chat session": "\u5F00\u59CB\u65B0\u7684\u804A\u5929\u4F1A\u8BDD",
  "Continue previous conversation": "\u7EE7\u7EED\u4E4B\u524D\u7684\u5BF9\u8BDD",
  "Welcome back! (Last updated: {{timeAgo}})": "\u6B22\u8FCE\u56DE\u6765\uFF01\uFF08\u6700\u540E\u66F4\u65B0\uFF1A{{timeAgo}}\uFF09",
  "Overall Goal:": "\u603B\u4F53\u76EE\u6807\uFF1A",
  "Connect a Provider": "\u8FDE\u63A5\u670D\u52A1\u5546",
  "You must connect a provider to proceed. Press Ctrl+C again to exit.": "\u5FC5\u987B\u8FDE\u63A5\u4E00\u4E2A\u670D\u52A1\u5546\u624D\u80FD\u7EE7\u7EED\u3002\u518D\u6B21\u6309 Ctrl+C \u9000\u51FA",
  "Terms of Services and Privacy Notice": "\u670D\u52A1\u6761\u6B3E\u548C\u9690\u79C1\u58F0\u660E",
  "Qwen OAuth": "Qwen OAuth (\u514D\u8D39)",
  "Discontinued \u2014 switch to Coding Plan or API Key": "\u5DF2\u505C\u7528 \u2014 \u8BF7\u5207\u6362\u5230 Coding Plan \u6216 API Key",
  "Qwen OAuth free tier was discontinued on 2026-04-15. Please select Coding Plan or API Key instead.": "Qwen OAuth \u514D\u8D39\u989D\u5EA6\u5DF2\u4E8E 2026-04-15 \u505C\u7528\u3002\u8BF7\u9009\u62E9 Coding Plan \u6216 API Key\u3002",
  "Qwen OAuth free tier was discontinued on 2026-04-15. Please select a model from another provider or run /auth to switch.": "Qwen OAuth\u514D\u8D39\u5C42\u5DF2\u4E8E2026-04-15\u505C\u6B62\u670D\u52A1\u3002\u8BF7\u9009\u62E9\u5176\u4ED6\u63D0\u4F9B\u5546\u7684\u6A21\u578B\u6216\u8FD0\u884C /auth \u5207\u6362\u3002",
  "\n\u26A0 Qwen OAuth free tier was discontinued on 2026-04-15. Please select another option.\n": "\n\u26A0 Qwen OAuth \u514D\u8D39\u989D\u5EA6\u5DF2\u4E8E 2026-04-15 \u505C\u7528\u3002\u8BF7\u9009\u62E9\u5176\u4ED6\u9009\u9879\u3002\n",
  "Paid \xB7 Up to 6,000 requests/5 hrs \xB7 All Alibaba Cloud Coding Plan Models": "\u4ED8\u8D39 \xB7 \u6BCF 5 \u5C0F\u65F6\u6700\u591A 6,000 \u6B21\u8BF7\u6C42 \xB7 \u652F\u6301\u963F\u91CC\u4E91\u767E\u70BC Coding Plan \u5168\u90E8\u6A21\u578B",
  "For teams \xB7 Paid \xB7 Up to 6,000 requests/5 hrs \xB7 All Alibaba Cloud Coding Plan Models": "\u9002\u5408\u56E2\u961F \xB7 \u4ED8\u8D39 \xB7 \u6BCF 5 \u5C0F\u65F6\u6700\u591A 6,000 \u6B21\u8BF7\u6C42 \xB7 \u652F\u6301\u963F\u91CC\u4E91\u767E\u70BC Coding Plan \u5168\u90E8\u6A21\u578B",
  "For individual developers \xB7 Pay per model call \xB7 5-hour/weekly quotas": "\u9002\u5408\u4E2A\u4EBA\u5F00\u53D1\u573A\u666F \xB7 \u6309\u6A21\u578B\u8C03\u7528\u6B21\u6570\u8BA1\u8D39 \xB7 \u6BCF 5 \u5C0F\u65F6/\u6BCF\u5468\u9650\u989D",
  Subscribe: "\u8BA2\u9605\u8BA1\u5212",
  "Paid subscription plans from Alibaba Cloud ModelStudio": "Alibaba Cloud ModelStudio \u4ED8\u8D39\u8BA2\u9605\u8BA1\u5212",
  "Select Subscription Plan": "\u9009\u62E9\u8BA2\u9605\u8BA1\u5212",
  "Alibaba Cloud Coding Plan": "\u963F\u91CC\u4E91\u767E\u70BC Coding Plan",
  "Alibaba Cloud Token Plan": "\u963F\u91CC\u4E91\u767E\u70BC Token Plan",
  "Pay-as-you-go tokens \xB7 Configure ModelStudio standard API key": "\u6309 Token \u4ED8\u8D39 \xB7 \u914D\u7F6E ModelStudio \u6807\u51C6 API Key",
  "For individuals \xB7 Pay-as-you-go tokens \xB7 Dedicated Token Plan endpoint": "\u9002\u5408\u4E2A\u4EBA \xB7 \u6309 Token \u4ED8\u8D39 \xB7 \u4F7F\u7528\u72EC\u7ACB Token Plan Endpoint",
  "For teams/companies \xB7 Credits deducted by token usage \xB7 Dedicated API key and base URL": "\u9002\u5408\u4E00\u4EBA\u516C\u53F8/\u56E2\u961F/\u4F01\u4E1A \xB7 \u6309 Token \u6D88\u8017\u62B5\u6263 Credits \xB7 \u4E13\u5C5E API Key \u548C Base URL",
  "Token Plan documentation": "Token Plan \u53C2\u8003\u6587\u6863",
  "Bring your own API key": "\u4F7F\u7528\u81EA\u5DF1\u7684 API Key",
  "Browser-based authentication with third-party providers (e.g. OpenRouter, ModelScope)": "\u57FA\u4E8E\u6D4F\u89C8\u5668\u7684\u7B2C\u4E09\u65B9\u63D0\u4F9B\u5546\u8BA4\u8BC1\uFF08\u4F8B\u5982 OpenRouter\u3001ModelScope\uFF09",
  "Authentication is enforced to be {{enforcedType}}, but you are currently using {{currentType}}.": "\u8BA4\u8BC1\u65B9\u5F0F\u88AB\u5F3A\u5236\u8BBE\u7F6E\u4E3A {{enforcedType}}\uFF0C\u4F46\u60A8\u5F53\u524D\u4F7F\u7528\u7684\u662F {{currentType}}",
  "Qwen OAuth Authentication": "Qwen OAuth \u8BA4\u8BC1",
  "Please visit this URL to authorize:": "\u8BF7\u8BBF\u95EE\u6B64 URL \u8FDB\u884C\u6388\u6743\uFF1A",
  "Waiting for authorization": "\u7B49\u5F85\u6388\u6743\u4E2D",
  "Time remaining:": "\u5269\u4F59\u65F6\u95F4\uFF1A",
  "Qwen OAuth Authentication Timeout": "Qwen OAuth \u8BA4\u8BC1\u8D85\u65F6",
  "OAuth token expired (over {{seconds}} seconds). Please select authentication method again.": "OAuth token \u5DF2\u8FC7\u671F\uFF08\u8D85\u8FC7 {{seconds}} \u79D2\uFF09\u3002\u8BF7\u91CD\u65B0\u9009\u62E9\u8BA4\u8BC1\u65B9\u6CD5",
  "Press any key to return to authentication type selection.": "\u6309\u4EFB\u610F\u952E\u8FD4\u56DE\u8BA4\u8BC1\u7C7B\u578B\u9009\u62E9",
  "Waiting for Qwen OAuth authentication...": "\u6B63\u5728\u7B49\u5F85 Qwen OAuth \u8BA4\u8BC1...",
  "Authentication timed out. Please try again.": "\u8BA4\u8BC1\u8D85\u65F6\u3002\u8BF7\u91CD\u8BD5\u3002",
  "Waiting for auth... (Press ESC or CTRL+C to cancel)": "\u6B63\u5728\u7B49\u5F85\u8BA4\u8BC1...\uFF08\u6309 ESC \u6216 CTRL+C \u53D6\u6D88\uFF09",
  "Missing API key for OpenAI-compatible auth. Set settings.security.auth.apiKey, or set the {{envKeyHint}} environment variable.": "\u7F3A\u5C11 OpenAI \u517C\u5BB9\u8BA4\u8BC1\u7684 API Key\u3002\u8BF7\u8BBE\u7F6E settings.security.auth.apiKey \u6216\u8BBE\u7F6E {{envKeyHint}} \u73AF\u5883\u53D8\u91CF\u3002",
  "{{envKeyHint}} environment variable not found. Please set it in your .env file or environment variables.": "\u672A\u627E\u5230 {{envKeyHint}} \u73AF\u5883\u53D8\u91CF\u3002\u8BF7\u5728 .env \u6587\u4EF6\u6216\u7CFB\u7EDF\u73AF\u5883\u53D8\u91CF\u4E2D\u8FDB\u884C\u8BBE\u7F6E\u3002",
  "{{envKeyHint}} environment variable not found (or set settings.security.auth.apiKey). Please set it in your .env file or environment variables.": "\u672A\u627E\u5230 {{envKeyHint}} \u73AF\u5883\u53D8\u91CF\uFF08\u6216\u8BBE\u7F6E settings.security.auth.apiKey\uFF09\u3002\u8BF7\u5728 .env \u6587\u4EF6\u6216\u7CFB\u7EDF\u73AF\u5883\u53D8\u91CF\u4E2D\u8FDB\u884C\u8BBE\u7F6E\u3002",
  "Missing API key for OpenAI-compatible auth. Set the {{envKeyHint}} environment variable.": "\u7F3A\u5C11 OpenAI \u517C\u5BB9\u8BA4\u8BC1\u7684 API Key\u3002\u8BF7\u8BBE\u7F6E {{envKeyHint}} \u73AF\u5883\u53D8\u91CF\u3002",
  "Anthropic provider missing required baseUrl in modelProviders[].baseUrl.": "Anthropic \u63D0\u4F9B\u5546\u7F3A\u5C11\u5FC5\u9700\u7684 baseUrl\uFF0C\u8BF7\u5728 modelProviders[].baseUrl \u4E2D\u914D\u7F6E\u3002",
  "ANTHROPIC_BASE_URL environment variable not found.": "\u672A\u627E\u5230 ANTHROPIC_BASE_URL \u73AF\u5883\u53D8\u91CF\u3002",
  "Invalid auth method selected.": "\u9009\u62E9\u4E86\u65E0\u6548\u7684\u8BA4\u8BC1\u65B9\u5F0F\u3002",
  "Failed to authenticate. Message: {{message}}": "\u8BA4\u8BC1\u5931\u8D25\u3002\u6D88\u606F\uFF1A{{message}}",
  "Authenticated successfully with {{authType}} credentials.": "\u4F7F\u7528 {{authType}} \u51ED\u636E\u6210\u529F\u8BA4\u8BC1\u3002",
  'Invalid QWEN_DEFAULT_AUTH_TYPE value: "{{value}}". Valid values are: {{validValues}}': '\u65E0\u6548\u7684 QWEN_DEFAULT_AUTH_TYPE \u503C\uFF1A"{{value}}"\u3002\u6709\u6548\u503C\u4E3A\uFF1A{{validValues}}',
  // ============================================================================
  // Dialogs - Model
  // ============================================================================
  "Select Model": "\u9009\u62E9\u6A21\u578B",
  " (this project)": "\uFF08\u5F53\u524D\u9879\u76EE\uFF09",
  " (global)": "\uFF08\u5168\u5C40\uFF09",
  "API Key": "API Key",
  "(default)": "(\u9ED8\u8BA4)",
  "(not set)": "(\u672A\u8BBE\u7F6E)",
  Modality: "\u6A21\u6001",
  "Context Window": "\u4E0A\u4E0B\u6587\u7A97\u53E3",
  text: "\u6587\u672C",
  "text-only": "\u7EAF\u6587\u672C",
  image: "\u56FE\u50CF",
  pdf: "PDF",
  audio: "\u97F3\u9891",
  video: "\u89C6\u9891",
  "not set": "\u672A\u8BBE\u7F6E",
  "not set (falls back to the main model)": "\u672A\u8BBE\u7F6E\uFF08\u56DE\u9000\u5230\u4E3B\u6A21\u578B\uFF09",
  'Current voice model: {{voiceModel}}\nUse "/model --voice <model-id>" to set voice model.': '\u5F53\u524D\u8BED\u97F3\u6A21\u578B\uFF1A{{voiceModel}}\n\u4F7F\u7528 "/model --voice <model-id>" \u8BBE\u7F6E\u8BED\u97F3\u6A21\u578B\u3002',
  'Current vision model: {{visionModel}}\nUse "/model --vision <model-id>" to set the vision bridge model.': '\u5F53\u524D\u89C6\u89C9\u6A21\u578B\uFF1A{{visionModel}}\n\u4F7F\u7528 "/model --vision <model-id>" \u8BBE\u7F6E\u89C6\u89C9\u6865\u63A5\u6A21\u578B\u3002',
  'Current image model: {{imageModel}}\nUse "/model --image <model-id>" to set the image generation model.': '\u5F53\u524D\u56FE\u50CF\u6A21\u578B\uFF1A{{imageModel}}\n\u4F7F\u7528 "/model --image <model-id>" \u8BBE\u7F6E\u56FE\u50CF\u751F\u6210\u6A21\u578B\u3002',
  "Compaction model override cleared": "\u538B\u7F29\u6A21\u578B\u8986\u76D6\u5DF2\u6E05\u9664",
  'Current compaction model: {{compactionModel}}\nUse "/model --compaction <model-id>" to set compaction model, or "/model --compaction clear" to clear the override.': '\u5F53\u524D\u538B\u7F29\u6A21\u578B\uFF1A{{compactionModel}}\n\u4F7F\u7528 "/model --compaction <model-id>" \u8BBE\u7F6E\u538B\u7F29\u6A21\u578B\uFF0C\u6216\u4F7F\u7528 "/model --compaction clear" \u6E05\u9664\u8986\u76D6\u8BBE\u7F6E\u3002',
  "Voice model '{{modelName}}' is ambiguous. Configure a unique model id before using /model --voice.": "\u8BED\u97F3\u6A21\u578B '{{modelName}}' \u4E0D\u552F\u4E00\u3002\u8BF7\u5148\u914D\u7F6E\u552F\u4E00\u7684\u6A21\u578B ID\uFF0C\u518D\u4F7F\u7528 /model --voice\u3002",
  "Image model '{{modelName}}' matches multiple configured endpoints. Run /model --image without an argument and choose the exact endpoint.": "\u56FE\u50CF\u6A21\u578B '{{modelName}}' \u5339\u914D\u4E86\u591A\u4E2A\u5DF2\u914D\u7F6E\u7684\u7AEF\u70B9\u3002\u8BF7\u8FD0\u884C /model --image\uFF08\u4E0D\u5E26\u53C2\u6570\uFF09\u5E76\u9009\u62E9\u786E\u5207\u7684\u7AEF\u70B9\u3002",
  "Image model '{{modelName}}' must declare a valid HTTPS baseUrl and credential environment variable.": "\u56FE\u50CF\u6A21\u578B '{{modelName}}' \u5FC5\u987B\u58F0\u660E\u6709\u6548\u7684 HTTPS baseUrl \u548C\u51ED\u636E\u73AF\u5883\u53D8\u91CF\u3002",
  "'{{model}}' must declare a valid HTTPS baseUrl and credential environment variable.": "'{{model}}' \u5FC5\u987B\u58F0\u660E\u6709\u6548\u7684 HTTPS baseUrl \u548C\u51ED\u636E\u73AF\u5883\u53D8\u91CF\u3002",
  none: "\u65E0",
  unknown: "\u672A\u77E5",
  // ============================================================================
  // Dialogs - Permissions
  // ============================================================================
  "Manage folder trust settings": "\u7BA1\u7406\u6587\u4EF6\u5939\u4FE1\u4EFB\u8BBE\u7F6E",
  "Manage permission rules": "\u7BA1\u7406 permission rules",
  Allow: "\u5141\u8BB8",
  Ask: "\u8BE2\u95EE",
  Deny: "\u62D2\u7EDD",
  Workspace: "\u5DE5\u4F5C\u533A",
  "Qwen Code won't ask before using allowed tools.": "Qwen Code \u4F7F\u7528\u5DF2\u5141\u8BB8\u7684\u5DE5\u5177\u524D\u4E0D\u4F1A\u8BE2\u95EE\u3002",
  "Qwen Code will ask before using these tools.": "Qwen Code \u4F7F\u7528\u8FD9\u4E9B\u5DE5\u5177\u524D\u4F1A\u5148\u8BE2\u95EE\u3002",
  "Qwen Code is not allowed to use denied tools.": "Qwen Code \u4E0D\u5141\u8BB8\u4F7F\u7528\u88AB\u62D2\u7EDD\u7684\u5DE5\u5177\u3002",
  "Manage trusted directories for this workspace.": "\u7BA1\u7406\u6B64\u5DE5\u4F5C\u533A\u7684\u53D7\u4FE1\u4EFB\u76EE\u5F55\u3002",
  "Any use of the {{tool}} tool": "{{tool}} \u5DE5\u5177\u7684\u4EFB\u4F55\u4F7F\u7528",
  "{{tool}} commands matching '{{pattern}}'": "\u5339\u914D '{{pattern}}' \u7684 {{tool}} \u547D\u4EE4",
  "From user settings": "\u6765\u81EA\u7528\u6237\u8BBE\u7F6E",
  "From project settings": "\u6765\u81EA\u9879\u76EE\u8BBE\u7F6E",
  "From session": "\u6765\u81EA\u4F1A\u8BDD",
  "Project settings": "\u9879\u76EE\u8BBE\u7F6E",
  "Checked in at .qwen/settings.json": "\u4FDD\u5B58\u5728 .qwen/settings.json",
  "User settings": "\u7528\u6237\u8BBE\u7F6E",
  "Saved in at ~/.qwen/settings.json": "\u4FDD\u5B58\u5728 ~/.qwen/settings.json",
  "Add a new rule\u2026": "\u6DFB\u52A0\u65B0\u89C4\u5219\u2026",
  "Add {{type}} permission rule": "\u6DFB\u52A0 {{type}} permission rule",
  "Permission rules are a tool name, optionally followed by a specifier in parentheses.": "permission rules \u662F\u5DE5\u5177\u540D\u79F0\uFF0C\u53EF\u9009\u5730\u540E\u8DDF\u62EC\u53F7\u4E2D\u7684\u9650\u5B9A\u7B26\u3002",
  "e.g.,": "\u4F8B\u5982",
  or: "\u6216",
  "Enter permission rule\u2026": "\u8F93\u5165 permission rule\u2026",
  "Enter to submit \xB7 Esc to cancel": "Enter \u63D0\u4EA4 \xB7 Esc \u53D6\u6D88",
  "Where should this rule be saved?": "\u6B64\u89C4\u5219\u5E94\u4FDD\u5B58\u5728\u54EA\u91CC\uFF1F",
  "Enter to confirm \xB7 Esc to cancel": "Enter \u786E\u8BA4 \xB7 Esc \u53D6\u6D88",
  "Delete {{type}} rule?": "\u5220\u9664{{type}}\u89C4\u5219\uFF1F",
  "Are you sure you want to delete this permission rule?": "\u786E\u5B9A\u8981\u5220\u9664\u6B64 permission rule \u5417\uFF1F",
  "Permissions:": "\u6743\u9650\uFF1A",
  "(\u2190/\u2192 or tab to cycle)": "\uFF08\u2190/\u2192 \u6216 Tab \u5207\u6362\uFF09",
  "Press \u2191\u2193 to navigate \xB7 Enter to select \xB7 Type to search \xB7 Esc to cancel": "\u6309 \u2191\u2193 \u5BFC\u822A \xB7 Enter \u9009\u62E9 \xB7 \u8F93\u5165\u641C\u7D22 \xB7 Esc \u53D6\u6D88",
  "Search\u2026": "\u641C\u7D22\u2026",
  // Workspace directory management
  "Add directory\u2026": "\u6DFB\u52A0\u76EE\u5F55\u2026",
  "Add directory to workspace": "\u6DFB\u52A0\u5DE5\u4F5C\u533A\u76EE\u5F55",
  "Qwen Code can read files in the workspace, and make edits when auto-accept edits is on.": "Qwen Code \u53EF\u4EE5\u8BFB\u53D6\u5DE5\u4F5C\u533A\u4E2D\u7684\u6587\u4EF6\uFF0C\u5E76\u5728\u81EA\u52A8\u63A5\u53D7\u7F16\u8F91\u6A21\u5F0F\u5F00\u542F\u65F6\u8FDB\u884C\u7F16\u8F91\u3002",
  "Qwen Code will be able to read files in this directory and make edits when auto-accept edits is on.": "Qwen Code \u5C06\u80FD\u591F\u8BFB\u53D6\u6B64\u76EE\u5F55\u4E2D\u7684\u6587\u4EF6\uFF0C\u5E76\u5728\u81EA\u52A8\u63A5\u53D7\u7F16\u8F91\u6A21\u5F0F\u5F00\u542F\u65F6\u8FDB\u884C\u7F16\u8F91\u3002",
  "Enter the path to the directory:": "\u8F93\u5165\u76EE\u5F55\u8DEF\u5F84\uFF1A",
  "Enter directory path\u2026": "\u8F93\u5165\u76EE\u5F55\u8DEF\u5F84\u2026",
  "Tab to complete \xB7 Enter to add \xB7 Esc to cancel": "Tab \u8865\u5168 \xB7 Enter \u6DFB\u52A0 \xB7 Esc \u53D6\u6D88",
  "Remove directory?": "\u5220\u9664\u76EE\u5F55\uFF1F",
  "Are you sure you want to remove this directory from the workspace?": "\u786E\u5B9A\u8981\u5C06\u6B64\u76EE\u5F55\u4ECE\u5DE5\u4F5C\u533A\u4E2D\u79FB\u9664\u5417\uFF1F",
  "  (Original working directory)": "  \uFF08\u539F\u59CB\u5DE5\u4F5C\u76EE\u5F55\uFF09",
  "  (from settings)": "  \uFF08\u6765\u81EA\u8BBE\u7F6E\uFF09",
  "Directory does not exist.": "\u76EE\u5F55\u4E0D\u5B58\u5728\u3002",
  "Path is not a directory.": "\u8DEF\u5F84\u4E0D\u662F\u76EE\u5F55\u3002",
  "This directory is already in the workspace.": "\u6B64\u76EE\u5F55\u5DF2\u5728\u5DE5\u4F5C\u533A\u4E2D\u3002",
  "Already covered by existing directory: {{dir}}": "\u5DF2\u88AB\u73B0\u6709\u76EE\u5F55\u8986\u76D6\uFF1A{{dir}}",
  // ============================================================================
  // Status Bar
  // ============================================================================
  "Using:": "\u5DF2\u52A0\u8F7D: ",
  "{{count}} open file": "{{count}} \u4E2A\u6253\u5F00\u7684\u6587\u4EF6",
  "{{count}} open files": "{{count}} \u4E2A\u6253\u5F00\u7684\u6587\u4EF6",
  "(ctrl+g to view)": "\uFF08\u6309 ctrl+g \u67E5\u770B\uFF09",
  "{{count}} {{name}} file": "{{count}} \u4E2A {{name}} \u6587\u4EF6",
  "{{count}} {{name}} files": "{{count}} \u4E2A {{name}} \u6587\u4EF6",
  "{{count}} MCP server": "{{count}} \u4E2A MCP server",
  "{{count}} MCP servers": "{{count}} \u4E2A MCP servers",
  "{{count}} Blocked": "{{count}} \u4E2A\u5DF2\u963B\u6B62",
  "(ctrl+t to view)": "\uFF08\u6309 ctrl+t \u67E5\u770B\uFF09",
  "(ctrl+t to toggle)": "\uFF08\u6309 ctrl+t \u5207\u6362\uFF09",
  "Press Ctrl+C again to exit.": "\u518D\u6B21\u6309 Ctrl+C \u9000\u51FA",
  "Press Ctrl+D again to exit.": "\u518D\u6B21\u6309 Ctrl+D \u9000\u51FA",
  "Press Esc again to clear.": "\u518D\u6B21\u6309 Esc \u6E05\u9664",
  "Ctrl+Q to queue \xB7 \u2191 to edit queued messages": "Ctrl+Q \u6392\u5230\u4E0B\u4E00\u8F6E \xB7 \u2191 \u7F16\u8F91\u6392\u961F\u6D88\u606F",
  "Enter to steer \xB7 Ctrl+Q to queue": "Enter \u8FFD\u52A0\u5230\u5F53\u524D\u4EFB\u52A1 \xB7 Ctrl+Q \u6392\u5230\u4E0B\u4E00\u8F6E",
  "Queue message for the next turn": "\u5C06\u6D88\u606F\u6392\u5230\u4E0B\u4E00\u8F6E",
  // ============================================================================
  // MCP Status
  // ============================================================================
  "No MCP servers configured.": "\u672A\u914D\u7F6E MCP servers",
  "\u25CC MCP servers are starting up ({{count}} initializing)...": "\u25CC MCP servers \u6B63\u5728\u542F\u52A8\uFF08{{count}} \u4E2A\u6B63\u5728\u521D\u59CB\u5316\uFF09...",
  "Note: First startup may take longer. Tool availability will update automatically.": "\u6CE8\u610F\uFF1A\u9996\u6B21\u542F\u52A8\u53EF\u80FD\u9700\u8981\u66F4\u957F\u65F6\u95F4\u3002\u5DE5\u5177\u53EF\u7528\u6027\u5C06\u81EA\u52A8\u66F4\u65B0",
  "Configured MCP servers:": "\u5DF2\u914D\u7F6E\u7684 MCP servers\uFF1A",
  Ready: "\u5C31\u7EEA",
  "Starting... (first startup may take longer)": "\u6B63\u5728\u542F\u52A8...\uFF08\u9996\u6B21\u542F\u52A8\u53EF\u80FD\u9700\u8981\u66F4\u957F\u65F6\u95F4\uFF09",
  Disconnected: "\u5DF2\u65AD\u5F00\u8FDE\u63A5",
  "{{count}} tool": "{{count}} \u4E2A\u5DE5\u5177",
  "{{count}} tools": "{{count}} \u4E2A\u5DE5\u5177",
  "{{count}} prompt": "{{count}} \u4E2A\u63D0\u793A",
  "{{count}} prompts": "{{count}} \u4E2A\u63D0\u793A",
  "(from {{extensionName}})": "\uFF08\u6765\u81EA {{extensionName}}\uFF09",
  OAuth: "OAuth",
  "OAuth expired": "OAuth \u5DF2\u8FC7\u671F",
  "OAuth not authenticated": "OAuth \u672A\u8BA4\u8BC1",
  "tools and prompts will appear when ready": "\u5DE5\u5177\u548C\u63D0\u793A\u5C06\u5728\u5C31\u7EEA\u65F6\u663E\u793A",
  "{{count}} tools cached": "{{count}} \u4E2A\u5DE5\u5177\u5DF2\u7F13\u5B58",
  "Tools:": "\u5DE5\u5177\uFF1A",
  "Parameters:": "\u53C2\u6570\uFF1A",
  "Prompts:": "\u63D0\u793A\uFF1A",
  "Resources:": "\u8D44\u6E90\uFF1A",
  Blocked: "\u5DF2\u963B\u6B62",
  "\u2605 Tips:": "\u2605 \u63D0\u793A\uFF1A",
  Use: "\u4F7F\u7528",
  "to show server and tool descriptions": "\u663E\u793A\u670D\u52A1\u5668\u548C\u5DE5\u5177\u63CF\u8FF0",
  "to show tool parameter schemas": "\u663E\u793A tool parameter schemas",
  "to hide descriptions": "\u9690\u85CF\u63CF\u8FF0",
  "to authenticate with OAuth-enabled servers": "\u4F7F\u7528\u652F\u6301 OAuth \u7684\u670D\u52A1\u5668\u8FDB\u884C\u8BA4\u8BC1",
  Press: "\u6309",
  "to toggle tool descriptions on/off": "\u5207\u6362\u5DE5\u5177\u63CF\u8FF0\u5F00\u5173",
  "Starting OAuth authentication for MCP server '{{name}}'...": "\u6B63\u5728\u4E3A MCP server '{{name}}' \u542F\u52A8 OAuth \u8BA4\u8BC1...",
  // ============================================================================
  // Startup Tips
  // ============================================================================
  "Tips:": "\u63D0\u793A\uFF1A",
  "Use /compress when the conversation gets long to summarize history and free up context.": "\u5BF9\u8BDD\u53D8\u957F\u65F6\u7528 /compress\uFF0C\u603B\u7ED3\u5386\u53F2\u5E76\u91CA\u653E\u4E0A\u4E0B\u6587\u3002",
  "Start a fresh idea with /clear or /new; the previous session stays available in history.": "\u7528 /clear \u6216 /new \u5F00\u542F\u65B0\u601D\u8DEF\uFF1B\u4E4B\u524D\u7684\u4F1A\u8BDD\u4F1A\u4FDD\u7559\u5728\u5386\u53F2\u8BB0\u5F55\u4E2D\u3002",
  "Use /bug to submit issues to the maintainers when something goes off.": "\u9047\u5230\u95EE\u9898\u65F6\uFF0C\u7528 /bug \u5C06\u95EE\u9898\u63D0\u4EA4\u7ED9\u7EF4\u62A4\u8005\u3002",
  "Switch auth type quickly with /auth.": "\u7528 /auth \u5FEB\u901F\u5207\u6362\u8BA4\u8BC1\u65B9\u5F0F\u3002",
  "You can run any shell commands from Qwen Code using ! (e.g. !ls).": "\u5728 Qwen Code \u4E2D\u4F7F\u7528 ! \u53EF\u8FD0\u884C\u4EFB\u610F shell \u547D\u4EE4\uFF08\u4F8B\u5982 !ls\uFF09\u3002",
  "Type / to open the command popup; Tab autocompletes slash commands and saved prompts.": "\u8F93\u5165 / \u6253\u5F00\u547D\u4EE4\u5F39\u7A97\uFF1B\u6309 Tab \u81EA\u52A8\u8865\u5168\u659C\u6760\u547D\u4EE4\u548C\u4FDD\u5B58\u7684\u63D0\u793A\u8BCD\u3002",
  "You can resume a previous conversation by running qwen --continue or qwen --resume.": "\u8FD0\u884C qwen --continue \u6216 qwen --resume \u53EF\u7EE7\u7EED\u4E4B\u524D\u7684\u4F1A\u8BDD\u3002",
  "You can switch permission mode quickly with Shift+Tab or /approval-mode.": "\u6309 Shift+Tab \u6216\u8F93\u5165 /approval-mode \u53EF\u5FEB\u901F\u5207\u6362\u6743\u9650\u6A21\u5F0F\u3002",
  "You can switch permission mode quickly with Tab or /approval-mode.": "\u6309 Tab \u6216\u8F93\u5165 /approval-mode \u53EF\u5FEB\u901F\u5207\u6362\u6743\u9650\u6A21\u5F0F\u3002",
  "Try /insight to generate personalized insights from your chat history.": "\u8BD5\u8BD5 /insight\uFF0C\u4ECE\u804A\u5929\u8BB0\u5F55\u4E2D\u751F\u6210\u4E2A\u6027\u5316\u6D1E\u5BDF\u3002",
  "Add a QWEN.md file to give Qwen Code persistent project context.": "\u6DFB\u52A0 QWEN.md \u6587\u4EF6\uFF0C\u4E3A Qwen Code \u63D0\u4F9B\u6301\u4E45\u7684\u9879\u76EE\u4E0A\u4E0B\u6587\u3002",
  "Use /btw to ask a quick side question without disrupting the conversation.": "\u7528 /btw \u5FEB\u901F\u95EE\u4E00\u4E2A\u5C0F\u95EE\u9898\uFF0C\u4E0D\u4F1A\u6253\u65AD\u5F53\u524D\u5BF9\u8BDD\u3002",
  "Context is almost full! Run /compress now or start /new to continue.": "\u4E0A\u4E0B\u6587\u5373\u5C06\u7528\u6EE1\uFF01\u8BF7\u7ACB\u5373\u6267\u884C /compress \u6216\u4F7F\u7528 /new \u5F00\u542F\u65B0\u4F1A\u8BDD\u3002",
  "Context is getting full. Use /compress to free up space.": "\u4E0A\u4E0B\u6587\u7A7A\u95F4\u4E0D\u8DB3\uFF0C\u7528 /compress \u91CA\u653E\u7A7A\u95F4\u3002",
  "Long conversation? /compress summarizes history to free context.": "\u5BF9\u8BDD\u592A\u957F\uFF1F\u7528 /compress \u603B\u7ED3\u5386\u53F2\uFF0C\u91CA\u653E\u4E0A\u4E0B\u6587\u3002",
  'Show context window usage breakdown. Use "/context detail" for per-item breakdown.': '\u663E\u793A\u4E0A\u4E0B\u6587\u7A97\u53E3\u4F7F\u7528\u60C5\u51B5\u660E\u7EC6\u3002\u4F7F\u7528 "/context detail" \u67E5\u770B\u9010\u9879\u660E\u7EC6\u3002',
  // ============================================================================
  // Exit Screen / Stats
  // ============================================================================
  "Agent powering down. Goodbye!": "Qwen Code \u6B63\u5728\u5173\u95ED\uFF0C\u518D\u89C1\uFF01",
  "To continue this session, run": "\u8981\u7EE7\u7EED\u6B64\u4F1A\u8BDD\uFF0C\u8BF7\u8FD0\u884C",
  "Interaction Summary": "\u4EA4\u4E92\u6458\u8981",
  "Session ID:": "\u4F1A\u8BDD ID\uFF1A",
  "Tool Calls:": "\u5DE5\u5177\u8C03\u7528\uFF1A",
  "Success Rate:": "\u6210\u529F\u7387\uFF1A",
  "User Agreement:": "\u7528\u6237\u540C\u610F\u7387\uFF1A",
  reviewed: "\u5DF2\u5BA1\u6838",
  "Code Changes:": "\u4EE3\u7801\u53D8\u66F4\uFF1A",
  Performance: "\u6027\u80FD",
  "Generation Metrics": "\u751F\u6210\u6307\u6807",
  "Latest Request": "\u6700\u8FD1\u8BF7\u6C42",
  "Generation Time": "\u751F\u6210\u65F6\u95F4",
  "Average TTFT": "\u5E73\u5747 TTFT",
  "Session TPS": "\u4F1A\u8BDD TPS",
  "Wall Time:": "\u603B\u8017\u65F6\uFF1A",
  "Agent Active:": "\u667A\u80FD\u4F53\u6D3B\u8DC3\u65F6\u95F4\uFF1A",
  "API Time:": "API \u65F6\u95F4\uFF1A",
  "Tool Time:": "\u5DE5\u5177\u65F6\u95F4\uFF1A",
  "Session Stats": "\u4F1A\u8BDD\u7EDF\u8BA1",
  "Model Usage": "\u6A21\u578B\u4F7F\u7528\u60C5\u51B5",
  "Input Tokens": "\u8F93\u5165 token \u6570",
  "Output Tokens": "\u8F93\u51FA token \u6570",
  "Savings Highlight:": "\u8282\u7701\u4EAE\u70B9\uFF1A",
  "of input tokens were served from the cache, reducing costs.": "\u4ECE\u7F13\u5B58\u8F7D\u5165 token \uFF0C\u964D\u4F4E\u4E86\u6210\u672C",
  "Tip: For a full token breakdown, run `/stats model`.": "\u63D0\u793A\uFF1A\u8981\u67E5\u770B\u5B8C\u6574\u7684 token \u660E\u7EC6\uFF0C\u8BF7\u8FD0\u884C `/stats model`",
  "Model Stats For Nerds": "\u6A21\u578B\u7EDF\u8BA1\uFF08\u6280\u672F\u7EC6\u8282\uFF09",
  "Tool Stats For Nerds": "\u5DE5\u5177\u7EDF\u8BA1\uFF08\u6280\u672F\u7EC6\u8282\uFF09",
  Metric: "\u6307\u6807",
  API: "API",
  Session: "\u4F1A\u8BDD",
  Activity: "\u6982\u89C8",
  Efficiency: "\u6027\u80FD",
  Success: "\u6210\u529F\u7387",
  Today: "\u4ECA\u5929",
  "Token Trend": "Token \u8D8B\u52BF",
  "Cache Hit Rate": "\u7F13\u5B58\u547D\u4E2D\u7387",
  "Tool Success": "\u5DE5\u5177\u6210\u529F\u7387",
  "Tool Leaderboard": "\u5DE5\u5177\u6392\u884C",
  Calls: "\u8C03\u7528\u6B21\u6570",
  Time: "\u8017\u65F6",
  Reqs: "\u8BF7\u6C42",
  Cache: "\u7F13\u5B58",
  Latency: "\u5EF6\u8FDF",
  "In/Out": "\u8F93\u5165/\u8F93\u51FA",
  "Code Impact": "\u4EE3\u7801\u53D8\u66F4",
  "Failed to load stats. Press r to retry.": "\u52A0\u8F7D\u7EDF\u8BA1\u5931\u8D25\uFF0C\u6309 r \u91CD\u8BD5\u3002",
  net: "\u51C0\u589E",
  streak: "\u8FDE\u7EED",
  best: "\u6700\u957F",
  Requests: "\u8BF7\u6C42\u6570",
  Errors: "\u9519\u8BEF\u6570",
  "Avg Latency": "\u5E73\u5747\u5EF6\u8FDF",
  Tokens: "Token",
  Total: "\u603B\u8BA1",
  Prompt: "\u63D0\u793A",
  Cached: "\u7F13\u5B58",
  Thoughts: "\u601D\u8003",
  Output: "\u8F93\u51FA",
  "No API calls have been made in this session.": "\u672C\u6B21\u4F1A\u8BDD\u4E2D\u672A\u8FDB\u884C\u4EFB\u4F55 API \u8C03\u7528",
  "Tool Name": "\u5DE5\u5177\u540D\u79F0",
  "Success Rate": "\u6210\u529F\u7387",
  "Avg Duration": "\u5E73\u5747\u8017\u65F6",
  "User Decision Summary": "\u7528\u6237\u51B3\u7B56\u6458\u8981",
  "Total Reviewed Suggestions:": "\u5DF2\u5BA1\u6838\u5EFA\u8BAE\u603B\u6570\uFF1A",
  " \xBB Accepted:": " \xBB \u5DF2\u63A5\u53D7\uFF1A",
  " \xBB Rejected:": " \xBB \u5DF2\u62D2\u7EDD\uFF1A",
  " \xBB Modified:": " \xBB \u5DF2\u4FEE\u6539\uFF1A",
  " Overall Agreement Rate:": " \u603B\u4F53\u540C\u610F\u7387\uFF1A",
  "No tool calls have been made in this session.": "\u672C\u6B21\u4F1A\u8BDD\u4E2D\u672A\u8FDB\u884C\u4EFB\u4F55\u5DE5\u5177\u8C03\u7528",
  "Session start time is unavailable, cannot calculate stats.": "\u4F1A\u8BDD\u5F00\u59CB\u65F6\u95F4\u4E0D\u53EF\u7528\uFF0C\u65E0\u6CD5\u8BA1\u7B97\u7EDF\u8BA1\u4FE1\u606F",
  // ============================================================================
  // Command Format Migration
  // ============================================================================
  "Command Format Migration": "\u547D\u4EE4\u683C\u5F0F\u8FC1\u79FB",
  "Found {{count}} TOML command file:": "\u53D1\u73B0 {{count}} \u4E2A TOML \u547D\u4EE4\u6587\u4EF6\uFF1A",
  "Found {{count}} TOML command files:": "\u53D1\u73B0 {{count}} \u4E2A TOML \u547D\u4EE4\u6587\u4EF6\uFF1A",
  "Current tasks": "\u5F53\u524D\u4EFB\u52A1",
  "... and {{count}} more": "... \u4EE5\u53CA\u5176\u4ED6 {{count}} \u4E2A",
  "The TOML format is deprecated. Would you like to migrate them to Markdown format?": "TOML \u683C\u5F0F\u5DF2\u5F03\u7528\u3002\u662F\u5426\u5C06\u5B83\u4EEC\u8FC1\u79FB\u5230 Markdown \u683C\u5F0F\uFF1F",
  "(Backups will be created and original files will be preserved)": "\uFF08\u5C06\u521B\u5EFA\u5907\u4EFD\uFF0C\u539F\u59CB\u6587\u4EF6\u5C06\u4FDD\u7559\uFF09",
  // ============================================================================
  // Loading Phrases
  // ============================================================================
  "Waiting for user confirmation...": "\u7B49\u5F85\u7528\u6237\u786E\u8BA4...",
  WITTY_LOADING_PHRASES: [
    // --- 职场搬砖系列 ---
    "\u6B63\u5728\u52AA\u529B\u642C\u7816\uFF0C\u8BF7\u7A0D\u5019...",
    "\u8001\u677F\u5728\u8EAB\u540E\uFF0C\u5FEB\u52A0\u8F7D\u554A\uFF01",
    "\u5934\u53D1\u6389\u5149\u524D\uFF0C\u4E00\u5B9A\u80FD\u52A0\u8F7D\u5B8C...",
    "\u670D\u52A1\u5668\u6B63\u5728\u6DF1\u547C\u5438\uFF0C\u51C6\u5907\u653E\u5927\u62DB...",
    "\u6B63\u5728\u5411\u670D\u52A1\u5668\u6295\u5582\u5496\u5561...",
    // --- 大厂黑话系列 ---
    "\u6B63\u5728\u8D4B\u80FD\u5168\u94FE\u8DEF\uFF0C\u5BFB\u627E\u5173\u952E\u6293\u624B...",
    "\u6B63\u5728\u964D\u672C\u589E\u6548\uFF0C\u4F18\u5316\u52A0\u8F7D\u8DEF\u5F84...",
    "\u6B63\u5728\u6253\u7834\u90E8\u95E8\u58C1\u5792\uFF0C\u6C89\u6DC0\u65B9\u6CD5\u8BBA...",
    "\u6B63\u5728\u62E5\u62B1\u53D8\u5316\uFF0C\u8FED\u4EE3\u6838\u5FC3\u4EF7\u503C...",
    "\u6B63\u5728\u5BF9\u9F50\u9897\u7C92\u5EA6\uFF0C\u6253\u78E8\u5E95\u5C42\u903B\u8F91...",
    "\u5927\u529B\u51FA\u5947\u8FF9\uFF0C\u6B63\u5728\u5F3A\u884C\u52A0\u8F7D...",
    // --- 程序员自嘲系列 ---
    "\u53EA\u8981\u6211\u4E0D\u5199\u4EE3\u7801\uFF0C\u4EE3\u7801\u5C31\u6CA1\u6709 Bug...",
    "\u6B63\u5728\u628A Bug \u8F6C\u5316\u4E3A Feature...",
    "\u53EA\u8981\u6211\u4E0D\u5C34\u5C2C\uFF0CBug \u5C31\u8FFD\u4E0D\u4E0A\u6211...",
    "\u6B63\u5728\u8BD5\u56FE\u7406\u89E3\u53BB\u5E74\u7684\u81EA\u5DF1\u5199\u4E86\u4EC0\u4E48...",
    "\u6B63\u5728\u733F\u529B\u89C9\u9192\u4E2D\uFF0C\u8BF7\u8010\u5FC3\u7B49\u5F85...",
    // --- 合作愉快系列 ---
    "\u6B63\u5728\u8BE2\u95EE\u4EA7\u54C1\u7ECF\u7406\uFF1A\u8FD9\u9700\u6C42\u662F\u771F\u7684\u5417\uFF1F",
    "\u6B63\u5728\u7ED9\u4EA7\u54C1\u7ECF\u7406\u753B\u997C\uFF0C\u8BF7\u7A0D\u7B49...",
    // --- 温暖治愈系列 ---
    "\u6BCF\u4E00\u884C\u4EE3\u7801\uFF0C\u90FD\u5728\u52AA\u529B\u8BA9\u4E16\u754C\u53D8\u5F97\u66F4\u597D\u4E00\u70B9\u70B9...",
    "\u6BCF\u4E00\u4E2A\u4F1F\u5927\u7684\u60F3\u6CD5\uFF0C\u90FD\u503C\u5F97\u8FD9\u4EFD\u8010\u5FC3\u7684\u7B49\u5F85...",
    "\u522B\u6025\uFF0C\u7F8E\u597D\u7684\u4E8B\u7269\u603B\u662F\u9700\u8981\u4E00\u70B9\u65F6\u95F4\u53BB\u915D\u917F...",
    "\u613F\u4F60\u7684\u4EE3\u7801\u6C38\u65E0 Bug\uFF0C\u613F\u4F60\u7684\u68A6\u60F3\u7EC8\u5C06\u6210\u771F...",
    "\u54EA\u6015\u53EA\u6709 0.1% \u7684\u8FDB\u5EA6\uFF0C\u4E5F\u662F\u5728\u5411\u76EE\u6807\u9760\u8FD1...",
    "\u52A0\u8F7D\u7684\u662F\u5B57\u8282\uFF0C\u627F\u8F7D\u7684\u662F\u5BF9\u6280\u672F\u7684\u70ED\u7231..."
  ],
  // ============================================================================
  // Extension Settings Input
  // ============================================================================
  "Enter value...": "\u8BF7\u8F93\u5165\u503C...",
  "Enter sensitive value...": "\u8BF7\u8F93\u5165\u654F\u611F\u503C...",
  "Press Enter to submit, Escape to cancel": "\u6309 Enter \u63D0\u4EA4\uFF0CEscape \u53D6\u6D88",
  // ============================================================================
  // Command Migration Tool
  // ============================================================================
  "Markdown file already exists: {{filename}}": "Markdown \u6587\u4EF6\u5DF2\u5B58\u5728\uFF1A{{filename}}",
  "TOML Command Format Deprecation Notice": "TOML \u547D\u4EE4\u683C\u5F0F\u5F03\u7528\u901A\u77E5",
  "Found {{count}} command file(s) in TOML format:": "\u53D1\u73B0 {{count}} \u4E2A TOML \u683C\u5F0F\u7684\u547D\u4EE4\u6587\u4EF6\uFF1A",
  "The TOML format for commands is being deprecated in favor of Markdown format.": "\u547D\u4EE4\u7684 TOML \u683C\u5F0F\u6B63\u5728\u88AB\u5F03\u7528\uFF0C\u63A8\u8350\u4F7F\u7528 Markdown \u683C\u5F0F\u3002",
  "Markdown format is more readable and easier to edit.": "Markdown \u683C\u5F0F\u66F4\u6613\u8BFB\u3001\u66F4\u6613\u7F16\u8F91\u3002",
  "You can migrate these files automatically using:": "\u60A8\u53EF\u4EE5\u4F7F\u7528\u4EE5\u4E0B\u547D\u4EE4\u81EA\u52A8\u8FC1\u79FB\u8FD9\u4E9B\u6587\u4EF6\uFF1A",
  "Or manually convert each file:": "\u6216\u624B\u52A8\u8F6C\u6362\u6BCF\u4E2A\u6587\u4EF6\uFF1A",
  'TOML: prompt = "..." / description = "..."': 'TOML\uFF1Aprompt = "..." / description = "..."',
  "Markdown: YAML frontmatter + content": "Markdown\uFF1AYAML frontmatter + \u5185\u5BB9",
  "The migration tool will:": "\u8FC1\u79FB\u5DE5\u5177\u5C06\uFF1A",
  "Convert TOML files to Markdown": "\u5C06 TOML \u6587\u4EF6\u8F6C\u6362\u4E3A Markdown",
  "Create backups of original files": "\u521B\u5EFA\u539F\u59CB\u6587\u4EF6\u7684\u5907\u4EFD",
  "Preserve all command functionality": "\u4FDD\u7559\u6240\u6709\u547D\u4EE4\u529F\u80FD",
  "TOML format will continue to work for now, but migration is recommended.": "TOML \u683C\u5F0F\u76EE\u524D\u4ECD\u53EF\u4F7F\u7528\uFF0C\u4F46\u5EFA\u8BAE\u8FC1\u79FB\u3002",
  // ============================================================================
  // Extensions - Explore Command
  // ============================================================================
  "Open extensions page in your browser": "\u5728\u6D4F\u89C8\u5668\u4E2D\u6253\u5F00\u6269\u5C55\u5E02\u573A\u9875\u9762",
  "Unknown extensions source: {{source}}.": "\u672A\u77E5\u7684\u6269\u5C55\u6765\u6E90\uFF1A{{source}}\u3002",
  "Would open extensions page in your browser: {{url}} (skipped in test environment)": "\u5C06\u5728\u6D4F\u89C8\u5668\u4E2D\u6253\u5F00\u6269\u5C55\u9875\u9762\uFF1A{{url}}\uFF08\u6D4B\u8BD5\u73AF\u5883\u4E2D\u5DF2\u8DF3\u8FC7\uFF09",
  "View available extensions at {{url}}": "\u5728 {{url}} \u67E5\u770B\u53EF\u7528\u6269\u5C55",
  "Opening extensions page in your browser: {{url}}": "\u6B63\u5728\u6D4F\u89C8\u5668\u4E2D\u6253\u5F00\u6269\u5C55\u9875\u9762\uFF1A{{url}}",
  "Failed to open browser. Check out the extensions gallery at {{url}}": "\u6253\u5F00\u6D4F\u89C8\u5668\u5931\u8D25\u3002\u8BF7\u8BBF\u95EE\u6269\u5C55\u5E02\u573A\uFF1A{{url}}",
  "Retrying in {{seconds}} seconds\u2026 (attempt {{attempt}}/{{maxRetries}})": "\u5C06\u4E8E {{seconds}} \u79D2\u540E\u91CD\u8BD5\u2026\uFF08\u7B2C {{attempt}}/{{maxRetries}} \u6B21\uFF09",
  "Press Ctrl+Y to retry": "\u6309 Ctrl+Y \u91CD\u8BD5\u3002",
  "No failed request to retry.": "\u6CA1\u6709\u53EF\u91CD\u8BD5\u7684\u5931\u8D25\u8BF7\u6C42\u3002",
  "to retry last request": "\u91CD\u8BD5\u4E0A\u4E00\u6B21\u8BF7\u6C42",
  "to queue for the next turn": "\u6392\u5230\u4E0B\u4E00\u8F6E",
  // ============================================================================
  // Coding Plan Authentication
  // ============================================================================
  "API key cannot be empty.": "API Key \u4E0D\u80FD\u4E3A\u7A7A\u3002",
  'Invalid API key. Coding Plan API keys start with "sk-sp-". Please check.': '\u65E0\u6548\u7684 API Key\u3002Coding Plan API Key \u4EE5 "sk-sp-" \u5F00\u5934\uFF0C\u8BF7\u68C0\u67E5\u3002',
  "You can get your Coding Plan API key here": "\u60A8\u53EF\u4EE5\u5728\u8FD9\u91CC\u83B7\u53D6 Coding Plan API Key",
  "You can get your Token Plan API key here": "\u60A8\u53EF\u4EE5\u5728\u8FD9\u91CC\u83B7\u53D6 Token Plan API Key",
  "API key is stored in settings.env. You can migrate it to a .env file for better security.": "API Key \u5DF2\u5B58\u50A8\u5728 settings.env \u4E2D\u3002\u60A8\u53EF\u4EE5\u5C06\u5176\u8FC1\u79FB\u5230 .env \u6587\u4EF6\u4EE5\u83B7\u5F97\u66F4\u597D\u7684\u5B89\u5168\u6027\u3002",
  "New model configurations are available for Alibaba Cloud Coding Plan. Update now?": "\u963F\u91CC\u4E91\u767E\u70BC Coding Plan \u6709\u65B0\u6A21\u578B\u914D\u7F6E\u53EF\u7528\u3002\u662F\u5426\u7ACB\u5373\u66F4\u65B0\uFF1F",
  "Coding Plan configuration updated successfully. New models are now available.": "Coding Plan \u914D\u7F6E\u66F4\u65B0\u6210\u529F\u3002\u65B0\u6A21\u578B\u73B0\u5DF2\u53EF\u7528\u3002",
  "Coding Plan API key not found. Please re-authenticate with Coding Plan.": "\u672A\u627E\u5230 Coding Plan API Key\u3002\u8BF7\u91CD\u65B0\u901A\u8FC7 Coding Plan \u8BA4\u8BC1\u3002",
  "Failed to update Coding Plan configuration: {{message}}": "\u66F4\u65B0 Coding Plan \u914D\u7F6E\u5931\u8D25\uFF1A{{message}}",
  // ============================================================================
  // Custom API Key Configuration
  // ============================================================================
  "You can configure your API key and models in settings.json": "\u60A8\u53EF\u4EE5\u5728 settings.json \u4E2D\u914D\u7F6E API Key \u548C\u6A21\u578B",
  "Refer to the documentation for setup instructions": "\u8BF7\u53C2\u8003\u6587\u6863\u4E86\u89E3\u914D\u7F6E\u8BF4\u660E",
  // ============================================================================
  // Auth Dialog - View Titles and Labels
  // ============================================================================
  "Coding Plan": "Coding Plan",
  Custom: "\u81EA\u5B9A\u4E49",
  "Select Region for Coding Plan": "\u9009\u62E9 Coding Plan \u533A\u57DF",
  "Choose based on where your account is registered": "\u8BF7\u6839\u636E\u60A8\u7684\u8D26\u53F7\u6CE8\u518C\u5730\u533A\u9009\u62E9",
  "Enter Coding Plan API Key": "\u8F93\u5165 Coding Plan API Key",
  "Enter Token Plan API Key": "\u8F93\u5165 Token Plan API Key",
  // ============================================================================
  // Coding Plan International Updates
  // ============================================================================
  "New model configurations are available for {{region}}. Update now?": "{{region}} \u6709\u65B0\u7684\u6A21\u578B\u914D\u7F6E\u53EF\u7528\u3002\u662F\u5426\u7ACB\u5373\u66F4\u65B0\uFF1F",
  '{{region}} configuration updated successfully. Model switched to "{{model}}".': '{{region}} \u914D\u7F6E\u66F4\u65B0\u6210\u529F\u3002\u6A21\u578B\u5DF2\u5207\u6362\u81F3 "{{model}}"\u3002',
  // ============================================================================
  // Context Usage
  // ============================================================================
  "Context Usage": "\u4E0A\u4E0B\u6587\u4F7F\u7528\u60C5\u51B5",
  "% used": "% \u5DF2\u7528",
  "% context used": "% \u4E0A\u4E0B\u6587\u5DF2\u7528",
  "Context exceeds limit! Use /compress or /clear to reduce.": "\u4E0A\u4E0B\u6587\u8D85\u51FA\u9650\u5236\uFF01\u8BF7\u4F7F\u7528 /compress \u6216 /clear \u6765\u51CF\u5C11\u4E0A\u4E0B\u6587\u3002",
  "Context window": "\u4E0A\u4E0B\u6587\u7A97\u53E3",
  Used: "\u5DF2\u7528",
  Free: "\u7A7A\u95F2",
  "Autocompact buffer": "\u81EA\u52A8\u538B\u7F29\u7F13\u51B2\u533A",
  "Usage by category": "\u5206\u7C7B\u7528\u91CF",
  "System prompt": "\u7CFB\u7EDF\u63D0\u793A",
  "Built-in tools": "\u5185\u7F6E\u5DE5\u5177",
  "MCP tools": "MCP tools",
  "Memory files": "\u8BB0\u5FC6\u6587\u4EF6",
  Skills: "\u6280\u80FD",
  Messages: "\u6D88\u606F",
  tokens: "tokens",
  "Estimated pre-conversation overhead": "\u9884\u4F30\u5BF9\u8BDD\u524D\u5F00\u9500",
  "No API response yet. Send a message to see actual usage.": "\u6682\u65E0 API \u54CD\u5E94\u3002\u53D1\u9001\u6D88\u606F\u4EE5\u67E5\u770B\u5B9E\u9645\u4F7F\u7528\u60C5\u51B5\u3002",
  "Run /context detail for per-item breakdown.": "\u8FD0\u884C /context detail \u67E5\u770B\u8BE6\u7EC6\u5206\u89E3\u3002",
  "body loaded": "\u5185\u5BB9\u5DF2\u52A0\u8F7D",
  memory: "\u8BB0\u5FC6",
  "{{region}} configuration updated successfully.": "{{region}} \u914D\u7F6E\u66F4\u65B0\u6210\u529F\u3002",
  "Authenticated successfully with {{region}}. API key and model configs saved to settings.json.": "\u6210\u529F\u901A\u8FC7 {{region}} \u8BA4\u8BC1\u3002API Key \u548C\u6A21\u578B\u914D\u7F6E\u5DF2\u4FDD\u5B58\u81F3 settings.json\u3002",
  "Tip: Use /model to switch between available Coding Plan models.": "\u63D0\u793A\uFF1A\u4F7F\u7528 /model \u5207\u6362\u53EF\u7528\u7684 Coding Plan \u6A21\u578B\u3002",
  "Type something...": "\u8F93\u5165\u5185\u5BB9...",
  Submit: "\u63D0\u4EA4",
  "Submit answers": "\u63D0\u4EA4\u7B54\u6848",
  Cancel: "\u53D6\u6D88",
  "Your answers:": "\u60A8\u7684\u7B54\u6848\uFF1A",
  "(not answered)": "(\u672A\u56DE\u7B54)",
  "Ready to submit your answers?": "\u51C6\u5907\u597D\u63D0\u4EA4\u60A8\u7684\u7B54\u6848\u4E86\u5417\uFF1F",
  "\u2191/\u2193: Navigate | \u2190/\u2192: Switch tabs | Enter: Select": "\u2191/\u2193: \u5BFC\u822A | \u2190/\u2192: \u5207\u6362\u6807\u7B7E\u9875 | Enter: \u9009\u62E9",
  "\u2191/\u2193: Navigate | Enter: Select | Esc: Cancel": "\u2191/\u2193: \u5BFC\u822A | Enter: \u9009\u62E9 | Esc: \u53D6\u6D88",
  "Authenticate using Qwen OAuth": "\u4F7F\u7528 Qwen OAuth \u8FDB\u884C\u8BA4\u8BC1",
  "Authenticate using Alibaba Cloud Coding Plan": "\u4F7F\u7528\u963F\u91CC\u4E91\u767E\u70BC Coding Plan \u8FDB\u884C\u8BA4\u8BC1",
  "Region for Coding Plan (china/global)": "Coding Plan \u533A\u57DF (china/global)",
  "API key for Coding Plan": "Coding Plan \u7684 API Key",
  "Show current authentication status": "\u663E\u793A\u5F53\u524D\u8BA4\u8BC1\u72B6\u6001",
  "Authentication completed successfully.": "\u8BA4\u8BC1\u5B8C\u6210\u3002",
  "Starting Qwen OAuth authentication...": "\u6B63\u5728\u542F\u52A8 Qwen OAuth \u8BA4\u8BC1...",
  "Successfully authenticated with Qwen OAuth.": "\u5DF2\u6210\u529F\u901A\u8FC7 Qwen OAuth \u8BA4\u8BC1\u3002",
  "Failed to authenticate with Qwen OAuth: {{error}}": "Qwen OAuth \u8BA4\u8BC1\u5931\u8D25\uFF1A{{error}}",
  "Processing Alibaba Cloud Coding Plan authentication...": "\u6B63\u5728\u5904\u7406\u963F\u91CC\u4E91\u767E\u70BC Coding Plan \u8BA4\u8BC1...",
  "Successfully authenticated with Alibaba Cloud Coding Plan.": "\u5DF2\u6210\u529F\u901A\u8FC7\u963F\u91CC\u4E91\u767E\u70BC Coding Plan \u8BA4\u8BC1\u3002",
  "Failed to authenticate with Coding Plan: {{error}}": "Coding Plan \u8BA4\u8BC1\u5931\u8D25\uFF1A{{error}}",
  Global: "\u5168\u7403",
  "Alibaba Cloud (alibabacloud.com)": "Alibaba Cloud (alibabacloud.com)",
  "Select region for Coding Plan:": "\u9009\u62E9 Coding Plan \u533A\u57DF\uFF1A",
  "Enter your Coding Plan API key: ": "\u8BF7\u8F93\u5165\u60A8\u7684 Coding Plan API Key\uFF1A",
  "Select authentication method:": "\u9009\u62E9\u8BA4\u8BC1\u65B9\u5F0F\uFF1A",
  "\n=== Authentication Status ===\n": "\n=== \u8BA4\u8BC1\u72B6\u6001 ===\n",
  "\u26A0  No authentication method configured.\n": "\u26A0  \u672A\u914D\u7F6E\u8BA4\u8BC1\u65B9\u5F0F\u3002\n",
  "Run one of the following commands to get started:\n": "\u8FD0\u884C\u4EE5\u4E0B\u547D\u4EE4\u4E4B\u4E00\u5F00\u59CB\u914D\u7F6E\uFF1A\n",
  "  qwen auth qwen-oauth     - Authenticate with Qwen OAuth (discontinued)": "  qwen auth qwen-oauth     - \u4F7F\u7528 Qwen OAuth \u767B\u5F55\uFF08\u5DF2\u505C\u7528\uFF09",
  "Or simply run:": "\u6216\u8005\u76F4\u63A5\u8FD0\u884C\uFF1A",
  "  qwen auth                - Interactive authentication setup\n": "  qwen auth                - \u4EA4\u4E92\u5F0F\u8BA4\u8BC1\u914D\u7F6E\n",
  "\u2713 Authentication Method: Qwen OAuth": "\u2713 \u8BA4\u8BC1\u65B9\u5F0F\uFF1AQwen OAuth",
  "  Type: Free tier (discontinued 2026-04-15)": "  \u7C7B\u578B\uFF1A\u514D\u8D39\u989D\u5EA6\uFF082026-04-15 \u5DF2\u505C\u7528\uFF09",
  "  Limit: No longer available": "  \u9650\u989D\uFF1A\u5DF2\u4E0D\u53EF\u7528",
  "Qwen OAuth free tier was discontinued on 2026-04-15. Run /auth to switch to Coding Plan, OpenRouter, Fireworks AI, or another provider.": "Qwen OAuth \u514D\u8D39\u989D\u5EA6\u5DF2\u4E8E 2026-04-15 \u505C\u7528\u3002\u8BF7\u8FD0\u884C /auth \u5207\u6362\u5230 Coding Plan\u3001OpenRouter\u3001Fireworks AI \u6216\u5176\u4ED6\u670D\u52A1\u5546\u3002",
  "\u2713 Authentication Method: Alibaba Cloud Coding Plan": "\u2713 \u8BA4\u8BC1\u65B9\u5F0F\uFF1A\u963F\u91CC\u4E91\u767E\u70BC Coding Plan",
  "Global - Alibaba Cloud": "\u5168\u7403 - Alibaba Cloud",
  "  Region: {{region}}": "  \u533A\u57DF\uFF1A{{region}}",
  "  Current Model: {{model}}": "  \u5F53\u524D\u6A21\u578B\uFF1A{{model}}",
  "  Config Version: {{version}}": "  \u914D\u7F6E\u7248\u672C\uFF1A{{version}}",
  "  Status: API key configured\n": "  \u72B6\u6001\uFF1AAPI Key \u5DF2\u914D\u7F6E\n",
  "\u26A0  Authentication Method: Alibaba Cloud Coding Plan (Incomplete)": "\u26A0  \u8BA4\u8BC1\u65B9\u5F0F\uFF1A\u963F\u91CC\u4E91\u767E\u70BC Coding Plan\uFF08\u4E0D\u5B8C\u6574\uFF09",
  "  Issue: API key not found in environment or settings\n": "  \u95EE\u9898\uFF1A\u5728\u73AF\u5883\u53D8\u91CF\u6216\u8BBE\u7F6E\u4E2D\u672A\u627E\u5230 API Key\n",
  "  Run `qwen auth coding-plan` to re-configure.\n": "  \u8FD0\u884C `qwen auth coding-plan` \u91CD\u65B0\u914D\u7F6E\u3002\n",
  "\u2713 Authentication Method: {{type}}": "\u2713 \u8BA4\u8BC1\u65B9\u5F0F\uFF1A{{type}}",
  "  Status: Configured\n": "  \u72B6\u6001\uFF1A\u5DF2\u914D\u7F6E\n",
  "Failed to check authentication status: {{error}}": "\u68C0\u67E5\u8BA4\u8BC1\u72B6\u6001\u5931\u8D25\uFF1A{{error}}",
  "Select an option:": "\u8BF7\u9009\u62E9\uFF1A",
  "Raw mode not available. Please run in an interactive terminal.": "\u539F\u59CB\u6A21\u5F0F\u4E0D\u53EF\u7528\u3002\u8BF7\u5728\u4EA4\u4E92\u5F0F\u7EC8\u7AEF\u4E2D\u8FD0\u884C\u3002",
  "(Use \u2191 \u2193 arrows to navigate, Enter to select, Ctrl+C to exit)\n": "(\u4F7F\u7528 \u2191 \u2193 \u7BAD\u5934\u5BFC\u822A\uFF0CEnter \u9009\u62E9\uFF0CCtrl+C \u9000\u51FA)\n",
  "Switch to plan mode or exit plan mode": "\u5207\u6362\u5230\u8BA1\u5212\u6A21\u5F0F\u6216\u9000\u51FA\u8BA1\u5212\u6A21\u5F0F",
  "Set how hard reasoning-capable models think ({{tiers}}); mapped and clamped per provider.": "\u8BBE\u7F6E\u5177\u5907\u63A8\u7406\u80FD\u529B\u7684\u6A21\u578B\u601D\u8003\u7684\u5F3A\u5EA6\uFF08{{tiers}}\uFF09\uFF1B\u6309\u5404\u63D0\u4F9B\u65B9\u8FDB\u884C\u6620\u5C04\u4E0E\u94B3\u5236\u3002",
  "Set a goal \u2014 keep working until the condition is met": "\u8BBE\u5B9A\u76EE\u6807 \u2014 \u6301\u7EED\u5DE5\u4F5C\u76F4\u5230\u6761\u4EF6\u6EE1\u8DB3",
  "Set or control a session goal": "\u8BBE\u5B9A\u6216\u63A7\u5236\u4F1A\u8BDD\u76EE\u6807",
  "Exited plan mode. Previous approval mode restored.": "\u5DF2\u9000\u51FA\u8BA1\u5212\u6A21\u5F0F\uFF0C\u5DF2\u6062\u590D\u4E4B\u524D\u7684\u5BA1\u6279\u6A21\u5F0F\u3002",
  "Enabled plan mode. The agent will analyze and plan without executing tools.": "\u542F\u7528\u8BA1\u5212\u6A21\u5F0F\u3002\u667A\u80FD\u4F53\u5C06\u53EA\u5206\u6790\u548C\u89C4\u5212\uFF0C\u800C\u4E0D\u6267\u884C\u5DE5\u5177\u3002",
  'Already in plan mode. Use "/plan exit" to exit plan mode.': '\u5DF2\u5904\u4E8E\u8BA1\u5212\u6A21\u5F0F\u3002\u4F7F\u7528 "/plan exit" \u9000\u51FA\u8BA1\u5212\u6A21\u5F0F\u3002',
  'Not in plan mode. Use "/plan" to enter plan mode first.': '\u672A\u5904\u4E8E\u8BA1\u5212\u6A21\u5F0F\u3002\u8BF7\u5148\u4F7F\u7528 "/plan" \u8FDB\u5165\u8BA1\u5212\u6A21\u5F0F\u3002',
  "Set up Qwen Code's status line UI": "\u914D\u7F6E Qwen Code \u7684\u72B6\u6001\u680F",
  // === Core: added from PR #3328 ===
  "Ask a quick side question without affecting the main conversation": "\u5728\u4E0D\u5F71\u54CD\u4E3B\u5BF9\u8BDD\u7684\u60C5\u51B5\u4E0B\u5FEB\u901F\u95EE\u4E00\u4E2A\u65C1\u652F\u95EE\u9898",
  "Manage Arena sessions": "\u7BA1\u7406 Arena \u4F1A\u8BDD",
  "Start an Arena session with multiple models competing on the same task": "\u542F\u52A8\u4E00\u4E2A Arena \u4F1A\u8BDD\uFF0C\u8BA9\u591A\u4E2A\u6A21\u578B\u5728\u540C\u4E00\u4EFB\u52A1\u4E0A\u7ADE\u4E89",
  "Stop the current Arena session": "\u505C\u6B62\u5F53\u524D Arena \u4F1A\u8BDD",
  "Show the current Arena session status": "\u663E\u793A\u5F53\u524D Arena \u4F1A\u8BDD\u72B6\u6001",
  "Select a model result and merge its diff into the current workspace": "\u9009\u62E9\u4E00\u4E2A\u6A21\u578B\u7ED3\u679C\u5E76\u5C06\u5176\u5DEE\u5F02\u5408\u5E76\u5230\u5F53\u524D\u5DE5\u4F5C\u533A",
  "No running Arena session found.": "\u672A\u627E\u5230\u6B63\u5728\u8FD0\u884C\u7684 Arena \u4F1A\u8BDD\u3002",
  "No Arena session found. Start one with /arena start.": "\u672A\u627E\u5230 Arena \u4F1A\u8BDD\u3002\u8BF7\u4F7F\u7528 /arena start \u542F\u52A8\u4E00\u4E2A\u3002",
  "Arena session is still running. Wait for it to complete or use /arena stop first.": "Arena \u4F1A\u8BDD\u4ECD\u5728\u8FD0\u884C\u4E2D\u3002\u8BF7\u7B49\u5F85\u5176\u5B8C\u6210\uFF0C\u6216\u5148\u4F7F\u7528 /arena stop\u3002",
  "No successful agent results to select from. All agents failed or were cancelled.": "\u6CA1\u6709\u53EF\u9009\u62E9\u7684\u6210\u529F\u667A\u80FD\u4F53\u7ED3\u679C\u3002\u6240\u6709\u667A\u80FD\u4F53\u5747\u5931\u8D25\u6216\u88AB\u53D6\u6D88\u3002",
  "Use /arena stop to end the session.": "\u4F7F\u7528 /arena stop \u7ED3\u675F\u4F1A\u8BDD\u3002",
  'No idle agent found matching "{{name}}".': '\u672A\u627E\u5230\u5339\u914D "{{name}}" \u7684\u7A7A\u95F2\u667A\u80FD\u4F53\u3002',
  "Failed to apply changes from {{label}}: {{error}}": "\u4ECE {{label}} \u5E94\u7528\u66F4\u6539\u5931\u8D25\uFF1A{{error}}",
  "Applied changes from {{label}} to workspace. Arena session complete.": "\u5DF2\u5C06 {{label}} \u7684\u66F4\u6539\u5E94\u7528\u5230\u5DE5\u4F5C\u533A\u3002Arena \u4F1A\u8BDD\u5B8C\u6210\u3002",
  "Discard all Arena results and clean up worktrees?": "\u4E22\u5F03\u6240\u6709 Arena \u7ED3\u679C\u5E76\u6E05\u7406\u5DE5\u4F5C\u6811\uFF1F",
  "Arena results discarded. All worktrees cleaned up.": "Arena \u7ED3\u679C\u5DF2\u4E22\u5F03\u3002\u6240\u6709\u5DE5\u4F5C\u6811\u5DF2\u6E05\u7406\u3002",
  "Arena is not supported in non-interactive mode. Use interactive mode to start an Arena session.": "Arena \u4E0D\u652F\u6301\u975E\u4EA4\u4E92\u6A21\u5F0F\u3002\u8BF7\u4F7F\u7528\u4EA4\u4E92\u6A21\u5F0F\u542F\u52A8 Arena \u4F1A\u8BDD\u3002",
  "Arena is not supported in non-interactive mode. Use interactive mode to stop an Arena session.": "Arena \u4E0D\u652F\u6301\u975E\u4EA4\u4E92\u6A21\u5F0F\u3002\u8BF7\u4F7F\u7528\u4EA4\u4E92\u6A21\u5F0F\u505C\u6B62 Arena \u4F1A\u8BDD\u3002",
  "Arena is not supported in non-interactive mode.": "Arena \u4E0D\u652F\u6301\u975E\u4EA4\u4E92\u6A21\u5F0F\u3002",
  "An Arena session exists. Use /arena stop or /arena select to end it before starting a new one.": "\u5DF2\u5B58\u5728 Arena \u4F1A\u8BDD\u3002\u8BF7\u4F7F\u7528 /arena stop \u6216 /arena select \u7ED3\u675F\u540E\u518D\u542F\u52A8\u65B0\u4F1A\u8BDD\u3002",
  "Usage: /arena start --models model1,model2 <task>": "\u7528\u6CD5\uFF1A/arena start --models model1,model2 <task>",
  "Models to compete (required, at least 2)": "\u53C2\u4E0E\u7ADE\u4E89\u7684\u6A21\u578B\uFF08\u5FC5\u987B\uFF0C\u81F3\u5C11 2 \u4E2A\uFF09",
  "Format: authType:modelId or just modelId": "\u683C\u5F0F\uFF1AauthType:modelId \u6216\u4EC5 modelId",
  "Arena requires at least 2 models. Use --models model1,model2 to specify.": "Arena \u81F3\u5C11\u9700\u8981 2 \u4E2A\u6A21\u578B\u3002\u8BF7\u4F7F\u7528 --models model1,model2 \u6307\u5B9A\u3002",
  'Arena started with {{count}} agents on task: "{{task}}"\nModels:\n{{modelList}}': 'Arena \u5DF2\u542F\u52A8 {{count}} \u4E2A\u667A\u80FD\u4F53\u5904\u7406\u4EFB\u52A1\uFF1A"{{task}}"\n\u6A21\u578B\uFF1A\n{{modelList}}',
  "Arena panes are running in tmux. Attach with: `{{command}}`": "Arena \u9762\u677F\u6B63\u5728 tmux \u4E2D\u8FD0\u884C\u3002\u4F7F\u7528\u4EE5\u4E0B\u547D\u4EE4\u9644\u52A0\uFF1A`{{command}}`",
  "[{{label}}] failed: {{error}}": "[{{label}}] \u5931\u8D25\uFF1A{{error}}",
  "Loading suggestions...": "\u6B63\u5728\u52A0\u8F7D\u5EFA\u8BAE...",
  "Open the memory manager.": "\u6253\u5F00\u8BB0\u5FC6\u7BA1\u7406\u5668\u3002",
  "Show current process memory diagnostics": "\u663E\u793A\u5F53\u524D\u8FDB\u7A0B\u7684\u5185\u5B58\u8BCA\u65AD\u3002",
  "Record a CPU profile for Chrome DevTools analysis": "\u5F55\u5236 CPU \u6027\u80FD\u5206\u6790\u6587\u4EF6\uFF0C\u7528\u4E8E Chrome DevTools \u5206\u6790",
  "Roll back a standalone update to the previous version": "\u5C06\u72EC\u7ACB\u5B89\u88C5\u56DE\u6EDA\u5230\u4E0A\u4E00\u4E2A\u7248\u672C",
  "Rollback is not available in ACP mode.": "\u56DE\u6EDA\u5728 ACP \u6A21\u5F0F\u4E0B\u4E0D\u53EF\u7528\u3002",
  "Rollback is only available for standalone installations.": "\u56DE\u6EDA\u4EC5\u9002\u7528\u4E8E\u72EC\u7ACB\u5B89\u88C5\u3002",
  "Rollback successful. Restart your terminal to use the previous version.": "\u56DE\u6EDA\u6210\u529F\u3002\u8BF7\u91CD\u542F\u7EC8\u7AEF\u4EE5\u4F7F\u7528\u4E0A\u4E00\u4E2A\u7248\u672C\u3002",
  "Rollback failed:": "\u56DE\u6EDA\u5931\u8D25\uFF1A",
  "Rollback on Windows requires manual intervention. Rename qwen-code.old to qwen-code in your installation directory.": "\u5728 Windows \u4E0A\u56DE\u6EDA\u9700\u8981\u624B\u52A8\u64CD\u4F5C\u3002\u8BF7\u5C06\u5B89\u88C5\u76EE\u5F55\u4E2D\u7684 qwen-code.old \u91CD\u547D\u540D\u4E3A qwen-code\u3002",
  "Save a durable memory to the memory system.": "\u5C06\u4E00\u6761\u6301\u4E45\u8BB0\u5FC6\u4FDD\u5B58\u5230\u8BB0\u5FC6\u7CFB\u7EDF\u3002",
  "Show per-item context usage breakdown.": "\u663E\u793A\u6309\u9879\u76EE\u5212\u5206\u7684\u4E0A\u4E0B\u6587\u4F7F\u7528\u8BE6\u60C5\u3002",
  "Manage extension settings": "\u7BA1\u7406\u6269\u5C55\u8BBE\u7F6E",
  // === Core: added from PR #3328 ===
  "Background tasks": "\u540E\u53F0\u4EFB\u52A1",
  "No tasks currently running": "\u5F53\u524D\u6CA1\u6709\u6B63\u5728\u8FD0\u884C\u7684\u4EFB\u52A1",
  "No entry to show.": "\u6CA1\u6709\u53EF\u663E\u793A\u7684\u6761\u76EE\u3002",
  "needs approval": "\u5F85\u5BA1\u6279",
  "rejected \u2014 edit config to re-approve": "\u5DF2\u62D2\u7EDD \u2014 \u7F16\u8F91\u914D\u7F6E\u4EE5\u91CD\u65B0\u5BA1\u6279",
  "Background agent needs approval": "\u540E\u53F0 agent \u7B49\u5F85\u5BA1\u6279",
  "Approve or deny the request above": "\u8BF7\u6279\u51C6\u6216\u62D2\u7EDD\u4E0A\u65B9\u7684\u8BF7\u6C42",
  Running: "\u8FD0\u884C\u4E2D",
  Paused: "\u5DF2\u6682\u505C",
  Completed: "\u5DF2\u5B8C\u6210",
  Failed: "\u5931\u8D25",
  Stopped: "\u5DF2\u505C\u6B62",
  Shell: "Shell",
  Monitor: "\u76D1\u63A7",
  Command: "\u547D\u4EE4",
  Dream: "\u8BB0\u5FC6\u6574\u7406",
  "[dream] memory consolidation": "[\u8BB0\u5FC6\u6574\u7406] \u8BB0\u5FC6\u6574\u7406",
  "[dream] memory consolidation (reviewing {{count}} session)": "[\u8BB0\u5FC6\u6574\u7406] \u8BB0\u5FC6\u6574\u7406\uFF08\u6B63\u5728\u5BA1\u9605 {{count}} \u4E2A\u4F1A\u8BDD\uFF09",
  "[dream] memory consolidation (reviewing {{count}} sessions)": "[\u8BB0\u5FC6\u6574\u7406] \u8BB0\u5FC6\u6574\u7406\uFF08\u6B63\u5728\u5BA1\u9605 {{count}} \u4E2A\u4F1A\u8BDD\uFF09",
  "{{count}} session": "{{count}} \u4E2A\u4F1A\u8BDD",
  "{{count}} sessions": "{{count}} \u4E2A\u4F1A\u8BDD",
  "{{count}} topic": "{{count}} \u4E2A\u4E3B\u9898",
  "{{count}} topics": "{{count}} \u4E2A\u4E3B\u9898",
  "{{count}} tokens": "{{count}} tokens",
  "{{count}} tool call": "{{count}} \u4E2A\u5DE5\u5177\u8C03\u7528",
  "{{count}} tool calls": "{{count}} \u4E2A\u5DE5\u5177\u8C03\u7528",
  "{{count}} event": "{{count}} \u4E2A\u4E8B\u4EF6",
  "{{count}} events": "{{count}} \u4E2A\u4E8B\u4EF6",
  "{{count}} dropped": "\u4E22\u5F03 {{count}} \u884C",
  "pid {{pid}}": "pid {{pid}}",
  "exit {{exitCode}}": "\u9000\u51FA\u7801 {{exitCode}}",
  "Sessions reviewing": "\u6B63\u5728\u5BA1\u9605\u7684\u4F1A\u8BDD",
  Progress: "\u8FDB\u5EA6",
  "Resume blocked": "\u6062\u590D\u53D7\u963B",
  "Working dir": "\u5DE5\u4F5C\u76EE\u5F55",
  "Output file": "\u8F93\u51FA\u6587\u4EF6",
  "Topics touched ({{count}})": "\u89E6\u53CA\u7684\u4E3B\u9898\uFF08{{count}}\uFF09",
  "{{count}} more": "{{count}} \u4E2A",
  "Lock release warning": "\u9501\u91CA\u653E\u8B66\u544A",
  "Metadata write warning": "\u5143\u6570\u636E\u5199\u5165\u8B66\u544A",
  "Subsequent dreams may be skipped as locked until the next session's staleness sweep cleans the file.": "\u540E\u7EED\u8BB0\u5FC6\u6574\u7406\u53EF\u80FD\u4F1A\u56E0\u9501\u5B9A\u800C\u8DF3\u8FC7\uFF0C\u76F4\u5230\u4E0B\u4E00\u6B21\u4F1A\u8BDD\u8FC7\u671F\u6E05\u7406\u6E05\u9664\u6B64\u6587\u4EF6\u3002",
  "The scheduler gate did not see this dream's timestamp; the next dream cycle may re-fire sooner than usual.": "\u8C03\u5EA6\u95E8\u63A7\u672A\u770B\u5230\u672C\u6B21\u8BB0\u5FC6\u6574\u7406\u7684\u65F6\u95F4\u6233\uFF1B\u4E0B\u4E00\u8F6E\u8BB0\u5FC6\u6574\u7406\u53EF\u80FD\u4F1A\u6BD4\u5E73\u65F6\u66F4\u65E9\u91CD\u65B0\u89E6\u53D1\u3002",
  // ============================================================================
  // Stats
  // ============================================================================
  // statsCommand non-interactive output
  "Session duration: {{duration}}": "\u4F1A\u8BDD\u65F6\u957F\uFF1A{{duration}}",
  "Prompts: {{count}}": "\u63D0\u793A\u6B21\u6570\uFF1A{{count}}",
  "API requests: {{count}}": "API \u8BF7\u6C42\u6570\uFF1A{{count}}",
  "Tokens \u2014 prompt: {{prompt}}, output: {{output}}": "Tokens \u2014 \u8F93\u5165\uFF1A{{prompt}}\uFF0C\u8F93\u51FA\uFF1A{{output}}",
  "Tool calls: {{total}} ({{success}} ok, {{fail}} fail)": "\u5DE5\u5177\u8C03\u7528\uFF1A{{total}}\uFF08{{success}} \u6210\u529F\uFF0C{{fail}} \u5931\u8D25\uFF09",
  "Files: +{{added}} / -{{removed}} lines": "\u6587\u4EF6\uFF1A+{{added}} / -{{removed}} \u884C",
  prompt: "\u8F93\u5165",
  output: "\u8F93\u51FA",
  cached: "\u7F13\u5B58",
  "Estimated cost: ${{cost}}": "\u9884\u4F30\u8D39\u7528\uFF1A${{cost}}",
  "No model usage data yet.": "\u6682\u65E0\u6A21\u578B\u4F7F\u7528\u6570\u636E\u3002",
  "No tool usage data yet.": "\u6682\u65E0\u5DE5\u5177\u4F7F\u7528\u6570\u636E\u3002",
  // StatsDialog
  Models: "\u6A21\u578B",
  "All time": "\u6240\u6709\u65F6\u95F4",
  "Last 7 days": "\u6700\u8FD1 7 \u5929",
  "Last 30 days": "\u6700\u8FD1 30 \u5929",
  "N/A": "\u65E0",
  Sessions: "\u4F1A\u8BDD\u6570",
  days: "\u5929",
  Input: "\u8F93\u5165",
  "Tool calls": "\u5DE5\u5177\u8C03\u7528",
  "Code changes": "\u4EE3\u7801\u53D8\u66F4",
  Projects: "\u9879\u76EE\u7EDF\u8BA1",
  Name: "\u540D\u79F0",
  Duration: "\u65F6\u957F",
  "Activity Heatmap": "\u7528\u91CF\u70ED\u529B\u7EDF\u8BA1",
  "Loading stats...": "\u52A0\u8F7D\u7EDF\u8BA1\u6570\u636E...",
  "\u2191 tabs \xB7 r to cycle dates \xB7 esc to close": "\u2191 tab \u5207\u6362\u6807\u7B7E \xB7 r \u5207\u6362\u65F6\u95F4\u8303\u56F4 \xB7 esc \u5173\u95ED",
  Cost: "\u8D39\u7528",
  Less: "\u5C11",
  More: "\u591A",
  "(no data)": "\uFF08\u65E0\u6570\u636E\uFF09",
  d: "\u5929",
  h: "\u65F6",
  m: "\u5206",
  // Stats Dashboard — keyboard hints (not translated)
  "tab \xB7 esc": "tab \xB7 esc",
  "tab \xB7 r dates \xB7 \u2190\u2192 month \xB7 esc": "tab \xB7 r dates \xB7 \u2190\u2192 month \xB7 esc",
  "tab \xB7 r dates \xB7 esc": "tab \xB7 r dates \xB7 esc",
  // Stats Dashboard — missing labels
  "API Requests": "API \u8BF7\u6C42",
  "Tool Calls": "\u5DE5\u5177\u8C03\u7528",
  "Success rate": "\u6210\u529F\u7387",
  "Code Changes": "\u4EE3\u7801\u53D8\u66F4",
  Tool: "\u5DE5\u5177",
  reqs: "\u8BF7\u6C42",
  in: "\u8F93\u5165",
  out: "\u8F93\u51FA",
  // === History collapse/expand commands ===
  "Set history to collapse by default when resuming a session": "\u6062\u590D\u4F1A\u8BDD\u65F6\u9ED8\u8BA4\u6298\u53E0\u5386\u53F2\u8BB0\u5F55",
  "Set history to expand by default when resuming a session": "\u6062\u590D\u4F1A\u8BDD\u65F6\u9ED8\u8BA4\u5C55\u5F00\u5386\u53F2\u8BB0\u5F55",
  "Expand the currently collapsed history transcript": "\u5C55\u5F00\u5F53\u524D\u6298\u53E0\u7684\u5386\u53F2\u8BB0\u5F55",
  "Control history display preferences and visibility": "\u63A7\u5236\u5386\u53F2\u8BB0\u5F55\u663E\u793A\u504F\u597D\u548C\u53EF\u89C1\u6027",
  "History will be collapsed by default for future resumed sessions.": "\u672A\u6765\u6062\u590D\u7684\u4F1A\u8BDD\u5C06\u9ED8\u8BA4\u6298\u53E0\u5386\u53F2\u8BB0\u5F55\u3002",
  "History will be expanded by default for future resumed sessions.": "\u672A\u6765\u6062\u590D\u7684\u4F1A\u8BDD\u5C06\u9ED8\u8BA4\u5C55\u5F00\u5386\u53F2\u8BB0\u5F55\u3002",
  "History is already expanded in this session.": "\u5F53\u524D\u4F1A\u8BDD\u7684\u5386\u53F2\u8BB0\u5F55\u5DF2\u5C55\u5F00\u3002",
  "Usage: /history collapse-on-resume|expand-on-resume|expand-now": "\u7528\u6CD5\uFF1A/history collapse-on-resume|expand-on-resume|expand-now",
  "History collapsed: {{n}} messages hidden. Use /history expand-now to show.": "\u5386\u53F2\u8BB0\u5F55\u5DF2\u6298\u53E0\uFF1A{{n}} \u6761\u6D88\u606F\u5DF2\u9690\u85CF\u3002\u4F7F\u7528 /history expand-now \u5C55\u5F00\u3002",
  // === Same-as-English optimization ===
  " (not in model registry)": "\uFF08\u4E0D\u5728\u6A21\u578B\u6CE8\u518C\u8868\u4E2D\uFF09",
  "start server": "\u542F\u52A8\u670D\u52A1\u5668",
  "\u4E2D\u56FD (China)": "\u4E2D\u56FD",
  "\u4E2D\u56FD (China) - \u963F\u91CC\u4E91\u767E\u70BC": "\u4E2D\u56FD - \u963F\u91CC\u4E91\u767E\u70BC",
  "\u963F\u91CC\u4E91\u767E\u70BC (aliyun.com)": "\u963F\u91CC\u4E91\u767E\u70BC\uFF08aliyun.com\uFF09",
  "No compression needed.": "\u65E0\u9700\u538B\u7F29\u3002",
  // Update command
  "Check for Qwen Code updates and install if available": "\u68C0\u67E5 Qwen Code \u66F4\u65B0\u5E76\u5B89\u88C5\uFF08\u5982\u679C\u53EF\u7528\uFF09",
  "Qwen Code update available! {{current}} \u2192 {{latest}}": "Qwen Code \u6709\u53EF\u7528\u66F4\u65B0\uFF01{{current}} \u2192 {{latest}}",
  "A new version of Qwen Code is available! {{current}} \u2192 {{latest}}": "Qwen Code \u6709\u65B0\u7248\u672C\u53EF\u7528\uFF01{{current}} \u2192 {{latest}}",
  "Qwen Code {{version}} is up to date!": "Qwen Code {{version}} \u5DF2\u662F\u6700\u65B0\uFF01",
  "Failed to check for updates ({{reason}}). Please check your network or registry configuration.": "\u68C0\u67E5\u66F4\u65B0\u5931\u8D25\uFF08{{reason}}\uFF09\u3002\u8BF7\u68C0\u67E5\u7F51\u7EDC\u6216 registry \u914D\u7F6E\u3002",
  "Update check skipped ({{reason}}) \u2014 run /update to retry.": "\u5DF2\u8DF3\u8FC7\u66F4\u65B0\u68C0\u67E5\uFF08{{reason}}\uFF09\u2014 \u53EF\u8FD0\u884C /update \u91CD\u8BD5\u3002",
  "registry did not respond within {{seconds}}s": "registry \u5728 {{seconds}} \u79D2\u5185\u672A\u54CD\u5E94",
  "registry unreachable": "registry \u65E0\u6CD5\u8FDE\u63A5",
  "registry error": "registry \u9519\u8BEF",
  "Unable to check for updates: {{reason}}": "\u65E0\u6CD5\u68C0\u67E5\u66F4\u65B0\uFF1A{{reason}}",
  "Update successful! The new version will be used on your next run.": "\u66F4\u65B0\u6210\u529F\uFF01\u65B0\u7248\u672C\u5C06\u5728\u4E0B\u6B21\u8FD0\u884C\u65F6\u751F\u6548\u3002",
  "Update downloaded. It will be applied after you exit this session.": "\u66F4\u65B0\u5DF2\u4E0B\u8F7D\u3002\u5C06\u5728\u9000\u51FA\u5F53\u524D\u4F1A\u8BDD\u540E\u5E94\u7528\u3002",
  "Update failed: {{error}}": "\u66F4\u65B0\u5931\u8D25\uFF1A{{error}}",
  "Downloading update...": "\u6B63\u5728\u4E0B\u8F7D\u66F4\u65B0...",
  "Update successful! Please restart Qwen Code to use the new version. Switching model providers before restarting may not work correctly.": "\u66F4\u65B0\u6210\u529F\uFF01\u8BF7\u91CD\u542F Qwen Code \u4EE5\u4F7F\u7528\u65B0\u7248\u672C\u3002\u91CD\u542F\u524D\u5207\u6362\u6A21\u578B\u63D0\u4F9B\u5546\u53EF\u80FD\u65E0\u6CD5\u6B63\u5E38\u5DE5\u4F5C\u3002",
  "Automatic update failed. Please try updating manually.": "\u81EA\u52A8\u66F4\u65B0\u5931\u8D25\u3002\u8BF7\u5C1D\u8BD5\u624B\u52A8\u66F4\u65B0\u3002",
  "Automatic update failed: {{error}}. Re-run the installer to update manually.": "\u81EA\u52A8\u66F4\u65B0\u5931\u8D25\uFF1A{{error}}\u3002\u8BF7\u91CD\u65B0\u8FD0\u884C\u5B89\u88C5\u7A0B\u5E8F\u4EE5\u624B\u52A8\u66F4\u65B0\u3002",
  'Running from a local git clone. Please update with "git pull".': '\u6B63\u5728\u4ECE\u672C\u5730 Git \u514B\u9686\u8FD0\u884C\u3002\u8BF7\u4F7F\u7528 "git pull" \u66F4\u65B0\u3002',
  "Running via npx, update not applicable.": "\u6B63\u5728\u901A\u8FC7 npx \u8FD0\u884C\uFF0C\u66F4\u65B0\u4E0D\u9002\u7528\u3002",
  "Running via pnpx, update not applicable.": "\u6B63\u5728\u901A\u8FC7 pnpx \u8FD0\u884C\uFF0C\u66F4\u65B0\u4E0D\u9002\u7528\u3002",
  "Running via bunx, update not applicable.": "\u6B63\u5728\u901A\u8FC7 bunx \u8FD0\u884C\uFF0C\u66F4\u65B0\u4E0D\u9002\u7528\u3002",
  'Installed via Homebrew. Please update with "brew upgrade".': '\u901A\u8FC7 Homebrew \u5B89\u88C5\u3002\u8BF7\u4F7F\u7528 "brew upgrade" \u66F4\u65B0\u3002',
  "Locally installed. Please update via your project's package.json.": "\u672C\u5730\u5B89\u88C5\u3002\u8BF7\u901A\u8FC7\u9879\u76EE\u7684 package.json \u66F4\u65B0\u3002",
  "Update requires sudo. Please run:": "\u66F4\u65B0\u9700\u8981 sudo\u3002\u8BF7\u8FD0\u884C\uFF1A",
  "Standalone install detected. Attempting to automatically update now...": "\u68C0\u6D4B\u5230\u72EC\u7ACB\u5B89\u88C5\u3002\u6B63\u5728\u5C1D\u8BD5\u81EA\u52A8\u66F4\u65B0...",
  "Standalone install detected. Please rerun the standalone installer to update:": "\u68C0\u6D4B\u5230\u72EC\u7ACB\u5B89\u88C5\u3002\u8BF7\u91CD\u65B0\u8FD0\u884C\u72EC\u7ACB\u5B89\u88C5\u7A0B\u5E8F\u4EE5\u66F4\u65B0\uFF1A",
  "Run the following to update:": "\u8FD0\u884C\u4EE5\u4E0B\u547D\u4EE4\u8FDB\u884C\u66F4\u65B0\uFF1A",
  "Unable to auto-update this standalone installation. Please reinstall from:": "\u65E0\u6CD5\u81EA\u52A8\u66F4\u65B0\u6B64\u72EC\u7ACB\u5B89\u88C5\u3002\u8BF7\u4ECE\u4EE5\u4E0B\u5730\u5740\u91CD\u65B0\u5B89\u88C5\uFF1A",
  "Manual update required. Please reinstall Qwen Code.": "\u9700\u8981\u624B\u52A8\u66F4\u65B0\u3002\u8BF7\u91CD\u65B0\u5B89\u88C5 Qwen Code\u3002",
  "This session uses the custom sandbox image {{image}}. Update that image and restart Qwen Code.": "\u6B64\u4F1A\u8BDD\u4F7F\u7528\u81EA\u5B9A\u4E49\u6C99\u7BB1\u955C\u50CF {{image}}\u3002\u8BF7\u66F4\u65B0\u8BE5\u955C\u50CF\u5E76\u91CD\u542F Qwen Code\u3002",
  "Update Qwen Code on the host, then restart the sandbox.": "\u8BF7\u5728\u5BBF\u4E3B\u673A\u4E0A\u66F4\u65B0 Qwen Code\uFF0C\u7136\u540E\u91CD\u542F\u6C99\u7BB1\u3002",
  "The update will be installed after you exit this session.": "\u9000\u51FA\u5F53\u524D\u4F1A\u8BDD\u540E\u5C06\u81EA\u52A8\u5B89\u88C5\u66F4\u65B0\u3002",
  "Run /update to install the update on the host.": "\u8FD0\u884C /update \u5728\u5BBF\u4E3B\u673A\u4E0A\u5B89\u88C5\u66F4\u65B0\u3002",
  "Run /update to install the update.": "\u8FD0\u884C /update \u5B89\u88C5\u66F4\u65B0\u3002",
  "\u26A0\uFE0F History gap: earlier conversation was lost before this point (storage interruption) and could not be recovered.": "\u26A0\uFE0F \u5386\u53F2\u8BB0\u5F55\u7F3A\u53E3\uFF1A\u6B64\u5904\u4E4B\u524D\u7684\u4F1A\u8BDD\u8BB0\u5F55\u5DF2\u4E22\u5931\uFF08\u5B58\u50A8\u4E2D\u65AD\uFF09\uFF0C\u4E14\u65E0\u6CD5\u627E\u56DE\u3002",
  // ============================================================================
  // reload-plugins 命令
  // ============================================================================
  "{{count}} extension": "{{count}} \u4E2A\u6269\u5C55",
  "{{count}} extensions": "{{count}} \u4E2A\u6269\u5C55",
  "{{count}} command": "{{count}} \u4E2A\u547D\u4EE4",
  "{{count}} commands": "{{count}} \u4E2A\u547D\u4EE4",
  "{{count}} skill": "{{count}} \u4E2A\u6280\u80FD",
  "{{count}} skills": "{{count}} \u4E2A\u6280\u80FD",
  "{{count}} agent": "{{count}} \u4E2A\u4EE3\u7406",
  "{{count}} agents": "{{count}} \u4E2A\u4EE3\u7406",
  "{{count}} hook": "{{count}} \u4E2A\u94A9\u5B50",
  "{{count}} hooks": "{{count}} \u4E2A\u94A9\u5B50",
  "{{count}} extension MCP server": "{{count}} \u4E2A\u6269\u5C55 MCP \u670D\u52A1\u5668",
  "{{count}} extension MCP servers": "{{count}} \u4E2A\u6269\u5C55 MCP \u670D\u52A1\u5668",
  "{{count}} extension LSP server": "{{count}} \u4E2A\u6269\u5C55 LSP \u670D\u52A1\u5668",
  "{{count}} extension LSP servers": "{{count}} \u4E2A\u6269\u5C55 LSP \u670D\u52A1\u5668",
  "Reload extension changes from disk": "\u4ECE\u78C1\u76D8\u91CD\u65B0\u52A0\u8F7D\u6269\u5C55\u53D8\u66F4",
  "Reloaded extensions: {{summary}}": "\u5DF2\u91CD\u65B0\u52A0\u8F7D\u6269\u5C55\uFF1A{{summary}}",
  "Reload failed: {{message}}": "\u91CD\u65B0\u52A0\u8F7D\u5931\u8D25\uFF1A{{message}}",
  "Reload failed.": "\u91CD\u65B0\u52A0\u8F7D\u5931\u8D25\u3002",
  "Extensions changed on disk. Run /reload-plugins to apply updates.": "\u78C1\u76D8\u4E0A\u7684\u6269\u5C55\u5DF2\u53D8\u66F4\u3002\u8FD0\u884C /reload-plugins \u6765\u5E94\u7528\u66F4\u65B0\u3002",
  "Failed to refresh extension content: {{message}}. Run /reload-plugins to apply updates.": "\u6269\u5C55\u5185\u5BB9\u5237\u65B0\u5931\u8D25\uFF1A{{message}}\u3002\u8FD0\u884C /reload-plugins \u6765\u5E94\u7528\u66F4\u65B0\u3002",
  "Failed to refresh extension content. Run /reload-plugins to apply updates.": "\u6269\u5C55\u5185\u5BB9\u5237\u65B0\u5931\u8D25\u3002\u8FD0\u884C /reload-plugins \u6765\u5E94\u7528\u66F4\u65B0\u3002",
  "Extension reload did not complete. Run /reload-plugins to try again.": "\u6269\u5C55\u91CD\u65B0\u52A0\u8F7D\u672A\u5B8C\u6210\u3002\u8FD0\u884C /reload-plugins \u91CD\u8BD5\u3002",
  "Precondition check": "\u524D\u7F6E\u6761\u4EF6\u68C0\u67E5",
  "Precondition not met \u2014 this scheduled run was skipped.": "\u524D\u7F6E\u6761\u4EF6\u4E0D\u6EE1\u8DB3 \u2014\u2014 \u5DF2\u8DF3\u8FC7\u672C\u6B21\u5B9A\u65F6\u8FD0\u884C\u3002",
  "The precondition check was cancelled \u2014 this scheduled run was skipped.": "\u524D\u7F6E\u6761\u4EF6\u68C0\u67E5\u5DF2\u53D6\u6D88 \u2014\u2014 \u5DF2\u8DF3\u8FC7\u672C\u6B21\u5B9A\u65F6\u8FD0\u884C\u3002",
  "The precondition check was interrupted \u2014 this scheduled run was skipped.": "\u524D\u7F6E\u6761\u4EF6\u68C0\u67E5\u88AB\u4E2D\u65AD \u2014\u2014 \u5DF2\u8DF3\u8FC7\u672C\u6B21\u5B9A\u65F6\u8FD0\u884C\u3002",
  "The precondition check failed \u2014 this scheduled run was skipped.": "\u524D\u7F6E\u6761\u4EF6\u68C0\u67E5\u5931\u8D25 \u2014\u2014 \u5DF2\u8DF3\u8FC7\u672C\u6B21\u5B9A\u65F6\u8FD0\u884C\u3002",
  "Running this scheduled task in a new session: {{link}}": "\u6B63\u5728\u65B0\u4F1A\u8BDD\u4E2D\u8FD0\u884C\u8BE5\u5B9A\u65F6\u4EFB\u52A1\uFF1A{{link}}",
  "This scheduled run could not be started: {{error}}": "\u672C\u6B21\u5B9A\u65F6\u8FD0\u884C\u65E0\u6CD5\u542F\u52A8\uFF1A{{error}}",
  "Session recording stopped after a write failure. New messages for the affected session will not be saved. Check disk space and permissions, then start a new session to resume recording. See the debug log for details.": "\u4F1A\u8BDD\u5F55\u5236\u56E0\u5199\u5165\u5931\u8D25\u800C\u505C\u6B62\u3002\u53D7\u5F71\u54CD\u4F1A\u8BDD\u4E2D\u7684\u65B0\u6D88\u606F\u5C06\u4E0D\u4F1A\u88AB\u4FDD\u5B58\u3002\u8BF7\u68C0\u67E5\u78C1\u76D8\u7A7A\u95F4\u548C\u6743\u9650\uFF0C\u7136\u540E\u521B\u5EFA\u4E00\u4E2A\u65B0\u4F1A\u8BDD\u4EE5\u6062\u590D\u5F55\u5236\u3002\u8BE6\u60C5\u8BF7\u67E5\u770B\u8C03\u8BD5\u65E5\u5FD7\u3002",
  "Session recording stopped after a write failure. New messages for the affected session will not be saved. Check disk space and permissions, then run `/clear` to start a new recorded session. See the debug log for details.": "\u4F1A\u8BDD\u5F55\u5236\u56E0\u5199\u5165\u5931\u8D25\u800C\u505C\u6B62\u3002\u53D7\u5F71\u54CD\u4F1A\u8BDD\u4E2D\u7684\u65B0\u6D88\u606F\u5C06\u4E0D\u4F1A\u88AB\u4FDD\u5B58\u3002\u8BF7\u68C0\u67E5\u78C1\u76D8\u7A7A\u95F4\u548C\u6743\u9650\uFF0C\u7136\u540E\u8FD0\u884C `/clear` \u521B\u5EFA\u4E00\u4E2A\u65B0\u7684\u53EF\u5F55\u5236\u4F1A\u8BDD\u3002\u8BE6\u60C5\u8BF7\u67E5\u770B\u8C03\u8BD5\u65E5\u5FD7\u3002",
  "Maintain project auto-skills based on recent use.": "\u6839\u636E\u6700\u8FD1\u7684\u4F7F\u7528\u60C5\u51B5\u7EF4\u62A4\u9879\u76EE\u81EA\u52A8\u6280\u80FD\u3002",
  "Show project auto-skill lifecycle status.": "\u663E\u793A\u9879\u76EE\u81EA\u52A8\u6280\u80FD\u7684\u751F\u547D\u5468\u671F\u72B6\u6001\u3002",
  "Run project auto-skill lifecycle maintenance.": "\u8FD0\u884C\u9879\u76EE\u81EA\u52A8\u6280\u80FD\u7684\u751F\u547D\u5468\u671F\u7EF4\u62A4\u3002",
  "Restore an archived project auto-skill.": "\u6062\u590D\u5DF2\u5F52\u6863\u7684\u9879\u76EE\u81EA\u52A8\u6280\u80FD\u3002",
  "Auto-skill curator": "\u81EA\u52A8\u6280\u80FD\u7BA1\u7406\u5668",
  "Last run: {{time}}": "\u4E0A\u6B21\u8FD0\u884C\uFF1A{{time}}",
  "Active: {{count}}": "\u6D3B\u8DC3\uFF1A{{count}}",
  "Stale: {{count}}": "\u9648\u65E7\uFF1A{{count}}",
  "Archived: {{count}}": "\u5DF2\u5F52\u6863\uFF1A{{count}}",
  "Stale skills:": "\u9648\u65E7\u6280\u80FD\uFF1A",
  "Pinned skills:": "\u56FA\u5B9A\u6280\u80FD\uFF1A",
  "Archived skills:": "\u5DF2\u5F52\u6863\u6280\u80FD\uFF1A",
  "Dry run complete.": "\u8BD5\u8FD0\u884C\u5B8C\u6210\u3002",
  "Curator run complete.": "\u7EF4\u62A4\u8FD0\u884C\u5B8C\u6210\u3002",
  "Checked: {{count}}": "\u5DF2\u68C0\u67E5\uFF1A{{count}}",
  "First observed: {{count}}": "\u9996\u6B21\u53D1\u73B0\uFF1A{{count}}",
  "Marked stale: {{count}}": "\u5DF2\u6807\u8BB0\u4E3A\u9648\u65E7\uFF1A{{count}}",
  "Reactivated: {{count}}": "\u5DF2\u91CD\u65B0\u6FC0\u6D3B\uFF1A{{count}}",
  "Skipped archive collisions: {{count}}": "\u5DF2\u8DF3\u8FC7\u5F52\u6863\u51B2\u7A81\uFF1A{{count}}",
  "Archive candidates:": "\u5F85\u5F52\u6863\u6280\u80FD\uFF1A",
  "Skipped archive collisions:": "\u5DF2\u8DF3\u8FC7\u7684\u5F52\u6863\u51B2\u7A81\uFF1A",
  "Skipped rename errors: {{count}}": "\u5DF2\u8DF3\u8FC7\u91CD\u547D\u540D\u9519\u8BEF\uFF1A{{count}}",
  "Skipped rename errors:": "\u5DF2\u8DF3\u8FC7\u7684\u91CD\u547D\u540D\u9519\u8BEF\uFF1A",
  "{{verb}}: {{count}}": "{{verb}}\uFF1A{{count}}",
  "Would archive": "\u5C06\u5F52\u6863",
  Archived: "\u5DF2\u5F52\u6863",
  "Failed to read auto-skill curator status: {{message}}": "\u8BFB\u53D6\u81EA\u52A8\u6280\u80FD\u7BA1\u7406\u5668\u72B6\u6001\u5931\u8D25\uFF1A{{message}}",
  "Usage: /curator run [--dry-run]": "\u7528\u6CD5\uFF1A/curator run [--dry-run]",
  "Failed to run auto-skill curator: {{message}}": "\u8FD0\u884C\u81EA\u52A8\u6280\u80FD\u7BA1\u7406\u5668\u5931\u8D25\uFF1A{{message}}",
  "Usage: /curator restore <directory>": "\u7528\u6CD5\uFF1A/curator restore <directory>",
  "Restored auto-skill: {{name}}": "\u5DF2\u6062\u590D\u81EA\u52A8\u6280\u80FD\uFF1A{{name}}",
  "Failed to restore auto-skill: {{message}}": "\u6062\u590D\u81EA\u52A8\u6280\u80FD\u5931\u8D25\uFF1A{{message}}",
  "Exclude an auto-skill from automatic maintenance.": "\u5C06\u81EA\u52A8\u6280\u80FD\u6392\u9664\u5728\u81EA\u52A8\u7EF4\u62A4\u4E4B\u5916\u3002",
  "Return a pinned auto-skill to automatic maintenance.": "\u6062\u590D\u5BF9\u56FA\u5B9A\u81EA\u52A8\u6280\u80FD\u7684\u81EA\u52A8\u7EF4\u62A4\u3002",
  "Usage: /curator pin <directory>": "\u7528\u6CD5\uFF1A/curator pin <directory>",
  "Usage: /curator unpin <directory>": "\u7528\u6CD5\uFF1A/curator unpin <directory>",
  "Pinned auto-skill: {{name}}": "\u5DF2\u56FA\u5B9A\u81EA\u52A8\u6280\u80FD\uFF1A{{name}}",
  "Unpinned auto-skill: {{name}}": "\u5DF2\u53D6\u6D88\u56FA\u5B9A\u81EA\u52A8\u6280\u80FD\uFF1A{{name}}",
  "Failed to update auto-skill pin: {{message}}": "\u66F4\u65B0\u81EA\u52A8\u6280\u80FD\u56FA\u5B9A\u72B6\u6001\u5931\u8D25\uFF1A{{message}}",
  "Auto-skill curator changes are disabled in safe mode.": "\u5B89\u5168\u6A21\u5F0F\u4E0B\u7981\u6B62\u66F4\u6539\u81EA\u52A8\u6280\u80FD\u7BA1\u7406\u5668\u3002",
  "Auto-skill curator changes are only available in trusted workspaces. Trust this folder via `/trust` and try again.": "\u4EC5\u53D7\u4FE1\u4EFB\u7684\u5DE5\u4F5C\u533A\u53EF\u4EE5\u66F4\u6539\u81EA\u52A8\u6280\u80FD\u7BA1\u7406\u5668\u3002\u8BF7\u901A\u8FC7 `/trust` \u4FE1\u4EFB\u6B64\u6587\u4EF6\u5939\u540E\u91CD\u8BD5\u3002"
};
export {
  zh_default as default
};
/**
 * @license
 * Copyright 2025 Qwen
 * SPDX-License-Identifier: Apache-2.0
 */
